#!/bin/bash

# Copyright (c) 2005 Chris Reuter. all rights reserved.
#
# This software may be freely redistributed under the terms of the GNU
# public license.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

# This script creates source and binary kits from the current directory.
# The directory name must be of the form "qfp-<version-number>" where
# <version-number> is the actual number (e.g. "qfp-1.02").


# The project name
projbase=qfp

# Cd to the inst directory.
cd `dirname $0`
cd ..

rootname=`basename \`pwd\``

tmpdir=latest-kits

linux_vm="squeak-bin/squeak"
win32_vm="squeak-bin/Squeak.exe"

cd ..

srckit_files=`echo $rootname/src/* $rootname/unix/*.sh $rootname/docs/*.txt \
				$rootname/win32/* | \
				sed -e 's/[^ ]*~//g'`

#linux_files=`echo $rootname/image/game.image.bz2 \
#				$rootname/docs/{Manual.txt,gpl.txt,SqueakLicense.txt} \
#				$rootname/unix/{qfp.sh,install.sh}`

src_tar=$rootname-src.tar
bin_tar=$rootname-linux.tar
win_zip=$rootname-win32.zip

# Set to "echo" for HOT DEBUGGING ACTION
DEBUG=


function die {
	echo $1
	exit 1
}

function md {
	echo "Creating $1"
	$DEBUG mkdir $1 || die "Unable to create directory $0"
}


# Create the temp directory
md $tmpdir



# The source kit.  This doesn't need the temp. directory except as the 
# destination
echo "Making $src_tar"
$DEBUG tar cvf $tmpdir/$src_tar $srckit_files
echo "Compressing..."
$DEBUG bzip2 -9 $tmpdir/$src_tar



# Tne binary distribution for Linux:
echo "Making $bin_tar"

md $tmpdir/$rootname
md $tmpdir/$rootname/image
md $tmpdir/$rootname/docs
md $tmpdir/$rootname/unix

$DEBUG cp $rootname/image/game.image.bz2 $tmpdir/$rootname/image/game.image.bz2
$DEBUG cp $rootname/docs/{Manual.txt,Install.txt,gpl.txt,SqueakLicense.txt,Copyright.txt} \
					$tmpdir/$rootname/docs/
$DEBUG cp $rootname/unix/{qfp.sh,install.sh} $tmpdir/$rootname/unix/
$DEBUG cp $linux_vm $tmpdir/$rootname/unix/

$DEBUG cp $rootname/unix/play-now.sh $tmpdir/$rootname/
$DEBUG chmod a+x $tmpdir/$rootname/play-now.sh

cd $tmpdir
$DEBUG tar cvf $bin_tar $rootname/ || die "Quitting."
cd ..

echo "Compressing..."
$DEBIG bzip2 -9 $tmpdir/$bin_tar
$DEBUG rm -r $tmpdir/$rootname/docs $tmpdir/$rootname/image \
			$tmpdir/$rootname/unix \
			$tmpdir/$rootname/play-now.sh
$DEBUG rmdir $tmpdir/$rootname/


# The binary distribution for Win32
echo "Making $win_zip"
md $tmpdir/$rootname
$DEBUG cp -a $rootname/win32/* $tmpdir/$rootname
$DEBUG cp -a $win32_vm $tmpdir/$rootname/Executables/
$DEBUG cp -a $rootname/image/game.image.bz2 $tmpdir/$rootname/GameData/
$DEBUG bunzip2 $tmpdir/$rootname/GameData/*
$DEBUG cp -a \
	$rootname/docs/{Copyright.txt,gpl.txt,Manual.txt,Install.txt,SqueakLicense.txt} \
	$tmpdir/$rootname/Docs/
$DEBUG unix2dos $tmpdir/$rootname/Docs/*.txt

cd $tmpdir
$DEBUG zip -9r $win_zip $rootname/
cd ..


# Final cleanup.  We pick and choose here to protect against
# accidental runaway rm.
$DEBUG rm -rf \
	$tmpdir/$rootname/{Docs,Executables,GameData,SavedGames,QuestForPants.vbs}
$DEBUG rmdir $tmpdir/$rootname/

# And the archives should now all be in $tmpdir, to be dealt with as desired.




