'From Squeak3.4 of 1 March 2003 [latest update: #5170] on 25 September 2005 at 7:53:25 pm'!
"Change Set:		QuestForPants
Date:			25 March 2005
Author:			Chris Reuter

Quest For Pants: An (Extremely) Unauthorized Sequel to Nethack.

This code is released under the terms of the GNU General Public License
with some exceptions added.  See the file 'Copyright.txt' for details.

"!

Object subclass: #GmAbstractCreatureBrain
	instanceVariableNames: 'owner '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Brainzzzzz'!
Object subclass: #GmAction
	instanceVariableNames: 'doer recipient '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Actions'!
GmAction subclass: #GmAttack
	instanceVariableNames: 'toHitRoll damageRoll recipientNotification '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Actions'!

!GmAttack commentStamp: 'cr 5/25/2005 00:18' prior: 0!
This is the abstract base class for all attacks.

recipientNotification		--	GmNotification. The notification to send to the recipient.  This is an
							instance variable because it will change depending on the results of
							various stages of the attack.

!

Object subclass: #GmDeploymentSlot
	instanceVariableNames: 'name item type '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Inventory'!

!GmDeploymentSlot commentStamp: 'cr 3/6/2005 18:47' prior: 0!
This is a structure representing a place you can put a Thing.  (For example, "feet"
which can wear "boots").

Structure:
 name			String		-- Descriptive name of the slot.
 item			GmThing	-- The item itself or 'nil' if the slot is empty.
XXX fitTest			Symbol		-- The name of a method to send to a prospective item to
								determine if it is of the right type to fit here.

For example, a DeploymentSlot representing the left hand (for the purpose of wearing
a ring) would have the name 'left hand' and the fitTest #isPutOnAble.


Any further useful comments about the general approach of this implementation.!

Object subclass: #GmDeployments
	instanceVariableNames: 'slots '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Inventory'!

!GmDeployments commentStamp: 'cr 3/6/2005 14:13' prior: 0!
This object manages wielding, wearing and putting-on.  What can be done by an object is determined by
the object itself.  This means that the above actions have a unified interface.  The downside is that you
can't have object that can, for example. be wielded OR worn.  You can do at most ONE of the above with
an object.

!

Object subclass: #GmDiceRoll
	instanceVariableNames: 'numDice numSides '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Utilities'!

!GmDiceRoll commentStamp: 'cr 5/29/2005 19:18' prior: 0!
Instances of this class represent a roll of one or more dice with the specified number of
sides.  The method names are designed to mimic the D&D notation 'XdY' where X is the number
of dice and Y is the number of sides each die has.  Thus, 2d6 means two six-sided dice.

You can do simple rolls with the #d: method of Integer:

	2 d: 5

This is the equivalent of:

	NhDiceRoll roll: 2 d: 6

which is the equivalent of:

	(NhDiceRoll new: 2 d: 6) roll

In addition to rolling dice, you can also query a roll for various values.  The
most (only?) usefule one of these is the sortValue, which we use to estimate the
value of weapons and such:

	(NhDiceRoll new: 2 d: 6) sortValue



Structure:
 numDice		Integer 	-- The number of dice to throw.
 numSides		Integer	-- The number of sides of each die.  (Sides are 1 to numSides.)

!

Object subclass: #GmDungeonBuilder
	instanceVariableNames: 'dungeon initialState genManagers game progressBarBlock progressCount '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Dungeon Builders'!

!GmDungeonBuilder commentStamp: 'cr 2/26/2005 03:40' prior: 0!
This is responsible for creating the dungeon initially.

In theory, it should be all lazy and stuff, only creating levels when the player wanders into
them, but screw that--it's too much work.

The initial generation state defaults to an instance of GmDungeonBuilderState but you can set
your own using #initialState:.


=====

Notes: I really have no idea what to do here so I'm going to just hack something together
and see how that goes.  Elegance can come later.

Appendum: okay, I sort of see how this is supposed to work.  Basically, the GmDungeonBuilder
is a big object-as-function that constructs levels according to the whims of whatever 
GmDungeonBuilderState is being used.

Note that GmDungeonBuilderState instances get copied for each new level so the behaviour has
to be in the class.

Hmmm.  Should we embed the *State object in the map itself as a kind of signpost to the nature
of the map?  It would be handy in opening up what sort of descriptions we can use.


!

Object subclass: #GmDungeonBuilderState
	instanceVariableNames: 'level mapGeneratorClasses '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Dungeon Builders'!

!GmDungeonBuilderState commentStamp: 'cr 2/23/2005 16:05' prior: 0!
When a DungeonBuilder constructs a dungeon, it does so recursively so that we can have things
like branches and merges.  Information about the dungeon is passed to each recursive call and
is held in each instance.

Note: at some point in the future, this may be split into an abstract base class and one or more subclasses.
Since right now I don't know what goes were, I'm making this class concrete and suitable for generating a
simple dungeon.

Possible useful expressions for doIt or printIt.

Structure:
 instVar1		type -- comment about the purpose of instVar1
 instVar2		type -- comment about the purpose of instVar2

Any further useful comments about the general approach of this implementation.!

GmAbstractCreatureBrain subclass: #GmGenericBrain
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Brainzzzzz'!
Object subclass: #GmInventory
	instanceVariableNames: 'items owner '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Inventory'!
Object subclass: #GmManagedObjectInfo
	instanceVariableNames: 'itemClass numCreated '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Dungeon Contents'!

!GmManagedObjectInfo commentStamp: 'cr 3/5/2005 20:58' prior: 0!
Data structure for managing creature or Thing creation.

Instances are created from an array.  As fields get added, we'll need to increase the
fields.

NOT DONE!!!!!!  Note that I'm moving from creating one of these from an array to using it's class.

Structure:
	itemClass			The	 class of the creature.
	numCreated 		The number created so far.
	maxAllowed			The maximum number that can be created (nil == unlimited).

These are to be removed.  Use #canCreateIn: instead.
	toughness			(TO DO: a number/function??? to set the creature's starting exp. level.)
	minLevel			The lowest level at which one may be created.
	maxLevel			The highest level at which one may be created (nil == infinity).
	branchConstraint	Block applied to a map to determine if an object may be created here.
!

Object subclass: #GmMap
	instanceVariableNames: 'game items litRegions creatureCache changedPoints creationState '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Map'!

!GmMap commentStamp: 'cr 3/10/2005 02:54' prior: 0!
Instances represent an individual map level and contain the entire contents of the
level.

Notes:

	-#at:putCreature: updates the monster list.  It's currently the only way to add
	 creatures so this guarantees that the monster list contains every creature on the map
	 (and them some, but that's another issue).

	 Always use #at:putCreature: or if you're going to add another way to put monsters,
	 make sure it also updates the list.

	 Removing monsters isn't necessary--we just filter out the ones that no longer reference
	 this map.

!

Object subclass: #GmMapBuilder
	instanceVariableNames: 'map rooms initialExtent '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Map Builders'!
GmMapBuilder subclass: #GmBigRoomBuilder
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Map Builders'!

!GmBigRoomBuilder commentStamp: 'cr 1/3/2004 18:05' prior: 0!
This is a MapBuilder which creates a map consisting of one big room.
!

GmMapBuilder subclass: #GmCustomRoomBuilder
	instanceVariableNames: 'featurePoints replacementPoints bottomRightCorners templateArray '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Map Builders'!

!GmCustomRoomBuilder commentStamp: 'cr 5/15/2005 22:01' prior: 0!
This is the abstract base class for all map builders which create a map from a
supplied template.  Subclasses should override #mapLayout and have it return
the desired layout.

Structure:
	featurePoints	 	Dictionary -- Maps points (map coordinates) to the class of the
						GmFeature that should go there.
	replacementPoints	OrderedCollection -- Contains at each index a Collection of points
						that had that number (minus 1) placed there in the template.
	bottomRightCorners	Set -- Holds the coordinates of each $/ in the template that was found
						to be the bottom-right corner of a room.
	templateArray		Array2D -- Contains the characters of the template string at the
						expected coordinates.

Template format:

	Each template is an array of at most 11 items.  The first item is the template string, an
ASCII-art map of the level.  The remaining 10 (at most) items are either nil or classes of
GmObjects.  If a class is present at a particular index, all spots in the template containing
the ASCII digit representing that index minus 2 will be replaced with instances of that class.

	So, for example, if index 2 of the array contains GmUpStairway, all of the 0's on the template
will be replaced by instances of GmUpStairway.  If the class is not a GmFixture, the fixture is
first set to GmFloor.  This way, creatures and items may be set.

	In the template format, the only significant characters are:

		/, \		-- The corners of a room.  Walls are ignored.
		+		-- Doors.
		#		-- Tunnels.
		<,>		-- Stairs.

	All other characters are ignored.

	The template may be smaller than the map extent but must not be bigger.

Hints:

	Use a fixed-width font when looking at a template.

	Do not use tabs in the template.  Beware of editors (e.g. XEmacs) that automatically
	replace spaces with tabs.

	Actually, XEmacs picture mode is pretty decent for editing maps.  However, be careful
	to disable tabs (via "(setq indent-tabs-mode nil)") first.

Future directions:

	I'm considering letting the array slots contain block contexts in addition to classes.  This
way, you can specify arbitrary code to generate what goes into a spot.



		





!

Object subclass: #GmMapEntry
	instanceVariableNames: 'feature creature pileOfStuff '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Map'!

!GmMapEntry commentStamp: '<historical>' prior: 0!
Data structure holding the contents of a map square.

Structure:
 monster		type -- The monster, if any, occupying this sector
 feature		type -- The kind of floor or wall we have here.
 pileOfStuff
!

Object subclass: #GmMessage
	instanceVariableNames: 'messageString '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!

!GmMessage commentStamp: 'cr 2/17/2005 22:38' prior: 0!
This is the base class for all game messages.

GmMessages are the messages the system gives when game objects make a request
and what game object use to notify other game objects of things.  GmMessages must be
'readable' by both the system and by humans.  Thus, they also contain human-readable
content.  Right now, this is a string but it's possible to extend this to contain multimedia
content such as, e.g., an object which a graphical interface could interpret as meaning
"Draw a fireball here".


!

Object subclass: #GmNotesInComment
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game'!

!GmNotesInComment commentStamp: 'cr 9/15/2005 22:52' prior: 0!
This class exists solely so that I have a place to put these notes that'll go into the changeset.
The method #versionHistory contains the change log in a comment.

Some notes about my coding style:

	1) The method category 'junk' holds those methods that I deem ready to delete but want
	to keep around for reference.  DO NOT CALL THEM.  If you DO call one, move it into another
	category first.

	2) Ditto for classes.


=====

	Attack System Rewrite

The main point of this is to easily calculate the value of a weapon in a way that has
some chance of being relevant to game play.

So:

	Weapon classes return a list of tuples containing:
		{AttackClass. GmDiceRoll new: 4 d: 6}
	From this, calculate the value.

	Of course, this screws up combat.  Currently, Attacks look to the weapon to provide
	useful description strings.  Alternately, I could just be generic in the base class and
	create specific subclasses for attacks with interesting attacks.  So butting would be
	a subclass of GmBluntAttack that uses the word "butt" in its description.  Which would
	lend itself to specialization, which I want.

	I could give each creature a default weapon (e.g. claw, teeth, etc.) and make them
	not generated.  The relevant routine would then (almost) always return a weapon.
	The problem with this is that it introduces weapons that really aren't.

	Okay, let's look at this again top-down:

		creature does "self attacks" to get the list of attacks.

	So basically, dummy weapons aren't really needed.  Great!!

=====

	Attacks:
		-everything goes in the attack.
		-to-hit is a roll.  attack hits if roll <= c+various modifiers from player.

	Hmmm.  Looking at Nethack, it seems that only the to-hit is rolled.  If the attacker
	hits, there is always a constant amount of damage done.

	Appendum:

	Fine, the above is too complicated.  Instead,
		-damageRating is the upper limit in the to-hit roll.  If it beats armorClass, it's a hit.
		-damage is calculated by (1 max: damageRating // 2).
	(With some multipliers/diviser tweaking.)


======

To do:

	The endgame needs to be changed for two reasons: 1) it's boring and 2) the huge room takes
	too long to rescan each turn.

	Related to this, I want to generate monsters and items such that value is proportional to
	level.  The code is sort of in place for items but not for monsters, so I'm going to do it
	at the StuffManager level and then refactor the relevant stuff down once monsters also
	have danger ratings.

	Corpses.

	Improve the balance of the experience system.

	Add lots of weapons.

	Add polearm attack.  (I.e. the ability to attack something that's one square away).

	Add something to make the climb back up more interesting.

	Need to fix the bug where random points are occasionally revealed.  (I think what's happening is
	is that you take the stairs, displacing the occupant which is teleported away and adding the
	destination to the damage list.)

	I need to make it so that putting an object in a map calls a #map: method with the map
	as its arguments.  Most objects will do nothing but those classes that need it can get at
	the map in this way.  Right now, Portals are handled specially all over.  Blech!!
	(...okay, this is partially done.  #map: is called when adding but not removing.  FIX this!!)




!

GmMessage subclass: #GmNotification
	instanceVariableNames: 'sender '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!

!GmNotification commentStamp: 'cr 2/27/2005 02:13' prior: 0!
Subinstances of this class are used to inform a game entity that something has
happened to it.

Note: Notifications (currently) have a hostility level.  This is an integer and the
higher it is, the more hostile the message will be considered.  Negative hostility
is also allowed and is interpreted benignly.

To do: define names for the hostility levels.
!

GmNotification subclass: #GmAttackNotification
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!
GmAttackNotification subclass: #GmAttacked
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!
GmAttackNotification subclass: #GmAttackedUnsuccessfully
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!
GmNotification subclass: #GmDisplacedAtPortal
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!

!GmDisplacedAtPortal commentStamp: 'cr 2/27/2005 02:01' prior: 0!
You were standing on a stairway or magic portal and got knocked aside when someone
came through.  Deal with it.

(Actually, you can get this message just by standing near a stairway because the displacements
may ripple.  That is, someone gets bumped out and they bump into you.!

GmNotification subclass: #GmNewLevel
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!
Object subclass: #GmObjGenManager
	instanceVariableNames: 'game itemInfo '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Dungeon Contents'!

!GmObjGenManager commentStamp: 'cr 3/26/2005 13:25' prior: 0!
This is an abstract base class.

Subinstances manage things like where an object can be generated and how many
can exist in total.

Class and object attributes such as #maxAllowed and #isUnique are intended as
hints to the relevant GmObjManager, which can (but probably shouldn't) override
them.

!

GmObjGenManager subclass: #GmBestiary
	instanceVariableNames: 'creatureInfo '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Dungeon Contents'!

!GmBestiary commentStamp: 'cr 3/26/2005 13:26' prior: 0!
Subinstances(?) are used to manage how, where and when creatures are created in
the level.
!

Object subclass: #GmObjStat
	instanceVariableNames: 'value prevValue owner '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Stats'!

!GmObjStat commentStamp: 'cr 2/6/2005 16:06' prior: 0!
This is the base class for in-game stats.

Stats contain a name, a value and a pointer to the object holding them.  To create a new
kind of stat, you create a subclass and implement the relevant bits of the core protocol, then
add it to the relevant list in the game object so that it'll get added to new objects.

Reading a stat in the normal way causes the stat object to search the owner for things that
modify the stat and then take that into account.  For example, if the player is wearing an
amulet that adds three points to strength, the strength attribute object will take that bonus into
account.  (The actual implementation of such tests are left as an exercise to the user.)

Likewise, setting a stat in the normal way can trigger side effects.  For example, a "HitPoints"
class could mark the owner as dead if it ever goes below zero.

!

GmObjStat subclass: #GmBoolStat
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Stats'!
GmBoolStat subclass: #GmBurdened
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Stats'!
GmBoolStat subclass: #GmConfused
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Stats'!
GmObjStat subclass: #GmNumStat
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Stats'!
GmNumStat subclass: #GmArmorClass
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Stats'!
GmNumStat subclass: #GmBoringNumStat
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Stats'!
GmBoringNumStat subclass: #GmCharisma
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Stats'!
GmBoringNumStat subclass: #GmConstitution
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Stats'!
GmBoringNumStat subclass: #GmDexterity
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Stats'!
GmNumStat subclass: #GmDungeonLevel
	instanceVariableNames: 'lastLevel '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Stats'!

!GmDungeonLevel commentStamp: 'cr 3/24/2005 21:58' prior: 0!
This isn't really a stat and shouldn't be set to anything.  It's here so that the control panel
has no trouble displaying it.

Its descriptionString method describes the current dungeon level and its value is the numeric
value of the level.

It determines whether it's changed by comparing the map with the map from the last time
it checked.
!

GmNumStat subclass: #GmExperience
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Stats'!
GmNumStat subclass: #GmHitPoints
	instanceVariableNames: 'maxHitpoints delayHealCount '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Stats'!

!GmHitPoints commentStamp: 'cr 3/10/2005 00:19' prior: 0!
This holds the number of hitpoints and their maximum.

The number of hitpoints is a float that gets truncated when read.  This way, we can increment
it by small amounts and have it still grow.
!

GmBoringNumStat subclass: #GmIntelligence
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Stats'!
Object subclass: #GmObject
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Abstract'!

!GmObject commentStamp: 'cr 1/8/2004 21:04' prior: 0!
This is the base class for game objects.  From here, we have three radically different subclasses:

	-Creatures (i.e. things that move and possibly attack).
	-Features (Parts of the level)
	-Things (Stuff that you find)

The (only) thing that they have in common is that they are visible to the player and they know
their map.

(The above may change but for the moment, I'm keeping them conceptually different so as to not go polymorphism crazy.)

=====

Engine notes:

	Inter-object ineractions happen at a higher abstraction level than system message passing.  We use GmMessage and subclasses for this.

	GmMessage implements constraints.  E.g. i X shoots Y, the GmShootMessage checks that X has a gun, bullets, etc.

	The three classes of game objects are more different than the same.  The system should treat them differently.  In particular, walls are different from fountains--walls are part of the map while fountains are fixed objects.  Doors are just a wierd kind of wall.




!

GmObject subclass: #GmCreature
	instanceVariableNames: 'map coordinates stats brain viewRegion inventory slots '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Abstract'!
GmObject subclass: #GmFeature
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Abstract'!
GmFeature subclass: #GmDoor
	instanceVariableNames: 'isOpen '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Features'!
GmFeature subclass: #GmFloor
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Features'!
Object subclass: #GmObjectDescription
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Display'!
GmObjectDescription subclass: #GmAsciiObjectDescription
	instanceVariableNames: 'letter color name '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Display'!

!GmAsciiObjectDescription commentStamp: '<historical>' prior: 0!
Instances (or subinstances) are used to tell the front end what a particular game object
looks like.  The representation is (I hope) independent of the nature of the front end.

Instances determine their descriptions from the object they're describing:

	GmObjectDescription of: someObject

'someObject' knows nothing about its own graphical (or otherwise) representation.

Right this minute, it assumes a single ASCII character tile and a short textual description.

!

GmAsciiObjectDescription class
	instanceVariableNames: 'knownClasses '!
Object subclass: #GmPanelEntry
	instanceVariableNames: 'morph object message messageArgs '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Display'!

!GmPanelEntry commentStamp: 'cr 1/31/2005 11:46' prior: 0!
Connects an expression (message sent to object) with a Prefab text field.  Whenever it receives the message #update,
it performs the expression and sets the Prefab's text to the result.

This is intended to be used when updating the scoreboard panel.

!

GmAbstractCreatureBrain subclass: #GmPlayerBrain
	instanceVariableNames: 'game '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Brainzzzzz'!
GmFloor subclass: #GmPortal
	instanceVariableNames: 'map endPoint '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Features'!

!GmPortal commentStamp: 'cr 2/23/2005 05:13' prior: 0!
This is the base-class for things that take you from one map to another.

Structure:
 endPoint		GmPortal -- the portal in which the creature emerges.

It's considered a kind of floor because it's a floor with stuff on it.!

GmMessage subclass: #GmResponse
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!

!GmResponse commentStamp: 'cr 2/27/2005 01:49' prior: 0!
This is the abstract base class for messages an object receives in response to
something it attempted.  Subclasses must therefore be either a kind of GmSuccess
or GmFailure.

!

GmResponse subclass: #GmFailure
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!

!GmFailure commentStamp: 'cr 1/4/2004 15:28' prior: 0!
Instances of this class indicate failure.

!

GmFailure subclass: #GmAlreadyUsed
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!

!GmAlreadyUsed commentStamp: 'cr 3/9/2005 00:03' prior: 0!
Caller attempted to #deploy an object that had already been deployed.  (E.g. tried to wear a ring
on two fingers at once).!

GmFailure subclass: #GmCancelled
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!

!GmCancelled commentStamp: 'cr 4/6/2005 00:38' prior: 0!
An instance of this means that the user cancelled the operation.  That means that it doesn't really
count.

(Arguably, this shouldn't be considered a Failure since it really means "undo the attempt", but I'm not going
to start messing with three-state logic over this.)
!

GmFailure subclass: #GmDefaultFailure
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!

!GmDefaultFailure commentStamp: 'cr 9/23/2005 12:45' prior: 0!
This is a Failure whose #replaceWith: discards its message.  It is meant to be used as the default
that has an effect only if nothing else happens.

Example:

	resp := GmDefaultFailure desc: 'For some reason, you are unable to attack.'.
	self attacks do: [ :attack |
		(resp := resp replaceWith: (attack applyTo: target))
			ifKilledTarget: [
				self statExperience add: target computedExperienceValue.
				^resp.
			]
	].

	^resp

In the above example, "resp" returns the initial value only if "self attacks" returns an empty
collection.

Got it?

!

GmFailure subclass: #GmDontHave
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!
GmFailure subclass: #GmImpossible
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!

!GmImpossible commentStamp: 'cr 3/6/2005 14:39' prior: 0!
You have attempted something that is conceptually implausible.
!

GmFailure subclass: #GmKnapsackFull
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!
GmFailure subclass: #GmMissed
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!
GmFailure subclass: #GmMoveFailed
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!
GmMoveFailed subclass: #GmInaccessible
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!

!GmInaccessible commentStamp: 'cr 1/4/2004 15:38' prior: 0!
Instances of this class are used to indicate that the move attempt didn't work because the destination is blocked, typically by a fixture or the edge of the map.
!

GmFailure subclass: #GmNoInventory
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!
GmFailure subclass: #GmNoSlotsLeft
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!
GmMoveFailed subclass: #GmOccupied
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!

!GmOccupied commentStamp: 'cr 1/4/2004 15:39' prior: 0!
This class indicates that a move failed because the sector is occupied by another creature.
!

GmMapBuilder subclass: #GmRoguelikeMapBuilder
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Map Builders'!

!GmRoguelikeMapBuilder commentStamp: 'cr 2/24/2005 23:06' prior: 0!
This generates a Rogue-style dungeon level.

Cleverness alert: we use exceptions to bail out of certain infinite loops.

Structure:
 instVar1		type -- comment about the purpose of instVar1
 instVar2		type -- comment about the purpose of instVar2

Any further useful comments about the general approach of this implementation.!

GmFailure subclass: #GmSilentFailure
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!
Object subclass: #GmSortedBucketCollection
	instanceVariableNames: 'buckets '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Junk'!
GmPortal subclass: #GmStairway
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Features'!
GmStairway subclass: #GmDownStairway
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Features'!
GmBoringNumStat subclass: #GmStrength
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Stats'!
GmObjGenManager subclass: #GmStuffManager
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Dungeon Contents'!

!GmStuffManager commentStamp: 'cr 5/11/2005 11:46' prior: 0!
Instances manage the creation of GmThings in the dungeon.

To do: migrate #pickItemForMap:filtered:or: et. al. upward to the base class.

!

GmResponse subclass: #GmSuccess
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!

!GmSuccess commentStamp: 'cr 1/3/2004 10:21' prior: 0!
Instances of this class indicate success.
!

GmSuccess subclass: #GmHitTarget
	instanceVariableNames: 'target '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!
GmSuccess subclass: #GmItemDropped
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!
GmHitTarget subclass: #GmKilledTarget
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!
GmSuccess subclass: #GmNowWielding
	instanceVariableNames: 'item '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!
GmSuccess subclass: #GmSilentSuccess
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!

!GmSilentSuccess commentStamp: 'cr 10/4/2004 01:06' prior: 0!
This class represents success which are self-evident and so don't need to contain a human-friendly message.

(Actually, it should carry a message, but the UI shouldn't display it.)
!

GmSuccess subclass: #GmSuccessfullyStoredItem
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!
GmObject subclass: #GmThing
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Abstract'!

!GmThing commentStamp: 'cr 1/2/2004 20:00' prior: 0!
This is the base class for all Things.

Things are those game objects which are neither monsters nor level features.
!

GmThing subclass: #GmClothing
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmClothing subclass: #GmBoots
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmThing subclass: #GmGem
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Gems'!
GmClothing subclass: #GmGloves
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmClothing subclass: #GmHelmet
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmHelmet subclass: #GmAssHat
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!

!GmAssHat commentStamp: 'cr 5/11/2005 11:35' prior: 0!
This is the last-ditch piece of armour that gets generated if the usual algorithm fails, something that might occasionally happen under ordinary circumstances.
!

GmThing subclass: #GmJewelry
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Rings'!
GmClothing subclass: #GmPants
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmJewelry subclass: #GmRing
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Rings'!
GmRing subclass: #GmRingOfNothing
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Rings'!
GmClothing subclass: #GmSuit
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Abstract'!
GmSuit subclass: #GmDragonSuit
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmObjectDescription subclass: #GmTiledObjectDescription
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Display'!
GmCreature subclass: #GmToolUser
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmToolUser subclass: #GmHumanoid
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmFloor subclass: #GmTunnelFloor
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Features'!

!GmTunnelFloor commentStamp: 'cr 1/21/2004 01:04' prior: 0!
Just like GmFloor except with a different glyph.
!

Object subclass: #GmTunneller
	instanceVariableNames: 'map position direction hitDoor '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Map Builders'!

!GmTunneller commentStamp: 'cr 2/24/2005 23:34' prior: 0!
Instances of this class are used to dig a single tunnel for a GmRoguelikeMapBuilder.  The tunnel
starts inside a room and ends either when 1) another room is reached (or more specifically, a
second door is created) 2) enough tunnel has been dug or 3) we leave the map.

Structure:
 map			GmMap		-- The map to dig.
 position		Point		-- The current position, i.e. the last point dug.
 direction		Point		-- The value added to position to move to the next square.
 hitDoor			Boolean		-- If true, it means we've created one door already.

As a bit of cleverness, I pass around a block containing a return to use as a non-local return.
This may, in retrospect, be better done using an exception but I'm not going to bother with that
right now.

To do: when creating a door, first check if the adjacent wall section already has a door and if so,
tunnel through it instead.  This will eliminate those walls made of doors that sometimes happen.

!

GmNumStat subclass: #GmTurn
	instanceVariableNames: 'game '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Stats'!
GmAttack subclass: #GmUnarmedAttack
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Actions'!
Error subclass: #GmUnlikelyEvent
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Exceptions'!

!GmUnlikelyEvent commentStamp: 'cr 2/26/2005 00:57' prior: 0!
This is the base class for those exceptions that get thrown when something that is highly unlikely
and undesirable happens.  For example, if you attempt to teleport but there are no spots on the
level to which you can be moved, the relevant routine would throw this exception.

If the intervening call stack does not catch this, the bottom-level will and display an
appropriately pithy message to the user.  (Note: This isn't done yet.)

When using this, be careful not to leave things half done.  For example, if you've removed the player from
the map only to discover that there's no place to put him, you need to catch this exception so that you can
put him back or (preferably) don't change anything until you know it'll succeed.

!

GmUnlikelyEvent subclass: #GmAttemptsExceeded
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Exceptions'!

!GmAttemptsExceeded commentStamp: 'cr 2/24/2005 23:03' prior: 0!
This is an exception which gets thrown when multiple attempts at getting a random result
that fits certain constraints (e.g. a room which fits on the map around a particular point)
fail.

It is an error not to catch this exception if it occurs.

It is meant primarily as a way to exit some stage of level construction.

!

GmUnlikelyEvent subclass: #GmNoRoom
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Exceptions'!

!GmNoRoom commentStamp: 'cr 2/26/2005 00:59' prior: 0!
Exception that gets thrown when there is no room to put a thing on a map.

!

GmFeature subclass: #GmUnusedSpace
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Features'!

!GmUnusedSpace commentStamp: 'cr 1/16/2004 00:00' prior: 0!
This is the null fixture.  It represents a solid, untouched sector.

!

GmStairway subclass: #GmUpStairway
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Features'!
GmUpStairway subclass: #GmDungeonExit
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Features'!
Object subclass: #GmViewRegion
	instanceVariableNames: 'viewer viewRegion enteredRoom '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Vision'!

!GmViewRegion commentStamp: 'cr 3/2/2005 23:20' prior: 0!
The region of the map in which the view can see everything.

Possible useful expressions for doIt or printIt.

Structure:
 instVar1		type -- comment about the purpose of instVar1
 instVar2		type -- comment about the purpose of instVar2

Any further useful comments about the general approach of this implementation.!

Object subclass: #GmViewablePointSet
	instanceVariableNames: 'bigRect littleRect '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Vision'!

!GmViewablePointSet commentStamp: 'cr 5/13/2005 18:32' prior: 0!
Instances pretend to be rectangles for the benefit of GmViewRegion.

The problem is that when you stand in a door, there are actually TWO overlapping 
viewable rectangles.  Instances of this class hold those two rectangles while implementing
enough Rectangle behaviour to let it pass for one when used by GmViewRegion.

=====

Possible useful expressions for doIt or printIt.

Structure:
 instVar1		type -- comment about the purpose of instVar1
 instVar2		type -- comment about the purpose of instVar2

Any further useful comments about the general approach of this implementation.




=====


findEdge: direction
        | point map |
        point := viewer coordinates.
        map := viewer map.

        [(map featureAt: point) isLit] assert.

        [(map containsPoint: point) and: [(map featureAt: point) isLit]]
                whileTrue: [point := point + direction].

        ^point.
!

GmFeature subclass: #GmWall
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Features'!
GmWall subclass: #GmCornerWall
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Features'!
GmWall subclass: #GmEastWestWall
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Features'!
GmWall subclass: #GmNorthSouthWall
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Features'!
GmThing subclass: #GmWeapon
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Abstract'!
GmWeapon subclass: #GmBluntWeapon
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmBluntWeapon subclass: #GmAluminumBaseballBat
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmWeapon subclass: #GmEdgedWeapon
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmEdgedWeapon subclass: #GmAxe
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmEdgedWeapon subclass: #GmBattleSpork
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmEdgedWeapon subclass: #GmKnife
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmKnife subclass: #GmCrudeDagger
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmWeapon subclass: #GmPointyWeapon
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmBluntWeapon subclass: #GmRubberBaseballBat
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!

!GmRubberBaseballBat commentStamp: 'cr 9/18/2005 15:22' prior: 0!
This is a dummy weapon of sorts.  It's what gets picked when the weapon picker algorithm
fails.   This is intended sort of as an error message.  Instead of reporting an internal error
when the picker can't find a weapon, it just creates one of these.

Note that finding one of these may not mean a bug--it could just be an indicator of an unlikely
random selection.  Finding lots of these, however, indicates a bug.

!

GmBattleSpork subclass: #GmSilverBattleSpork
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmEdgedWeapon subclass: #GmSword
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmSword subclass: #GmBroadsword
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmSword subclass: #GmLongSword
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmSword subclass: #GmShortSword
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmAttack subclass: #GmWeaponAttack
	instanceVariableNames: 'weapon '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Actions'!

!GmWeaponAttack commentStamp: 'cr 9/15/2005 23:18' prior: 0!
This is the vanilla weapon attack.  More specialized attacks may be subclassed from here.
Does all the die rolling.
!

GmWeaponAttack subclass: #GmUndeadBonusAttack
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Actions'!

!GmUndeadBonusAttack commentStamp: 'cr 9/22/2005 11:38' prior: 0!
This is the attack that silver weapons do against undead creatures in addition to their normal
attacks.

!

GmBoringNumStat subclass: #GmWisdom
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Stats'!
GmNotification subclass: #GmYouAttack
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!
GmHitTarget subclass: #GmYouDoUndeadAttack
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!
GmYouDoUndeadAttack subclass: #GmSilverKilledUndeadTarget
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!
GmSuccess subclass: #GmYouSee
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!
GmMoveFailed subclass: #GmYouSeeNoNounHere
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game Messages'!

!GmYouSeeNoNounHere commentStamp: 'cr 2/26/2005 01:22' prior: 0!
Indicates that you tried to do something that affects your environment when there
is no such object nearby.  For example, trying to open a door when you are not near
a door.
!

PrefabManager subclass: #GmPrefabFullScreenManager
	instanceVariableNames: 'resizeNotification '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Display'!

!GmPrefabFullScreenManager commentStamp: 'cr 3/13/2005 22:16' prior: 0!
This is a manager which will fill the entire World and at the back.  It will resize 
itself to continue to fill the World via a #step method.

The purpose of this is to make the entire image look like an application window.

!

GmBluntWeapon subclass: #NhAklys
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmGem subclass: #NhAmber
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Gems'!
GmGem subclass: #NhAmethyst
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Gems'!
GmGem subclass: #NhAquamarine
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Gems'!
GmKnife subclass: #NhAthame
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmSuit subclass: #NhBandedMail
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmAxe subclass: #NhBattleAxe
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmBestiary subclass: #NhBestiary
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Dungeon Contents'!
GmDragonSuit subclass: #NhBlackDragonScaleMail
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmDragonSuit subclass: #NhBlackDragonScales
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmToolUser subclass: #NhBlackNagaHatchling
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmKnife subclass: #NhBlade
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmDragonSuit subclass: #NhBlueDragonScaleMail
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmDragonSuit subclass: #NhBlueDragonScales
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmSuit subclass: #NhBronzePlateMail
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmHumanoid subclass: #NhBugbear
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmSuit subclass: #NhChainMail
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmBluntWeapon subclass: #NhClub
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmHelmet subclass: #NhCommonHelmet
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmHelmet subclass: #NhCornuthaum
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmKnife subclass: #NhCrysknife
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmSuit subclass: #NhCrystalPlateMail
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmHelmet subclass: #NhDentedPot
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmGem subclass: #NhDiamond
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Gems'!
GmGem subclass: #NhDilithiumCrystal
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Gems'!
GmCreature subclass: #NhDragon
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhDragon subclass: #NhBabyBlackDragon
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhDragon subclass: #NhBabyBlueDragon
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhDragon subclass: #NhBabyGrayDragon
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhDragon subclass: #NhBabyGreenDragon
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhDragon subclass: #NhBabyOrangeDragon
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhDragon subclass: #NhBabyRedDragon
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhDragon subclass: #NhBabySilverDragon
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhDragon subclass: #NhBabyWhiteDragon
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhDragon subclass: #NhBabyYellowDragon
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmHelmet subclass: #NhDunceCap
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmDungeonBuilderState subclass: #NhDungeonBuilderState
	instanceVariableNames: 'branchNum branchName '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Dungeon Builders'!
GmHumanoid subclass: #NhDwarf
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmHumanoid subclass: #NhDwarfKing
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmHumanoid subclass: #NhDwarfLord
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmHelmet subclass: #NhDwarvishIronHelm
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmSuit subclass: #NhDwarvishMithrilCoat
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmShortSword subclass: #NhDwarvishShortSword
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmPointyWeapon subclass: #NhDwarvishSpear
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmHumanoid subclass: #NhElfin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhElfin subclass: #NhElf
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhElfin subclass: #NhElfLord
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmBroadsword subclass: #NhElvenBroadsword
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmKnife subclass: #NhElvenDagger
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmHelmet subclass: #NhElvenLeatherHelm
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmSuit subclass: #NhElvenMithrilCoat
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmShortSword subclass: #NhElvenShortSword
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmPointyWeapon subclass: #NhElvenSpear
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmGem subclass: #NhEmerald
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Gems'!
Smalltalk renameClassNamed: #GmEndgameLevelBuilder as: #NhEndgameLevelBuilder!
GmCustomRoomBuilder subclass: #NhEndgameLevelBuilder
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Map Builders'!

!NhEndgameLevelBuilder commentStamp: 'cr 5/15/2005 21:36' prior: 0!
This class builds the bottom-most (endgame) level.
!

GmHelmet subclass: #NhFedora
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmGem subclass: #NhFluorite
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Gems'!
GmCreature subclass: #NhFlyingThing
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhFlyingThing subclass: #NhBat
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhFlyingThing subclass: #NhCrow
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmCreature subclass: #NhFogCloud
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmToolUser subclass: #NhForestCentaur
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
Object subclass: #NhGame
	instanceVariableNames: 'dungeon view player turn creatureManager stuffManager mapThisTurn debugMode '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Game'!

!NhGame commentStamp: 'cr 3/11/2005 14:57' prior: 0!
The game object.  Each instance represents a game in play.

!

GmGem subclass: #NhGarnet
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Gems'!
NhFlyingThing subclass: #NhGiantBat
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmHumanoid subclass: #NhGnomoid
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhGnomoid subclass: #NhGnome
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhGnomoid subclass: #NhGnomeKing
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhGnomoid subclass: #NhGnomeLord
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmHumanoid subclass: #NhGoblinoid
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhGoblinoid subclass: #NhGoblin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmToolUser subclass: #NhGoldenNagaHatchling
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmCreature subclass: #NhGolem
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhGolem subclass: #NhGlassGolem
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmDragonSuit subclass: #NhGrayDragonScaleMail
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmDragonSuit subclass: #NhGrayDragonScales
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmDragonSuit subclass: #NhGreenDragonScaleMail
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmDragonSuit subclass: #NhGreenDragonScales
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
NhElfin subclass: #NhGreenElf
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhElfin subclass: #NhGreyElf
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmToolUser subclass: #NhGuardianNagaHatchling
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmBoots subclass: #NhHighBoots
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
NhGoblinoid subclass: #NhHillOrc
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmHumanoid subclass: #NhHobbit
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhGoblinoid subclass: #NhHobgoblin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmHumanoid subclass: #NhHuman
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmBoolStat subclass: #NhHungover
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Stats'!
GmCreature subclass: #NhImp
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmCreature subclass: #NhInsect
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhInsect subclass: #NhCaveSpider
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhInsect subclass: #NhGiantAnt
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhInsect subclass: #NhGiantBeetle
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhGolem subclass: #NhIronGolem
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmBoots subclass: #NhIronShoes
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmGem subclass: #NhJade
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Gems'!
GmGem subclass: #NhJasper
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Gems'!
GmPointyWeapon subclass: #NhJavelin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmLongSword subclass: #NhKatana
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmHumanoid subclass: #NhKoboldoid
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhKoboldoid subclass: #NhKobold
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhKoboldoid subclass: #NhKoboldLord
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmPointyWeapon subclass: #NhLance
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
NhKoboldoid subclass: #NhLargeKobold
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmSuit subclass: #NhLeatherArmor
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmGloves subclass: #NhLeatherGloves
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmSuit subclass: #NhLeatherJacket
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
NhImp subclass: #NhLemure
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmBoots subclass: #NhLowBoots
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmBluntWeapon subclass: #NhMace
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
NhImp subclass: #NhManes
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhDragon subclass: #NhMauveDragon
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmCreature subclass: #NhMinorDemon
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmHumanoid subclass: #NhMinotaur
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmCreature subclass: #NhMisc
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!

!NhMisc commentStamp: 'cr 3/11/2005 21:40' prior: 0!
This is a base class for stuff I don't know what to do with.  This class should eventually
be eliminated.
!

NhMisc subclass: #NhApe
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhMisc subclass: #NhCarnivorousApe
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhMisc subclass: #NhGargoyle
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhMisc subclass: #NhGhost
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhMisc subclass: #NhGlassPiercer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhMisc subclass: #NhIronPiercer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhGoblinoid subclass: #NhMordorOrc
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmBluntWeapon subclass: #NhMorningStar
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmToolUser subclass: #NhMountainCentaur
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmHumanoid subclass: #NhMummy
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhMummy subclass: #NhDwarfMummy
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhMummy subclass: #NhElfMummy
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhMummy subclass: #NhEttinMummy
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhMummy subclass: #NhGiantMummy
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhMummy subclass: #NhGnomeMummy
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhMummy subclass: #NhHumanMummy
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhMummy subclass: #NhKoboldMummy
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmHumanoid subclass: #NhOgroid
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhOgroid subclass: #NhOgre
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhOgroid subclass: #NhOgreKing
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhOgroid subclass: #NhOgreLord
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmGem subclass: #NhOpal
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Gems'!
GmDragonSuit subclass: #NhOrangeDragonScaleMail
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmDragonSuit subclass: #NhOrangeDragonScales
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
NhGoblinoid subclass: #NhOrc
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhGoblinoid subclass: #NhOrcCaptain
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhMummy subclass: #NhOrcMummy
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmSuit subclass: #NhOrcishChainMail
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmKnife subclass: #NhOrcishDagger
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmHelmet subclass: #NhOrcishHelm
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmSuit subclass: #NhOrcishRingMail
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmShortSword subclass: #NhOrcishShortSword
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmPointyWeapon subclass: #NhOrcishSpear
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmPants subclass: #NhPantsOfYendor
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
NhGolem subclass: #NhPaperGolem
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmToolUser subclass: #NhPlainsCentaur
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmSuit subclass: #NhPlateMail
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmCreature subclass: #NhQuadruped
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhQuadruped subclass: #NhCanid
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhCanid subclass: #NhCoyote
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhCanid subclass: #NhDingo
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhCanid subclass: #NhDog
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhQuadruped subclass: #NhFeline
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhCanid subclass: #NhFox
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhFeline subclass: #NhHousecat
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhCanid subclass: #NhJackal
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhFeline subclass: #NhJaguar
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhFeline subclass: #NhKitten
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhFeline subclass: #NhLargeCat
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhCanid subclass: #NhLargeDog
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhQuadruped subclass: #NhLargeQuadruped
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhLargeQuadruped subclass: #NhBaluchitherium
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhLargeQuadruped subclass: #NhHorse
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhLargeQuadruped subclass: #NhLeocrotta
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhCanid subclass: #NhLittleDog
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhLargeQuadruped subclass: #NhMastodon
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhLargeQuadruped subclass: #NhMumak
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhLargeQuadruped subclass: #NhPony
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmBluntWeapon subclass: #NhQuarterstaff
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
NhInsect subclass: #NhQueenBee
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhFlyingThing subclass: #NhRaven
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmDragonSuit subclass: #NhRedDragonScaleMail
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmDragonSuit subclass: #NhRedDragonScales
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmToolUser subclass: #NhRedNagaHatchling
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmSuit subclass: #NhRingMail
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmRing subclass: #NhRingOfCharisma
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Rings'!
GmRing subclass: #NhRingOfConstitution
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Rings'!
GmRing subclass: #NhRingOfDexterity
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Rings'!
GmRing subclass: #NhRingOfIntelligence
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Rings'!
GmRing subclass: #NhRingOfStrength
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Rings'!
GmRing subclass: #NhRingOfStudliness
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Rings'!
GmRing subclass: #NhRingOfWisdom
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Rings'!
NhMisc subclass: #NhRockPiercer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhQuadruped subclass: #NhRodent
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhRodent subclass: #NhDevilBunny
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhRodent subclass: #NhGiantRat
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhRodent subclass: #NhRockMole
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhGolem subclass: #NhRopeGolem
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhLargeQuadruped subclass: #NhRothe
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmGem subclass: #NhRuby
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Gems'!
GmBroadsword subclass: #NhRunesword
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmShortSword subclass: #NhSaber
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmGem subclass: #NhSapphire
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Gems'!
NhMisc subclass: #NhSasquatch
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmSuit subclass: #NhScaleMail
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmKnife subclass: #NhScalpel
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmShortSword subclass: #NhScimitar
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
NhRodent subclass: #NhSewerRat
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhMisc subclass: #NhShade
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmKnife subclass: #NhSilverDagger
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmDragonSuit subclass: #NhSilverDragonScaleMail
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmDragonSuit subclass: #NhSilverDragonScales
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmPointyWeapon subclass: #NhSilverSpear
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
NhInsect subclass: #NhSoldierAnt
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmPointyWeapon subclass: #NhSpear
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmSuit subclass: #NhSplintMail
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmKnife subclass: #NhStiletto
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
NhGolem subclass: #NhStoneGolem
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhGolem subclass: #NhStrawGolem
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmSuit subclass: #NhStuddedLeatherArmor
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmStuffManager subclass: #NhStuffManager
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Dungeon Contents'!
NhHuman subclass: #NhTailorOfYendor
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhImp subclass: #NhTengu
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhFeline subclass: #NhTiger
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhLargeQuadruped subclass: #NhTitanothere
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmGem subclass: #NhTopaz
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Gems'!
GmPointyWeapon subclass: #NhTrident
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
GmToolUser subclass: #NhTrolloid
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhTrolloid subclass: #NhOlogHai
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhTrolloid subclass: #NhTroll
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmGem subclass: #NhTurquoise
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Gems'!
NhGoblinoid subclass: #NhUrukHai
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmBluntWeapon subclass: #NhWarHammer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
NhCanid subclass: #NhWarg
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhLargeQuadruped subclass: #NhWarhorse
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmDragonSuit subclass: #NhWhiteDragonScaleMail
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmDragonSuit subclass: #NhWhiteDragonScales
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
NhMisc subclass: #NhWingedGargoyle
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhCanid subclass: #NhWolf
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhRodent subclass: #NhWoodchuck
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhElfin subclass: #NhWoodlandElf
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmKnife subclass: #NhWormTooth
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Weapons'!
NhLargeQuadruped subclass: #NhWumpus
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhMisc subclass: #NhXorn
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmDragonSuit subclass: #NhYellowDragonScaleMail
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
GmDragonSuit subclass: #NhYellowDragonScales
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Armour'!
NhMisc subclass: #NhYeti
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
GmHumanoid subclass: #NhZombie
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhZombie subclass: #NhDwarfZombie
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhZombie subclass: #NhElfZombie
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhZombie subclass: #NhEttinZombie
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhZombie subclass: #NhGhoul
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhZombie subclass: #NhGiantZombie
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhZombie subclass: #NhGnomeZombie
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhZombie subclass: #NhHumanZombie
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhZombie subclass: #NhKoboldZombie
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhZombie subclass: #NhOrcZombie
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhZombie subclass: #NhSkeleton
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
NhLargeQuadruped subclass: #NhZruty
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Objects-Creatures'!
Prefab subclass: #RoguelikeMapDisplay
	instanceVariableNames: 'view characters font highlightPoint '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Display'!
Object subclass: #SimpleGUI
	instanceVariableNames: 'game manager panel controlPanel messagePanel tileExtentCache keyTranslationTable statDict map seenLevels monsterPoints '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ObjHack-Display'!
SimpleGUI class
	instanceVariableNames: 'cachedMapPanel '!

!BlockContext methodsFor: '*ObjHack-evaluating' stamp: 'cr 3/6/2005 16:22'!
valueMaybeWith: arg
	self numArgs = 0
		ifTrue: [^self value]
		ifFalse: [^self value: arg].
! !


!Collection methodsFor: '*ObjHack-GUI' stamp: 'cr 3/5/2005 23:08'!
ifChoicePickOneOr: cancelBlock withCaption: caption
	self size = 1 ifTrue: [^self anyOne].
	^self pickOneOr: cancelBlock withCaption: caption.
		! !

!Collection methodsFor: '*ObjHack-GUI' stamp: 'cr 3/5/2005 18:57'!
pickOneOr: cancelBlock
	^self pickOneOr: cancelBlock withCaption: 'Pick an item:'.
! !

!Collection methodsFor: '*ObjHack-GUI' stamp: 'cr 4/3/2005 15:12'!
pickOneOr: cancelBlock withCaption: caption
	^self pickOneOr: cancelBlock withCaption: caption ifMatches: [ :i | false] addLabel: ''.

"
	| list labels index |
	self isEmpty ifTrue: [^cancelBlock value].

	list := self asOrderedCollection.
	labels := (list collect: [ :item | item descriptionString]), #('Cancel').
	
	index := (PopUpMenu labelArray: labels lines: {list size}) startUpWithCaption: caption.
	(list includesIndex: index)	""I may not be able to trust PopUpMenu""
		ifFalse: [^cancelBlock value]
		ifTrue: [^list at: index].
"! !

!Collection methodsFor: '*ObjHack-GUI' stamp: 'cr 4/3/2005 00:09'!
pickOneOr: cancelBlock withCaption: caption ifMatches: testBlock addLabel: labelAdded
	| list labels index |
	self isEmpty ifTrue: [^cancelBlock value].

	list := self asOrderedCollection.
	labels := list withIndexCollect: [ :item :ndx |
		ndx asString, ' ', (	(testBlock valueMaybeWith: item)
								ifTrue: [item descriptionString, labelAdded]
								ifFalse: [item descriptionString])
	].

	labels add: 'Cancel'.
	
	index := (PopUpMenu labelArray: labels lines: {list size}) startUpWithCaption: caption.
	(list includesIndex: index)	"I may not be able to trust PopUpMenu"
		ifFalse: [^cancelBlock value]
		ifTrue: [^list at: index].
! !

!Collection methodsFor: '*ObjHack-GUI' stamp: 'cr 3/5/2005 22:55'!
pickOneWithCaption: caption
	^self pickOneOr: [^nil] withCaption: caption! !

!Collection methodsFor: '*ObjHack-GUI' stamp: 'cr 3/6/2005 20:15'!
pickOneWithFirst: anElement appending: firstLabel withCaption: caption or: cancelBlock

	^self pickOneOr: cancelBlock withCaption: 'Pick an item:'.
! !

!Collection methodsFor: '*ObjHack-GUI' stamp: 'cr 4/3/2005 00:11'!
pickWeaponWhileHolding: wielded withCaption: caption or: cancelBlock
	"Let the user select a weapon to wield, assuming that wielded already contains weapons
	 being wielded and thus means the same as cancel.  Also adds a 'bare hands' option."
	| list labels index wieldedOrdered |

	"Blech!! This code needs to be cleaned up."

	(self isEmpty and: [wielded isEmpty]) ifTrue: [^cancelBlock value].

	wieldedOrdered := wielded asOrderedCollection.

	list := self asOrderedCollection copyWithoutAll: wielded.
	labels := (list withIndexCollect: [ :item :ndx | ndx asString, ' ', item descriptionString]),
				 #('Nothing' 'Cancel').
	list addAllFirst: wieldedOrdered.
	labels addAllFirst: (wieldedOrdered collect: [ :item | item descriptionString, ' (wielded)']).

	"this is so that we return nil for bare-handed."
	list add: nil.	

	index := (PopUpMenu labelArray: labels lines: {list size - 1. list size}) startUpWithCaption: caption.
	(list includesIndex: index)	"I may not be able to trust PopUpMenu"
		ifTrue: [^list at: index]
		ifFalse: [^cancelBlock value].
! !

!Collection methodsFor: '*ObjHack-printing' stamp: 'cr 3/8/2005 23:17'!
contentsString
	self size = 1 ifTrue: [^self anyOne asString].
	^self allButFirst inject: self first into: [ :result :item  | result, ', ', item asString]! !

!Collection methodsFor: '*ObjHack-printing' stamp: 'cr 3/6/2005 00:03'!
objDescriptionListString
	^(self collect: [ :obj | obj descriptionString]) contentsString! !

!Collection methodsFor: '*ObjHack-util' stamp: 'cr 9/22/2005 12:08'!
flatten
	| result |
	result := OrderedCollection new.
	self do: [ :elem |
		((elem isKindOf: Collection) and: [elem ~~ self])
			ifTrue: [result addAll: elem flatten]
			ifFalse: [result add: elem]
	].

	^self species withAll: result.
! !

!Collection methodsFor: '*ObjHack-util' stamp: 'cr 9/15/2005 23:04'!
ifEmpty: emptyBlock
	self isEmpty ifTrue: [^emptyBlock value].
! !

!Collection methodsFor: '*ObjHack-debugging' stamp: 'cr 4/2/2005 23:38'!
showHistogram
	GraphMorph new 
		data: (self asBag sortedElements collect: [ :assoc | assoc value]);
		openInWorld.
! !

!Collection methodsFor: '*ObjHack-Math' stamp: 'cr 4/25/2005 02:44'!
zeroPlusSum
	"This is just like sum except that on an empty Collection, it returns zero.  Thus, it's
	 self sum + 0 with the zero indicating a numeric result."
	^self isEmpty
		ifTrue: [0]
		ifFalse: [self sum].
! !


!GmAbstractCreatureBrain methodsFor: 'initialization' stamp: 'cr 3/3/2005 14:57'!
for: aCreature
	owner := aCreature.
! !

!GmAbstractCreatureBrain methodsFor: 'stimulus' stamp: 'cr 3/3/2005 15:04'!
notify: aNotification
	^self subclassResponsibility
! !

!GmAbstractCreatureBrain methodsFor: 'response' stamp: 'cr 3/3/2005 15:02'!
makeMove
	^self subclassResponsibility
! !

!GmAbstractCreatureBrain methodsFor: 'constants' stamp: 'cr 3/10/2005 23:27'!
directions
	^#('north' 'south' 'east' 'west' 'northEast' 'northWest' 'southEast' 'southWest')! !

!GmAbstractCreatureBrain methodsFor: 'tests' stamp: 'cr 3/10/2005 03:02'!
isPlayerBrain
	^false
! !


!GmAbstractCreatureBrain class methodsFor: 'instance creation' stamp: 'cr 3/3/2005 14:58'!
for: aCreature
	^self new for: aCreature.
! !


!GmAction methodsFor: 'core protocol' stamp: 'cr 3/9/2005 14:37'!
applyTo: rcpt
	^self applyTo: rcpt with: nil! !

!GmAction methodsFor: 'core protocol' stamp: 'cr 9/15/2005 23:09'!
applyTo: rcpt with: arg
	| actionResult |
	self recipient: rcpt.

	actionResult := self doAction.
"	self informRecipient."		"do from doAction"
	^actionResult.		
! !

!GmAction methodsFor: 'core protocol' stamp: 'cr 3/9/2005 14:38'!
doAction
	^self subclassResponsibility
! !

!GmAction methodsFor: 'core protocol' stamp: 'cr 3/9/2005 14:33'!
informRecipient
	recipient inform: self recipientNotification.
! !

!GmAction methodsFor: 'accessing' stamp: 'cr 3/9/2005 14:26'!
doer
	^doer! !

!GmAction methodsFor: 'accessing' stamp: 'cr 3/9/2005 14:26'!
doer: newValue
	doer := newValue! !

!GmAction methodsFor: 'accessing' stamp: 'cr 3/9/2005 14:26'!
recipient
	^recipient! !

!GmAction methodsFor: 'accessing' stamp: 'cr 3/9/2005 14:26'!
recipient: newValue
	recipient := newValue! !

!GmAction methodsFor: 'overrides' stamp: 'cr 3/9/2005 14:34'!
recipientNotification
	"This is what tells the recipient that it's being acted on."
	^self subclassResponsibility.
! !


!GmAction class methodsFor: 'instance creation' stamp: 'cr 3/9/2005 23:25'!
doer: theDoer
	^self new
		doer: theDoer;
		yourself.
! !


!GmAttack methodsFor: 'notifications' stamp: 'cr 9/22/2005 12:30'!
doerHitTargetResponse
	^GmHitTarget creature: recipient
! !

!GmAttack methodsFor: 'notifications' stamp: 'cr 9/22/2005 12:31'!
doerKilledTargetResponse
	^GmKilledTarget creature: recipient.
! !

!GmAttack methodsFor: 'notifications' stamp: 'cr 4/3/2005 00:18'!
rcptHitHarmlesslyNotification
	^GmAttackedUnsuccessfully theCreature: self doer does: 'hits, but the blow glances off.'! !

!GmAttack methodsFor: 'notifications' stamp: 'cr 4/2/2005 23:13'!
rcptHitNotification
	^GmAttacked theCreature: self doer does: self attacksMessage.
! !

!GmAttack methodsFor: 'notifications' stamp: 'cr 4/2/2005 13:49'!
rcptMissedNotification
	^GmAttackedUnsuccessfully theCreature: self doer does: 'swings at you but misses'.
! !

!GmAttack methodsFor: 'notifications' stamp: 'cr 4/2/2005 13:54'!
recipientNotification
	^recipientNotification
		ifNil: [
			"We shouldn't get here.  If we do, indicate failure but return a
			 stealth debug message."
			GmAttackedUnsuccessfully theCreature: doer does: 'glares at you.'
		].! !

!GmAttack methodsFor: 'notifications' stamp: 'cr 4/3/2005 23:13'!
setRcptNotificationForDamage: damage
	recipientNotification := 
		damage > 0
			ifTrue: [self rcptHitNotification]
			ifFalse: [self rcptHitHarmlesslyNotification].
! !

!GmAttack methodsFor: 'accessing' stamp: 'cr 6/1/2005 18:11'!
damageRoll: aRoll
	damageRoll := aRoll
! !

!GmAttack methodsFor: 'accessing' stamp: 'cr 6/1/2005 18:11'!
toHitRoll: aRoll
	toHitRoll := aRoll
! !

!GmAttack methodsFor: 'utility' stamp: 'cr 4/3/2005 22:38'!
attacksMessage
	^'hits you', (self weapon ifNil: ['.'] ifNotNil: [' with ', self weapon descriptionString]).
! !

!GmAttack methodsFor: 'utility' stamp: 'cr 4/2/2005 23:13'!
weapon
	^nil		"so that attacksMessage will work."! !

!GmAttack methodsFor: 'rolls' stamp: 'cr 9/20/2005 12:45'!
canHitTarget
	^self doerToHitValue > 20 atRandom! !

!GmAttack methodsFor: 'rolls' stamp: 'cr 9/16/2005 12:06'!
damageAmount
"	^doer atStatStrength d: self doerDamageRating * 3."
	self subclassResponsibility.
! !

!GmAttack methodsFor: 'rolls' stamp: 'cr 9/22/2005 12:11'!
doDamage
	| damage |
	damage := self damageAmount.

	recipient inform: self rcptHitNotification.

	(damage > 0 and: [recipient isAlive])
		ifTrue: [recipient statHitPoints subtract: damage].
! !

!GmAttack methodsFor: 'rolls' stamp: 'cr 9/25/2005 17:04'!
doerToHitValue
	^1
		+ doer computedHitBonus

		+ (2 * doer statExperience levelValue) // 3	"Nethack uses Luck here but I don't have that,
												 	 plus it's kind of superstitious.  So experience helps."

		"Give starting players a slight advantage so that they don't get wiped out quite as quickly
		 at the start."
		+ ((doer isPlayer and: [doer atStatExperience < 3]) ifTrue: [1] ifFalse: [0])

		"Attractive targets are a bit of a distraction."
		+ (recipient atStatCharisma > 15 ifTrue: [-1] ifFalse: [0])

		+ (recipient atStatArmorClass negated + 10).

		"Hmmm.  We should add other bonuses here as well.  I'm thinking in the weapon and creature
		 classes."
! !

!GmAttack methodsFor: 'core protocol' stamp: 'cr 9/22/2005 12:31'!
doAction

	self canHitTarget
		ifFalse: [
			recipient inform: self rcptMissedNotification.
			^GmMissed creature: recipient
		].

	self doDamage.

	recipient isDead
		ifTrue: [^self doerKilledTargetResponse]
		ifFalse: [^self doerHitTargetResponse].
! !

!GmAttack methodsFor: 'debug' stamp: 'cr 9/21/2005 13:09'!
averageDamage
	"Return the average damage this attack will do."
	^((1 to: 100000) collect: [ :x | self damageAmount asFloat max: 0]) average! !

!GmAttack methodsFor: 'debug' stamp: 'cr 4/3/2005 15:22'!
canHitFraction
	"Return the probability that canHitTarget will return true."
	^((1 to: 10000) collect: [ :x | self canHitTarget ifTrue: [1.0] ifFalse: [0]]) average! !

!GmAttack methodsFor: 'debug' stamp: 'cr 9/20/2005 13:17'!
xxxxxDEBUGcanHitTarget

	| dth roll |
	dth := self doerToHitValue.
	roll := 20 atRandom.

	Transcript 
		nextPutAll: doer descriptionString; space;
		nextPutAll: dth printString, ' > '; 
		nextPutAll: roll printString;
		cr;
		endEntry.
	^dth > roll

"	^self doerToHitValue > 20 atRandom"! !


!GmAttack class methodsFor: 'instance creation' stamp: 'cr 6/1/2005 18:14'!
toHit: thDice d: thSides damage: dDice d: dSides
	^self new
		toHitRoll: (GmDiceRoll new: thDice d: thSides);
		damageRoll: (GmDiceRoll new: dDice d: dSides);
		yourself.
! !


!GmDeploymentSlot methodsFor: 'accessing' stamp: 'cr 3/6/2005 19:04'!
clear
	self item: nil.
! !

!GmDeploymentSlot methodsFor: 'accessing' stamp: 'cr 3/6/2005 17:15'!
item
	^item! !

!GmDeploymentSlot methodsFor: 'accessing' stamp: 'cr 3/6/2005 17:15'!
item: newValue
	item := newValue! !

!GmDeploymentSlot methodsFor: 'accessing' stamp: 'cr 3/6/2005 17:15'!
name
	^name! !

!GmDeploymentSlot methodsFor: 'accessing' stamp: 'cr 3/6/2005 17:15'!
name: newValue
	name := newValue! !

!GmDeploymentSlot methodsFor: 'accessing' stamp: 'cr 3/6/2005 17:41'!
type
	^type! !

!GmDeploymentSlot methodsFor: 'accessing' stamp: 'cr 3/6/2005 18:43'!
type: newValue

	[GmDeployments knownSlotTypeNames includes: newValue] assert.

	type := newValue.
! !

!GmDeploymentSlot methodsFor: 'tests' stamp: 'cr 3/6/2005 17:25'!
isEmpty
	^item isNil
! !


!GmDeploymentSlot class methodsFor: 'instance creation' stamp: 'cr 3/6/2005 19:04'!
name: n type: t
	^self new
		name: n;
		type: t;
		yourself.
! !


!GmDeployments methodsFor: 'initialization' stamp: 'cr 3/6/2005 16:37'!
initialize
	slots := OrderedCollection new.
! !

!GmDeployments methodsFor: 'deployment' stamp: 'cr 3/8/2005 00:27'!
deploy: aThing or: errorBlock
	| slot |
	(self isDeploying: aThing) ifTrue: [^errorBlock value: GmAlreadyUsed new].

	slot := self emptySlotFor: aThing or: [ :rsp | ^errorBlock value: rsp].
	slot item: aThing.
	^GmSilentSuccess new.
			! !

!GmDeployments methodsFor: 'deployment' stamp: 'cr 3/6/2005 16:25'!
undeploy: aThing or: errorBlock
	| slot |
	slot := self slotHolding: aThing or: [ :rsp | ^errorBlock valueMaybeWith: rsp].
	slot item: nil.
	^GmSilentSuccess new.
! !

!GmDeployments methodsFor: 'queries' stamp: 'cr 3/12/2005 03:18'!
allInSlots
	^slots select: [ :sl | sl isEmpty not] thenCollect: [ :sl | sl item]! !

!GmDeployments methodsFor: 'queries' stamp: 'cr 3/7/2005 17:40'!
allInSlots: slotTypeNames
	^slots select: [ :sl | sl item notNil and: [slotTypeNames includes: sl type]] thenCollect: [ :sl | sl item]! !

!GmDeployments methodsFor: 'queries' stamp: 'cr 3/7/2005 23:31'!
allPutOn
	^self allInSlots: self class putOnSlotTypeNames! !

!GmDeployments methodsFor: 'queries' stamp: 'cr 3/7/2005 17:59'!
allWielded
	^self allInSlots: self class wieldSlotTypeNames! !

!GmDeployments methodsFor: 'queries' stamp: 'cr 3/7/2005 17:41'!
allWorn
	^self allInSlots: self class wearSlotTypeNames
! !

!GmDeployments methodsFor: 'queries' stamp: 'cr 3/8/2005 00:28'!
isDeploying: aThing
	slots do: [ :slot | slot item == aThing ifTrue: [^true]].
	^false

	! !

!GmDeployments methodsFor: 'queries' stamp: 'cr 3/8/2005 16:54'!
sumOf: aBlock
	^slots inject: 0 into: [ :sum :slot | slot item ifNil: [sum] ifNotNil: [sum + aBlock value: slot item]]
! !

!GmDeployments methodsFor: 'slots' stamp: 'cr 3/6/2005 16:38'!
addSlot: aDeploymentSlot
	slots add: aDeploymentSlot.
! !

!GmDeployments methodsFor: 'slots' stamp: 'cr 3/7/2005 14:32'!
emptySlotFor: aThing or: errorBlock
	| canSlot |
	canSlot := false.
	slots do: [ :slot | ((aThing fitsInSlot: slot) and: [canSlot := true. slot isEmpty]) ifTrue: [^slot]].
	^errorBlock valueMaybeWith: (canSlot ifTrue: [GmNoSlotsLeft] ifFalse: [GmImpossible]) new.
! !

!GmDeployments methodsFor: 'slots' stamp: 'cr 3/6/2005 19:50'!
slotHolding: aThing or: errorBlock
	slots do: [ :slot | slot item == aThing ifTrue: [^slot]].
	^errorBlock valueMaybeWith: (GmDontHave item: aThing).! !


!GmDeployments class methodsFor: 'instance creation' stamp: 'cr 3/6/2005 19:06'!
new
	^self basicNew initialize
! !

!GmDeployments class methodsFor: 'instance creation' stamp: 'cr 3/6/2005 19:40'!
newForHumanoid
	^self fromDescrArray: {

		"Wielding:"		
		{'weapon hand'. #wield}.

		"Wearing:"
		{'head'.			#head}.
		{'hands'.		#hands}.
		{'feet'.			#feet}.
		{'upper body'.	#upperBody}.
		{'lower body'.	#lowerBody}.

		"Putting on:"
		{'left hand'.		#finger}.
		{'right hand'.	#finger}.
		{'neck'.			#neck}
	}! !

!GmDeployments class methodsFor: 'constants' stamp: 'cr 3/6/2005 19:45'!
knownSlotTypeNames
	"The following is the list of slot type names that we're allowed to use."
	^self putOnSlotTypeNames, self wearSlotTypeNames, self wieldSlotTypeNames.! !

!GmDeployments class methodsFor: 'constants' stamp: 'cr 3/6/2005 19:44'!
putOnSlotTypeNames
	"The following is the list of slot type names that can be used to hold jewelry."
	^#(finger neck) ! !

!GmDeployments class methodsFor: 'constants' stamp: 'cr 3/6/2005 19:43'!
wearSlotTypeNames
	"The following is the list of slot type names that refer to clothing."
	^#(head hands feet upperBody lowerBody) ! !

!GmDeployments class methodsFor: 'constants' stamp: 'cr 3/6/2005 19:45'!
wieldSlotTypeNames
	"The following is the list of slot type names that refer to weapons."
	^#(wield)! !

!GmDeployments class methodsFor: 'private instance creation' stamp: 'cr 3/6/2005 19:03'!
fromDescrArray: descrArray
	| instance |
	instance := self new.
	descrArray
		do: [ :entry | instance addSlot: (GmDeploymentSlot name: entry first type: entry second)].
	^instance
! !


!GmDiceRoll methodsFor: 'accessing' stamp: 'cr 5/29/2005 19:16'!
numDice
	"Answer the value of numDice"

	^ numDice! !

!GmDiceRoll methodsFor: 'accessing' stamp: 'cr 5/29/2005 19:16'!
numDice: anObject
	"Set the value of numDice"

	numDice _ anObject! !

!GmDiceRoll methodsFor: 'accessing' stamp: 'cr 5/29/2005 19:16'!
numSides
	"Answer the value of numSides"

	^ numSides! !

!GmDiceRoll methodsFor: 'accessing' stamp: 'cr 5/29/2005 19:16'!
numSides: anObject
	"Set the value of numSides"

	numSides _ anObject! !

!GmDiceRoll methodsFor: 'rolling' stamp: 'cr 5/29/2005 19:16'!
roll
	^((1 to: numDice) collect: [ :x | (1 to: numSides) atRandom]) sum
! !

!GmDiceRoll methodsFor: 'math' stamp: 'cr 5/29/2005 19:16'!
maxValue
	^numDice * numSides
! !

!GmDiceRoll methodsFor: 'math' stamp: 'cr 5/29/2005 19:16'!
minValue
	^numDice! !

!GmDiceRoll methodsFor: 'math' stamp: 'cr 5/29/2005 19:16'!
sortValue

	"This is the value we use to rate the effectiveness of a roll.  Ideally, it should be some
	 kind of average value but I don't have my stats textbook handy right now, plus I'm lazy,
	 so this is an estimate."

	^numDice * ((numSides + 1) / 2) rounded.
! !


!GmDiceRoll class methodsFor: 'instance creation' stamp: 'cr 5/29/2005 19:16'!
new: dice d: sides
	^self new
		numDice: dice; 
		numSides: sides;
		yourself.
! !

!GmDiceRoll class methodsFor: 'rolling' stamp: 'cr 5/29/2005 19:16'!
roll: numDice d: numSides
	^(self new: numDice d: numSides) roll.
! !


!GmDungeonBuilder methodsFor: 'initialization' stamp: 'cr 3/10/2005 04:11'!
game: theGame initialState: newState genManagers: mgrs
	self initialize.

	game := theGame.
	initialState := newState.
	genManagers := mgrs.
! !

!GmDungeonBuilder methodsFor: 'initialization' stamp: 'cr 3/5/2005 22:17'!
initialize
	progressCount := 0.
	genManagers := #().! !

!GmDungeonBuilder methodsFor: 'accessing' stamp: 'cr 2/26/2005 00:42'!
dungeon
	^dungeon! !

!GmDungeonBuilder methodsFor: 'dungeon creation' stamp: 'cr 5/15/2005 23:29'!
attachMap: map to: portal
	portal 
		ifNil: [
			dungeon := map.
			^self.
		].

	map connectSomePortalTo: portal.
! !

!GmDungeonBuilder methodsFor: 'dungeon creation' stamp: 'cr 2/26/2005 03:33'!
buildDungeon

	'    Constructing levels...    '
		displayProgressAt: Display extent // 2
		from: 0 to: initialState totalMapsToBeGenerated
		during: [:bar | self buildDungeonUpdating: bar].


! !

!GmDungeonBuilder methodsFor: 'dungeon creation' stamp: 'cr 2/26/2005 03:32'!
buildDungeonUpdating: barBlock
	progressCount := 0.
	progressBarBlock := barBlock.

	self generateLevel: initialState fromPortal: nil.

	progressBarBlock := nil.
! !

!GmDungeonBuilder methodsFor: 'dungeon creation' stamp: 'cr 5/15/2005 23:30'!
generateLevel: state fromPortal: portal
	| map |
	self updateProgressBar.

	map := (state mapGenerator mapExtent: state defaultMapExtent)
				buildMap;
				map.

	map
		creationState: state;
		game: game.

	self attachMap: map to: portal.
	genManagers do: [ :mgr | mgr setupMap: map].
	state finalChangesTo: map.

	self generateNextLevelFrom: map accordingTo: state! !

!GmDungeonBuilder methodsFor: 'dungeon creation' stamp: 'cr 2/25/2005 00:00'!
generateNextLevelFrom: map accordingTo: state

	state outPortalsHere withIndexDo: [ :portal :index | 
		map addPortal: portal.
		self generateLevel: (state nextLevelOnBranch: index) fromPortal: portal.
	]
! !

!GmDungeonBuilder methodsFor: 'progress' stamp: 'cr 2/26/2005 03:28'!
updateProgressBar

	progressCount := progressCount + 1.
	progressBarBlock 
		ifNotNil: [progressBarBlock value: progressCount].
! !


!GmDungeonBuilder class methodsFor: 'instance creation' stamp: 'cr 3/10/2005 04:10'!
inGame: game withState: state genManagers: mgrs
	^ self new initialize;
		game: game initialState: state genManagers: mgrs;
		yourself.
! !


!GmDungeonBuilderState methodsFor: 'initialization' stamp: 'cr 2/23/2005 16:11'!
initialize
	level := 1.
	mapGeneratorClasses := GmMapBuilder allSubclasses.
! !

!GmDungeonBuilderState methodsFor: 'copying' stamp: 'cr 2/24/2005 23:57'!
nextLevelOnBranch: branchNum

	"Insert cleverness here.  Specifically, we can use branchnum and index to figure whether
	 this is a sidebranch and if so how to deal with it.  For now, we ignore the branch number."

	^self copy
		level: level + 1;
		yourself.! !

!GmDungeonBuilderState methodsFor: 'level information' stamp: 'cr 3/12/2005 11:12'!
mapGenerator

"	should be: ^self subclassResponsibility."	
"	^mapGeneratorClasses atRandom"
	^level = 3
		ifTrue: [GmBigRoomBuilder]
		ifFalse: [GmRoguelikeMapBuilder]
! !

!GmDungeonBuilderState methodsFor: 'level information' stamp: 'cr 2/25/2005 00:20'!
outPortalsHere
	"Return the portal objects leading out of here (to new levels)."
	| result |

	self isBottom ifTrue: [^#()].

	result := OrderedCollection with: GmDownStairway new.

	"There are branches at levels 2 and 4."
	(level = 2 or: [level = 4])
		ifTrue: [result add: GmDownStairway new].

	^result.! !

!GmDungeonBuilderState methodsFor: 'level information' stamp: 'cr 2/26/2005 02:58'!
totalMapsToBeGenerated

	"This needs to be calculated in advance, since it's used for showing a progress bar."
	
	^3 * self maxLevelsPerBranch.
! !

!GmDungeonBuilderState methodsFor: 'level customization' stamp: 'cr 3/12/2005 11:14'!
finalChangesTo: aMap
	"no-op.  Override if you want to add any final touches."
! !

!GmDungeonBuilderState methodsFor: 'map information' stamp: 'cr 3/3/2005 14:51'!
descriptionString
	^'Dungeon of Blah, level ', level printString
! !

!GmDungeonBuilderState methodsFor: 'testing' stamp: 'cr 2/26/2005 02:58'!
isBottom
	^level >= self maxLevelsPerBranch! !

!GmDungeonBuilderState methodsFor: 'testing' stamp: 'cr 3/12/2005 11:37'!
isTop
	^level = 1.
! !

!GmDungeonBuilderState methodsFor: 'accessing' stamp: 'cr 2/23/2005 15:58'!
level
	^level! !

!GmDungeonBuilderState methodsFor: 'accessing' stamp: 'cr 2/23/2005 15:58'!
level: newValue
	level := newValue! !

!GmDungeonBuilderState methodsFor: 'constants' stamp: 'cr 2/25/2005 00:57'!
defaultMapExtent
	^160@50
! !

!GmDungeonBuilderState methodsFor: 'constants' stamp: 'cr 2/26/2005 02:57'!
maxLevelsPerBranch
	^5! !


!GmDungeonBuilderState class methodsFor: 'instance creation' stamp: 'cr 2/23/2005 15:56'!
new
	^self basicNew initialize.
! !


!GmGenericBrain methodsFor: 'stimulus' stamp: 'cr 3/10/2005 02:41'!
notify: aNotification
	"no-op for now pending better creature AI."
! !

!GmGenericBrain methodsFor: 'attacking' stamp: 'cr 3/10/2005 16:17'!
canAttackPlayer
	| pc |
	pc := owner map playerCoordsOr: [^false].
	^self coordinates eightNeighbors includes: pc
! !

!GmGenericBrain methodsFor: 'response' stamp: 'cr 5/14/2005 19:19'!
getsDistracted
	^owner map creationState isFinalLevel
		ifTrue: [(1 d: 6) = 1]
		ifFalse: [(owner coordinates - (owner map playerCoordsOr: [^false])) r > (5 d: 3)].! !

!GmGenericBrain methodsFor: 'response' stamp: 'cr 3/10/2005 23:33'!
goInRandomDirection
	^owner perform: ('go', self possibleDirections atRandom capitalized) asSymbol.! !

!GmGenericBrain methodsFor: 'response' stamp: 'cr 3/10/2005 23:17'!
makeMove
	self tryToAttackPlayer and: [^self].
	self tryToMoveTowardPlayer and: [^self].
	self goInRandomDirection.
! !

!GmGenericBrain methodsFor: 'response' stamp: 'cr 9/21/2005 12:52'!
tryToAttackPlayer

	| map |
	map := owner map.
	(owner coordinates eightNeighbors includes: (map playerCoordsOr: [^false]))
		ifFalse: [^false].

	"I move instead of attacking in this direction because the attack will happen if there's something
	 there.  If there's a bug in the above code, though, at last SOMETHING happens so it doesn't look
	 as obviously buggy and I don't look as bad.  Genius!!"
	owner goInDirection: self directionOfPlayer.

	^true.! !

!GmGenericBrain methodsFor: 'response' stamp: 'cr 5/14/2005 19:08'!
tryToMoveTowardPlayer
	
	owner map containsPlayer ifFalse: [^false].
	(self walkableDirections includes: self directionOfPlayer) ifFalse: [^false].
	self getsDistracted ifTrue: [^false].

	owner goInDirection: self directionOfPlayer.
	^true.

! !

!GmGenericBrain methodsFor: 'response' stamp: 'cr 3/10/2005 23:24'!
walkableDirections
	^self directions select: [ :dir | owner map canPutCreature: owner at: (owner pointToThe: dir)]
! !

!GmGenericBrain methodsFor: 'player direction' stamp: 'cr 3/10/2005 22:21'!
directionOfPlayer
	^owner map directionFrom: owner coordinates to: owner map player coordinates! !

!GmGenericBrain methodsFor: 'player direction' stamp: 'cr 3/10/2005 23:33'!
possibleDirections 
	^self directions select: [ :dir | owner map terrainAt: (owner pointToThe: dir) fitFor: owner]
! !


!GmInventory methodsFor: 'initialization' stamp: 'cr 3/5/2005 16:31'!
initialize
	items := IdentitySet new.
! !

!GmInventory methodsFor: 'stuff management' stamp: 'cr 3/5/2005 16:27'!
insert: anObject
	^self insert: anObject or: [ :rsp | rsp].
! !

!GmInventory methodsFor: 'stuff management' stamp: 'cr 3/5/2005 16:26'!
insert: anObject or: errorBlock
	items size >= self maxItems
		ifTrue: [^errorBlock value: GmKnapsackFull new].

	items add: anObject.
	^GmSuccessfullyStoredItem item: anObject.
! !

!GmInventory methodsFor: 'stuff management' stamp: 'cr 3/5/2005 18:04'!
remove: aThing
	^self remove: aThing or: [ :rsp | ^rsp]
! !

!GmInventory methodsFor: 'stuff management' stamp: 'cr 3/5/2005 23:13'!
remove: aThing or: errBlock
	(items includes: aThing)
		ifFalse: [^GmDontHave item: aThing].

	items remove: aThing.
	^GmItemDropped item: aThing.
! !

!GmInventory methodsFor: 'contents' stamp: 'cr 3/7/2005 17:37'!
allClothing
	^self allContentsOrdered select: [ :th | th isWearable].
! !

!GmInventory methodsFor: 'contents' stamp: 'cr 3/5/2005 22:59'!
allContentsOrdered
	^items asArray.

	"To do: use a better ordering scheme than just what the conversion routine feels like doing."
! !

!GmInventory methodsFor: 'contents' stamp: 'cr 3/7/2005 23:41'!
allPutOnables
	^self allContentsOrdered select: [ :th | th isPutOnAble].
! !

!GmInventory methodsFor: 'contents' stamp: 'cr 3/6/2005 20:11'!
allWeapons
	^self allContentsOrdered select: [ :th | th isWieldable].
! !

!GmInventory methodsFor: 'contents' stamp: 'cr 4/25/2005 02:45'!
totalWeight
	^(items collect: [ :item | item weight]) zeroPlusSum
! !

!GmInventory methodsFor: 'constants' stamp: 'cr 3/5/2005 23:19'!
maxItems
	^52! !


!GmInventory class methodsFor: 'instance creation' stamp: 'cr 3/5/2005 16:32'!
new
	^self basicNew initialize
! !


!GmManagedObjectInfo methodsFor: 'initialization' stamp: 'cr 3/5/2005 21:02'!
initializeOn: ic
	itemClass := ic.
	numCreated := 0.
! !

!GmManagedObjectInfo methodsFor: 'accessing' stamp: 'cr 3/5/2005 20:15'!
itemClass
	^itemClass! !

!GmManagedObjectInfo methodsFor: 'accessing' stamp: 'cr 3/5/2005 21:03'!
maxAllowed
	^self itemClass maxAllowed! !

!GmManagedObjectInfo methodsFor: 'accessing' stamp: 'cr 2/13/2005 20:45'!
numCreated
	^numCreated! !

!GmManagedObjectInfo methodsFor: 'testing' stamp: 'cr 3/5/2005 21:04'!
canCreateIn: map
	^self countExhausted not and: [itemClass canCreateIn: map].
! !

!GmManagedObjectInfo methodsFor: 'testing' stamp: 'cr 2/13/2005 22:19'!
countExhausted
	^self maxAllowed notNil and: [self maxAllowed > self numCreated]
! !

!GmManagedObjectInfo methodsFor: 'item creation' stamp: 'cr 3/5/2005 22:33'!
create
	[itemClass maxAllowed isNil or: [numCreated < itemClass maxAllowed]] assert.

	numCreated := numCreated + 1.
	^itemClass new.
! !

!GmManagedObjectInfo methodsFor: 'item creation' stamp: 'cr 2/13/2005 23:01'!
uncreate
	"Call this when the creature was created but couldn't be placed in the game for some reason."
	numCreated := numCreated - 1.
		
! !

!GmManagedObjectInfo methodsFor: 'printing' stamp: 'cr 3/5/2005 22:26'!
printOn: aStream
	super printOn: aStream.
	aStream 	nextPut: $(;
				nextPutAll: itemClass printString;
				nextPut: $,;
				nextPutAll: numCreated printString;
				nextPut: $).
! !


!GmManagedObjectInfo class methodsFor: 'instance creation' stamp: 'cr 3/5/2005 21:02'!
for: objClass
	^self new 
		initializeOn: objClass;
		yourself.
! !


!GmMap methodsFor: 'initialization' stamp: 'cr 3/10/2005 04:08'!
game: theGame
	game := theGame
! !

!GmMap methodsFor: 'initialization' stamp: 'cr 5/13/2005 23:32'!
initializeToExtent: extent
	items := self itemsWithExtent: extent.
	litRegions := #().
	changedPoints := Set new.
	creatureCache := IdentitySet new.
! !

!GmMap methodsFor: 'initialization' stamp: 'cr 3/12/2005 13:24'!
itemsWithExtent: extent
	| initValue |
	initValue := (1 to: extent displacementRectArea)
		collect: [ :xxx | GmMapEntry new feature: GmUnusedSpace new; yourself].

	^Array2D new extent: extent fromArray: initValue.! !

!GmMap methodsFor: 'accessing' stamp: 'cr 2/25/2005 01:19'!
adjacentMaps
	| result |
	result := (self portals collect: [ :portal | portal endPointMap]) asIdentitySet.
	result remove: self ifAbsent: [].
	^result.

	! !

!GmMap methodsFor: 'accessing' stamp: 'cr 3/10/2005 03:00'!
allCreatures
	self purgeMissingCreatures.
	^creatureCache
! !

!GmMap methodsFor: 'accessing' stamp: 'cr 5/15/2005 23:48'!
at: point addThing: thing
	(self entryAt: point) addThing: thing.
	thing map: self.! !

!GmMap methodsFor: 'accessing' stamp: 'cr 5/15/2005 23:50'!
at: point putCreature: creature
	(self entryAt: point) creature: creature.
	creature setMap: self andCoords: point.
	creatureCache add: creature.		"Every method that adds creatures must do this!!"

	"This probably won't be necessary.  Basically, #map: is redundant in this case but
	 it's implemented by the root class so putting it in a map or removing it from one
	 should call it.  So there ya go."
	creature map: self.
! !

!GmMap methodsFor: 'accessing' stamp: 'cr 5/15/2005 23:50'!
at: point putFeature: feature
	(self entryAt: point) feature: feature.
	feature map: self.! !

!GmMap methodsFor: 'accessing' stamp: 'cr 3/5/2005 22:50'!
at: point putObject: aGmObject
	^self perform: ('at:put', aGmObject rootTypeName, ':') asSymbol withArguments: {point. aGmObject}.
! !

!GmMap methodsFor: 'accessing' stamp: 'cr 1/20/2004 01:40'!
bounds
	^1@1 extent: self extent - 1.! !

!GmMap methodsFor: 'accessing' stamp: 'cr 2/26/2005 01:38'!
coordinatesOf: aGmObject
	self entriesWithPointsDo: [ :entry :coord | (entry contains: aGmObject) ifTrue: [^coord]].
	self error: 'Object not in map.'! !

!GmMap methodsFor: 'accessing' stamp: 'cr 3/3/2005 14:51'!
creationState
	^creationState! !

!GmMap methodsFor: 'accessing' stamp: 'cr 3/3/2005 14:51'!
creationState: newValue
	creationState := newValue! !

!GmMap methodsFor: 'accessing' stamp: 'cr 1/3/2004 09:57'!
creatureAt: point
	^(self entryAt: point) creature.! !

!GmMap methodsFor: 'accessing' stamp: 'cr 3/9/2005 23:48'!
entryAt: point
	self changedAt: point.		"Yes, this is overkill.  Some entryAt: calls are for reading."
	^items at: point x at: point y.! !

!GmMap methodsFor: 'accessing' stamp: 'cr 1/3/2004 09:26'!
extent
	^items extent.
! !

!GmMap methodsFor: 'accessing' stamp: 'cr 1/3/2004 09:57'!
featureAt: point
	^(self entryAt: point) feature.! !

!GmMap methodsFor: 'accessing' stamp: 'cr 3/10/2005 04:08'!
game
	^game
! !

!GmMap methodsFor: 'accessing' stamp: 'cr 5/15/2005 12:43'!
litRegions
	^litRegions
! !

!GmMap methodsFor: 'accessing' stamp: 'cr 5/13/2005 23:23'!
litRegions: litRegionArray
	litRegions := litRegionArray
! !

!GmMap methodsFor: 'accessing' stamp: 'cr 2/25/2005 01:03'!
lowerLevels
	^self portals select: [ :portal | portal isDownStairway] thenCollect: [ :portal | portal endPointMap].! !

!GmMap methodsFor: 'accessing' stamp: 'cr 2/25/2005 00:49'!
portals
	^(self entriesSelect: [ :entry | entry feature isPortal]) collect: [ :entry | entry feature]! !

!GmMap methodsFor: 'accessing' stamp: 'cr 3/10/2005 03:04'!
shuffledNonPlayerCreatures
	^self allCreatures asOrderedCollection shuffled.! !

!GmMap methodsFor: 'accessing' stamp: 'cr 1/3/2004 09:58'!
thingsAt: point
	^(self entryAt: point) pileOfStuff.
! !

!GmMap methodsFor: 'accessing' stamp: 'cr 5/24/2005 19:06'!
topmostAt: point
	^(self entryAt: point) topmostObject! !

!GmMap methodsFor: 'accessing' stamp: 'cr 2/25/2005 01:03'!
upperLevels
	^self portals select: [ :portal | portal isUpStairway] thenCollect: [ :portal | portal endPointMap].! !

!GmMap methodsFor: 'removing' stamp: 'cr 3/18/2005 21:41'!
removeCreature: aCreature
	self removeCreatureAt: aCreature coordinates.
! !

!GmMap methodsFor: 'removing' stamp: 'cr 3/18/2005 21:43'!
removeCreatureAt: coords
	| entry |
	entry := self entryAt: coords.
	entry creature setMap: nil andCoords: nil.
	entry removeCreature.
! !

!GmMap methodsFor: 'random placement' stamp: 'cr 2/27/2005 01:42'!
placeCreature: aCreature
	| creatureCoord |
	creatureCoord := self randomCoordMatching: [ :pt | self canPutCreature: aCreature at: pt]
							onFailure: [GmNoRoom signal].
	self at: creatureCoord putCreature: aCreature.
! !

!GmMap methodsFor: 'random placement' stamp: 'cr 4/3/2005 16:56'!
placeThing: aThing or: errorBlock
	| point |
	point := self randomSpotFor: aThing or: [^errorBlock value].
	self at: point putObject: aThing.

! !

!GmMap methodsFor: 'portals' stamp: 'cr 5/15/2005 23:31'!
addEndpointFor: aPortal
	| endPoint |
	endPoint := aPortal endpointClass new.

	aPortal endPoint: endPoint.
	self addPortal: endPoint.! !

!GmMap methodsFor: 'portals' stamp: 'cr 2/25/2005 01:07'!
addPortal: aPortal
	| point |
	point := self randomCoordMatching: [ :pt | (self featureAt: pt) canReplaceWithPortal]
					onFailure: [self error: 'invalid level'].
	self at: point putFeature: aPortal.
	aPortal map: self.! !

!GmMap methodsFor: 'portals' stamp: 'cr 5/15/2005 23:30'!
connectSomePortalTo: aPortal
	"Guarantees that a portal in self will be the endpoint of 'aPortal'.  It tries, in order,
	 finding a portal connected to aPortal, finding a portal with no endpoint and connecting
	 that to 'aPortal' or creating a new portal and connecting that to 'aPortal'."
	| ap endPoint |
	ap := self allPortals.

	ap do: [ :ep | ep endPoint == aPortal ifTrue: [^ep]].

	endPoint := ap detect: [ :ep | ep canBeEndpointFor: aPortal] ifNone: [^self addEndpointFor: aPortal].
	endPoint endPoint: aPortal.

	^endPoint.! !

!GmMap methodsFor: 'display' stamp: 'cr 3/3/2005 03:00'!
asciiTileAt: point
	^(self entryAt: point) asciiTile.
! !

!GmMap methodsFor: 'display' stamp: 'cr 4/3/2005 19:56'!
nonCreatureAsciiTileAt: point
	^(self entryAt: point) nonCreatureAsciiTile
! !

!GmMap methodsFor: 'geometry' stamp: 'cr 1/3/2004 19:56'!
center
	^(self extent / 2) rounded max: 1@1.
! !

!GmMap methodsFor: 'geometry' stamp: 'cr 3/10/2005 16:52'!
directionFrom: src to: dest
	| bestDist bestDir diff |

	src = dest ifTrue: [^nil].

	bestDist := 99999.
	bestDir := nil.

	"Note to self: I think this could be cleaner if I use #inject:into: but right now I'm too tired."

	self directionNames do: [ :dir | 
		diff := ((src + (self perform: dir)) - dest).
		diff r < bestDist
			ifTrue: [
				bestDist := diff r.
				bestDir := dir.
			]
	].

	^bestDir
! !

!GmMap methodsFor: 'enumeration' stamp: 'cr 1/3/2004 18:46'!
doAndSetFeatures: block
	^self entriesDo: [ :entry | entry feature: (block value: entry feature)].
! !

!GmMap methodsFor: 'enumeration' stamp: 'cr 1/3/2004 18:45'!
entriesDo: block
	items do: block.
! !

!GmMap methodsFor: 'enumeration' stamp: 'cr 2/25/2005 00:48'!
entriesSelect: block
	| result |
	result := Set new.
	self entriesDo: [ :entry | (block value: entry) ifTrue: [result add: entry]].
	^result.
! !

!GmMap methodsFor: 'enumeration' stamp: 'cr 1/3/2004 19:30'!
entriesWithPointsDo: block
	(1 to: items width) do: [ :x |
		(1 to: items height) do: [ :y |
			block value: (items at: x at: y) value: x@y.
		].
	].
! !

!GmMap methodsFor: 'enumeration' stamp: 'cr 5/15/2005 18:55'!
selectFeatures: selectBlock
	| result feature |
	result := WriteStream on: (Array new: 20).
	self entriesWithPointsDo: [ :entry :point | 
		feature := self featureAt: point.
		(selectBlock value: feature) ifTrue: [result nextPut: feature]
	].

	^result contents.

! !

!GmMap methodsFor: 'enumeration' stamp: 'cr 2/25/2005 00:14'!
selectPoints: selectBlock

	| result |
	result := WriteStream on: (Array new: 20).
	self entriesWithPointsDo: [ :entry :point | (selectBlock value: point) ifTrue: [result nextPut: point]].

	^result contents.

! !

!GmMap methodsFor: 'queries' stamp: 'cr 5/15/2005 18:57'!
allPortals
	^self selectFeatures: [ :ft | ft isPortal]! !

!GmMap methodsFor: 'queries' stamp: 'cr 2/27/2005 01:42'!
canPutCreature: creature at: coords
	^(self terrainAt: coords fitFor: creature)
		and: [(self creatureAt: coords) isNil].! !

!GmMap methodsFor: 'queries' stamp: 'cr 3/11/2005 15:05'!
containsPlayer
	^self player map == self! !

!GmMap methodsFor: 'queries' stamp: 'cr 1/3/2004 22:27'!
containsPoint: aPoint
	^aPoint > (1@1) and: [aPoint <= self extent].! !

!GmMap methodsFor: 'queries' stamp: 'cr 3/5/2005 19:55'!
descriptionString
	^creationState descriptionString
! !

!GmMap methodsFor: 'queries' stamp: 'cr 3/5/2005 21:26'!
difficultyLevel
	^self creationState level
! !

!GmMap methodsFor: 'queries' stamp: 'cr 4/3/2005 19:37'!
hasCreatureAt: point
	^(self creatureAt: point) notNil! !

!GmMap methodsFor: 'queries' stamp: 'cr 5/13/2005 23:42'!
litAreaWithPoint: targetPt or: notFoundBlock
	^litRegions detect: [ :rect | rect plusWalls containsPoint: targetPt] ifNone: notFoundBlock.
! !

!GmMap methodsFor: 'queries' stamp: 'cr 3/10/2005 04:13'!
player
	^game player
! !

!GmMap methodsFor: 'queries' stamp: 'cr 3/11/2005 15:06'!
playerCoordsOr: notHereBlock
	self containsPlayer ifFalse: [^notHereBlock value].
	^self player coordinates.

		! !

!GmMap methodsFor: 'queries' stamp: 'cr 1/4/2004 15:22'!
positionOf: gameObject
	^self positionOf: gameObject ifAbsent: [self error: 'game object not found in map.'].! !

!GmMap methodsFor: 'queries' stamp: 'cr 1/4/2004 15:21'!
positionOf: gameObject ifAbsent: errorBlock
	self entriesWithPointsDo: [ :entry :point |
		(entry contains: gameObject)
			ifTrue: [^point]
	].

	^errorBlock value.

	! !

!GmMap methodsFor: 'queries' stamp: 'cr 3/2/2005 14:10'!
quickRandomCoordMatching: aBlock onFailure: errorBlock
	"Pick a bunch of spots and see if 'aBlock' returns true on one of them.  Return nil on failure."

	| point |
	self randomPlacementAttempts timesRepeat: [
		point := self bounds randomInternalPoint.
		(aBlock value: point) ifTrue: [^point].
	].

	^errorBlock value.


	
			! !

!GmMap methodsFor: 'queries' stamp: 'cr 2/25/2005 00:08'!
randomCoordMatching: checkBlock onFailure: failBlock

	| point pointList |

	(point := self quickRandomCoordMatching: checkBlock onFailure: [nil])
		ifNotNil: [^point].

	"Okay, now we do it the hard way."
	pointList := self selectPoints: checkBlock.

	pointList isEmpty
		ifTrue: [^failBlock value].

	^pointList atRandom.! !

!GmMap methodsFor: 'queries' stamp: 'cr 3/14/2005 19:55'!
randomSpotFor: aGmObject or: errorBlock

	[aGmObject isFeature not] assert.		"change this later."
	^self randomCoordMatching: [ :coord | self terrainAt: coord fitFor: aGmObject]
			onFailure: errorBlock.
! !

!GmMap methodsFor: 'queries' stamp: 'cr 2/25/2005 00:13'!
sectorsWithCreatures
	^self selectPoints: [ :pt | (self creatureAt: pt) notNil].! !

!GmMap methodsFor: 'queries' stamp: 'cr 3/5/2005 22:39'!
terrainAt: position fitFor: aCreatureOrThing

	(self containsPoint: position)
		ifFalse: [^false].

	^(self entryAt: position) terrainAllows: aCreatureOrThing.

! !

!GmMap methodsFor: 'changes' stamp: 'cr 3/4/2005 16:43'!
changedPoints
	^changedPoints
! !

!GmMap methodsFor: 'changes' stamp: 'cr 3/4/2005 16:43'!
clearChangedPoints
	changedPoints := Set new.
	! !

!GmMap methodsFor: 'changes' stamp: 'cr 1/8/2004 22:22'!
getAndClearChangedPoints
	| cp |
	cp := changedPoints.
	changedPoints := Set new.
	^cp.
! !

!GmMap methodsFor: 'creature movement' stamp: 'cr 3/5/2005 23:51'!
moveCreature: creature to: position
	| destination |

	[creature map = self] assert.

	(self terrainAt: position fitFor: creature)
		ifFalse: [^GmInaccessible desc: 'Ouch!!'].

	destination := self entryAt: position.
	destination hasCreature
		ifTrue: [^GmOccupied desc: 'There is already something there.'].

	(self entryAt: creature coordinates) removeCreature.
	self		changedAt: creature coordinates;
			changedAt: position.
	destination creature: creature.

	creature setMap: self andCoords: position.

	^GmYouSee recipient: creature.
! !

!GmMap methodsFor: 'creature movement' stamp: 'cr 1/8/2004 22:00'!
moveEast: aCreature
	^self moveCreature: aCreature to: aCreature coordinates + (1 @ 0).
! !

!GmMap methodsFor: 'creature movement' stamp: 'cr 1/8/2004 22:03'!
moveNorth: aCreature
	^self moveCreature: aCreature to: aCreature coordinates + (0 @ -1).
! !

!GmMap methodsFor: 'creature movement' stamp: 'cr 1/8/2004 22:03'!
moveNorthEast: aCreature
	^self moveCreature: aCreature to: aCreature coordinates + (1 @ -1).
! !

!GmMap methodsFor: 'creature movement' stamp: 'cr 1/8/2004 22:03'!
moveNorthWest: aCreature
	^self moveCreature: aCreature to: aCreature coordinates + (-1 @ -1).
! !

!GmMap methodsFor: 'creature movement' stamp: 'cr 1/8/2004 22:03'!
moveSouth: aCreature
	^self moveCreature: aCreature to: aCreature coordinates + (0 @ 1).
! !

!GmMap methodsFor: 'creature movement' stamp: 'cr 1/8/2004 22:03'!
moveSouthEast: aCreature
	^self moveCreature: aCreature to: aCreature coordinates + (1 @ 1).
! !

!GmMap methodsFor: 'creature movement' stamp: 'cr 1/8/2004 22:03'!
moveSouthWest: aCreature
	^self moveCreature: aCreature to: aCreature coordinates + (-1 @ 1).
! !

!GmMap methodsFor: 'creature movement' stamp: 'cr 1/8/2004 22:04'!
moveWest: aCreature
	^self moveCreature: aCreature to: aCreature coordinates + (-1 @ 0).
! !

!GmMap methodsFor: 'constants' stamp: 'cr 3/14/2005 20:07'!
randomPlacementAttempts
	^200
! !

!GmMap methodsFor: 'constants-directions' stamp: 'cr 3/10/2005 16:38'!
directionNames
	^#(east north northEast northWest south southEast southWest west)
! !

!GmMap methodsFor: 'constants-directions' stamp: 'cr 3/9/2005 01:40'!
east
	^1@0.
! !

!GmMap methodsFor: 'constants-directions' stamp: 'cr 3/9/2005 01:41'!
north
	^0@-1.
! !

!GmMap methodsFor: 'constants-directions' stamp: 'cr 3/9/2005 01:39'!
northEast
	^1 @ -1.
! !

!GmMap methodsFor: 'constants-directions' stamp: 'cr 3/9/2005 01:39'!
northWest
	^-1 @ -1.
! !

!GmMap methodsFor: 'constants-directions' stamp: 'cr 3/9/2005 01:40'!
south
	^0@1.
! !

!GmMap methodsFor: 'constants-directions' stamp: 'cr 3/9/2005 01:40'!
southEast
	^1@1.
! !

!GmMap methodsFor: 'constants-directions' stamp: 'cr 3/9/2005 01:40'!
southWest
	^-1@1.
! !

!GmMap methodsFor: 'constants-directions' stamp: 'cr 3/9/2005 01:40'!
west
	^-1@0.
! !

!GmMap methodsFor: 'private' stamp: 'cr 3/5/2005 22:48'!
at: point putThing: thing
	"This is here so that putObject: works correctly."
	^self at: point addThing: thing! !

!GmMap methodsFor: 'private' stamp: 'cr 1/8/2004 22:23'!
changedAt: point
	changedPoints add: point.
! !

!GmMap methodsFor: 'private' stamp: 'cr 3/11/2005 00:56'!
purgeMissingCreatures
	creatureCache := creatureCache reject: [ :creature | creature map ~~ self]! !

!GmMap methodsFor: 'debug' stamp: 'cr 3/12/2005 01:32'!
displaySoFar
	| panel |
	panel := RoguelikeMapDisplay new.
	panel setSize: self extent font: (StrikeFont familyName: 'DefaultTextStyle' size: 10).

	self entriesWithPointsDo: [ :e :p | panel at: p put: (self asciiTileAt: p) letter asString].

	panel drawOn: World canvas.
 ! !

!GmMap methodsFor: 'serialization-not used' stamp: 'cr 3/12/2005 14:01'!
itemsAsPointAndValuePairs
	| result |

	result := OrderedCollection new: 100.
	result add: {nil. self extent}.		"extent is the first element.  yes, this is gross.  Fix later."
	self entriesWithPointsDo: [ :entry :point | entry feature class = GmUnusedSpace ifFalse: [result add: {entry. point}]].

	^result.

! !

!GmMap methodsFor: 'serialization-not used' stamp: 'cr 3/12/2005 13:32'!
sixxFix

	"In order to get a smaller save file, we first replace 'items' with a list of pairs of 
	 coordinate and value (where the first is nil, extent).  This way, we don't have to
	 save all of those empty spaces.  Once reloaded though, the items field is incorrect.
	 This fixes it."

	| itemsHold itemsExtent |
	itemsHold := items.
	itemsExtent := itemsHold removeFirst second.

	items := self itemsWithExtent: itemsExtent.
	itemsHold do: [ :pair | items at: pair second x at: pair second y put: pair first].
! !


!GmMap class methodsFor: 'instance creation' stamp: 'cr 1/3/2004 09:32'!
new
	^self shouldNotImplement.
	"use #withExtent: instead."! !

!GmMap class methodsFor: 'instance creation' stamp: 'cr 1/3/2004 09:31'!
withExtent: extent
	^self basicNew initializeToExtent: extent.! !

!GmMap class methodsFor: 'instance creation-sixx' stamp: 'cr 3/12/2005 13:34'!
createInstanceOf: aClass withSixxElement: sixxElement 
	| instance |
	instance := super createInstanceOf: aClass withSixxElement: sixxElement.
	instance sixxFix.
	^instance.! !


!GmMapBuilder methodsFor: 'initialization' stamp: 'cr 5/15/2005 17:05'!
initializeToExtent: extent
	initialExtent := extent.
	rooms := Set new.! !

!GmMapBuilder methodsFor: 'build parameters' stamp: 'cr 1/3/2004 18:08'!
initialExtent: newExtent
	initialExtent := newExtent.
! !

!GmMapBuilder methodsFor: 'map building' stamp: 'cr 1/14/2004 21:13'!
addDoorAt: point
	self at: point putFeature: GmDoor new.! !

!GmMapBuilder methodsFor: 'map building' stamp: 'cr 5/13/2005 23:34'!
addLitRegionList
	map litRegions: self litRegionList.
! !

!GmMapBuilder methodsFor: 'map building' stamp: 'cr 9/29/2004 22:39'!
at: point putDoorOr: aWallObject
	"We put in a wall UNLESS the spot is currently occupied by a bit of tunnel, in which case we install a door."

	| newFtr |
	newFtr := (map featureAt: point) isUnusedSpace ifTrue: [aWallObject] ifFalse: [GmDoor new].
	self at: point putFeature: newFtr.
! !

!GmMapBuilder methodsFor: 'map building' stamp: 'cr 1/14/2004 21:11'!
at: position putFeature: feature
	map at: position putFeature: feature.
! !

!GmMapBuilder methodsFor: 'map building' stamp: 'cr 5/13/2005 23:30'!
buildMap
	self buildMapFeatures.
	self addLitRegionList.
! !

!GmMapBuilder methodsFor: 'map building' stamp: 'cr 5/13/2005 23:29'!
buildMapFeatures
	^self subclassResponsibility! !

!GmMapBuilder methodsFor: 'map building' stamp: 'cr 1/13/2004 22:48'!
initializeMap
	map := GmMap withExtent: initialExtent.
! !

!GmMapBuilder methodsFor: 'map building' stamp: 'cr 5/15/2005 17:11'!
litRegionList
	^rooms asArray
! !

!GmMapBuilder methodsFor: 'utilities' stamp: 'cr 1/14/2004 21:18'!
fillRegion: regionRect with: featureClass
	regionRect allInteriorPointsDo: [ :pt | self at: pt putFeature: featureClass new].! !

!GmMapBuilder methodsFor: 'utilities' stamp: 'cr 1/15/2004 22:14'!
randomInsidePoint
	^self randomPointBetween: self bounds origin and: self bounds corner.
! !

!GmMapBuilder methodsFor: 'utilities' stamp: 'cr 3/2/2005 14:10'!
randomPointBetween: origin and: corner
	^(origin corner: corner) randomInternalPoint.
! !

!GmMapBuilder methodsFor: 'accessing' stamp: 'cr 1/9/2004 20:18'!
map
	^map
! !

!GmMapBuilder methodsFor: 'accessing' stamp: 'cr 1/15/2004 23:39'!
mapBounds
	^self map bounds! !

!GmMapBuilder methodsFor: 'accessing' stamp: 'cr 1/14/2004 21:37'!
mapExtent
	^map
		ifNil: [initialExtent]
		ifNotNil: [map extent].
! !

!GmMapBuilder methodsFor: 'accessing' stamp: 'cr 5/15/2005 17:09'!
rooms
	^rooms! !

!GmMapBuilder methodsFor: 'construction-walls' stamp: 'cr 3/4/2005 02:02'!
addCornersFor: aRect
	aRect corners
		do: [ :corner | map at: corner putFeature: GmCornerWall new].
! !

!GmMapBuilder methodsFor: 'construction-walls' stamp: 'cr 3/4/2005 02:02'!
addEWWallFrom: left to: right
	[left y = right y] assert.

	(left x to: right x) do: [ :x | self at: x @ left y putDoorOr: GmEastWestWall new].! !

!GmMapBuilder methodsFor: 'construction-walls' stamp: 'cr 3/4/2005 02:03'!
addNSWallFrom: top to: bottom
	[top x = bottom x] assert.

	(top y to: bottom y) do: [ :y | self at: top x @ y putDoorOr: GmNorthSouthWall new].! !

!GmMapBuilder methodsFor: 'construction-walls' stamp: 'cr 3/4/2005 02:01'!
addWallsFor: aRect
	self addNSWallFrom: aRect topLeft to: aRect bottomLeft.
	self addNSWallFrom: aRect topRight to: aRect bottomRight.

	self addEWWallFrom: aRect topLeft to: aRect topRight.
	self addEWWallFrom: aRect bottomLeft to: aRect bottomRight.

	self addCornersFor: aRect.


! !

!GmMapBuilder methodsFor: 'construction-rooms' stamp: 'cr 5/15/2005 17:06'!
addRoomWithBounds: aRect
	self addWallsFor: aRect.
	self fillRegion: aRect withInsideRectPoints with: GmFloor.
	self rooms add: aRect.

! !

!GmMapBuilder methodsFor: 'debug' stamp: 'cr 3/3/2005 03:00'!
displaySoFar

	| panel |
	panel := RoguelikeMapDisplay new.
	panel setSize: map extent font: (StrikeFont familyName: 'DefaultTextStyle' size: 10).

	map entriesWithPointsDo: [ :e :p | panel at: p put: (map asciiTileAt: p) letter asString].

	panel drawOn: World canvas.
 ! !


!GmBigRoomBuilder methodsFor: 'map building' stamp: 'cr 5/15/2005 17:26'!
buildMapFeatures
	self initializeMap.

	self fillRegion: map bounds withInsideRectPoints with: GmFloor.
	self addWallsFor: map bounds.
! !


!GmCustomRoomBuilder methodsFor: 'initialization' stamp: 'cr 5/15/2005 18:22'!
initializeToExtent: extent
	super initializeToExtent: extent.

	featurePoints := Dictionary new.
	bottomRightCorners := Set new.

	templateArray := Array2D extent: extent.
	templateArray atAllPut: Character space.	

	replacementPoints := (1 to: 11) collect: [ :x | OrderedCollection new].
! !

!GmCustomRoomBuilder methodsFor: 'map building' stamp: 'cr 5/15/2005 21:22'!
addNumberedEntries
	| replaceClass |
	replacementPoints withIndexDo: [ :pointSet :index |
		replaceClass := self mapLayout at: index + 1 ifAbsent: [nil].
		pointSet do: [ :pt | self replaceInMapAt: pt withInstanceOf: replaceClass].
	].
! !

!GmCustomRoomBuilder methodsFor: 'map building' stamp: 'cr 5/15/2005 17:31'!
buildLevelFromTemplate
	self processTemplate.
	self addAllRooms.
	self addOtherFeatures.
! !

!GmCustomRoomBuilder methodsFor: 'map building' stamp: 'cr 5/15/2005 21:17'!
buildMapFeatures
	self initializeMap.
	self buildLevelFromTemplate.
	self addNumberedEntries.
! !

!GmCustomRoomBuilder methodsFor: 'map building' stamp: 'cr 5/15/2005 21:48'!
replaceInMapAt: pt withInstanceOf: objClass
	(map featureAt: pt) isNil ifTrue: [map at: pt putFeature: GmFloor new].
	objClass ifNil: [^self].
	map at: pt putObject: objClass new.

! !

!GmCustomRoomBuilder methodsFor: 'feature construction' stamp: 'cr 5/15/2005 17:31'!
addAllRooms
	self rooms do: [ :r | self addRoomWithBounds: r].
! !

!GmCustomRoomBuilder methodsFor: 'feature construction' stamp: 'cr 5/15/2005 18:32'!
addOtherFeatures
	featurePoints keysAndValuesDo: [ :coord :featClass | map at: coord putFeature: featClass new].! !

!GmCustomRoomBuilder methodsFor: 'map layout' stamp: 'cr 5/15/2005 22:02'!
mapLayout
	^self subclassResponsibility.

"Here's a simple example.  View with a fixed-width font for best results.

	^{
'
 /=======\    /======\
 |       |    |      |
 |       |    |      |
 |       +####+  0   |
 |   1   |    |      |
 |       |    |      |
 |       |    \======/
 \=======/
'.
	GmUpStairway.
	GmDownStairway
	}
"! !

!GmCustomRoomBuilder methodsFor: 'template parsing' stamp: 'cr 5/15/2005 22:13'!
addFeatureEntry: templateChar at: coord

	templateChar isDigit
		ifTrue: [
			(replacementPoints at: templateChar digitValue + 1) add: coord.
			^self
		].

	{$# -> GmTunnelFloor. $+ -> GmDoor. $< -> GmUpStairway. $> -> GmDownStairway} 
		do: [ :assoc | 
			assoc key = templateChar
				ifTrue: [
					featurePoints at: coord put: assoc value.
					^self
				].
		].
! !

!GmCustomRoomBuilder methodsFor: 'template parsing' stamp: 'cr 5/15/2005 21:00'!
backSlashBelow: aPoint
	| currPt |
	currPt := aPoint.
	[(templateArray at: currPt x at: currPt y) = $\] whileFalse: [currPt := currPt + (0@1)].
	^currPt.
! !

!GmCustomRoomBuilder methodsFor: 'template parsing' stamp: 'cr 5/15/2005 18:08'!
bottomRightFor: topLeftPoint
	^self forwardSlashRightOf: (self backSlashBelow: topLeftPoint)! !

!GmCustomRoomBuilder methodsFor: 'template parsing' stamp: 'cr 5/15/2005 17:44'!
copyTemplateToArray
	| x y |
	x := 1.
	y := 1.
	self mapLayout first do: [ :mapChar |
		mapChar = Character space ifFalse: [templateArray at: x at: y put: mapChar].
		mapChar = Character cr
			ifTrue: [y := y + 1. x := 1]
			ifFalse: [x := x + 1].
	].
	! !

!GmCustomRoomBuilder methodsFor: 'template parsing' stamp: 'cr 5/15/2005 18:19'!
findFeaturesAndReplacements
	templateArray horizFirstWithCoordsDo: 
		[ :coords :value | self addFeatureEntry: value at: coords]! !

!GmCustomRoomBuilder methodsFor: 'template parsing' stamp: 'cr 5/15/2005 18:16'!
findRoomAt: point
	| bottomRight |
	(bottomRightCorners includes: point) ifTrue: [^self].

	bottomRight := self bottomRightFor: point.
	bottomRightCorners add: bottomRight.
	rooms add: (point corner: bottomRight).
! !

!GmCustomRoomBuilder methodsFor: 'template parsing' stamp: 'cr 5/15/2005 21:00'!
forwardSlashRightOf: aPoint
	| currPt |
	currPt := aPoint.
	[(templateArray at: currPt x at: currPt y) = $/] whileFalse: [currPt := currPt + (1@0)].
	^currPt.
! !

!GmCustomRoomBuilder methodsFor: 'template parsing' stamp: 'cr 5/15/2005 18:00'!
makeRoomList
	templateArray horizFirstWithCoordsDo: 
		[ :coords :value | value = $/ ifTrue: [self findRoomAt: coords]].! !

!GmCustomRoomBuilder methodsFor: 'template parsing' stamp: 'cr 5/15/2005 17:49'!
processTemplate
	self copyTemplateToArray.
	self makeRoomList.
	self findFeaturesAndReplacements.
! !


!GmMapBuilder class methodsFor: 'instance creation' stamp: 'cr 1/3/2004 11:20'!
mapExtent: extent
	^self basicNew initializeToExtent: extent.
! !

!GmMapBuilder class methodsFor: 'instance creation' stamp: 'cr 1/3/2004 18:07'!
new
	^self initializeToExtent: 10@10.
! !

!GmMapBuilder class methodsFor: 'debug' stamp: 'cr 5/15/2005 22:07'!
makeAndShow
	^self makeAndShow: 160@50.
! !

!GmMapBuilder class methodsFor: 'debug' stamp: 'cr 5/15/2005 22:07'!
makeAndShow: size
	^(self mapExtent: size) buildMap; displaySoFar; yourself.
! !


!GmMapEntry methodsFor: 'initialization' stamp: 'cr 1/3/2004 09:50'!
initialize
	pileOfStuff := OrderedCollection new.
! !

!GmMapEntry methodsFor: 'accessing' stamp: 'cr 1/3/2004 09:52'!
addThing: newThing
	pileOfStuff addLast: newThing.
! !

!GmMapEntry methodsFor: 'accessing' stamp: 'cr 1/3/2004 09:49'!
creature
	^creature
! !

!GmMapEntry methodsFor: 'accessing' stamp: 'cr 1/3/2004 09:49'!
creature: newCreature
	creature := newCreature.! !

!GmMapEntry methodsFor: 'accessing' stamp: 'cr 1/2/2004 13:07'!
feature
	^feature! !

!GmMapEntry methodsFor: 'accessing' stamp: 'cr 1/2/2004 13:08'!
feature: newFeature
	feature := newFeature.! !

!GmMapEntry methodsFor: 'accessing' stamp: 'cr 1/3/2004 09:50'!
pileOfStuff
	^pileOfStuff
! !

!GmMapEntry methodsFor: 'contents' stamp: 'cr 1/3/2004 20:18'!
firstThing
	^self pileOfStuff isEmpty
		ifTrue: [nil]
		ifFalse: [self pileOfStuff first].! !

!GmMapEntry methodsFor: 'contents' stamp: 'cr 4/3/2005 19:55'!
nonCreatureTopmostObject
	^ self firstThing ifNil: [self feature].

		
	! !

!GmMapEntry methodsFor: 'contents' stamp: 'cr 1/4/2004 16:15'!
removeCreature
	self creature: nil.
! !

!GmMapEntry methodsFor: 'contents' stamp: 'cr 1/3/2004 20:16'!
topmostObject
	^self creature ifNil: [
		self firstThing ifNil: [self feature]
	].

		
	! !

!GmMapEntry methodsFor: 'tests' stamp: 'cr 1/4/2004 15:19'!
contains: gameObject

	^ self creature = gameObject or: [self feature = gameObject
		or: [self pileOfStuff includes: gameObject]].! !

!GmMapEntry methodsFor: 'tests' stamp: 'cr 1/4/2004 15:43'!
hasCreature
	^self creature notNil.
! !

!GmMapEntry methodsFor: 'tests' stamp: 'cr 1/4/2004 15:44'!
hasStuff
	^self pileOfStuff isEmpty not.
! !

!GmMapEntry methodsFor: 'tests' stamp: 'cr 3/5/2005 22:41'!
terrainAllows: creatureOrThing
	^creatureOrThing isCreature
		ifTrue: [self feature allowsAccessBy: creatureOrThing]
		ifFalse: [self feature isDug]
! !

!GmMapEntry methodsFor: 'display' stamp: 'cr 3/3/2005 03:02'!
asciiTile
	^self topmostObject class asciiObjectDescription
! !

!GmMapEntry methodsFor: 'display' stamp: 'cr 4/3/2005 19:56'!
nonCreatureAsciiTile
	^self nonCreatureTopmostObject class asciiObjectDescription
! !


!GmMapEntry class methodsFor: 'instance creation' stamp: 'cr 1/3/2004 09:50'!
new
	^self basicNew initialize.! !

!GmMapEntry class methodsFor: 'display class' stamp: 'cr 1/3/2004 20:21'!
descriptionClass
	^GmAsciiObjectDescription

! !


!GmMessage methodsFor: 'testing' stamp: 'cr 10/4/2004 01:05'!
hasUserMessage
	^messageString isEmptyOrNil not.! !

!GmMessage methodsFor: 'testing' stamp: 'cr 2/27/2005 01:55'!
isNotification
	^false
! !

!GmMessage methodsFor: 'testing' stamp: 'cr 2/27/2005 01:50'!
isResponse
	^false
! !

!GmMessage methodsFor: 'testing' stamp: 'cr 1/3/2004 10:15'!
isStatusResponse
	^false
! !

!GmMessage methodsFor: 'flow control' stamp: 'cr 3/10/2005 03:07'!
ifHasUserMessage: aBlock
	self hasUserMessage	ifTrue: [^aBlock valueMaybeWith: self]
! !

!GmMessage methodsFor: 'initialize' stamp: 'cr 9/23/2005 13:20'!
desc: descriptionString
	messageString := descriptionString withBlanksTrimmed.
! !

!GmMessage methodsFor: 'accessing' stamp: 'cr 1/3/2004 10:13'!
humanDesc

	"This is not guaranteed to remain a string.  The UI should know what to do with this."
	^messageString
! !

!GmMessage methodsFor: 'message ops' stamp: 'cr 9/23/2005 13:19'!
replaceWith: aGmMessage
	"Return a copy of aGmMessage containing this message's human-readable message (i.e. an
	 English text string) prepended to its own."

	| newMsg |
	newMsg := messageString, String cr, aGmMessage humanDesc.

	aGmMessage
		ifHasUserMessage: [^aGmMessage withDesc: newMsg].

	^aGmMessage talkingSpecies desc: newMsg.
! !

!GmMessage methodsFor: 'message ops' stamp: 'cr 9/23/2005 13:17'!
talkingSpecies
	"Return a class like this one's but capable of carrying a user message."
	^self class
! !

!GmMessage methodsFor: 'message ops' stamp: 'cr 9/23/2005 12:31'!
withDesc: newDesc
	^self copy desc: newDesc.! !


!GmMessage class methodsFor: 'instance creation' stamp: 'cr 1/3/2004 10:10'!
desc: messageString
	^self basicNew desc: messageString.
! !

!GmMessage class methodsFor: 'instance creation' stamp: 'cr 3/5/2005 16:15'!
new
	^self subclassResponsibility

	"Subclasses that implement #new need to set the description to something reasonable."
! !


!GmNotesInComment methodsFor: 'messages in comments' stamp: 'cr 9/23/2005 12:56'!
patternWierdnesses
	"

	This method comment contains some notes on various design patterns I'm using that are
	in some way broken.  Basically, this is where I document things that need to be cleaned
	up but I haven't gotten around to yet.

Descripions:

	You can get an object description both from a GmObject and from its ASCII tile.  The former,
	returned by #descriptionString and related methods,	describes that object while the latter,
	returned by #asciiObjectDescription, describes the meaning of that symbol.

	So for example, the description of a diamond would be 'a diamond' while its tile's description
	would be '* a gem or stone'.

 	The problem is that the tile description isn't necessarily that.  It sometimes describes the object
	itself.  This is wrong.  Long term, the symbol-description mapping should be in the Tile class, I
	think.

	This is all moot right now since we don't actually use the tile description (I THINK).

Type Attributes

	A lot of GmObject properties are managed by test methods (e.g. 'isUndead').  They are defined
	in the base class to return the most general result and overridden by various subclasses so that
	they accurately describe the object.

	Initially, I made them into instance methods, but this makes it difficult to query the class.  So, the
	pattern is to put the test into the class and add an instance method that just queries the class and
	returns its result.  When overriding, you override the class method.

	The problem is that some but not all tests work this way and I'm still in the process of converting
	them all over.






	"! !

!GmNotesInComment methodsFor: 'messages in comments' stamp: 'cr 9/24/2005 22:28'!
versionHistory

"

	Changes for 1.02:

		-Added the 'burdened' stat.
		-Adjusted the weights to match nethack's (times 100).  This is more or less weight in grams.
		-Fixed bug in randomizer initialization.  (Was initializing from the millisecondClock value
		 which, I discovered, is reset when the VM starts.  I changed it to use the date in seconds.)
		-Now recenters the player whenever the main window is resized.
		-Added 'r' key, which rests until either the player is healed or a monster comes into view.
		-Adjusted object generation so that the more valuable objects tend to appear lower.
		 Probably still needs balancing.
		-Added monster drop (but no corpses, yet.)
		-Fixed the 'beaded curtain' problem--that is, you can now look into an entire room while
		 standing in the doorway.
		-Fixed bug in displaying changes in the burdeneds stat.
		-Made the monsters at the bottom level more aggressive.
		-Added GmCustomRoomBuilder.
		-Added custom bottom level and a unique final boss creature, the Tailor of Yendor.
		-Added lots of extra weapons.
		-Ajusted the number of monsters created per level so that the user isn't in for quite
		 as big a pummelling at startup.
		-Increased the kickassness of the battle spork for the same reason.
		-Bug fix: naked humanoids had an AC of 3.  Changed that to 0.
		-Stuff Manager now divides the random stuff found in the dungeon evenly between
		 the GmThing top-level subclasses.
		-Made silver weapons have a bonus attack against undead.
		-Made charisma, intelligence and wisdom slightly useful.




"! !


!GmNotification methodsFor: 'testing' stamp: 'cr 2/27/2005 01:54'!
isNotification
	^true
! !

!GmNotification methodsFor: 'interpretation' stamp: 'cr 2/27/2005 01:57'!
hostilityLevel
	^0	"Really, this should be subclass responsibility, but hey!!"
! !

!GmNotification methodsFor: 'accessing' stamp: 'cr 2/27/2005 02:04'!
sender
	^sender! !

!GmNotification methodsFor: 'accessing' stamp: 'cr 2/27/2005 02:04'!
sender: newValue
	sender := newValue! !


!GmAttackNotification methodsFor: 'interpretation' stamp: 'cr 4/2/2005 21:47'!
hostilityLevel
	^1000		"This ain't no friendly gesture."
! !


!GmDisplacedAtPortal methodsFor: 'interpretation' stamp: 'cr 2/27/2005 01:58'!
hostilityLevel
	^2		"Not very hostile"! !


!GmAttackNotification class methodsFor: 'instance creation' stamp: 'cr 4/2/2005 21:50'!
desc: descString byCreature: aCreature
	^self new
		sender: aCreature;
		desc: descString
		yourself.! !

!GmAttackNotification class methodsFor: 'instance creation' stamp: 'cr 4/2/2005 21:50'!
theCreature: aCreature does: attackString
	^self basicNew
		sender: aCreature;
		desc: aCreature theDescriptionString capitalized, ' ', attackString;
		yourself.! !


!GmDisplacedAtPortal class methodsFor: 'instance creation' stamp: 'cr 2/27/2005 02:18'!
byCreature: aCreature
	^self new
		sender: aCreature;
		desc: aCreature descriptionString capitalized, 
				' bumps into you, knocking you out of the way.';
		yourself.! !


!GmNewLevel class methodsFor: 'instance creation' stamp: 'cr 5/13/2005 14:42'!
levelNum: newLevel from: prevLevel
	^newLevel >= prevLevel
		ifTrue: [self desc: 'You feel more experienced.']
		ifFalse: [self desc: 'You feel like you''ve lost something.']
! !

!GmNewLevel class methodsFor: 'instance creation' stamp: 'cr 5/13/2005 14:46'!
new
	^self desc: 'You feel experienced.'.! !


!GmObjGenManager methodsFor: 'initialization' stamp: 'cr 3/5/2005 21:07'!
addToItemInfo: class
	itemInfo add: (GmManagedObjectInfo for: class).
! !

!GmObjGenManager methodsFor: 'initialization' stamp: 'cr 3/5/2005 20:55'!
fillItemInfoFrom: classRoot
	classRoot allSubclassesDo: [ :class | class isConcrete ifTrue: [self addToItemInfo: class]]! !

!GmObjGenManager methodsFor: 'initialization' stamp: 'cr 4/26/2005 23:01'!
initialize
	self initializeItemInfo.

! !

!GmObjGenManager methodsFor: 'initialization' stamp: 'cr 4/26/2005 23:01'!
initializeItemInfo
	itemInfo := OrderedCollection new.
! !

!GmObjGenManager methodsFor: 'initialization' stamp: 'cr 2/13/2005 20:26'!
on: aGame
	game := aGame.
! !

!GmObjGenManager methodsFor: 'map population' stamp: 'cr 3/5/2005 21:50'!
setupMap: map
	self generateItemsIn: map count: (self numRequiredIn: map)! !

!GmObjGenManager methodsFor: 'map population' stamp: 'cr 3/5/2005 21:51'!
updateMap: map
	self generateItemsIn: map count: (self numForUpdateIn: map)! !

!GmObjGenManager methodsFor: 'item generation' stamp: 'cr 3/12/2005 11:07'!
addItem: anObjectClass to: map ifUnable: aBlock
	| slot object point |

	slot := self slotForClass: anObjectClass.
	object := slot create.

	point := map randomSpotFor: object or: [slot uncreate. ^aBlock value].
	map at: point putObject: object.


! !

!GmObjGenManager methodsFor: 'item generation' stamp: 'cr 4/3/2005 15:53'!
addRandomItemTo: map ifUnable: aBlock
	| slot object point |

	slot := self pickItemForMap: map or: [^aBlock value].
	object := slot create.
	self prepareObject: object forMap: map.

	point := map randomSpotFor: object or: [slot uncreate. ^aBlock value].
	map at: point putObject: object.


! !

!GmObjGenManager methodsFor: 'item generation' stamp: 'cr 9/19/2005 00:57'!
generateItemsIn: map count: count
	count timesRepeat: [self addRandomItemTo: map ifUnable: [^self]].! !

!GmObjGenManager methodsFor: 'item generation' stamp: 'cr 5/11/2005 10:56'!
itemsAvailableOnMap: map
	^self itemsAvailableOnMap: map and: [ :dummyArg | true].
! !

!GmObjGenManager methodsFor: 'item generation' stamp: 'cr 5/11/2005 10:42'!
itemsAvailableOnMap: map and: otherSelectBlock
	^self itemInfo select: [ :ci | (ci canCreateIn: map) and: [otherSelectBlock value: ci]].
! !

!GmObjGenManager methodsFor: 'item generation' stamp: 'cr 4/3/2005 22:04'!
pickItemForMap: level or: errorBlock
	| viableItems |

	viableItems := self itemsAvailableOnMap: level.
	viableItems isEmpty	ifTrue: [^errorBlock value].
	^viableItems atRandom





	! !

!GmObjGenManager methodsFor: 'item generation' stamp: 'cr 4/3/2005 15:54'!
prepareObject: object forMap: map
	^self subclassResponsibility! !

!GmObjGenManager methodsFor: 'accessing' stamp: 'cr 3/5/2005 20:47'!
itemInfo
	^itemInfo
! !

!GmObjGenManager methodsFor: 'accessing' stamp: 'cr 3/12/2005 10:54'!
slotForClass: objectClass
	^itemInfo detect: [ :classInfo | classInfo itemClass == objectClass]
! !

!GmObjGenManager methodsFor: 'calculations' stamp: 'cr 3/5/2005 21:48'!
numForUpdateIn: map

	"Given a map, figure out how many items are to be created here initially."

	^self subclassResponsibility
! !

!GmObjGenManager methodsFor: 'calculations' stamp: 'cr 3/5/2005 21:48'!
numRequiredIn: map

	"Given a map, figure out how many items are to be created here initially."

	^self subclassResponsibility
! !


!GmBestiary methodsFor: 'initialization' stamp: 'cr 3/5/2005 21:08'!
initialize
	super initialize.
	self fillItemInfoFrom: GmCreature.
	! !

!GmBestiary methodsFor: 'monster generation' stamp: 'cr 4/2/2005 13:24'!
createPlayer
	| player |
	player := NhHuman new.
	player addStats: {GmDungeonLevel -> 42}.

	#('Strength' 'Wisdom' 'Intelligence' 'Dexterity' 'Constitution' 'Charisma')
		do: [ :stat | player atStat: stat put: (5 d: 3)].

	player atStatHitPoints: (10 to: 20) atRandom.

	^player
! !

!GmBestiary methodsFor: 'calculations' stamp: 'cr 3/5/2005 21:52'!
numForUpdateIn: map
	^10		"To do: make this cleverer."

! !

!GmBestiary methodsFor: 'calculations' stamp: 'cr 3/5/2005 21:52'!
numRequiredIn: map
	"Given a map, figure out how many items are to be created here initially."
	^40! !


!GmObjGenManager class methodsFor: 'instance creation' stamp: 'cr 2/13/2005 20:29'!
new

	"should use #on: instead."
	
	^self shouldNotImplement.! !

!GmObjGenManager class methodsFor: 'instance creation' stamp: 'cr 2/13/2005 20:28'!
on: aGame
	^self basicNew
		initialize;
		on: aGame;
		yourself.
! !


!GmObjStat methodsFor: 'initialization' stamp: 'cr 5/14/2005 16:52'!
initialize
	prevValue := nil.
! !

!GmObjStat methodsFor: 'initialization' stamp: 'cr 4/26/2005 00:08'!
on: object value: v
	owner := object.
	value := v.
! !

!GmObjStat methodsFor: 'core protocol' stamp: 'cr 5/14/2005 17:22'!
basicSetValue: newValue oldValue: ov

	"subclasses can override this to hook onto value changes.  Just remember to set 
	 prevValue first."

	prevValue := ov.
	value := newValue.
	^value.
! !

!GmObjStat methodsFor: 'core protocol' stamp: 'cr 2/6/2005 15:55'!
basicValue
	"Do not override this.  Instead, override #value."
	^value! !

!GmObjStat methodsFor: 'core protocol' stamp: 'cr 2/13/2005 23:46'!
descString
	^self name, ': ', self value printString.
! !

!GmObjStat methodsFor: 'core protocol' stamp: 'cr 5/14/2005 16:52'!
markChanged
	prevValue := nil.
! !

!GmObjStat methodsFor: 'core protocol' stamp: 'cr 4/24/2005 20:26'!
name
	"This should never change and needs to always uniquely identify this stat type."
	^self className allButFirst: 2
! !

!GmObjStat methodsFor: 'core protocol' stamp: 'cr 5/14/2005 17:22'!
setValue: newValue

	"subclasses can override this to hook onto value changes.  Just remember to set 
	 prevValue first."

	self basicSetValue: newValue oldValue: self value.! !

!GmObjStat methodsFor: 'core protocol' stamp: 'cr 2/13/2005 19:20'!
showFlag
	^true.		"Return false if you don't want the user to see this stat."
! !

!GmObjStat methodsFor: 'core protocol' stamp: 'cr 2/13/2005 19:18'!
sortKey
	^self name
! !

!GmObjStat methodsFor: 'core protocol' stamp: 'cr 5/14/2005 17:24'!
value
	"Subclasses can override this.  However, overridden versions should not call #setValue:"	
	^value
! !

!GmObjStat methodsFor: 'tests' stamp: 'cr 5/14/2005 16:52'!
isChanged
	^self value ~= prevValue
! !

!GmObjStat methodsFor: 'tests' stamp: 'cr 2/6/2005 15:34'!
isSet
	^self subclassResponsibility! !

!GmObjStat methodsFor: 'tests' stamp: 'cr 5/14/2005 16:51'!
testAndClearChanged
	| c |
	c := self isChanged.
	prevValue := self value.
	^c.
! !

!GmObjStat methodsFor: 'printing' stamp: 'cr 2/13/2005 19:27'!
printOn: aStream
	super printOn: aStream.
	aStream 	nextPutAll: ' (';
				nextPutAll: self value printString;
				nextPut: $).
! !


!GmBoolStat methodsFor: 'initialization' stamp: 'cr 2/23/2005 16:49'!
initialize
	super initialize.
	value := false.
! !

!GmBoolStat methodsFor: 'core protocol' stamp: 'cr 4/24/2005 20:31'!
descString
	^self value
		ifTrue: [self valueName] ifFalse: [''].

! !

!GmBoolStat methodsFor: 'core protocol' stamp: 'cr 4/25/2005 00:22'!
sortKey
	^'ZZZZZZZZZZZZ', super sortKey.

	"Boolean stats get sorted after the numbered stats."! !

!GmBoolStat methodsFor: 'core protocol' stamp: 'cr 2/6/2005 15:48'!
valueName
	^self subclassResponsibility! !

!GmBoolStat methodsFor: 'testing and setting' stamp: 'cr 2/6/2005 15:30'!
clear
	self setValue: false.

! !

!GmBoolStat methodsFor: 'testing and setting' stamp: 'cr 2/6/2005 15:30'!
isSet
	^self value
! !

!GmBoolStat methodsFor: 'testing and setting' stamp: 'cr 2/6/2005 15:29'!
set
	self setValue: true! !

!GmBoolStat methodsFor: 'testing and setting' stamp: 'cr 2/6/2005 15:29'!
toggle
	self setValue: self value not.

! !

!GmBoolStat methodsFor: 'control flow' stamp: 'cr 2/6/2005 15:25'!
ifFalse: aBlock
	^self value ifFalse: aBlock! !

!GmBoolStat methodsFor: 'control flow' stamp: 'cr 2/6/2005 15:25'!
ifTrue: aBlock
	^self value ifTrue: aBlock! !

!GmBoolStat methodsFor: 'control flow' stamp: 'cr 2/6/2005 15:25'!
ifTrue: trueBlock ifFalse: falseBlock
	^self value ifTrue: trueBlock ifFalse: falseBlock.
! !

!GmBoolStat methodsFor: 'accessing' stamp: 'cr 2/6/2005 15:19'!
value
	^value! !


!GmBurdened methodsFor: 'value management' stamp: 'cr 5/14/2005 17:44'!
updateValue

	"We need to avoid calling #setValue: here because this gets called by #value and that produces an
	 infinite recursion."

	value := owner inventoryWeight > self weightThreshold.
! !

!GmBurdened methodsFor: 'value management' stamp: 'cr 4/26/2005 22:48'!
weightThreshold
"	^owner atStatStrength * 10000."

	^(((owner atStatStrength + owner atStatConstitution) // 2) + 1) * 5000.		"50 * 100"

	"This formula is taken from Nethack, only multiplied by 100 to make up for my assumption
	 that each Nethack weight unit is 100 grams."
! !

!GmBurdened methodsFor: 'core protocol' stamp: 'cr 4/24/2005 20:18'!
setValue: newValue
	"do nothing. Value gets changed by inventory and strength."! !

!GmBurdened methodsFor: 'core protocol' stamp: 'cr 4/24/2005 20:05'!
value
	self updateValue.
	^super value.
! !

!GmBurdened methodsFor: 'core protocol' stamp: 'cr 4/24/2005 20:19'!
valueName
	^'Burdened'
! !

!GmBurdened methodsFor: 'testing and setting' stamp: 'cr 5/14/2005 16:23'!
testAndClearChanged
	self updateValue.
	^super testAndClearChanged.
! !


!GmConfused methodsFor: 'core protocol' stamp: 'cr 2/6/2005 16:08'!
valueName
	^'Confused'
! !


!GmNumStat methodsFor: 'initialization' stamp: 'cr 2/23/2005 16:49'!
initialize
	super initialize.
	value := 0.
! !

!GmNumStat methodsFor: 'arithmetic' stamp: 'cr 3/12/2005 03:16'!
add: num
	self setValue: self basicValue + num asNumber! !

!GmNumStat methodsFor: 'arithmetic' stamp: 'cr 2/6/2005 15:33'!
asNumber
	^self value.
! !

!GmNumStat methodsFor: 'arithmetic' stamp: 'cr 9/20/2005 12:33'!
occupiesWhichRangeIn: range startingIndex: startingIndex
	"Determine which range of values 'self' currently occupies."
	| index |
	index := startingIndex.
	range do: [ :rangeBorder | 
		self value < rangeBorder ifTrue: [^index].
		index := index + 1.
	].

	^index! !

!GmNumStat methodsFor: 'arithmetic' stamp: 'cr 3/12/2005 03:16'!
subtract: num
	self setValue: self basicValue - num asNumber! !

!GmNumStat methodsFor: 'tests' stamp: 'cr 2/6/2005 15:35'!
isSet
	"this basically tests whether the Stat has any effect at all."
	^self value > 0! !

!GmNumStat methodsFor: 'core protocol' stamp: 'cr 3/8/2005 15:27'!
name
	^self class name allButFirst: 2.
! !


!GmArmorClass methodsFor: 'core protocol' stamp: 'cr 3/12/2005 04:10'!
value
	^super value + (owner applyToDeployedAndSum: #armorClassMod) max: 0
! !


!GmBoringNumStat methodsFor: 'core protocol' stamp: 'cr 3/8/2005 12:11'!
add: num
	super add: num.
	self constrainValue.
! !

!GmBoringNumStat methodsFor: 'core protocol' stamp: 'cr 3/8/2005 12:11'!
subtract: num
	super subtract: num.
	self constrainValue.
! !

!GmBoringNumStat methodsFor: 'core protocol' stamp: 'cr 3/12/2005 04:22'!
value
	^super value + (owner applyToDeployedAndSum: self modifierMessage) max: 0
! !

!GmBoringNumStat methodsFor: 'constants' stamp: 'cr 3/8/2005 12:09'!
maxValue
	^18! !

!GmBoringNumStat methodsFor: 'constants' stamp: 'cr 3/8/2005 12:08'!
minValue
	^0
! !

!GmBoringNumStat methodsFor: 'stat modifications' stamp: 'cr 3/12/2005 04:22'!
modifierMessage
	^self subclassResponsibility! !

!GmBoringNumStat methodsFor: 'private-constraints' stamp: 'cr 3/8/2005 12:11'!
constrainValue
	value := value min: self minValue max: self maxValue! !


!GmCharisma methodsFor: 'stat modifications' stamp: 'cr 3/12/2005 04:23'!
modifierMessage
	^#charismaMod! !


!GmConstitution methodsFor: 'stat modifications' stamp: 'cr 3/12/2005 04:23'!
modifierMessage
	^#constitutionMod! !


!GmDexterity methodsFor: 'core protocol' stamp: 'cr 5/14/2005 16:33'!
value
	^(super value + self burdenedModifier) max: 0.
! !

!GmDexterity methodsFor: 'stat modifications' stamp: 'cr 4/26/2005 22:32'!
burdenedModifier
	^owner atStatBurdened
		ifTrue: [-3]
		ifFalse: [0].! !

!GmDexterity methodsFor: 'stat modifications' stamp: 'cr 3/12/2005 04:24'!
modifierMessage
	^#dexterityMod! !


!GmDungeonLevel methodsFor: 'core protocol' stamp: 'cr 3/10/2005 00:52'!
descString
	^ owner map creationState descriptionString.
! !

!GmDungeonLevel methodsFor: 'core protocol' stamp: 'cr 5/14/2005 17:52'!
setValue: v
	"disabled."
! !

!GmDungeonLevel methodsFor: 'core protocol' stamp: 'cr 5/14/2005 17:54'!
value
	| level |
	level := owner map creationState level.
	self basicSetValue: level oldValue: value.
	^super value.

! !

!GmDungeonLevel methodsFor: 'tests' stamp: 'cr 3/24/2005 22:12'!
testAndClearChanged

	| hasChanged |
	hasChanged := (lastLevel == owner map) not.
	lastLevel := owner map.
	^hasChanged.
! !


!GmExperience methodsFor: 'core protocol' stamp: 'cr 3/8/2005 16:40'!
descString
	^self name, ': ', self levelValue printString, '/', self value printString! !

!GmExperience methodsFor: 'core protocol' stamp: 'cr 4/1/2005 17:52'!
setValue: newValue
	| oldLevel |

	"Once again, blech!!  Different abstraction levels in the same method!!"	

	oldLevel := self levelValue.
	super setValue: newValue.
	
	self levelValue > oldLevel
		ifTrue: [self levelValue - oldLevel timesRepeat: [owner updateForGainedLevel]].
! !

!GmExperience methodsFor: 'level values' stamp: 'cr 4/3/2005 16:27'!
levelValue
	^(self levelForExperience: self value) rounded.
! !

!GmExperience methodsFor: 'level values' stamp: 'cr 5/13/2005 14:44'!
setLevelValue: newLevel

	"This should be the inverse of levelValue.  It's not quite but it's close enough for
	 what we need it."

	self setValue: (self expForLevel: newLevel) rounded.! !

!GmExperience methodsFor: 'private- exp to level calculation' stamp: 'cr 4/3/2005 16:38'!
expForLevel: level
	"MUST mirror levelForExperience: "
	^10 * (2 raisedTo: level)! !

!GmExperience methodsFor: 'private- exp to level calculation' stamp: 'cr 4/3/2005 16:39'!
levelForExperience: exp
	"This MUST mirror #expForLevel:  The one exception is that this will never return a negative level,
	 even though that's what you'll get when exp < about 20 or so."
	^((exp / 10) log: 2) max: 1.! !


!GmHitPoints methodsFor: 'initialization' stamp: 'cr 9/16/2005 11:57'!
initialize
	super initialize.
	delayHealCount := 0.
! !

!GmHitPoints methodsFor: 'maximum  value' stamp: 'cr 3/10/2005 00:15'!
clipValue
	value := value min: self maxHitpoints truncated.
! !

!GmHitPoints methodsFor: 'maximum  value' stamp: 'cr 5/14/2005 16:53'!
increaseMaxBy: newMax
	maxHitpoints := self maxHitpoints + newMax.
	self markChanged.! !

!GmHitPoints methodsFor: 'maximum  value' stamp: 'cr 3/10/2005 00:16'!
maxHitpoints
	^maxHitpoints
		ifNil: [maxHitpoints := value]	
! !

!GmHitPoints methodsFor: 'core protocol' stamp: 'cr 3/10/2005 00:30'!
descString
	^self name, ': ', self value printString, ' (', self maxHitpoints printString, ')'! !

!GmHitPoints methodsFor: 'core protocol' stamp: 'cr 2/13/2005 19:24'!
name
	^'HitPoints'
! !

!GmHitPoints methodsFor: 'core protocol' stamp: 'cr 9/21/2005 16:15'!
setValue: newValue

	newValue < self value ifTrue: [self delayHealing].

	super setValue: newValue.
	self clipValue.
	(self value <= 0) ifTrue: [owner die].
! !

!GmHitPoints methodsFor: 'core protocol' stamp: 'cr 3/10/2005 00:18'!
value
	^super value truncated.
! !

!GmHitPoints methodsFor: 'tests' stamp: 'cr 5/12/2005 13:55'!
isAtMaximum
	^self value >= self maxHitpoints
! !

!GmHitPoints methodsFor: 'healing' stamp: 'cr 9/16/2005 11:59'!
delayHealing
	delayHealCount := 6.
! !

!GmHitPoints methodsFor: 'healing' stamp: 'cr 9/19/2005 23:50'!
heal

	delayHealCount > 0
		ifTrue: [
			delayHealCount := delayHealCount - 1.
			^self.
		].

	"We access the variables directly here to get past the data laundering properties of
	 the accessors.  This may not be the best coding style."
	value := value + (owner atStatConstitution / 255.0).	"At max const, one HP per 15 turns."

	self clipValue.
! !

!GmHitPoints methodsFor: 'healing' stamp: 'cr 3/11/2005 14:03'!
healToMax
	self setValue: maxHitpoints! !


!GmIntelligence methodsFor: 'stat modifications' stamp: 'cr 3/12/2005 04:24'!
modifierMessage
	^#intelligenceMod! !


!GmObjStat class methodsFor: 'instance creation' stamp: 'cr 2/6/2005 16:07'!
new
	^self basicNew initialize
! !

!GmObjStat class methodsFor: 'instance creation' stamp: 'cr 2/6/2005 16:08'!
on: object value: v
	^self new on: object value: v.
! !


!GmObject methodsFor: 'initialization' stamp: 'cr 1/3/2004 19:06'!
initialize

	"this is here so that new doesn't break."
! !

!GmObject methodsFor: 'type tests' stamp: 'cr 1/3/2004 23:09'!
isCreature
	^false
! !

!GmObject methodsFor: 'type tests' stamp: 'cr 1/2/2004 19:57'!
isFeature
	^false
! !

!GmObject methodsFor: 'type tests' stamp: 'cr 1/2/2004 19:58'!
isThing
	^false
! !

!GmObject methodsFor: 'description' stamp: 'cr 3/4/2005 18:04'!
descriptionString
	^(self className allButFirst: 2) studlyCapsToWords withIndefiniteArticle! !

!GmObject methodsFor: 'description' stamp: 'cr 5/24/2005 19:12'!
longDescriptionString

	"This is a placeholder.  The result is a standalone descriptive phrase, meant to be used
	 outside of a specific context.

	 E.g. if self is a snake named Buddy, descriptionString would return 'Buddy' but
	 longDescriptionString should return 'a snake named Buddy.'.

	 This gets used by the map examination feature."

	^self descriptionString.! !

!GmObject methodsFor: 'description' stamp: 'cr 4/3/2005 19:03'!
theDescriptionString
	^ (self className allButFirst: 2) studlyCapsToWords withDefiniteArticle! !

!GmObject methodsFor: 'type properties' stamp: 'cr 3/26/2005 13:24'!
isUnique
	^self class maxAllowed = 1.
! !

!GmObject methodsFor: 'map reference' stamp: 'cr 5/15/2005 23:54'!
map: aMap
	"do nothing.  Classes that need to reference the map will do so."

	"WARNING: this only gets called when something is placed on the map, NOT when it's
	 removed.  This is fine(ish) for fixtures but troublesome elsewhere."! !


!GmCreature methodsFor: 'initialization' stamp: 'cr 3/8/2005 15:24'!
addDefaultStats
	self addStats: self class initialStatValues.! !

!GmCreature methodsFor: 'initialization' stamp: 'cr 3/6/2005 19:39'!
addSlots
	slots := GmDeployments new.! !

!GmCreature methodsFor: 'initialization' stamp: 'cr 2/13/2005 18:47'!
addStat: statClass initializedTo: initVal
	| stat |
	stat := statClass on: self value: initVal.
	stats at: stat name put: stat.



! !

!GmCreature methodsFor: 'initialization' stamp: 'cr 3/8/2005 15:24'!
addStats: statList
	statList do: [ :assoc |	self addStat: assoc key initializedTo: assoc value].
! !

!GmCreature methodsFor: 'initialization' stamp: 'cr 3/6/2005 19:39'!
initialize
	super initialize.
	
	stats := Dictionary new.
	brain := self brainClass for: self.
	viewRegion := GmViewRegion viewer: self.
	inventory := GmInventory new.

	self addDefaultStats.
	self addSlots.

! !

!GmCreature methodsFor: 'accessing' stamp: 'cr 3/10/2005 03:16'!
brain
	^brain
! !

!GmCreature methodsFor: 'accessing' stamp: 'cr 3/3/2005 15:16'!
brain: aBrain
	brain := aBrain! !

!GmCreature methodsFor: 'accessing' stamp: 'cr 3/6/2005 20:00'!
slots
	^slots! !

!GmCreature methodsFor: 'type tests' stamp: 'cr 1/3/2004 23:10'!
isCreature
	^true
! !

!GmCreature methodsFor: 'type tests' stamp: 'cr 4/3/2005 21:23'!
isHumanoid
	^false
! !

!GmCreature methodsFor: 'type tests' stamp: 'cr 9/22/2005 11:29'!
isUndead
	^self class isUndead
! !

!GmCreature methodsFor: 'type info' stamp: 'cr 3/5/2005 20:41'!
rootTypeName
	^#Creature! !

!GmCreature methodsFor: 'stats' stamp: 'cr 4/6/2005 00:25'!
addStatObject: stat
	stats at: stat name put: stat.



! !

!GmCreature methodsFor: 'stats' stamp: 'cr 2/13/2005 18:59'!
atStat: statName
	^(stats at: statName) value.
! !

!GmCreature methodsFor: 'stats' stamp: 'cr 2/13/2005 18:59'!
atStat: statName put: statValue
	^(stats at: statName) setValue: statValue.
! !

!GmCreature methodsFor: 'stats' stamp: 'cr 3/12/2005 03:02'!
markStatsChanged
	stats do: [ :stat | stat markChanged].
! !

!GmCreature methodsFor: 'stats' stamp: 'cr 2/13/2005 23:59'!
sortedStatList
	^stats values asSortedCollection: [ :l :r | l sortKey <= r sortKey]! !

!GmCreature methodsFor: 'stats' stamp: 'cr 2/13/2005 19:51'!
statNamed: name
	^stats at: name
! !

!GmCreature methodsFor: 'stats-dnu' stamp: 'cr 2/13/2005 20:09'!
commentReadMe
	self error: 'Don''t call this method--just read the comment.'.

	"
	About #doesNotUnderstand: and Stats
	==========================================

	For flexibility, creature statistics are are implemented as a dictionary of objects, one for
	each stat.  This lets you add new stats without modifying the class heirarchy but makes
	it difficult to write accessors to get at them.

	It's easier to write
		someMonster hitPoints + 1
	than
		(someMonster atStat: 'HitPoints') + 1

	Fortunately, through the magic of Smalltalk messages, we can get the best of both worlds.
	This class's #doesNotUnderstand: responds to certain message patterns by doing stat lookups.
	Specifically:

		1) atStat<stat-name> reads the value of the stat.  (e.g. someMonster atStatHitPoints).
		2) atStat<stat-name>: value sets the value of the stat.  (e.g. someMonster atStatHitPoints: 42).
		3) stat<stat-name> returns the stat object with that name (e.g. someMonster statHitPoints value).

	"


! !

!GmCreature methodsFor: 'stats-dnu' stamp: 'cr 2/13/2005 19:53'!
doesNotUnderstand: aMessage

	"This is here so that we can access stats as though they were instance variables.  Some rules:

		1) Stat accessors must begin with 'stat' and a capital letter (e.g. 'statStrength:').
		2) Stat accessors can be set or read, depending on the presence of the trailing colon.
	
	Missing stats fall through as invalid message sends.
	"

	| selector |

	selector := aMessage selector.
	
	selector = selector asStatName
		ifTrue: [^super doesNotUnderstand: aMessage].

	(selector beginsWith: 'atStat')
		ifTrue: [^self statAccessMsg: aMessage]
		ifFalse: [^self statObjAccessMsg: aMessage]
! !

!GmCreature methodsFor: 'stats-dnu' stamp: 'cr 2/13/2005 19:34'!
statAccessMsg: aMessage
	aMessage arguments size = 0
		ifTrue: [^self atStat: aMessage selector asStatName]
		ifFalse: [^self atStat: aMessage selector asStatName put: aMessage argument]

! !

!GmCreature methodsFor: 'stats-dnu' stamp: 'cr 2/13/2005 19:54'!
statObjAccessMsg: aMessage

	aMessage arguments isEmpty
		ifFalse: [^super doesNotUnderstand: aMessage].

	^self statNamed: aMessage selector asStatName.
! !

!GmCreature methodsFor: 'tests--capabilites' stamp: 'cr 1/3/2004 22:44'!
flies
	^false
! !

!GmCreature methodsFor: 'tests--capabilites' stamp: 'cr 1/3/2004 22:44'!
swims
	^false
! !

!GmCreature methodsFor: 'tests--capabilites' stamp: 'cr 9/23/2005 12:49'!
usesTools
	^self class usesTools
! !

!GmCreature methodsFor: 'tests--capabilites' stamp: 'cr 3/12/2005 01:44'!
walks
	^true! !

!GmCreature methodsFor: 'tests--capabilites' stamp: 'cr 4/3/2005 22:50'!
wearsArmor
	^false.

	"More specifically: can it wear humanoid armor.  I'm not going to bother with non-humanoid armor."! !

!GmCreature methodsFor: 'tests--circumstances' stamp: 'cr 2/26/2005 01:30'!
standingOnPortal
	^self featureHere isPortal! !

!GmCreature methodsFor: 'tests--stats' stamp: 'cr 9/22/2005 12:11'!
isAlive
	^self isDead not
! !

!GmCreature methodsFor: 'tests--stats' stamp: 'cr 3/9/2005 23:33'!
isDead
	^self atStatHitPoints <= 0.
! !

!GmCreature methodsFor: 'tests' stamp: 'cr 5/12/2005 13:53'!
canSeeCreatureNotMe
	^self viewRegion canSeeCreatureNot: self.
! !

!GmCreature methodsFor: 'tests' stamp: 'cr 3/10/2005 03:02'!
isPlayer
	^brain isPlayerBrain! !

!GmCreature methodsFor: 'tests' stamp: 'cr 3/12/2005 11:25'!
isWearingPants
	slots allInSlots detect: [ :item | item isPantsOfYendor] ifNone: [^false].
	^true.
! !

!GmCreature methodsFor: 'attributes' stamp: 'cr 9/19/2005 12:31'!
computedExperienceValue
	^(self statExperience levelValue * self experienceValue) // 10 max: 1
! !

!GmCreature methodsFor: 'attributes' stamp: 'cr 9/25/2005 17:58'!
computedHitBonus

	| strengthBonus dexBonus burdenedBonus |

	"These are based on Nethack's formula. The strength of 100 can't currently happen, 
	 although that may change.  Items 20 and 22 are added by me."

	strengthBonus := self statStrength occupiesWhichRangeIn: #(6 8 17 18 20 22 100) startingIndex: -2. 

	dexBonus := self statDexterity occupiesWhichRangeIn: #(4 6 8 14) startingIndex: -3.
	self atStatDexterity > 14 ifTrue: [dexBonus := self atStatDexterity - 14].

	"Nethack also adds a bonus of 1 if the player's experience < 3.  Consider adding this later."

	"This didn't come from Nethack."
	burdenedBonus := self atStatBurdened ifTrue: [-2] ifFalse: [0].

	^strengthBonus + dexBonus + burdenedBonus.! !

!GmCreature methodsFor: 'attributes' stamp: 'cr 3/11/2005 22:02'!
damageRating
	"This is the number of dice in rolling the damage rating."
	^1
! !

!GmCreature methodsFor: 'attributes' stamp: 'cr 3/10/2005 00:01'!
experienceValue
	^1.
! !

!GmCreature methodsFor: 'attributes' stamp: 'cr 4/24/2005 20:08'!
inventoryWeight
	^inventory totalWeight
! !

!GmCreature methodsFor: 'attributes' stamp: 'cr 4/3/2005 00:21'!
toHitRating
	"This is the number of dice in rolling the 'to-hit'."
	^2
! !

!GmCreature methodsFor: 'creature capabilities' stamp: 'cr 1/8/2004 21:36'!
goEast
	^self goInDirection: #East.
! !

!GmCreature methodsFor: 'creature capabilities' stamp: 'cr 1/8/2004 21:36'!
goNorth
	^self goInDirection: #North.
! !

!GmCreature methodsFor: 'creature capabilities' stamp: 'cr 1/8/2004 21:36'!
goNorthEast
	^self goInDirection: #NorthEast.
! !

!GmCreature methodsFor: 'creature capabilities' stamp: 'cr 1/8/2004 21:36'!
goNorthWest
	^self goInDirection: #NorthWest.
! !

!GmCreature methodsFor: 'creature capabilities' stamp: 'cr 1/8/2004 21:36'!
goSouth
	^self goInDirection: #South.
! !

!GmCreature methodsFor: 'creature capabilities' stamp: 'cr 1/8/2004 21:36'!
goSouthEast
	^self goInDirection: #SouthEast.
! !

!GmCreature methodsFor: 'creature capabilities' stamp: 'cr 1/8/2004 21:36'!
goSouthWest
	^self goInDirection: #SouthWest.
! !

!GmCreature methodsFor: 'creature capabilities' stamp: 'cr 1/8/2004 21:36'!
goWest
	^self goInDirection: #West.
! !

!GmCreature methodsFor: 'creature capabilities' stamp: 'cr 3/12/2005 11:20'!
invokePortal
	
	| otherPortal |
	self standingOnPortal
		ifFalse: [^GmYouSeeNoNounHere noun: 'exit'].

	"BLECH!! This should all be done in the portal code.  Ick!!"
	self featureHere isDungeonExit
		ifTrue: [^self tryToLeaveDungeon].

	otherPortal := self featureHere endPoint.
	otherPortal displaceOccupant.

	^self moveToEndpoint: otherPortal.
	

	
	! !

!GmCreature methodsFor: 'creature capabilities' stamp: 'cr 2/26/2005 01:17'!
wait
	^GmSilentSuccess new.
! !

!GmCreature methodsFor: 'creature capabilities -- player' stamp: 'cr 4/4/2005 03:55'!
interactiveDrop
	"Just like #drop: except it pops up a menu to let the user select which item to drop."
	| item |
	item := inventory allContentsOrdered 
				pickOneOr: [^GmCancelled new] withCaption: 'Drop what?' 
				ifMatches: [ :i | slots isDeploying: i] addLabel: ' (in use)'.
	^self drop: item.! !

!GmCreature methodsFor: 'creature capabilities -- player' stamp: 'cr 9/25/2005 12:49'!
interactiveInventory
	| contents |
	contents := inventory allContentsOrdered.
	contents isEmpty ifTrue: [^GmNoInventory new].

	contents pickOneOr: [] withCaption: 'Your inventory:'
				ifMatches: [ :item | self isDeploying: item] addLabel: ' (in use)'.
	^GmCancelled silent.! !

!GmCreature methodsFor: 'creature capabilities -- player' stamp: 'cr 3/7/2005 23:54'!
interactivePutOn
	| item allPutOn |
	allPutOn := slots allPutOn asIdentitySet.

	item := inventory allPutOnables
			pickOneOr: [^GmCancelled new] withCaption: 'Put on what?'
				ifMatches: [ :i | allPutOn includes: i] addLabel: ' (being worn)'.

	^self deploy: item.
! !

!GmCreature methodsFor: 'creature capabilities -- player' stamp: 'cr 3/12/2005 12:37'!
interactiveSaveAndQuit

	self isPlayer ifFalse: [^GmImpossible new].		"Probably can't happen."

	(self confirm: 'Really save and quit?')
		ifTrue: [brain game saveAndQuit].

	^GmSilentSuccess new.! !

!GmCreature methodsFor: 'creature capabilities -- player' stamp: 'cr 3/5/2005 23:08'!
interactiveTake
	"Just like #take: except it pops up a menu to let the user select which item to take."
	^self take: (self stuffHere ifChoicePickOneOr: [^GmCancelled new] withCaption: 'Pick up what?').
! !

!GmCreature methodsFor: 'creature capabilities -- player' stamp: 'cr 3/7/2005 23:29'!
interactiveTakeOff
	| item |

	item := slots allPutOn pickOneOr: [^GmCancelled new] withCaption: 'Remove what?'.
	^self undeploy: item.
! !

!GmCreature methodsFor: 'creature capabilities -- player' stamp: 'cr 3/7/2005 17:49'!
interactiveUnWear
	| item |

	"Which I name 'unwear' because I always get 'remove' and 'take off' confused."

	item := slots allWorn pickOneOr: [^GmCancelled new] withCaption: 'Take off what armor?'.
	^self undeploy: item.
! !

!GmCreature methodsFor: 'creature capabilities -- player' stamp: 'cr 3/7/2005 18:12'!
interactiveWear
	| item allWorn |
	allWorn := slots allWorn asIdentitySet.

	item := inventory allClothing
			pickOneOr: [^GmCancelled new] withCaption: 'Wear what armor?'
				ifMatches: [ :i | allWorn includes: i] addLabel: ' (being worn)'.

	^self deploy: item.
! !

!GmCreature methodsFor: 'creature capabilities -- player' stamp: 'cr 3/7/2005 14:33'!
interactiveWield
	| weapon |
	weapon := inventory allWeapons
		pickWeaponWhileHolding: slots allWielded
			withCaption: 'Wield what?'
			or: [^GmCancelled new].

	^self wield: weapon.
! !

!GmCreature methodsFor: 'creature capabilities -- non-interactive' stamp: 'cr 9/23/2005 12:43'!
attackInDirection: dirName
	| target resp |

	"To do: come up with some way of returning multiple responses (or maybe a composite response?)
	 informing the player of all of the attacks, not just the last one."

	target := map creatureAt: (self pointToThe: dirName).

	resp := GmDefaultFailure desc: 'For some reason, you are unable to attack.'.
	self attacks do: [ :attack |
		(resp := resp replaceWith: (attack applyTo: target))
			ifKilledTarget: [
				self statExperience add: target computedExperienceValue.
				^resp.
			]
	].

	^resp! !

!GmCreature methodsFor: 'creature capabilities -- non-interactive' stamp: 'cr 5/14/2005 18:01'!
deploy: aThing
	slots deploy: aThing or: [ :rsp | ^rsp].
"	self markStatsChanged."
	^GmSilentSuccess new.
! !

!GmCreature methodsFor: 'creature capabilities -- non-interactive' stamp: 'cr 5/12/2005 22:39'!
drop: aThing

	"If there's something preventing dropping (e.g. curses), that goes here."

	^self removeAndDrop: aThing or: [ :rsp | rsp].! !

!GmCreature methodsFor: 'creature capabilities -- non-interactive' stamp: 'cr 3/10/2005 23:28'!
goInDirection: dirName
	^(self map perform: ('move', dirName capitalized, ':') asSymbol with: self)
		ifSpaceOccupied: [^self attackInDirection: dirName unCapitalized asSymbol]! !

!GmCreature methodsFor: 'creature capabilities -- non-interactive' stamp: 'cr 3/5/2005 23:09'!
take: aThing
	(self stuffHere includes: aThing)
		ifFalse: [^GmYouSeeNoNounHere noun: aThing descriptionString].

	self stuffHere remove: aThing.
	^inventory insert: aThing or: [ :rsp | self stuffHere add: aThing. ^rsp].
! !

!GmCreature methodsFor: 'creature capabilities -- non-interactive' stamp: 'cr 5/14/2005 18:01'!
undeploy: aThing
	slots undeploy: aThing or: [:rsp | ^rsp].
"	self markStatsChanged."
	^GmSilentSuccess new.
! !

!GmCreature methodsFor: 'creature capabilities -- non-interactive' stamp: 'cr 4/7/2005 22:43'!
wield: weaponOrNil

	"Wield whatever weapon is given, unless it's nil in which case we go to bare hands.  Note
	 that this whole system suffers from confusion over whether or not you can wield more than
	 one weapon at a time.  Right now, the answer is no but some of the components are written to
	 allow more."

	slots allWielded do: [ :weapon | self undeploy: weapon].
	weaponOrNil
		ifNotNil: [(self deploy: weaponOrNil) ifFailure: [ :rsp | ^rsp]].
	^GmNowWielding item: weaponOrNil.
! !

!GmCreature methodsFor: 'creature communication' stamp: 'cr 3/11/2005 14:48'!
inform: aGmMessage
	self isPlayer
		ifTrue: [brain game playerMessage: aGmMessage]

	"To do: this could also go to the creature brain but the code isn't there to do anything smart with it."! !

!GmCreature methodsFor: 'creature actions' stamp: 'cr 3/11/2005 00:40'!
attacks
	^self intrinsicAttacks
! !

!GmCreature methodsFor: 'creature actions' stamp: 'cr 9/21/2005 12:43'!
intrinsicAttacks
	"These are the attacks that a creature has if it has no weapons.  If an artifact
	 grants new attacks, they would be included here."
	^self class bareIntrinsicAttackClasses collect: [ :attack | attack doer: self].! !

!GmCreature methodsFor: 'creature status changes' stamp: 'cr 5/12/2005 22:40'!
die
	"to do: work in life-saving here."

	self isPlayer
		ifTrue: [
			(brain game debugMode and: [(self confirm: 'Really die?') not])
				ifTrue: [self statHitPoints healToMax. ^self].

			brain game gameOverPlayerDied.
		].
	self dropAllItems.
	self map removeCreature: self.

		! !

!GmCreature methodsFor: 'creature status changes' stamp: 'cr 3/10/2005 00:35'!
heal
	self statHitPoints heal.
! !

!GmCreature methodsFor: 'creature status changes' stamp: 'cr 5/15/2005 23:03'!
healFully
	self statHitPoints healToMax.
! !

!GmCreature methodsFor: 'creature status changes' stamp: 'cr 5/13/2005 14:48'!
updateForGainedLevel
	self statHitPoints
		increaseMaxBy: (3 d: 4);
		add: self atStatHitPoints // 5.
	self inform: GmNewLevel new.! !

!GmCreature methodsFor: 'current square accessing' stamp: 'cr 3/5/2005 19:08'!
addToStuffHere: aThing
	self map at: self coordinates addThing: aThing.
! !

!GmCreature methodsFor: 'current square accessing' stamp: 'cr 2/26/2005 01:29'!
featureHere
	^self map featureAt: self coordinates
! !

!GmCreature methodsFor: 'current square accessing' stamp: 'cr 2/26/2005 01:31'!
stuffHere
	^self map thingsAt: self coordinates! !

!GmCreature methodsFor: 'game cycle' stamp: 'cr 3/10/2005 03:11'!
endOfTurnUpdate
	self heal.

	"Other stuff probably goes here."! !

!GmCreature methodsFor: 'position' stamp: 'cr 1/8/2004 21:36'!
coordinates
	^coordinates
! !

!GmCreature methodsFor: 'position' stamp: 'cr 1/8/2004 21:20'!
map
	^map
! !

!GmCreature methodsFor: 'position' stamp: 'cr 3/10/2005 23:27'!
pointToThe: direction
	^self coordinates + (map perform: direction asSymbol).
! !

!GmCreature methodsFor: 'position' stamp: 'cr 3/2/2005 23:26'!
yourFloor
	^map featureAt: coordinates
! !

!GmCreature methodsFor: 'position cache' stamp: 'cr 3/11/2005 14:50'!
setMap: newMap andCoords: newCoords
	"This holds the location of self in map.  This should ONLY EVER be called by a map
	 when this object is moved onto it."
	map := newMap.
	coordinates := newCoords.
! !

!GmCreature methodsFor: 'vision' stamp: 'cr 3/3/2005 23:13'!
viewRegion
	^viewRegion
! !

!GmCreature methodsFor: 'inventory' stamp: 'cr 3/12/2005 03:16'!
applyToDeployedAndSum: message
	^slots allInSlots inject: 0 into: [ :sum :item | sum + (item perform: message)]
! !

!GmCreature methodsFor: 'inventory' stamp: 'cr 9/25/2005 18:29'!
dropAllItems
	inventory allContentsOrdered do: [ :item | self removeAndDrop: item or: [self error: 'drop failed']].
! !

!GmCreature methodsFor: 'inventory' stamp: 'cr 9/25/2005 18:31'!
insert: aThing or: errorBlock

	"This is for when an outside agency silently puts something in your inventory."

	inventory insert: aThing or: [^errorBlock value].
	^GmSilentSuccess new.
	! !

!GmCreature methodsFor: 'inventory' stamp: 'cr 9/25/2005 18:30'!
insertAndDeploy: aThing or: errorBlock

"	[self map isNil] assert."

	inventory insert: aThing or: [^errorBlock value].
	(self deploy: aThing)
		ifFailure: [
			inventory remove: aThing or: [].
			^errorBlock value
		].

	! !

!GmCreature methodsFor: 'inventory' stamp: 'cr 9/25/2005 12:49'!
isDeploying: item
	^slots isDeploying: item
! !

!GmCreature methodsFor: 'inventory' stamp: 'cr 5/12/2005 22:39'!
removeAndDrop: aThing or: errorBlock
	| response |
	response := inventory remove: aThing or: [ :rsp | ^errorBlock valueMaybeWith: rsp].

	self addToStuffHere: aThing.
	self slots undeploy: aThing or: [].

	^response.
! !

!GmCreature methodsFor: 'inventory' stamp: 'cr 3/11/2005 14:33'!
totalPointValue
	^inventory allContentsOrdered inject: 0 into: [ :sum :item | sum + item pointValue]! !

!GmCreature methodsFor: 'printing' stamp: 'cr 1/9/2004 21:28'!
printOn: aStream
	super printOn: aStream.
	aStream
		nextPutAll: ' (at ';
		nextPutAll: self coordinates printString;
		nextPut: $).

! !

!GmCreature methodsFor: 'class attributes' stamp: 'cr 3/5/2005 19:58'!
brainClass
	^self class brainClass
! !

!GmCreature methodsFor: 'private-movement' stamp: 'cr 3/18/2005 21:44'!
moveToEndpoint: aPortal
	self map removeCreature: self.
	aPortal map at: aPortal coordinates putCreature: self.

	^GmSilentSuccess new.
! !

!GmCreature methodsFor: 'private-movement' stamp: 'cr 3/12/2005 12:19'!
tryToLeaveDungeon

	"To do: this should really be in the Portal code, but I don't have time right now."

	| msg |
	self isPlayer ifFalse: [^GmImpossible new].		"This should never happen."

	self isWearingPants
		ifFalse: [
			msg :=	'The stairway is blocked by a barred door.  Behind the door, a\',
					'guard says, "You heard the judge.  You''re not leaving until\',
					'you put on some pants!!"'.		
			^GmInaccessible desc: msg withCRs.
		].

	msg :=	'The guard says, "I see you finally decided to join decent society."  The door\',
			'swings open.  You are free.'.

	self inform: (GmSuccess desc: msg withCRs).
	self brain game gameOverPlayerWins.

	"This is probably never reached, but just in case..."
	^GmSilentSuccess new.
! !


!GmFeature methodsFor: 'access tests--overrides' stamp: 'cr 1/3/2004 23:01'!
allowsFlyers
	^self subclassResponsibility! !

!GmFeature methodsFor: 'access tests--overrides' stamp: 'cr 1/3/2004 10:30'!
allowsSwimmers
	^self subclassResponsibility! !

!GmFeature methodsFor: 'access tests--overrides' stamp: 'cr 1/3/2004 23:01'!
allowsWalkers
	^self subclassResponsibility! !

!GmFeature methodsFor: 'access tests--convenience' stamp: 'cr 1/3/2004 23:00'!
allowsAllAccess
	^self allowsFlyers & self allowsSwimmers & self allowsWalkers! !

!GmFeature methodsFor: 'access tests--convenience' stamp: 'cr 1/3/2004 23:01'!
allowsSomeAccess
	^self allowsFlyers | self allowsWalkers | self allowsSwimmers.! !

!GmFeature methodsFor: 'access tests--creatures' stamp: 'cr 1/3/2004 23:07'!
allowsAccessBy: aCreature
	^(self allowsSwimmers & aCreature swims) or: [self allowsFlyers & aCreature flies
			or: [self allowsWalkers & aCreature walks]]
! !

!GmFeature methodsFor: 'type tests' stamp: 'cr 1/24/2004 18:08'!
isDiggable
	^false
! !

!GmFeature methodsFor: 'type tests' stamp: 'cr 2/24/2004 01:11'!
isDoor
	^false
! !

!GmFeature methodsFor: 'type tests' stamp: 'cr 2/25/2005 00:52'!
isDownStairway
	^false! !

!GmFeature methodsFor: 'type tests' stamp: 'cr 1/24/2004 18:08'!
isDug
	^false
! !

!GmFeature methodsFor: 'type tests' stamp: 'cr 3/12/2005 11:19'!
isDungeonExit
	^false.
! !

!GmFeature methodsFor: 'type tests' stamp: 'cr 1/16/2004 00:11'!
isFloor
	^false
! !

!GmFeature methodsFor: 'type tests' stamp: 'cr 3/3/2005 23:29'!
isLit
	^false
! !

!GmFeature methodsFor: 'type tests' stamp: 'cr 2/25/2005 00:50'!
isPortal
	^false
! !

!GmFeature methodsFor: 'type tests' stamp: 'cr 5/13/2005 18:19'!
isRoomPart
	^false
! !

!GmFeature methodsFor: 'type tests' stamp: 'cr 3/2/2005 23:27'!
isTunnelFloor
	^false
! !

!GmFeature methodsFor: 'type tests' stamp: 'cr 9/28/2004 23:44'!
isUnusedSpace
	^false.
! !

!GmFeature methodsFor: 'type tests' stamp: 'cr 2/25/2005 00:52'!
isUpStairway
	^false! !

!GmFeature methodsFor: 'type tests' stamp: 'cr 2/24/2005 03:23'!
isWall
	^false.
! !

!GmFeature methodsFor: 'type info' stamp: 'cr 3/5/2005 20:42'!
rootTypeName
	^#Feature! !

!GmFeature methodsFor: 'construction tests' stamp: 'cr 10/3/2004 18:36'!
canReplaceWithDoor
	^true
! !

!GmFeature methodsFor: 'construction tests' stamp: 'cr 2/23/2005 16:27'!
canReplaceWithPortal
	^false.

	"Only floor can be replaced with a portal."! !

!GmFeature methodsFor: 'construction' stamp: 'cr 1/24/2004 18:29'!
constrDigYields
	^GmTunnelFloor.
! !

!GmFeature methodsFor: 'creature management' stamp: 'cr 3/10/2005 02:40'!
displaceOccupantOf: coord in: map

	"This is an ugly hack, but it probably won't happen so no big deal.  Basically,
	 the problem is that if a creature takes a portal and there's another creature at the
	 endpoint, it needs to be moved.  Instead of doing something reasonable like shoving
	 it out of the way, I'm just going to teleport it somewhere else in the level or, if that
	 fails, kill it."
	
	| creature |
	creature := map creatureAt: coord.
	map moveCreature: creature to: (map randomSpotFor: creature or: [creature die]).

! !

!GmFeature methodsFor: 'creature management' stamp: 'cr 3/18/2005 21:24'!
ifRoomDisplaceOccupantOf: coord in: map by: creature
	| occupant |
	occupant := map creatureAt: coord.
	coord eightNeighbors do: [ :pt |
		(map canPutCreature: occupant at: pt)
			ifTrue: [^ self displaceCreature: occupant to: pt in: map by: creature].
	].

	^GmOccupied new.
! !

!GmFeature methodsFor: 'private' stamp: 'cr 3/18/2005 21:24'!
displaceCreature: occupant to: newPos in: map by: creature
	(map moveCreature: occupant to: newPos)
		ifFailure: [self error: 'Can''t displace occupant.'].
	occupant inform: (GmDisplacedAtPortal byCreature: creature).
	^GmSilentSuccess new.
! !


!GmDoor methodsFor: 'initialization' stamp: 'cr 1/14/2004 20:53'!
initialize
	isOpen := true.
! !

!GmDoor methodsFor: 'accessing' stamp: 'cr 1/14/2004 20:54'!
isOpen
	^isOpen! !

!GmDoor methodsFor: 'access tests' stamp: 'cr 1/14/2004 20:53'!
allowsFlyers
	^self isOpen
! !

!GmDoor methodsFor: 'access tests' stamp: 'cr 1/14/2004 20:55'!
allowsSwimmers
	^false
! !

!GmDoor methodsFor: 'access tests' stamp: 'cr 1/14/2004 20:54'!
allowsWalkers
	^self isOpen
! !

!GmDoor methodsFor: 'construction tests' stamp: 'cr 1/24/2004 18:11'!
isDug
	^true! !

!GmDoor methodsFor: 'type tests' stamp: 'cr 2/24/2004 01:13'!
isDoor
	^true! !

!GmDoor methodsFor: 'type tests' stamp: 'cr 5/13/2005 18:19'!
isRoomPart
	^true! !


!GmFloor methodsFor: 'construction tests' stamp: 'cr 2/23/2005 16:28'!
canReplaceWithPortal
	^true.
! !

!GmFloor methodsFor: 'construction tests' stamp: 'cr 1/24/2004 18:08'!
isDug
	^true
! !

!GmFloor methodsFor: 'tests' stamp: 'cr 1/8/2004 22:01'!
allowsFlyers
	^true
! !

!GmFloor methodsFor: 'tests' stamp: 'cr 1/8/2004 22:01'!
allowsSwimmers
	^false
! !

!GmFloor methodsFor: 'tests' stamp: 'cr 1/8/2004 22:01'!
allowsWalkers
	^true
! !

!GmFloor methodsFor: 'type tests' stamp: 'cr 1/16/2004 00:11'!
isFloor
	^true
! !

!GmFloor methodsFor: 'type tests' stamp: 'cr 3/3/2005 23:29'!
isLit
	^true
! !

!GmFloor methodsFor: 'type tests' stamp: 'cr 5/13/2005 18:19'!
isRoomPart
	^true! !


!GmObject class methodsFor: 'instance creation' stamp: 'cr 1/2/2004 19:52'!
new
	^self basicNew initialize.
! !

!GmObject class methodsFor: 'object management stats' stamp: 'cr 3/5/2005 20:26'!
canCreateIn: aMap
	^true		"more sophisticated tests go here."
! !

!GmObject class methodsFor: 'object management stats' stamp: 'cr 3/5/2005 20:23'!
isConcrete
	^false.		"Must set to true to allow instance creation."
! !

!GmObject class methodsFor: 'object management stats' stamp: 'cr 3/5/2005 20:25'!
maxAllowed
	^nil			"unlimited."
! !


!GmCreature class methodsFor: 'stat defaults' stamp: 'cr 4/24/2005 20:14'!
initialStatValues
	"You can override any of these by overriding the method and appending the new association
	 to the result.  That is, the results are read front to back with the last definition winning."
	^{
		GmStrength		-> 1.
		GmWisdom		-> 1.
		GmIntelligence	-> 1.
		GmDexterity		-> 1.
		GmConstitution	-> 1.
		GmCharisma		-> 1.
		GmExperience	-> 1.
		GmArmorClass	-> 3.

		GmHitPoints		-> (10 + 10 atRandom).
		NhHungover	-> false.
		GmConfused		-> false.
		GmBurdened		-> false.
	}.! !

!GmCreature class methodsFor: 'class attributes' stamp: 'cr 3/5/2005 19:58'!
brainClass
	^GmGenericBrain
! !

!GmCreature class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 01:10'!
canCreateIn: aMap
	^aMap creationState level >= self minCreationLevel

! !

!GmCreature class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 01:01'!
minCreationLevel
	^0
! !

!GmCreature class methodsFor: 'type info' stamp: 'cr 9/21/2005 12:37'!
bareIntrinsicAttackClasses
	^{GmUnarmedAttack}.		"Every creature gets one by default."

! !

!GmCreature class methodsFor: 'type info' stamp: 'cr 9/22/2005 11:29'!
isUndead
	^false! !

!GmCreature class methodsFor: 'type info' stamp: 'cr 9/23/2005 12:48'!
usesTools
	^false! !


!GmDoor class methodsFor: 'ascii tiles' stamp: 'cr 3/3/2005 03:06'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $+ color: Color black name: 'door'
! !

!GmDoor class methodsFor: 'object management stats' stamp: 'cr 3/5/2005 20:29'!
isConcrete
	^true
! !


!GmFloor class methodsFor: 'ascii tiles' stamp: 'cr 3/3/2005 03:06'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $. color: Color black name: 'floor tile'
! !

!GmFloor class methodsFor: 'object management stats' stamp: 'cr 3/5/2005 20:29'!
isConcrete
	^true
! !


!GmObjectDescription methodsFor: 'initialization' stamp: 'cr 1/3/2004 20:08'!
initializeFor: mapEntry
	^self subclassResponsibility! !


!GmAsciiObjectDescription methodsFor: 'initialization' stamp: 'cr 1/3/2004 10:48'!
letter: ltr color: clr name: nm
	letter := ltr.
	color := clr.
	name := nm.

! !

!GmAsciiObjectDescription methodsFor: 'accessing' stamp: 'cr 1/3/2004 21:53'!
color
	^color
! !

!GmAsciiObjectDescription methodsFor: 'accessing' stamp: 'cr 1/2/2004 19:46'!
letter
	^letter
! !

!GmAsciiObjectDescription methodsFor: 'accessing' stamp: 'cr 1/2/2004 19:46'!
name
	^name
! !

!GmAsciiObjectDescription methodsFor: 'description' stamp: 'cr 5/24/2005 19:34'!
longDescription
	^ letter asString, ' -- ', name
! !

!GmAsciiObjectDescription methodsFor: 'junk' stamp: 'cr 3/3/2005 03:06'!
flort
        ^self class name, ' letter: ', letter printString, ' color: Color black name: ', name printString.! !


!GmObjectDescription class methodsFor: 'instance creation' stamp: 'cr 1/3/2004 20:09'!
for: mapEntry
	^self basicNew initializeFor: mapEntry
! !

!GmObjectDescription class methodsFor: 'instance creation' stamp: 'cr 1/2/2004 19:49'!
new
	^self shouldNotImplement
! !


!GmAsciiObjectDescription class methodsFor: 'instance creation' stamp: 'cr 1/3/2004 10:47'!
letter: char color: clr name: nameString
	^self basicNew letter: char color: clr name: nameString.! !


!GmPanelEntry methodsFor: 'accessing' stamp: 'cr 1/31/2005 11:37'!
message
	^message! !

!GmPanelEntry methodsFor: 'accessing' stamp: 'cr 1/31/2005 11:37'!
message: newValue
	message := newValue! !

!GmPanelEntry methodsFor: 'accessing' stamp: 'cr 1/31/2005 11:37'!
messageArgs
	^messageArgs! !

!GmPanelEntry methodsFor: 'accessing' stamp: 'cr 1/31/2005 11:37'!
messageArgs: newValue
	messageArgs := newValue! !

!GmPanelEntry methodsFor: 'accessing' stamp: 'cr 1/31/2005 11:37'!
morph
	^morph! !

!GmPanelEntry methodsFor: 'accessing' stamp: 'cr 1/31/2005 11:37'!
morph: newValue
	morph := newValue! !

!GmPanelEntry methodsFor: 'accessing' stamp: 'cr 1/31/2005 11:37'!
object
	^object! !

!GmPanelEntry methodsFor: 'accessing' stamp: 'cr 1/31/2005 11:37'!
object: newValue
	object := newValue! !

!GmPanelEntry methodsFor: 'updating' stamp: 'cr 1/31/2005 11:40'!
update
	| value |
	value := object perform: message withArguments: messageArgs.
	morph text: value asString.
! !


!GmPanelEntry class methodsFor: 'instance creation' stamp: 'cr 1/31/2005 11:38'!
on: aMorph and: gameObject sending: message withArgs: argList
	^self new
		morph: aMorph;
		object: gameObject;
		message: message;
		messageArgs: argList;
		yourself.
! !


!GmPlayerBrain methodsFor: 'accessing' stamp: 'cr 3/3/2005 14:59'!
game
	^game! !

!GmPlayerBrain methodsFor: 'accessing' stamp: 'cr 3/3/2005 14:59'!
game: newValue
	game := newValue! !

!GmPlayerBrain methodsFor: 'stimulus' stamp: 'cr 3/11/2005 14:39'!
notify: aNotification
	game playerMessage: aNotification.
! !

!GmPlayerBrain methodsFor: 'response' stamp: 'cr 3/10/2005 02:36'!
makeMove
	"no-op. The actual move gets done from the GUI."
! !

!GmPlayerBrain methodsFor: 'tests' stamp: 'cr 3/10/2005 03:02'!
isPlayerBrain
	^true
! !


!GmPortal methodsFor: 'accessing' stamp: 'cr 2/26/2005 01:39'!
coordinates
	^self map coordinatesOf: self.	"not fast"
! !

!GmPortal methodsFor: 'accessing' stamp: 'cr 2/23/2005 05:18'!
endPoint
	"Answer the value of endPoint"

	^ endPoint! !

!GmPortal methodsFor: 'accessing' stamp: 'cr 2/25/2005 01:02'!
endPoint: otherPortal
	"Set the value of endPoint.  Note that endpoints need to be two-way."

	endPoint := otherPortal.

	otherPortal endPoint == self
		ifFalse: [otherPortal endPoint: self].
! !

!GmPortal methodsFor: 'accessing' stamp: 'cr 2/25/2005 00:59'!
endPointMap
	^self endPoint map.
! !

!GmPortal methodsFor: 'accessing' stamp: 'cr 2/23/2005 16:29'!
map
	^map! !

!GmPortal methodsFor: 'accessing' stamp: 'cr 2/23/2005 16:29'!
map: newValue
	map := newValue! !

!GmPortal methodsFor: 'maps' stamp: 'cr 2/23/2005 05:23'!
destinationMap
	^endPoint
		ifNil: [nil]
		ifNotNil: [endPoint map]
! !

!GmPortal methodsFor: 'invoking' stamp: 'cr 2/27/2005 01:36'!
displaceOccupant
	| coord occupant |
	coord := self coordinates.
	occupant := map creatureAt: coord.

	occupant ifNil: [^self].

	self displaceOccupantOf: coord in: map
! !

!GmPortal methodsFor: 'type tests' stamp: 'cr 2/25/2005 00:50'!
isPortal
	^true! !

!GmPortal methodsFor: 'construction' stamp: 'cr 2/23/2005 16:17'!
endpointClass
	^self class! !

!GmPortal methodsFor: 'construction tests' stamp: 'cr 5/15/2005 20:15'!
canBeEndpointFor: aPortal
	^self endPoint isNil and: [self endpointClass == aPortal class]! !

!GmPortal methodsFor: 'construction tests' stamp: 'cr 2/23/2005 16:28'!
canReplaceWithPortal
	^false

	"Replacing a portal with another portal is a Bad Idea."
! !


!GmPortal class methodsFor: 'object management stats' stamp: 'cr 3/5/2005 20:29'!
isConcrete
	^false! !


!GmResponse methodsFor: 'flow control' stamp: 'cr 4/6/2005 00:39'!
ifCancelled: aBlock
! !

!GmResponse methodsFor: 'flow control' stamp: 'cr 4/6/2005 00:39'!
ifFailure: block
! !

!GmResponse methodsFor: 'flow control' stamp: 'cr 3/9/2005 18:48'!
ifKilledTarget: aBlock
! !

!GmResponse methodsFor: 'flow control' stamp: 'cr 3/9/2005 01:32'!
ifSpaceOccupied: aBlock
! !

!GmResponse methodsFor: 'flow control' stamp: 'cr 4/6/2005 00:39'!
ifSuccess: block
! !

!GmResponse methodsFor: 'flow control' stamp: 'cr 4/6/2005 00:39'!
ifSuccess: sBlock ifFailure: fBlock
! !

!GmResponse methodsFor: 'testing' stamp: 'cr 2/27/2005 01:50'!
isResponse
	^true! !


!GmFailure methodsFor: 'flow control' stamp: 'cr 3/6/2005 16:23'!
ifFailure: failureBlock
	^failureBlock valueMaybeWith: self.

! !

!GmFailure methodsFor: 'flow control' stamp: 'cr 1/3/2004 10:24'!
ifSuccess: successBlock
! !

!GmFailure methodsFor: 'flow control' stamp: 'cr 3/6/2005 16:23'!
ifSuccess: successBlock ifFailure: failureBlock
	^failureBlock valueMaybeWith: self
! !

!GmFailure methodsFor: 'testing' stamp: 'cr 1/3/2004 10:22'!
isStatusResponse
	^true
! !


!GmCancelled methodsFor: 'flow control' stamp: 'cr 4/6/2005 00:39'!
ifCancelled: failureBlock
	^failureBlock valueMaybeWith: self.

! !


!GmDefaultFailure methodsFor: 'message ops' stamp: 'cr 9/23/2005 12:42'!
replaceWith: aGmMessage
	^aGmMessage! !


!GmOccupied methodsFor: 'flow control' stamp: 'cr 3/9/2005 01:32'!
ifSpaceOccupied: aBlock
	^aBlock valueMaybeWith: self.
! !


!GmAlreadyUsed class methodsFor: 'instance creation' stamp: 'cr 3/7/2005 17:53'!
new
	^super desc: 'You''re already using it.'
! !


!GmCancelled class methodsFor: 'instance creation' stamp: 'cr 3/5/2005 18:15'!
new
	^self desc: 'Never mind.'
! !

!GmCancelled class methodsFor: 'instance creation' stamp: 'cr 4/6/2005 00:46'!
silent
	^self desc: ''.! !


!GmDontHave class methodsFor: 'instance creation' stamp: 'cr 3/5/2005 23:15'!
desc: aString
	^self shouldNotImplement
! !

!GmDontHave class methodsFor: 'instance creation' stamp: 'cr 3/5/2005 23:17'!
item: aThing
	^super desc: 'You do not possess ', aThing descriptionString, '.'.! !


!GmImpossible class methodsFor: 'as yet unclassified' stamp: 'cr 3/6/2005 14:40'!
new
	^self desc: 'That''s impossible.'
! !


!GmKnapsackFull class methodsFor: 'as yet unclassified' stamp: 'cr 3/5/2005 16:13'!
new
	^self desc: 'There is no room in your knapsack.'
! !


!GmMissed class methodsFor: 'instance creation' stamp: 'cr 3/9/2005 18:34'!
creature: aCreature
	^super desc: 'You fail to hit ', aCreature theDescriptionString, '.'! !


!GmNoInventory class methodsFor: 'instance creation' stamp: 'cr 3/5/2005 22:57'!
new
	^self desc: 'Your knapsack is empty.'
! !


!GmNoSlotsLeft class methodsFor: 'as yet unclassified' stamp: 'cr 3/6/2005 17:35'!
new
	^self desc: 'You have nowhere to put it.'.! !


!GmRoguelikeMapBuilder methodsFor: 'map building' stamp: 'cr 5/13/2005 23:29'!
buildMapFeatures
	self initializeMap.
	self addRoomsAndTunnels.

! !

!GmRoguelikeMapBuilder methodsFor: 'creature placement' stamp: 'cr 5/15/2005 17:01'!
randomCandidatePoint
	^(self rooms atRandom insetBy: 1) randomInternalPoint! !

!GmRoguelikeMapBuilder methodsFor: 'construction' stamp: 'cr 5/15/2005 17:03'!
addRoomsAndTunnels
	| attempts |
	self addRandomRoom.

	attempts := 0.
	[attempts < self maxRoomAttempts]
		whileTrue: [
			[	self newCorridorFrom: self rooms atRandom.
				attempts := 0.		"Reset the counter on success."
			] on: GmAttemptsExceeded do: [
				attempts := attempts + 1
			].
		].

! !

!GmRoguelikeMapBuilder methodsFor: 'construction' stamp: 'cr 1/19/2004 23:06'!
randomDirection
	^{-1@0. 1@0. 0@-1. 0@1} atRandom! !

!GmRoguelikeMapBuilder methodsFor: 'construction-rooms' stamp: 'cr 3/2/2005 14:10'!
addRandomRoom
	self addRoomAround: (map bounds insetBy: self minRoomExtent * 3) randomInternalPoint



! !

!GmRoguelikeMapBuilder methodsFor: 'construction-rooms' stamp: 'cr 2/24/2005 23:10'!
addRoomAround: aPoint
	self addRoomWithBounds: (self validRoomBoundsAround: aPoint).
! !

!GmRoguelikeMapBuilder methodsFor: 'construction-corridors' stamp: 'cr 3/2/2005 14:11'!
newCorridorFrom: startRoomRect
	| endPoint |

	endPoint := self tunnelFrom: (startRoomRect insideRect) randomInternalPoint.
	self addRoomAround: endPoint.

! !

!GmRoguelikeMapBuilder methodsFor: 'construction-corridors' stamp: 'cr 2/24/2005 22:33'!
tunnelFrom: startingPoint
	^GmTunneller digFrom: startingPoint in: map.
! !

!GmRoguelikeMapBuilder methodsFor: 'tests' stamp: 'cr 1/15/2004 23:39'!
canContainRect: aRect
	^self mapBounds containsRect: aRect
! !

!GmRoguelikeMapBuilder methodsFor: 'randomness constraints' stamp: 'cr 5/15/2005 17:03'!
maxRoomAttempts
	^30 max: (300 - (self rooms size * 30))
! !

!GmRoguelikeMapBuilder methodsFor: 'room rectangles' stamp: 'cr 10/2/2004 20:47'!
adjacentPathOn: side inRect: aRect

	| adjDoorCount |

	adjDoorCount := 0.

	aRect perform: (side, 'InsideDo:') asSymbol with: [ :pt |
		(map featureAt: pt) isFloor
			ifFalse: [adjDoorCount := 0]
			ifTrue: [
				adjDoorCount := adjDoorCount + 1.
				adjDoorCount > self maxAdjacentDoors
					ifTrue: [^true].
			].
	].

	"This is here so that things like 'senders of' can find this method."
	[nil topInsideDo: nil; bottomInsideDo: nil; leftInsideDo: nil; rightInsideDo: nil].

	^false.

! !

!GmRoguelikeMapBuilder methodsFor: 'room rectangles' stamp: 'cr 3/2/2005 15:10'!
canMakeRoomShapedBy: aRect

	(self canContainRect: aRect)
		ifFalse: [^false].

	(self hasRoomIntersecting: aRect)
		ifTrue: [^false].

	(self needWackyDoorsFor: aRect)
		ifTrue: [^false].

	^true! !

!GmRoguelikeMapBuilder methodsFor: 'room rectangles' stamp: 'cr 5/15/2005 17:01'!
hasRoomIntersecting: aRect

	self rooms do: [ :roomRect | (roomRect expanded intersects: aRect) ifTrue: [^true]].
	^false.
	! !

!GmRoguelikeMapBuilder methodsFor: 'room rectangles' stamp: 'cr 3/2/2005 13:51'!
needWackyDoorsFor: aRect

	"By 'wacky', I mean a wall made up of doors."

	"Because the tunnels are either horizontal or vertical (and NOT diagonal), we can prevent most
	 (all?) cases of door wackiness by returning true if any of the room's corners happen to occupy
	 an existing tunnel."

	aRect corners do: [ :cornerPt |
		(self map featureAt: cornerPt) isDug
			ifTrue: [^true].
	].

	^false! !

!GmRoguelikeMapBuilder methodsFor: 'room rectangles' stamp: 'cr 1/15/2004 22:40'!
roomRectAround: aPoint
	| rect |
	rect := 1@1 extent: (self randomPointBetween: self minRoomExtent and: self maxRoomExtent).
	^ rect translateBy: (self transFactorFor: rect toBeAround: aPoint).
! !

!GmRoguelikeMapBuilder methodsFor: 'room rectangles' stamp: 'cr 3/2/2005 14:11'!
transFactorFor: aRect toBeAround: aPoint
	| rangeRect |
	rangeRect := (aPoint - aRect origin) rect: (aPoint - aRect corner).

	^rangeRect randomInternalPoint max: 0@0.
! !

!GmRoguelikeMapBuilder methodsFor: 'room rectangles' stamp: 'cr 2/24/2005 23:09'!
validRoomBoundsAround: aPoint

	| rect |
	self maxSingleRoomAttempts timesRepeat: [
		(self canMakeRoomShapedBy: (rect := self roomRectAround: aPoint))
			ifTrue: [^rect].
	].

	GmAttemptsExceeded signal.
! !

!GmRoguelikeMapBuilder methodsFor: 'constants' stamp: 'cr 1/28/2004 01:32'!
maxAdjacentDoors
	^2
! !

!GmRoguelikeMapBuilder methodsFor: 'constants' stamp: 'cr 1/14/2004 21:43'!
maxRoomExtent
	^15@15.
! !

!GmRoguelikeMapBuilder methodsFor: 'constants' stamp: 'cr 2/24/2005 22:54'!
maxSingleRoomAttempts
	^30! !

!GmRoguelikeMapBuilder methodsFor: 'constants' stamp: 'cr 3/2/2005 15:09'!
minRoomDistance
	^10! !

!GmRoguelikeMapBuilder methodsFor: 'constants' stamp: 'cr 1/14/2004 21:44'!
minRoomExtent
	^4@4.
! !

!GmRoguelikeMapBuilder methodsFor: 'junk' stamp: 'cr 5/15/2005 17:01'!
isTooCloseToOtherRoom: aRect
	self rooms do: [ :room | (room within: self minRoomDistance of: aRect) ifTrue: [^true]].

	^false
! !

!GmRoguelikeMapBuilder methodsFor: 'junk' stamp: 'cr 2/24/2005 23:16'!
nilOrValidRoomBoundsAround: aPoint

	| rect |
	self maxSingleRoomAttempts timesRepeat: [
"		failedRoomAttempts := failedRoomAttempts + 1."
		(self canMakeRoomShapedBy: (rect := self roomRectAround: aPoint))
			ifTrue: [
"				failedRoomAttempts := 0."
				^rect
			].
	].

	^nil
! !

!GmRoguelikeMapBuilder methodsFor: 'junk' stamp: 'cr 1/24/2004 18:01'!
randomDirectionNot: direction
	^( {-1@0. 1@0. 0@-1. 0@1}  without: direction) atRandom! !

!GmRoguelikeMapBuilder methodsFor: 'junk' stamp: 'cr 3/2/2005 14:11'!
randomRoomCornerPointFor: originPoint
	
	| rangeOrigin rangeCorner |
	rangeOrigin := originPoint + self minRoomExtent.
	rangeCorner := (originPoint + self maxRoomExtent) min: self mapExtent.
	^(rangeOrigin corner: rangeCorner) randomInternalPoint.
! !

!GmRoguelikeMapBuilder methodsFor: 'junk' stamp: 'cr 3/2/2005 14:11'!
randomRoomOriginPoint
	^(1@1 extent: self mapExtent - self minRoomExtent) randomInternalPoint.
! !

!GmRoguelikeMapBuilder methodsFor: 'junk' stamp: 'cr 1/15/2004 21:55'!
randomRoomRect
	| origin |

	origin := self randomRoomOriginPoint.
	^origin corner: (self randomRoomCornerPointFor: origin).
! !

!GmRoguelikeMapBuilder methodsFor: 'junk' stamp: 'cr 5/15/2005 17:01'!
rectIsSuitable: rect

	(self bounds containsRect: rect)
		ifFalse: [^false].

	self rooms do: [ :roomRect | 
		(roomRect intersects: rect)
			ifTrue: [^false].
	].

	^true.
! !


!GmSilentFailure methodsFor: 'testing' stamp: 'cr 9/23/2005 13:05'!
hasUserMessage
	^false
! !

!GmSilentFailure methodsFor: 'message ops' stamp: 'cr 9/23/2005 13:18'!
talkingSpecies
	^GmFailure
! !


!GmSilentFailure class methodsFor: 'instance creation' stamp: 'cr 9/23/2005 13:05'!
new
	^self desc: ''.
! !


!GmSortedBucketCollection methodsFor: 'initialize' stamp: 'cr 5/4/2005 00:05'!
initialize
	buckets := SortedCollection new.

! !

!GmSortedBucketCollection methodsFor: 'contents' stamp: 'cr 5/4/2005 21:32'!
add: item
	(self bucketFor: item) value add: item.! !

!GmSortedBucketCollection methodsFor: 'contents' stamp: 'cr 8/5/2005 20:20'!
itemsValuedAround: cost
	| top |
	top := buckets firstIndexRejecting: [ :item | item key <= cost].
! !

!GmSortedBucketCollection methodsFor: 'private-buckets' stamp: 'cr 5/4/2005 21:32'!
bucketFor: itemInfoObj
	^buckets findBinary: [ :x | itemInfoObj itemClass baseCost - x key] 
				ifNone: [self newBucketFor: itemInfoObj].
! !

!GmSortedBucketCollection methodsFor: 'private-buckets' stamp: 'cr 5/4/2005 21:31'!
newBucketFor: itemInfoObj
	^itemInfoObj itemClass baseCost -> Set new.


! !


!GmSortedBucketCollection class methodsFor: 'instance creation' stamp: 'cr 5/4/2005 00:04'!
new
	^self basicNew initialize.
! !


!GmDownStairway methodsFor: 'type tests' stamp: 'cr 2/25/2005 00:52'!
isDownStairway
	^true
! !

!GmDownStairway methodsFor: 'construction' stamp: 'cr 2/23/2005 16:17'!
endpointClass
	^GmUpStairway! !


!GmDownStairway class methodsFor: 'ascii tiles' stamp: 'cr 3/3/2005 03:06'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $> color: Color black name: 'stairs down'
! !

!GmDownStairway class methodsFor: 'object management stats' stamp: 'cr 3/5/2005 20:30'!
isConcrete
	^true
! !


!GmStrength methodsFor: 'stat modifications' stamp: 'cr 3/12/2005 04:24'!
modifierMessage
	^#strengthMod! !


!GmStuffManager methodsFor: 'initialization' stamp: 'cr 8/5/2005 21:12'!
initialize
	super initialize.
	self fillItemInfoFrom: GmThing.! !

!GmStuffManager methodsFor: 'initialization' stamp: 'cr 5/11/2005 10:56'!
initializeItemInfo
	itemInfo := SortedCollection
					sortBlock: [ :left :right | left itemClass baseCost <= right itemClass baseCost].


! !

!GmStuffManager methodsFor: 'item generation' stamp: 'cr 9/20/2005 13:33'!
addRandomItemTo: map filtered: filterBlock ifUnable: aBlock
	| slot object point |

	slot := self pickItemForMap: map filtered: filterBlock or: [^aBlock value].
	object := slot create.
	self prepareObject: object forMap: map.

	point := map randomSpotFor: object or: [slot uncreate. ^aBlock value].
	map at: point putObject: object.


! !

!GmStuffManager methodsFor: 'item generation' stamp: 'cr 9/20/2005 15:58'!
generateItemsIn: map count: count
	| subgroups |
	subgroups := GmThing subclasses.
	(count // subgroups size) + 1
		timesRepeat: [
			subgroups do: [ :sg | self addRandomItemTo: map 
										filtered: [ :x | x itemClass inheritsFrom: sg]
										ifUnable: ["self halt."]]
		].
! !

!GmStuffManager methodsFor: 'item generation' stamp: 'cr 5/11/2005 11:49'!
pickAndCreateItemForMap: levelMap filtered: filterBlock or: errorBlock
	^(self pickItemForMap: levelMap filtered: filterBlock or: errorBlock) itemClass new.! !

!GmStuffManager methodsFor: 'item generation' stamp: 'cr 9/24/2005 21:33'!
pickItemForMap: levelMap filtered: filterBlock or: errorBlock
	| viableItems depthFraction |

	viableItems := self itemsAvailableOnMap: levelMap and: filterBlock.
	viableItems isEmpty	ifTrue: [^errorBlock value].

	depthFraction := (levelMap creationState level + self depthFudgeFactor) / self maxDepth.
	^viableItems atRandomUpToFraction: depthFraction

! !

!GmStuffManager methodsFor: 'item generation' stamp: 'cr 5/11/2005 11:29'!
pickItemForMap: levelMap or: errorBlock
	^self pickItemForMap: levelMap filtered: [ :x | true] or: errorBlock
! !

!GmStuffManager methodsFor: 'item generation' stamp: 'cr 4/3/2005 15:54'!
prepareObject: object forMap: map
	"nothing needs to be done for now."! !

!GmStuffManager methodsFor: 'item generation' stamp: 'cr 5/11/2005 11:50'!
someArmorForMonsterIn: map
	^self pickAndCreateItemForMap: map filtered: [ :ic | ic itemClass isClothing] or: [self lastDitchArmor]! !

!GmStuffManager methodsFor: 'item generation' stamp: 'cr 5/11/2005 11:50'!
someWeaponForMonsterIn: map
	^self pickAndCreateItemForMap: map filtered: [ :ic | ic itemClass isWeapon] or: [self lastDitchWeapon]! !

!GmStuffManager methodsFor: 'overrides' stamp: 'cr 9/24/2005 21:32'!
depthFudgeFactor
	"The amount by which we offset the depth to get better stuff sooner."
	^self subclassResponsibility! !

!GmStuffManager methodsFor: 'overrides' stamp: 'cr 5/11/2005 11:30'!
lastDitchArmor
	^self subclassResponsibility
! !

!GmStuffManager methodsFor: 'overrides' stamp: 'cr 5/11/2005 11:30'!
lastDitchWeapon
	^self subclassResponsibility
! !

!GmStuffManager methodsFor: 'overrides' stamp: 'cr 9/24/2005 20:23'!
maxDepth
	^self subclassResponsibility! !

!GmStuffManager methodsFor: 'overrides' stamp: 'cr 5/11/2005 10:52'!
numPartitions
	^self subclassResponsibility! !


!GmSuccess methodsFor: 'control flow' stamp: 'cr 1/3/2004 10:19'!
ifFailure: failureBlock
! !

!GmSuccess methodsFor: 'control flow' stamp: 'cr 3/6/2005 16:23'!
ifSuccess: aBlock
	^aBlock valueMaybeWith: self.

! !

!GmSuccess methodsFor: 'control flow' stamp: 'cr 3/6/2005 16:24'!
ifSuccess: aBlock ifFailure: failureBlock
	^aBlock valueMaybeWith: self
! !

!GmSuccess methodsFor: 'testing' stamp: 'cr 1/3/2004 10:25'!
isStatusResponse
	^true
! !


!GmHitTarget methodsFor: 'accessing' stamp: 'cr 3/9/2005 18:41'!
target
	^target! !

!GmHitTarget methodsFor: 'accessing' stamp: 'cr 3/9/2005 18:41'!
target: newValue
	target := newValue! !


!GmHitTarget class methodsFor: 'instance creation' stamp: 'cr 3/9/2005 23:53'!
creature: aCreature

	| verb |
	verb := (self = GmHitTarget ifTrue: ['hit '] ifFalse: ['kill ']).
	^(super desc: 'You ', verb, aCreature theDescriptionString)
 		target: aCreature;
		yourself.
! !


!GmItemDropped class methodsFor: 'instance creation' stamp: 'cr 3/5/2005 23:14'!
desc: aString
	^self shouldNotImplement! !

!GmItemDropped class methodsFor: 'instance creation' stamp: 'cr 3/5/2005 23:14'!
item: obj
	^ super desc: 'You drop ', obj descriptionString, '.'.
! !


!GmKilledTarget methodsFor: 'flow control' stamp: 'cr 3/9/2005 18:47'!
ifKilledTarget: aBlock
	^aBlock valueMaybeWith: self
! !


!GmNowWielding methodsFor: 'accessing' stamp: 'cr 4/7/2005 22:38'!
item
	"Answer the value of item"

	^ item! !

!GmNowWielding methodsFor: 'accessing' stamp: 'cr 4/7/2005 22:38'!
item: anObject
	"Set the value of item"

	item _ anObject! !


!GmNowWielding class methodsFor: 'instance creation' stamp: 'cr 4/7/2005 22:38'!
desc: str
	^self shouldNotImplement.
! !

!GmNowWielding class methodsFor: 'instance creation' stamp: 'cr 4/7/2005 22:41'!
item: weaponOrNil

	| message resp |
	message := weaponOrNil
				ifNil: ['You are now empty-handed.']
				ifNotNil: ['You wield ', weaponOrNil theDescriptionString].

	resp := super desc: message.
	resp item: resp.
	^resp.! !


!GmSilentSuccess methodsFor: 'testing' stamp: 'cr 3/18/2005 21:43'!
hasUserMessage
	^false
! !

!GmSilentSuccess methodsFor: 'message ops' stamp: 'cr 9/23/2005 13:18'!
talkingSpecies
	^GmSuccess
! !


!GmSilentSuccess class methodsFor: 'instance creation' stamp: 'cr 1/4/2004 15:27'!
new
	^self desc: ''.
! !


!GmSuccessfullyStoredItem class methodsFor: 'instance creation' stamp: 'cr 3/5/2005 23:14'!
desc: aString
	^self shouldNotImplement
! !

!GmSuccessfullyStoredItem class methodsFor: 'instance creation' stamp: 'cr 3/5/2005 23:16'!
item: obj
	^ super desc: 'You store ', obj descriptionString, ' in your knapsack.'
! !


!GmThing methodsFor: 'type tests' stamp: 'cr 4/3/2005 22:11'!
isClothing
	^self class isClothing! !

!GmThing methodsFor: 'type tests' stamp: 'cr 3/4/2005 17:43'!
isGem
	^false
! !

!GmThing methodsFor: 'type tests' stamp: 'cr 3/6/2005 17:12'!
isJewelry
	^false
! !

!GmThing methodsFor: 'type tests' stamp: 'cr 3/12/2005 05:41'!
isPantsOfYendor
	^false
! !

!GmThing methodsFor: 'type tests' stamp: 'cr 9/18/2005 14:44'!
isSilver
	^self class isSilver
! !

!GmThing methodsFor: 'type tests' stamp: 'cr 1/3/2004 23:10'!
isThing
	^true! !

!GmThing methodsFor: 'type tests' stamp: 'cr 4/3/2005 22:09'!
isWeapon
	^self class isWeapon
! !

!GmThing methodsFor: 'type info' stamp: 'cr 5/3/2005 23:49'!
cost
	^self class baseCost
! !

!GmThing methodsFor: 'type info' stamp: 'cr 5/3/2005 23:48'!
pointValue
	"The number of points possessing one adds to your final score.  By default, this is the
	 cost, although there may be cases where that'll change."
	^self cost
! !

!GmThing methodsFor: 'type info' stamp: 'cr 3/5/2005 20:42'!
rootTypeName
	^#Thing
! !

!GmThing methodsFor: 'type info' stamp: 'cr 4/24/2005 16:46'!
weight
	^self class baseWeight
! !

!GmThing methodsFor: 'slot tests' stamp: 'cr 3/6/2005 17:44'!
fitsInSlot: aSlot
	^aSlot type = self slotType.! !

!GmThing methodsFor: 'slot tests' stamp: 'cr 3/6/2005 19:48'!
isPutOnAble

	"I.e. it's jewelry, which is 'put on' instead of 'worn'.  Yes, I know this is a tortured
	 distinction.  Blame the NetHack dev team."

	^GmDeployments putOnSlotTypeNames includes: self slotType! !

!GmThing methodsFor: 'slot tests' stamp: 'cr 3/6/2005 19:46'!
isWearable
	^GmDeployments wearSlotTypeNames includes: self slotType! !

!GmThing methodsFor: 'slot tests' stamp: 'cr 3/6/2005 19:46'!
isWieldable
	^GmDeployments wieldSlotTypeNames includes: self slotType! !

!GmThing methodsFor: 'slot info' stamp: 'cr 3/6/2005 17:39'!
slotType
	^#none		"Needs to match the names in slot 'type' field."! !

!GmThing methodsFor: 'stat modifications' stamp: 'cr 3/12/2005 04:09'!
armorClassMod
	^0
! !

!GmThing methodsFor: 'stat modifications' stamp: 'cr 3/12/2005 04:18'!
charismaMod
	^0
! !

!GmThing methodsFor: 'stat modifications' stamp: 'cr 3/12/2005 04:18'!
constitutionMod
	^0
! !

!GmThing methodsFor: 'stat modifications' stamp: 'cr 3/12/2005 04:18'!
dexterityMod
	^0
! !

!GmThing methodsFor: 'stat modifications' stamp: 'cr 3/12/2005 04:18'!
intelligenceMod
	^0
! !

!GmThing methodsFor: 'stat modifications' stamp: 'cr 3/12/2005 04:18'!
strengthMod
	^0
! !

!GmThing methodsFor: 'stat modifications' stamp: 'cr 3/12/2005 04:18'!
wisdomMod
	^0
! !


!GmClothing methodsFor: 'type tests' stamp: 'cr 4/3/2005 19:05'!
isPair
	^false! !

!GmClothing methodsFor: 'utility' stamp: 'cr 4/3/2005 18:58'!
descriptionAsPair
	^'pair of ', (self className allButFirst: 2) studlyCapsToWords! !

!GmClothing methodsFor: 'description' stamp: 'cr 4/3/2005 19:07'!
descriptionString
	self isPair ifFalse: [^super descriptionString].
	^self descriptionAsPair withIndefiniteArticle
! !

!GmClothing methodsFor: 'description' stamp: 'cr 4/3/2005 19:07'!
theDescriptionString
	self isPair ifFalse: [^super descriptionString].
	^self descriptionAsPair withDefiniteArticle
! !

!GmClothing methodsFor: 'stat modifications' stamp: 'cr 4/26/2005 23:36'!
armorClassMod
	^self class baseArmorClassMod.
! !


!GmBoots methodsFor: 'slot info' stamp: 'cr 3/12/2005 04:49'!
slotType
	^#feet! !

!GmBoots methodsFor: 'type tests' stamp: 'cr 4/3/2005 19:06'!
isPair
	^true! !


!GmGem methodsFor: 'type info' stamp: 'cr 3/11/2005 14:30'!
pointValue
	^1000
! !

!GmGem methodsFor: 'type tests' stamp: 'cr 3/4/2005 17:44'!
isGem
	^true
! !


!GmGloves methodsFor: 'type tests' stamp: 'cr 4/3/2005 19:06'!
isPair
	^true! !

!GmGloves methodsFor: 'slot info' stamp: 'cr 3/12/2005 04:49'!
slotType
	^#hands! !


!GmHelmet methodsFor: 'slot info' stamp: 'cr 3/7/2005 17:28'!
slotType
	^#head
! !


!GmJewelry methodsFor: 'type tests' stamp: 'cr 3/8/2005 03:30'!
isJewelry
	^true
! !


!GmPants methodsFor: 'slot info' stamp: 'cr 3/12/2005 05:31'!
slotType
	^#lowerBody
! !

!GmPants methodsFor: 'type tests' stamp: 'cr 4/3/2005 19:06'!
isPair
	^true! !


!GmRing methodsFor: 'slot info' stamp: 'cr 3/8/2005 03:31'!
slotType
	^#finger
! !


!GmSuit methodsFor: 'slot info' stamp: 'cr 3/12/2005 04:47'!
slotType
	^#upperBody! !


!GmThing class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:00'!
canCreateIn: aMap
	^aMap creationState level >= self minCreationLevel.
! !

!GmThing class methodsFor: 'object management stats' stamp: 'cr 4/3/2005 22:11'!
isClothing
	"I.e. is it armor?  For our purposes, Clothing == Armor."
	^false
! !

!GmThing class methodsFor: 'object management stats' stamp: 'cr 4/3/2005 22:10'!
isWeapon
	^false! !

!GmThing class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:00'!
minCreationLevel
	^0
! !

!GmThing class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:10'!
baseCost
	^self subclassResponsibility
! !

!GmThing class methodsFor: 'type info' stamp: 'cr 4/24/2005 16:46'!
baseWeight
	^1

	"Weight is (very) loosely in grams."
! !

!GmThing class methodsFor: 'type info' stamp: 'cr 9/18/2005 14:44'!
isSilver
	^false! !


!GmClothing class methodsFor: 'ascii tiles' stamp: 'cr 3/7/2005 17:33'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'armor'! !

!GmClothing class methodsFor: 'object management stats' stamp: 'cr 9/21/2005 16:44'!
baseCost
	^ (50000 * self baseArmorClassMod) - (self baseWeight) max: 1.! !

!GmClothing class methodsFor: 'object management stats' stamp: 'cr 4/3/2005 22:12'!
isClothing
	^true
! !


!GmAssHat class methodsFor: 'object management stats' stamp: 'cr 3/7/2005 17:34'!
isConcrete
	^true
! !

!GmAssHat class methodsFor: 'object management stats' stamp: 'cr 5/11/2005 11:38'!
minCreationLevel
	^100		"Shouldn't ever get generated in the normal way."! !

!GmAssHat class methodsFor: 'type info' stamp: 'cr 5/12/2005 22:59'!
baseArmorClassMod
	^2
! !

!GmAssHat class methodsFor: 'type info' stamp: 'cr 4/24/2005 17:04'!
baseWeight
       ^1200

! !


!GmDragonSuit class methodsFor: 'type info' stamp: 'cr 4/24/2005 18:58'!
baseWeight
	^40000! !


!GmGem class methodsFor: 'type info' stamp: 'cr 4/24/2005 19:06'!
baseWeight
	^100! !


!GmRing class methodsFor: 'ascii tiles' stamp: 'cr 3/8/2005 03:32'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $= color: Color black name: 'ring'! !

!GmRing class methodsFor: 'type info' stamp: 'cr 5/3/2005 23:58'!
baseCost
	^600! !

!GmRing class methodsFor: 'type info' stamp: 'cr 4/24/2005 19:07'!
baseWeight
	^300! !


!GmRingOfNothing class methodsFor: 'type info' stamp: 'cr 5/3/2005 23:58'!
baseCost
	^200
! !

!GmRingOfNothing class methodsFor: 'object management stats' stamp: 'cr 3/8/2005 03:34'!
isConcrete
	^true
! !


!GmToolUser methodsFor: 'creature actions' stamp: 'cr 9/15/2005 23:04'!
attacks
	^self weaponAttacks
		ifEmpty: [self intrinsicAttacks]
! !

!GmToolUser methodsFor: 'creature actions' stamp: 'cr 9/15/2005 23:01'!
weaponAttacks
	^slots allWielded
		inject: OrderedCollection new
			into: [ :list :weapon | list addAll: (weapon attacksFrom: self); yourself].! !

!GmToolUser methodsFor: 'tests--capabilites' stamp: 'cr 3/12/2005 01:44'!
walks
	^true! !


!GmHumanoid methodsFor: 'initialization' stamp: 'cr 3/6/2005 19:40'!
addSlots
	slots := GmDeployments newForHumanoid.
! !

!GmHumanoid methodsFor: 'tests--capabilites' stamp: 'cr 1/9/2004 19:14'!
flies
	^false
! !

!GmHumanoid methodsFor: 'tests--capabilites' stamp: 'cr 1/9/2004 19:14'!
swims
	^false
! !

!GmHumanoid methodsFor: 'tests--capabilites' stamp: 'cr 1/9/2004 19:14'!
walks
	^true
! !

!GmHumanoid methodsFor: 'tests--capabilites' stamp: 'cr 4/3/2005 22:51'!
wearsArmor
	^true! !

!GmHumanoid methodsFor: 'type tests' stamp: 'cr 4/3/2005 21:23'!
isHumanoid
	^true! !


!GmToolUser class methodsFor: 'type info' stamp: 'cr 9/24/2005 21:02'!
usesTools
	^true
! !


!GmHumanoid class methodsFor: 'stat defaults' stamp: 'cr 9/21/2005 12:28'!
initialStatValues
	^super initialStatValues, {
		GmArmorClass	-> 0.
	}.! !


!GmTunnelFloor methodsFor: 'construction tests' stamp: 'cr 3/20/2005 16:30'!
canReplaceWithPortal
	^false		"No portals in the tunnels, please."! !

!GmTunnelFloor methodsFor: 'type tests' stamp: 'cr 3/3/2005 23:29'!
isLit
	^false
! !

!GmTunnelFloor methodsFor: 'type tests' stamp: 'cr 5/13/2005 18:20'!
isRoomPart
	^false
! !

!GmTunnelFloor methodsFor: 'type tests' stamp: 'cr 3/2/2005 23:27'!
isTunnelFloor
	^true
! !


!GmTunnelFloor class methodsFor: 'ascii tiles' stamp: 'cr 3/3/2005 03:06'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $# color: Color black name: 'tunnel floor'
! !


!GmTunneller methodsFor: 'initialization' stamp: 'cr 2/24/2005 22:41'!
map: newMap position: pos
	map := newMap.
	position := pos.

	hitDoor := false.
	direction := self randomDirection.
! !

!GmTunneller methodsFor: 'digging' stamp: 'cr 2/24/2005 22:34'!
digAt: coord or: quitBlock
	self eval: quitBlock unlessDiggableAt: coord.
	map at: coord putFeature: (map featureAt: coord) constrDigYields new.

! !

!GmTunneller methodsFor: 'digging' stamp: 'cr 3/2/2005 14:45'!
digStraightOr: quitBlock
	direction := self randomNewDirection.

	self segmentLength timesRepeat: [
		self digAt: position + direction or: quitBlock.
		position := position + direction.
		self evalIfAtSecondDoor: quitBlock.
	].

	^position
		
	! !

!GmTunneller methodsFor: 'digging' stamp: 'cr 3/2/2005 14:47'!
digTunnel
	(self minZigZags to: self maxZigZags) atRandom
		timesRepeat: [self digStraightOr: [^self]].
! !

!GmTunneller methodsFor: 'digging' stamp: 'cr 2/24/2005 22:34'!
eval: doneBlock unlessDiggableAt: coord
	| feature |

	(map containsPoint: coord)
		ifFalse: [^doneBlock value].

	feature := map featureAt: coord.
	(feature isDug or: [feature canReplaceWithDoor not])
		ifTrue: [^doneBlock value].


! !

!GmTunneller methodsFor: 'digging' stamp: 'cr 2/24/2004 01:26'!
evalIfAtSecondDoor: quitBlock
	"Evaluate 'quitBlock' if the current position contains a door and this is the second time
	 we've found one.

	 This makes a lot more sense if you realize that 
		1) evaluating quitBlock has the effect of ending the entire tunnelling operation and
		2) finding a second door means we've tunnelled from one room to another, an exit
		   condition.  (The first door comes from getting out of the starting room.)

	"

	(map featureAt: position) isDoor
		ifTrue: [
			hitDoor ifTrue: [^quitBlock value].
			hitDoor := true.
		].

! !

!GmTunneller methodsFor: 'digging' stamp: 'cr 2/24/2005 22:41'!
randomDirection
	^{-1@0. 1@0. 0@-1. 0@1} atRandom
! !

!GmTunneller methodsFor: 'digging' stamp: 'cr 2/24/2005 23:22'!
randomNewDirection
	direction ifNil: [^self randomDirection].
	^({-1@0. 1@0. 0@-1. 0@1} select: [ :d | d ~= direction]) atRandom
! !

!GmTunneller methodsFor: 'accessing' stamp: 'cr 2/24/2004 01:27'!
position
	^position
! !

!GmTunneller methodsFor: 'random numbers' stamp: 'cr 2/24/2004 00:53'!
segmentLength
	^(self straightSegmentMinLen to: self straightSegmentMaxLen) atRandom! !

!GmTunneller methodsFor: 'constants' stamp: 'cr 2/24/2004 00:47'!
maxZigZags
	^10.
! !

!GmTunneller methodsFor: 'constants' stamp: 'cr 3/2/2005 14:48'!
minZigZags
	^2! !

!GmTunneller methodsFor: 'constants' stamp: 'cr 3/2/2005 14:45'!
straightSegmentMaxLen
	^10! !

!GmTunneller methodsFor: 'constants' stamp: 'cr 3/2/2005 15:29'!
straightSegmentMinLen
	^8! !


!GmTunneller class methodsFor: 'digging' stamp: 'cr 2/24/2004 01:29'!
digFrom: startPoint in: map
	^self new
		map: map position: startPoint;
		digTunnel;
		position.! !


!GmTurn methodsFor: 'game access' stamp: 'cr 4/6/2005 00:21'!
game: aGame
	game := aGame! !

!GmTurn methodsFor: 'game access' stamp: 'cr 4/6/2005 00:19'!
gameTurn
	^game
		ifNil: [0]
		ifNotNil: [game turn].

	"The whole test is not really needed, but it lets me prod a new
	 instance without getting errors."! !

!GmTurn methodsFor: 'game access' stamp: 'cr 5/14/2005 17:24'!
value
	owner ifNil: [^0].

	self gameTurn == value
		ifFalse: [self basicSetValue: self gameTurn oldValue: self basicValue].

	^super value.


	! !


!GmUnarmedAttack methodsFor: 'rolls' stamp: 'cr 9/16/2005 12:08'!
damageAmount
	^doer damageRating! !


!GmAttemptsExceeded methodsFor: 'armor' stamp: 'cr 3/12/2005 04:51'!
armorEntries
^{
"base class   description           cost  AC"
{GmSuit. 'leather jacket'.             10. 1}.
{GmSuit. 'leather armor'.               5. 2}.
{GmSuit. 'orcish ring mail'.           80. 2}.
{GmSuit. 'studded leather armor'.      15. 3}.
{GmSuit. 'ring mail'.                 100. 3}.
{GmSuit. 'scale mail'.                 45. 4}.
{GmSuit. 'orcish chain mail'.          75. 4}.
{GmSuit. 'chain mail'.                 75. 5}.
{GmSuit. 'elven mithril coat'.        240. 5}.
{GmSuit. 'splint mail'.                80. 6}.
{GmSuit. 'banded mail'.                90. 6}.
{GmSuit. 'dwarvish mithril coat'.     240. 6}.
{GmSuit. 'bronze plate mail'.         400. 6}.
{GmSuit. 'plate mail'.                600. 7}.
{GmSuit. 'crystal plate mail'.        820. 7}.
{GmDragonSuit. 'red dragon scales'.         500. 3}.
{GmDragonSuit. 'white dragon scales'.       500. 3}.
{GmDragonSuit. 'orange dragon scales'.      500. 3}.
{GmDragonSuit. 'blue dragon scales'.        500. 3}.
{GmDragonSuit. 'green dragon scales'.       500. 3}.
{GmDragonSuit. 'yellow dragon scales'.      500. 3}.
{GmDragonSuit. 'black dragon scales'.       700. 3}.
{GmDragonSuit. 'silver dragon scales'.      700. 3}.
{GmDragonSuit. 'gray dragon scales'.        700. 3}.
{GmDragonSuit. 'red dragon scale mail'.     900. 9}.
{GmDragonSuit. 'white dragon scale mail'.   900. 9}.
{GmDragonSuit. 'orange dragon scale mail'.  900. 9}.
{GmDragonSuit. 'blue dragon scale mail'.    900. 9}.
{GmDragonSuit. 'green dragon scale mail'.   900. 9}.
{GmDragonSuit. 'yellow dragon scale mail'.  900. 9}.
{GmDragonSuit. 'black dragon scale mail'.  1200. 9}.
{GmDragonSuit. 'silver dragon scale mail'. 1200. 9}.
{GmDragonSuit. 'gray dragon scale mail'.   1200. 9}.
{GmHelmet. 'fedora'.                      1. 0}.
{GmHelmet. 'dunce cap'.                   1. 0}.
{GmHelmet. 'cornuthaum'.                 80. 0}.
{GmHelmet. 'dented pot'.                  8. 1}.
{GmHelmet. 'elven leather helm'.          8. 1}.
{GmHelmet. 'helmet'. 10. 1}.
{GmHelmet. 'orcish helm'.                10. 1}.
{GmHelmet. 'helm of brilliance'.         50. 1}.
{GmHelmet. 'hm of opposite alignment'.   50. 1}.
{GmHelmet. 'helm of telepathy'.          50. 1}.
{GmHelmet. 'dwarvish iron helm'.         20. 2}.
{GmGloves. 'leather gloves'.              8. 1}.
{GmBoots. 'low boots'.                   8. 1}.
{GmBoots. 'high boots'.                 12. 2}.
{GmBoots. 'iron shoes'.                 16. 2}
}.
! !


!GmUnusedSpace methodsFor: 'tests' stamp: 'cr 1/15/2004 23:57'!
allowsFlyers
	^false
! !

!GmUnusedSpace methodsFor: 'tests' stamp: 'cr 1/15/2004 23:58'!
allowsSwimmers
	^false
! !

!GmUnusedSpace methodsFor: 'tests' stamp: 'cr 1/15/2004 23:58'!
allowsWalkers
	^false
! !

!GmUnusedSpace methodsFor: 'construction tests' stamp: 'cr 1/24/2004 18:10'!
isDiggable
	^true
! !

!GmUnusedSpace methodsFor: 'type tests' stamp: 'cr 9/28/2004 23:44'!
isUnusedSpace
	^true.
! !


!GmUnusedSpace class methodsFor: 'ascii tiles' stamp: 'cr 3/3/2005 03:06'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $  color: Color black name: 'solid rock'
! !

!GmUnusedSpace class methodsFor: 'instance creation' stamp: 'cr 3/5/2005 20:30'!
isConcrete
	^true
! !


!GmUpStairway methodsFor: 'construction' stamp: 'cr 2/23/2005 16:17'!
endpointClass
	^GmDownStairway
! !

!GmUpStairway methodsFor: 'type tests' stamp: 'cr 2/25/2005 00:52'!
isUpStairway
	^true! !


!GmDungeonExit methodsFor: 'type tests' stamp: 'cr 3/12/2005 11:19'!
isDungeonExit
	^true.
! !


!GmUpStairway class methodsFor: 'ascii tiles' stamp: 'cr 3/3/2005 03:06'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $< color: Color black name: 'stairs up'
! !

!GmUpStairway class methodsFor: 'object management stats' stamp: 'cr 3/5/2005 20:30'!
isConcrete
	^true
! !


!GmViewRegion methodsFor: 'initialization' stamp: 'cr 3/3/2005 23:44'!
initialize: v
	viewer := v.

	self clearCache.
! !

!GmViewRegion methodsFor: 'updating' stamp: 'cr 5/14/2005 15:05'!
clearCache

	"In this case, there's not really a cache.  This just sets the internal state to force a full 
	 recalculation next time."
	
	viewRegion := 0@0 corner: -1@-1.		"null rectangle"
	enteredRoom := true.
! !

!GmViewRegion methodsFor: 'updating' stamp: 'cr 5/14/2005 15:39'!
update
	self stillInSameRoom
		ifTrue: [^self clearEnteredFlag].

	self setEnteredFlag.

	viewRegion := GmViewablePointSet roomPointsIn: viewer map around: viewer coordinates.

! !

!GmViewRegion methodsFor: 'visibility' stamp: 'cr 4/3/2005 19:47'!
changedVisiblePointsDo: aBlock
	(viewer map changedPoints select: [ :pt | self canSeePoint: pt]) do: aBlock.
! !

!GmViewRegion methodsFor: 'visibility' stamp: 'cr 5/14/2005 15:05'!
containsPoint: aPoint
	^viewRegion containsPoint: aPoint
! !

!GmViewRegion methodsFor: 'visibility' stamp: 'cr 3/4/2005 17:15'!
fastVisiblePointsDo: aBlock
	^self canOptimize
		ifTrue: [self changedVisiblePointsDo: aBlock]
		ifFalse: [self visiblePointsDo: aBlock]
! !

!GmViewRegion methodsFor: 'visibility' stamp: 'cr 3/2/2005 23:39'!
ifIncludes: aPoint do: aBlock
	(self containsPoint: aPoint)
		ifTrue: [^aBlock value]
		ifFalse: [^nil]

! !

!GmViewRegion methodsFor: 'visibility' stamp: 'cr 5/14/2005 15:05'!
visiblePointsDo: aBlock
	viewRegion plusWalls allInteriorPointsDo: aBlock.
! !

!GmViewRegion methodsFor: 'whole-room updates' stamp: 'cr 3/3/2005 23:46'!
clearEnteredFlag
	enteredRoom := false.
! !

!GmViewRegion methodsFor: 'whole-room updates' stamp: 'cr 3/3/2005 23:46'!
setEnteredFlag
	enteredRoom := true.
! !

!GmViewRegion methodsFor: 'tests' stamp: 'cr 3/8/2005 16:25'!
canOptimize
	^self enteredRoom not and: [self lightRadiusSmall not]! !

!GmViewRegion methodsFor: 'tests' stamp: 'cr 5/12/2005 13:52'!
canSeeCreatureNot: aCreature
	self visiblePointsDo: [ :pt |
		((viewer map creatureAt: pt) ifNil: [aCreature]) == aCreature ifFalse: [^true]].
	^false.

! !

!GmViewRegion methodsFor: 'tests' stamp: 'cr 5/14/2005 15:05'!
canSeePoint: point
	^viewRegion plusWalls containsPoint: point.! !

!GmViewRegion methodsFor: 'tests' stamp: 'cr 3/3/2005 23:47'!
enteredRoom
	^enteredRoom
! !

!GmViewRegion methodsFor: 'tests' stamp: 'cr 5/14/2005 15:05'!
lightRadiusSmall
	^viewRegion extent <= ((self darkRoomLightRadius * 2) + 1)! !

!GmViewRegion methodsFor: 'tests' stamp: 'cr 5/14/2005 15:17'!
stillInSameRoom
	"There's a bit of a kludge here: if the current viewRegion is small (the size used by
	 unlit regions), we assume that the player just entered the room.  This isn't *always*
	 true but it's adequate for our purposes.	 Modify this if that changes."

	^(viewRegion containsPointInAllRects: viewer coordinates) and: [self lightRadiusSmall not]

! !

!GmViewRegion methodsFor: 'printing' stamp: 'cr 5/14/2005 15:05'!
printOn: aStream
	super printOn: aStream.

	aStream nextPut: $(.
	viewRegion printOn: aStream.
	aStream nextPut: $).

! !

!GmViewRegion methodsFor: 'junk' stamp: 'cr 5/14/2005 15:05'!
calculateRoomRectangle
	viewRegion := GmViewablePointSet
						roomPointsIn: viewer map around: viewer coordinates.
 ! !

!GmViewRegion methodsFor: 'junk' stamp: 'cr 5/14/2005 15:05'!
createDarkRoomViewable
	| vc |
	vc := viewer coordinates.
	viewRegion := (vc - self darkRoomLightRadius corner: vc + self darkRoomLightRadius) 
						intersect: viewer map bounds.
! !

!GmViewRegion methodsFor: 'junk' stamp: 'cr 5/13/2005 18:06'!
createDoorwayViewable
	^self createLitRoomViewable.			"TODO: change this."! !

!GmViewRegion methodsFor: 'junk' stamp: 'cr 3/4/2005 16:47'!
createLitRoomViewable

	"This makes the somewhat limiting assumption that any lit room is rectangular."

	self stillInSameRoom
		ifTrue: [^self clearEnteredFlag].

	self setEnteredFlag.
	self calculateRoomRectangle.
! !

!GmViewRegion methodsFor: 'junk' stamp: 'cr 3/4/2005 17:28'!
darkRoomLightRadius
	^1@1! !

!GmViewRegion methodsFor: 'junk' stamp: 'cr 5/13/2005 18:37'!
findEdge: direction
	
	"OBSOLETE!!  REMOVE!!"

        | point map |
        point := viewer coordinates.
        map := viewer map.

        [(map featureAt: point) isRoomPart] assert.

        [(map containsPoint: point) and: [(map featureAt: point) isLit]]
                whileTrue: [point := point + direction].

        ^point.
! !

!GmViewRegion methodsFor: 'junk' stamp: 'cr 5/14/2005 15:05'!
oldCalculateRoomRectangle
	| top bottom left right |

	top		:= (self findEdge: 0@-1)	y.
	bottom 	:= (self findEdge: 0@1)	y.
	left		:= (self findEdge: -1@0)	x.
	right	:= (self findEdge: 1@0)	x.

	viewRegion := left@top corner: right@bottom.
! !


!GmViewRegion class methodsFor: 'instance creation' stamp: 'cr 3/2/2005 23:41'!
viewer: aCreature
	^self basicNew initialize: aCreature
! !


!GmViewablePointSet methodsFor: 'initialization' stamp: 'cr 5/14/2005 14:37'!
bigRect: br littleRect: lr
	bigRect := br.
	littleRect := lr.
! !

!GmViewablePointSet methodsFor: 'tests' stamp: 'cr 5/14/2005 15:16'!
containsPointInAllRects: point
	^(bigRect containsPoint: point) and: [littleRect containsPoint: point]! !

!GmViewablePointSet methodsFor: 'tests' stamp: 'cr 5/13/2005 17:58'!
isRectangle
	^false! !

!GmViewablePointSet methodsFor: 'rectangle manipulation' stamp: 'cr 5/14/2005 14:22'!
mergedRects
	^bigRect merge: littleRect.
! !

!GmViewablePointSet methodsFor: 'rectangle functions' stamp: 'cr 5/14/2005 14:49'!
allInteriorPointsDo: aBlock
	bigRect allInteriorPointsDo: aBlock.
	littleRect allInteriorPointsDo: [ :pt | (bigRect containsPoint: pt) ifFalse: [aBlock value: pt]].! !

!GmViewablePointSet methodsFor: 'rectangle functions' stamp: 'cr 5/14/2005 14:27'!
containsPoint: aPoint
	^(bigRect containsPoint: aPoint) or: [littleRect containsPoint: aPoint]
! !

!GmViewablePointSet methodsFor: 'rectangle functions' stamp: 'cr 5/14/2005 14:21'!
extent
	^self mergedRects extent.
! !

!GmViewablePointSet methodsFor: 'rectangle functions' stamp: 'cr 5/14/2005 14:47'!
plusWalls
	^GmViewablePointSet bigRect: bigRect plusWalls littleRect: littleRect plusWalls.! !

!GmViewablePointSet methodsFor: 'printing' stamp: 'cr 5/14/2005 14:54'!
printOn: aStream
	super printOn: aStream.
	aStream		nextPut: $(;
				nextPutAll: bigRect printString;
				nextPut: $,;
				nextPutAll: littleRect printString;
				nextPut: $).

! !


!GmViewablePointSet class methodsFor: 'viewable points' stamp: 'cr 5/14/2005 15:57'!
roomPointsIn: aMap around: aPoint
	^(aMap featureAt: aPoint) isDoor
		ifTrue: [self newIn: aMap around: aPoint]
"		ifTrue: [self findLitRoomRectIn: aMap around: aPoint]"
		ifFalse: [self roomRectIn: aMap around: aPoint].! !

!GmViewablePointSet class methodsFor: 'instance creation' stamp: 'cr 5/14/2005 14:42'!
bigRect: br littleRect: lr
	^self basicNew 
		bigRect: br littleRect: lr;
		yourself.

! !

!GmViewablePointSet class methodsFor: 'instance creation' stamp: 'cr 5/14/2005 14:38'!
new
	^self shouldNotImplement.

	"Use #newIn:around: instead."! !

!GmViewablePointSet class methodsFor: 'instance creation' stamp: 'cr 5/14/2005 14:42'!
newIn: aMap around: aPoint

	[(aMap featureAt: aPoint) isDoor] assert.

	^self
		bigRect: (self findLitRoomRectIn: aMap around: aPoint)
			littleRect: (self calculateDarkRoomRectIn: aMap around: aPoint)
! !

!GmViewablePointSet class methodsFor: 'constants' stamp: 'cr 5/14/2005 14:31'!
darkRoomLightRadius
	^1@1! !

!GmViewablePointSet class methodsFor: 'private' stamp: 'cr 5/14/2005 14:36'!
calculateDarkRoomRectIn: map around: viewerCoords
	^(viewerCoords - self darkRoomLightRadius corner: viewerCoords + self darkRoomLightRadius) 
						intersect: map bounds.
! !

!GmViewablePointSet class methodsFor: 'private' stamp: 'cr 5/14/2005 15:54'!
findLitRoomRectIn: aMap around: aPoint
	^aMap litAreaWithPoint: aPoint or: [self error: 'can''t find room.']! !

!GmViewablePointSet class methodsFor: 'private' stamp: 'cr 5/14/2005 15:57'!
roomRectIn: aMap around: aPoint
	^(aMap featureAt: aPoint) isLit
		ifTrue: [aMap litAreaWithPoint: aPoint or: [self error: 'can''t find room.']]
		ifFalse: [self calculateDarkRoomRectIn: aMap around: aPoint].
! !

!GmViewablePointSet class methodsFor: 'junk' stamp: 'cr 5/13/2005 18:33'!
findEdge: direction in: map around: startPoint
	| point |
	point := startPoint.
	[(map featureAt: point) isRoomPart] assert.

	[(map containsPoint: point) and: [(map featureAt: point) isRoomPart]]
		whileTrue: [point := point + direction].

	^point.
! !

!GmViewablePointSet class methodsFor: 'junk' stamp: 'cr 5/13/2005 23:39'!
oldCalculateRoomRectIn: aMap around: aPoint
	| top bottom left right |

	top		:= (self findEdge: 0@-1	in: aMap around: aPoint)	y.
	bottom 	:= (self findEdge: 0@1	in: aMap around: aPoint)	y.
	left		:= (self findEdge: -1@0	in: aMap around: aPoint)	x.
	right	:= (self findEdge: 1@0	in: aMap around: aPoint)	x.

	^(left@top corner: right@bottom) insetBy: 1.
! !


!GmWall methodsFor: 'tests' stamp: 'cr 1/14/2004 20:48'!
allowsFlyers
	^false! !

!GmWall methodsFor: 'tests' stamp: 'cr 1/14/2004 20:48'!
allowsSwimmers
	^false! !

!GmWall methodsFor: 'tests' stamp: 'cr 1/14/2004 20:48'!
allowsWalkers
	^false! !

!GmWall methodsFor: 'type tests' stamp: 'cr 5/13/2005 18:20'!
isRoomPart
	^true
! !

!GmWall methodsFor: 'wall tests' stamp: 'cr 1/21/2004 01:12'!
isCornerWall
	^false
! !

!GmWall methodsFor: 'wall tests' stamp: 'cr 1/24/2004 18:11'!
isDiggable
	^true! !

!GmWall methodsFor: 'wall tests' stamp: 'cr 2/24/2005 03:23'!
isWall
	^true! !

!GmWall methodsFor: 'construction' stamp: 'cr 1/24/2004 18:30'!
constrDigYields
	^GmDoor.
! !


!GmCornerWall methodsFor: 'wall tests' stamp: 'cr 1/21/2004 01:12'!
isCornerWall
	^true.
! !

!GmCornerWall methodsFor: 'wall tests' stamp: 'cr 10/3/2004 18:31'!
isDiggable
	^false! !

!GmCornerWall methodsFor: 'construction tests' stamp: 'cr 10/3/2004 18:34'!
canReplaceWithDoor
	^false
! !


!GmCornerWall class methodsFor: 'ascii tiles' stamp: 'cr 3/3/2005 03:06'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $= color: Color black name: 'wall'
! !

!GmCornerWall class methodsFor: 'object management stats' stamp: 'cr 3/5/2005 20:31'!
isConcrete
	^true
! !


!GmEastWestWall class methodsFor: 'ascii tiles' stamp: 'cr 3/3/2005 03:06'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $= color: Color black name: 'wall'
! !

!GmEastWestWall class methodsFor: 'object management stats' stamp: 'cr 3/5/2005 20:31'!
isConcrete
	^true
! !


!GmNorthSouthWall class methodsFor: 'object management stats' stamp: 'cr 3/5/2005 20:31'!
isConcrete
	^true
! !

!GmNorthSouthWall class methodsFor: 'ascii tiles' stamp: 'cr 3/3/2005 03:06'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $| color: Color black name: 'wall'
! !


!GmWeapon methodsFor: 'type tests' stamp: 'cr 4/3/2005 21:46'!
isSword
	^false
! !

!GmWeapon methodsFor: 'slot info' stamp: 'cr 3/6/2005 19:07'!
slotType
	^#wield
! !

!GmWeapon methodsFor: 'attacks' stamp: 'cr 9/22/2005 11:53'!
attacksFrom: wielder
	| attacks |

	attacks := OrderedCollection with: (GmWeaponAttack doer: wielder withWeapon: self).

	self isSilver
		ifTrue: [attacks add: (GmUndeadBonusAttack doer: wielder withWeapon: self)].

	^attacks! !

!GmWeapon methodsFor: 'attributes' stamp: 'cr 4/26/2005 23:58'!
damageRating
	^self class baseDamageRating! !


!GmBattleSpork methodsFor: 'attacks' stamp: 'cr 9/25/2005 19:11'!
attacksFrom: wielder
	"A battlespork has 4 prongs, so 4 attacks."
	^((1 to: 4) collect: [ :x | super attacksFrom: wielder]) flatten! !


!GmSword methodsFor: 'type tests' stamp: 'cr 4/3/2005 21:46'!
isSword
	^true! !


!GmWeapon class methodsFor: 'ascii tiles' stamp: 'cr 3/5/2005 23:39'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color red name: 'weapon'! !

!GmWeapon class methodsFor: 'object management stats' stamp: 'cr 4/3/2005 22:09'!
isWeapon
	^true! !

!GmWeapon class methodsFor: 'type info' stamp: 'cr 9/22/2005 11:49'!
baseCost
	^(self baseDamageRating - 4 max: 1) * 2000 *
		(self isSilver ifTrue: [1.2] ifFalse: [1]).! !

!GmWeapon class methodsFor: 'type info' stamp: 'cr 9/25/2005 16:21'!
baseDamageRating
	^1
! !


!GmAxe class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!GmAxe class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!GmAxe class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^3
! !

!GmAxe class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^6
! !

!GmAxe class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^60
! !


!GmBattleSpork class methodsFor: 'object management stats' stamp: 'cr 4/3/2005 21:04'!
isConcrete
	^true
! !

!GmBattleSpork class methodsFor: 'object management stats' stamp: 'cr 4/3/2005 21:05'!
minCreationLevel
	^0! !

!GmBattleSpork class methodsFor: 'ascii tiles' stamp: 'cr 4/3/2005 21:05'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'battle spork'! !

!GmBattleSpork class methodsFor: 'type info' stamp: 'cr 9/19/2005 12:03'!
baseCost
	^10000		"'cuz of the multiple attacks."! !

!GmBattleSpork class methodsFor: 'type info' stamp: 'cr 9/23/2005 23:27'!
baseDamageRating
	^3! !

!GmBattleSpork class methodsFor: 'type info' stamp: 'cr 4/24/2005 20:13'!
baseWeight
	^1000! !


!GmAluminumBaseballBat class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 10:09'!
isConcrete
	^true
! !

!GmAluminumBaseballBat class methodsFor: 'object management stats' stamp: 'cr 5/3/2005 23:40'!
minCreationLevel
	^10
! !

!GmAluminumBaseballBat class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 10:09'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color red name: 'short sword'! !

!GmAluminumBaseballBat class methodsFor: 'type info' stamp: 'cr 4/27/2005 00:02'!
baseDamageRating
	^25! !

!GmAluminumBaseballBat class methodsFor: 'type info' stamp: 'cr 4/24/2005 19:09'!
baseWeight
	^2000! !


!GmBroadsword class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!GmBroadsword class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!GmBroadsword class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^5
! !

!GmBroadsword class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^8
! !

!GmBroadsword class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^70
! !


!GmCrudeDagger class methodsFor: 'object management stats' stamp: 'cr 4/3/2005 21:06'!
isConcrete
	^true
! !

!GmCrudeDagger class methodsFor: 'object management stats' stamp: 'cr 4/3/2005 21:06'!
minCreationLevel
	^0
! !

!GmCrudeDagger class methodsFor: 'ascii tiles' stamp: 'cr 4/3/2005 21:07'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'crude dagger'! !

!GmCrudeDagger class methodsFor: 'type info' stamp: 'cr 4/27/2005 00:02'!
baseDamageRating
	^5! !

!GmCrudeDagger class methodsFor: 'type info' stamp: 'cr 4/24/2005 19:10'!
baseWeight
	^900! !


!GmLongSword class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 10:07'!
isConcrete
	^true
! !

!GmLongSword class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 10:08'!
minCreationLevel
	^7
! !

!GmLongSword class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 10:07'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color red name: 'short sword'! !

!GmLongSword class methodsFor: 'type info' stamp: 'cr 9/25/2005 16:23'!
baseDamageRating
	^9! !

!GmLongSword class methodsFor: 'type info' stamp: 'cr 4/24/2005 19:11'!
baseWeight
	^4000! !


!GmRubberBaseballBat class methodsFor: 'object management stats' stamp: 'cr 5/29/2005 19:22'!
canCreateIn: map
	^false.		"Never create this by ordinary means."! !

!GmRubberBaseballBat class methodsFor: 'object management stats' stamp: 'cr 5/11/2005 11:32'!
isConcrete
	^true
! !

!GmRubberBaseballBat class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 15:26'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color red name: 'rubber baseball bat'! !

!GmRubberBaseballBat class methodsFor: 'type info' stamp: 'cr 5/11/2005 11:33'!
baseDamageRating
	^3! !

!GmRubberBaseballBat class methodsFor: 'type info' stamp: 'cr 5/11/2005 11:32'!
baseWeight
	^2000! !


!GmShortSword class methodsFor: 'object management stats' stamp: 'cr 3/5/2005 23:29'!
isConcrete
	^true
! !

!GmShortSword class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 10:07'!
minCreationLevel
	^0
! !

!GmShortSword class methodsFor: 'ascii tiles' stamp: 'cr 3/5/2005 23:39'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color red name: 'short sword'! !

!GmShortSword class methodsFor: 'type info' stamp: 'cr 4/27/2005 00:02'!
baseDamageRating
	^10! !

!GmShortSword class methodsFor: 'type info' stamp: 'cr 4/24/2005 19:11'!
baseType
	^3000! !


!GmSilverBattleSpork class methodsFor: 'type info' stamp: 'cr 9/25/2005 19:12'!
baseDamageRating
	^4! !

!GmSilverBattleSpork class methodsFor: 'type info' stamp: 'cr 9/22/2005 11:47'!
isSilver
	^true! !


!GmWeaponAttack methodsFor: 'rolls' stamp: 'cr 9/25/2005 17:13'!
damageAmount
	^	"We start with the weapon damage."
		(self weapon damageRating max: 1)

		"An intelligent/wise fighter is better at identifying weak spots."
	+	(((self doer atStatIntelligence + self doer atStatWisdom) >= 28)
			ifTrue: [1] ifFalse: [0])
! !

!GmWeaponAttack methodsFor: 'accessing' stamp: 'cr 3/9/2005 23:31'!
weapon
	^weapon! !

!GmWeaponAttack methodsFor: 'accessing' stamp: 'cr 3/9/2005 23:31'!
weapon: newValue
	weapon := newValue! !


!GmUndeadBonusAttack methodsFor: 'notifications' stamp: 'cr 9/22/2005 12:40'!
doerHitTargetResponse
	^GmYouDoUndeadAttack creature: recipient.
! !

!GmUndeadBonusAttack methodsFor: 'notifications' stamp: 'cr 9/22/2005 12:40'!
doerKilledTargetResponse
	^GmSilverKilledUndeadTarget creature: recipient.
! !

!GmUndeadBonusAttack methodsFor: 'core protocol' stamp: 'cr 9/23/2005 13:07'!
doAction
	recipient isUndead
		ifTrue: [^super doAction].

	"Since it's a bonus attack, even doing nothing counts as a success."
	^GmSilentSuccess new.
! !


!GmWeaponAttack class methodsFor: 'instance creation' stamp: 'cr 3/9/2005 18:21'!
doer: aCreature
	self shouldNotImplement.
! !

!GmWeaponAttack class methodsFor: 'instance creation' stamp: 'cr 3/9/2005 23:33'!
doer: aCreature withWeapon: aWeapon
	^(super doer: aCreature) 
		weapon: aWeapon;
		yourself.
! !


!GmWisdom methodsFor: 'stat modifications' stamp: 'cr 3/12/2005 04:25'!
modifierMessage
	^#wisdomMod! !


!GmYouDoUndeadAttack class methodsFor: 'instance creation' stamp: 'cr 9/22/2005 12:42'!
creature: aCreature
	^self desc: aCreature theDescriptionString capitalized, ' seems to wither from the attack.'! !


!GmSilverKilledUndeadTarget class methodsFor: 'instance creation' stamp: 'cr 9/22/2005 12:42'!
creature: aCreature
	^self desc: aCreature theDescriptionString capitalized, ' shrinks to a dead,dried husk.'! !


!GmYouSee class methodsFor: 'description string creation' stamp: 'cr 4/3/2005 20:14'!
fixtureDescriptionFor: aCreature
	^aCreature featureHere isPortal
		ifTrue: ['There is ', aCreature featureHere descriptionString, ' here.']
		ifFalse: [''].	! !

!GmYouSee class methodsFor: 'description string creation' stamp: 'cr 4/3/2005 20:16'!
stuffPileDescriptionFor: aCreature

	aCreature stuffHere isEmpty ifTrue: [^''].

	aCreature stuffHere size > 6
		ifTrue: [^'There are many items here.  '].

	^'You see here: ', aCreature stuffHere objDescriptionListString, '.  '
! !

!GmYouSee class methodsFor: 'instance creation' stamp: 'cr 3/5/2005 23:42'!
desc: string
	^self shouldNotImplement.
! !

!GmYouSee class methodsFor: 'instance creation' stamp: 'cr 4/3/2005 20:08'!
recipient: aCreature
	^super desc: (self stuffPileDescriptionFor: aCreature), (self fixtureDescriptionFor: aCreature)! !


!GmYouSeeNoNounHere class methodsFor: 'instance creation' stamp: 'cr 2/26/2005 01:20'!
noun: aString
	^super desc: 'You see no ', aString, ' here.'.
! !


!Integer methodsFor: '*ObjHack-Dice' stamp: 'cr 5/29/2005 19:17'!
d: sides
	^GmDiceRoll roll: self d: sides.

	"This will make a whole lot more sense if you're familiar with the XdY notation
	 used by some games to describe dice rolling.  X is the number of dice and Y is the
	 number of size.

	 For example, rolling 5 6-sided dice is notated as 5d6 or, in Smalltalk, 5 d: 6."! !


!Morph methodsFor: 'halos and balloon help' stamp: 'cr 3/13/2005 22:03'!
addHalo: evt
	| halo prospectiveHaloClass |

	Preferences allHalosDisabled ifTrue: [^self].

	prospectiveHaloClass _ Smalltalk at: self haloClass ifAbsent: [HaloMorph].
	halo _ prospectiveHaloClass new bounds: self worldBoundsForHalo.
	halo popUpFor: self event: evt.
	^halo! !


!GmPrefabFullScreenManager methodsFor: 'initialization' stamp: 'cr 5/11/2005 12:29'!
initialize
	resizeNotification := PrefabResponse new.
	super initialize.
	self stopStepping.
	! !

!GmPrefabFullScreenManager methodsFor: 'screen filling' stamp: 'cr 3/24/2005 19:21'!
step

	| wsm |

	 "It seems that we get steps even when we don't want them."
	self owner = World ifFalse: [^self stopStepping]. 

	self extent = World extent
		ifFalse: [self bounds: World bounds].

	wsm := World submorphs.
	(wsm isEmpty not and: [wsm last == self])	"If wsm is empty, that assumes we haven't been restored yet."
		ifFalse: [World addMorphBack: self].
! !

!GmPrefabFullScreenManager methodsFor: 'screen filling' stamp: 'cr 3/13/2005 22:21'!
stepTime
	^500		"Twice a second."! !

!GmPrefabFullScreenManager methodsFor: 'events' stamp: 'cr 3/27/2005 16:20'!
handlesMouseDown: evt
	^true! !

!GmPrefabFullScreenManager methodsFor: 'API' stamp: 'cr 5/11/2005 12:28'!
extent: newExtent
	newExtent = self extent ifTrue: [^self].
	super extent: newExtent.
	resizeNotification ifNotNil: [resizeNotification invoke].
! !

!GmPrefabFullScreenManager methodsFor: 'API' stamp: 'cr 5/11/2005 12:30'!
resizeAction: blockOrSymbol
	resizeNotification action: blockOrSymbol
! !

!GmPrefabFullScreenManager methodsFor: 'API' stamp: 'cr 5/11/2005 12:30'!
resizeArgs: args
	resizeNotification args: args
! !

!GmPrefabFullScreenManager methodsFor: 'API' stamp: 'cr 5/11/2005 12:30'!
resizeTarget: target
	resizeNotification target: target! !


!NhAklys class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhAklys class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhAklys class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^3
! !

!NhAklys class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^6
! !

!NhAklys class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^15
! !


!NhAmber class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 03:53'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $* color: Color black name: 'amber'

! !

!NhAmber class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 03:53'!
isConcrete
	^true
! !

!NhAmber class methodsFor: 'type info' stamp: 'cr 5/3/2005 23:56'!
baseCost
	^1000


! !


!NhAmethyst class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 03:53'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $* color: Color black name: 'amethyst'

! !

!NhAmethyst class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 03:53'!
isConcrete
	^true
! !

!NhAmethyst class methodsFor: 'type info' stamp: 'cr 5/3/2005 23:56'!
baseCost
	^600


! !


!NhAquamarine class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 03:53'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $* color: Color black name: 'aquamarine'

! !

!NhAquamarine class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 03:53'!
isConcrete
	^true
! !

!NhAquamarine class methodsFor: 'type info' stamp: 'cr 5/3/2005 23:56'!
baseCost
	^1500


! !


!NhAthame class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhAthame class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhAthame class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^1
! !

!NhAthame class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^4
! !

!NhAthame class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^10
! !


!NhBandedMail class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'banded mail'

! !

!NhBandedMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhBandedMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^0
! !

!NhBandedMail class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^6
! !

!NhBandedMail class methodsFor: 'type info' stamp: 'cr 4/24/2005 17:27'!
baseWeight
       ^9000

! !


!NhBattleAxe class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhBattleAxe class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhBattleAxe class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^11
! !

!NhBattleAxe class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^14
! !

!NhBattleAxe class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^120
! !


!NhBestiary methodsFor: 'calculations' stamp: 'cr 9/19/2005 01:47'!
numRequiredIn: map
	"Given a map, figure out how many items are to be created here initially."
	^ map creationState isBottom
		ifTrue: [10 d: 8]
		ifFalse: [((map creationState level min: 10) d: 6) + 4].
! !

!NhBestiary methodsFor: 'map population' stamp: 'cr 4/3/2005 21:09'!
addExtraDevilBunniesTo: map
	(10 d: 4) timesRepeat: [self addItem: NhDevilBunny to: map ifUnable: []].
! !

!NhBestiary methodsFor: 'map population' stamp: 'cr 9/23/2005 13:00'!
prepareObject: creature forMap: map

	| stuffMgr |
	stuffMgr := game stuffManager.

	"We need to level each monster up to a difficult level corresponding to its depth."
	creature statExperience setLevelValue: map creationState level.

	"And we need to arm the creature with appropriate weapons and armor."
	creature usesTools
		ifTrue: [creature insertAndDeploy: (stuffMgr someWeaponForMonsterIn: map) or: []].

	creature wearsArmor
		ifTrue: [
			(1 d: 3)
				timesRepeat: [creature insertAndDeploy: (stuffMgr someArmorForMonsterIn: map) or: []].
		].! !

!NhBestiary methodsFor: 'map population' stamp: 'cr 4/3/2005 21:09'!
setupMap: aMap
	super setupMap: aMap.

	aMap creationState isBottom 		"note: add more checks if more than one branch"
		ifTrue: [self addExtraDevilBunniesTo: aMap].
! !


!NhBlackDragonScaleMail class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'black dragon scale mail'

! !

!NhBlackDragonScaleMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhBlackDragonScaleMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^12
! !

!NhBlackDragonScaleMail class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^9
! !


!NhBlackDragonScales class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'black dragon scales'

! !

!NhBlackDragonScales class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhBlackDragonScales class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^7
! !

!NhBlackDragonScales class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^3
! !


!NhBlackNagaHatchling methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhBlackNagaHatchling methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^160
! !

!NhBlackNagaHatchling methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhBlackNagaHatchling class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $N color: Color black name: 'black naga hatchling'

! !

!NhBlackNagaHatchling class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhBlackNagaHatchling class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^3
! !

!NhBlackNagaHatchling class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 8.
		GmConstitution	-> 5.
		GmExperience	-> 4.
		GmDexterity		-> 10.
	}.
! !


!NhBlade class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhBlade class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhBlade class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^0
! !

!NhBlade class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^3
! !

!NhBlade class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^10
! !


!NhBlueDragonScaleMail class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'blue dragon scale mail'

! !

!NhBlueDragonScaleMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhBlueDragonScaleMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^9
! !

!NhBlueDragonScaleMail class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^9
! !


!NhBlueDragonScales class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'blue dragon scales'

! !

!NhBlueDragonScales class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhBlueDragonScales class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^5
! !

!NhBlueDragonScales class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^3
! !


!NhBronzePlateMail class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'bronze plate mail'

! !

!NhBronzePlateMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhBronzePlateMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^4
! !

!NhBronzePlateMail class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^8
! !

!NhBronzePlateMail class methodsFor: 'type info' stamp: 'cr 4/24/2005 17:28'!
baseWeight
       ^40000

! !


!NhBugbear methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhBugbear methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^160
! !

!NhBugbear methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhBugbear class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $h color: Color black name: 'bugbear'

! !

!NhBugbear class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhBugbear class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^3
! !

!NhBugbear class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 8.
		GmConstitution	-> 6.
		GmExperience	-> 4.
		GmDexterity		-> 10.
	}.
! !


!NhChainMail class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'chain mail'

! !

!NhChainMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhChainMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^0
! !

!NhChainMail class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^5
! !

!NhChainMail class methodsFor: 'type info' stamp: 'cr 4/24/2005 17:28'!
baseWeight
       ^7500

! !


!NhClub class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhClub class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhClub class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^3
! !

!NhClub class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^6
! !

!NhClub class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^30
! !


!NhCommonHelmet class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'helmet'

! !

!NhCommonHelmet class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhCommonHelmet class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^0
! !

!NhCommonHelmet class methodsFor: 'type info' stamp: 'cr 5/12/2005 22:59'!
baseArmorClassMod
	^3
! !

!NhCommonHelmet class methodsFor: 'type info' stamp: 'cr 4/24/2005 17:24'!
baseWeight
       ^3000

! !


!NhCornuthaum methodsFor: 'stat modifications' stamp: 'cr 3/12/2005 05:28'!
intelligenceMod
	^4
! !


!NhCornuthaum class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'cornuthaum'

! !

!NhCornuthaum class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhCornuthaum class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^0
! !

!NhCornuthaum class methodsFor: 'type info' stamp: 'cr 5/12/2005 22:59'!
baseArmorClassMod
	^1
! !

!NhCornuthaum class methodsFor: 'type info' stamp: 'cr 4/24/2005 17:25'!
baseWeight
       ^400

! !


!NhCrysknife class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhCrysknife class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhCrysknife class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^7
! !

!NhCrysknife class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^10
! !

!NhCrysknife class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^20
! !


!NhCrystalPlateMail class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'crystal plate mail'

! !

!NhCrystalPlateMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhCrystalPlateMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^8
! !

!NhCrystalPlateMail class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^7
! !

!NhCrystalPlateMail class methodsFor: 'type info' stamp: 'cr 4/24/2005 17:28'!
baseWeight
       ^82000

! !


!NhDentedPot class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'dented pot'

! !

!NhDentedPot class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhDentedPot class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^0
! !

!NhDentedPot class methodsFor: 'type info' stamp: 'cr 5/12/2005 22:59'!
baseArmorClassMod
	^2
! !

!NhDentedPot class methodsFor: 'type info' stamp: 'cr 4/24/2005 17:25'!
baseWeight
       ^1000

! !


!NhDiamond class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 03:53'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $* color: Color black name: 'diamond'

! !

!NhDiamond class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 03:53'!
isConcrete
	^true
! !

!NhDiamond class methodsFor: 'type info' stamp: 'cr 5/3/2005 23:56'!
baseCost
	^4000


! !


!NhDilithiumCrystal class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 03:53'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $* color: Color black name: 'dilithium crystal'

! !

!NhDilithiumCrystal class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 03:53'!
isConcrete
	^true
! !

!NhDilithiumCrystal class methodsFor: 'type info' stamp: 'cr 5/3/2005 23:56'!
baseCost
	^4500


! !


!NhBabyBlackDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhBabyBlackDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^520
! !

!NhBabyBlackDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhBabyBlueDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhBabyBlueDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^520
! !

!NhBabyBlueDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhBabyGrayDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhBabyGrayDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^520
! !

!NhBabyGrayDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhBabyGreenDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhBabyGreenDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^520
! !

!NhBabyGreenDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhBabyOrangeDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhBabyOrangeDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^520
! !

!NhBabyOrangeDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhBabyRedDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhBabyRedDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^520
! !

!NhBabyRedDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhBabySilverDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhBabySilverDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^520
! !

!NhBabySilverDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhBabyWhiteDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhBabyWhiteDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^520
! !

!NhBabyWhiteDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhBabyYellowDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhBabyYellowDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^520
! !

!NhBabyYellowDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhDragon class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 10:39'!
initialStatValues
	^super initialStatValues,
	{
		GmArmorClass	-> 6.
	}! !


!NhBabyBlackDragon class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $D color: Color black name: 'baby black dragon'

! !

!NhBabyBlackDragon class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhBabyBlackDragon class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^12
! !

!NhBabyBlackDragon class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 17.
		GmConstitution	-> 15.
		GmExperience	-> 13.
		GmDexterity		-> 18.
	}.
! !


!NhBabyBlueDragon class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $D color: Color black name: 'baby blue dragon'

! !

!NhBabyBlueDragon class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhBabyBlueDragon class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^12
! !

!NhBabyBlueDragon class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 17.
		GmConstitution	-> 15.
		GmExperience	-> 13.
		GmDexterity		-> 18.
	}.
! !


!NhBabyGrayDragon class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $D color: Color black name: 'baby gray dragon'

! !

!NhBabyGrayDragon class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhBabyGrayDragon class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^12
! !

!NhBabyGrayDragon class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 17.
		GmConstitution	-> 15.
		GmExperience	-> 13.
		GmDexterity		-> 18.
	}.
! !


!NhBabyGreenDragon class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $D color: Color black name: 'baby green dragon'

! !

!NhBabyGreenDragon class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhBabyGreenDragon class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^12
! !

!NhBabyGreenDragon class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 17.
		GmConstitution	-> 15.
		GmExperience	-> 13.
		GmDexterity		-> 18.
	}.
! !


!NhBabyOrangeDragon class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $D color: Color black name: 'baby orange dragon'

! !

!NhBabyOrangeDragon class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhBabyOrangeDragon class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^12
! !

!NhBabyOrangeDragon class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 17.
		GmConstitution	-> 15.
		GmExperience	-> 13.
		GmDexterity		-> 18.
	}.
! !


!NhBabyRedDragon class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $D color: Color black name: 'baby red dragon'

! !

!NhBabyRedDragon class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhBabyRedDragon class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^12
! !

!NhBabyRedDragon class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 17.
		GmConstitution	-> 15.
		GmExperience	-> 13.
		GmDexterity		-> 18.
	}.
! !


!NhBabySilverDragon class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $D color: Color black name: 'baby silver dragon'

! !

!NhBabySilverDragon class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhBabySilverDragon class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^12
! !

!NhBabySilverDragon class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 17.
		GmConstitution	-> 15.
		GmExperience	-> 13.
		GmDexterity		-> 18.
	}.
! !


!NhBabyWhiteDragon class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $D color: Color black name: 'baby white dragon'

! !

!NhBabyWhiteDragon class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhBabyWhiteDragon class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^12
! !

!NhBabyWhiteDragon class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 17.
		GmConstitution	-> 15.
		GmExperience	-> 13.
		GmDexterity		-> 18.
	}.
! !


!NhBabyYellowDragon class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $D color: Color black name: 'baby yellow dragon'

! !

!NhBabyYellowDragon class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhBabyYellowDragon class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^12
! !

!NhBabyYellowDragon class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 17.
		GmConstitution	-> 15.
		GmExperience	-> 13.
		GmDexterity		-> 18.
	}.
! !


!NhDunceCap methodsFor: 'stat modifications' stamp: 'cr 5/15/2005 20:46'!
intelligenceMod
	^-4! !


!NhDunceCap class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'dunce cap'

! !

!NhDunceCap class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhDunceCap class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^0
! !

!NhDunceCap class methodsFor: 'type info' stamp: 'cr 5/12/2005 23:00'!
baseArmorClassMod
	^1
! !

!NhDunceCap class methodsFor: 'type info' stamp: 'cr 4/24/2005 17:26'!
baseWeight
       ^100

! !


!NhDungeonBuilderState methodsFor: 'initialization' stamp: 'cr 3/5/2005 19:44'!
initialize
	super initialize.
	branchName = #main.
! !

!NhDungeonBuilderState methodsFor: 'constants' stamp: 'cr 3/5/2005 19:29'!
defaultMapExtent
	^160@50
! !

!NhDungeonBuilderState methodsFor: 'constants' stamp: 'cr 3/14/2005 19:59'!
maxLevelsPerBranch
	^20! !

!NhDungeonBuilderState methodsFor: 'testing' stamp: 'cr 5/14/2005 19:12'!
isFinalLevel
	^self isBottom and: [branchNum = 1].
! !

!NhDungeonBuilderState methodsFor: 'copying' stamp: 'cr 3/5/2005 19:44'!
nextLevelOnBranch: branch

	"Insert cleverness here.  Specifically, we can use branchnum and index to figure whether
	 this is a sidebranch and if so how to deal with it.  For now, we ignore the branch number."

	^self copy
		level: level + 1;
		branch: branch;
		yourself.! !

!NhDungeonBuilderState methodsFor: 'copying-private' stamp: 'cr 3/5/2005 19:44'!
branch: branch
	branchNum := branch.
! !

!NhDungeonBuilderState methodsFor: 'map information' stamp: 'cr 3/5/2005 19:46'!
descriptionString
	^'Town Dungeon, level ', self level printString.

	"To do: return something different based on the value of branch.  This is to support side dungeons."! !

!NhDungeonBuilderState methodsFor: 'level information' stamp: 'cr 5/15/2005 22:51'!
mapGenerator
	^self isBottom
		ifTrue: [NhEndgameLevelBuilder]
		ifFalse: [GmRoguelikeMapBuilder]
! !

!NhDungeonBuilderState methodsFor: 'level information' stamp: 'cr 3/5/2005 20:07'!
outPortalsHere
	"Return the portal objects leading out of here (to new levels)."
	| result |

	self isBottom ifTrue: [^#()].

[
	result := OrderedCollection with: GmDownStairway new.

	"There are branches at levels 2 and 4."
	(level = 2 or: [level = 4])
		ifTrue: [result add: GmDownStairway new].
].

	result := {GmDownStairway new}.
	^result.
! !

!NhDungeonBuilderState methodsFor: 'level information' stamp: 'cr 3/12/2005 10:13'!
totalMapsToBeGenerated

	"This needs to be calculated in advance, since it's used for showing a progress bar."
	
	^self maxLevelsPerBranch.
! !

!NhDungeonBuilderState methodsFor: 'level customization' stamp: 'cr 3/12/2005 11:57'!
finalChangesTo: aMap

	aMap creationState isTop
		ifTrue: [aMap addPortal: GmDungeonExit new].
! !


!NhDwarf methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhDwarf methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^120
! !

!NhDwarf methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^8
! !


!NhDwarf class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $h color: Color black name: 'dwarf'

! !

!NhDwarf class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhDwarf class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^2
! !

!NhDwarf class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 7.
		GmConstitution	-> 4.
		GmExperience	-> 3.
		GmDexterity		-> 9.
	}.
! !


!NhDwarfKing methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhDwarfKing methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^280
! !

!NhDwarfKing methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhDwarfKing class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $h color: Color black name: 'dwarf king'

! !

!NhDwarfKing class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhDwarfKing class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^6
! !

!NhDwarfKing class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 11.
		GmConstitution	-> 9.
		GmExperience	-> 7.
		GmDexterity		-> 13.
	}.
! !


!NhDwarfLord methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhDwarfLord methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^200
! !

!NhDwarfLord methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhDwarfLord class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $h color: Color black name: 'dwarf lord'

! !

!NhDwarfLord class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhDwarfLord class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^4
! !

!NhDwarfLord class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 9.
		GmConstitution	-> 7.
		GmExperience	-> 5.
		GmDexterity		-> 11.
	}.
! !


!NhDwarvishIronHelm class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'dwarvish iron helm'

! !

!NhDwarvishIronHelm class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhDwarvishIronHelm class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^0
! !

!NhDwarvishIronHelm class methodsFor: 'type info' stamp: 'cr 5/12/2005 23:00'!
baseArmorClassMod
	^4
! !

!NhDwarvishIronHelm class methodsFor: 'type info' stamp: 'cr 4/24/2005 17:26'!
baseWeight
       ^2000

! !


!NhDwarvishMithrilCoat class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'dwarvish mithril coat'

! !

!NhDwarvishMithrilCoat class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhDwarvishMithrilCoat class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^2
! !

!NhDwarvishMithrilCoat class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^6
! !

!NhDwarvishMithrilCoat class methodsFor: 'type info' stamp: 'cr 4/24/2005 17:29'!
baseWeight
       ^24000

! !


!NhDwarvishShortSword class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhDwarvishShortSword class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhDwarvishShortSword class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^4
! !

!NhDwarvishShortSword class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^7
! !

!NhDwarvishShortSword class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^30
! !


!NhDwarvishSpear class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhDwarvishSpear class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhDwarvishSpear class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^5
! !

!NhDwarvishSpear class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^8
! !

!NhDwarvishSpear class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^35
! !


!NhElf methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhElf methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^440
! !

!NhElf methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^8
! !


!NhElf class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $@ color: Color black name: 'elf'

! !

!NhElf class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhElf class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^10
! !

!NhElf class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 15.
		GmConstitution	-> 12.
		GmExperience	-> 11.
		GmDexterity		-> 17.
	}.
! !


!NhElfLord methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhElfLord methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^360
! !

!NhElfLord methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhElfLord class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $@ color: Color black name: 'elf-lord'

! !

!NhElfLord class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhElfLord class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^8
! !

!NhElfLord class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 13.
		GmConstitution	-> 11.
		GmExperience	-> 9.
		GmDexterity		-> 15.
	}.
! !


!NhElvenBroadsword class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhElvenBroadsword class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhElvenBroadsword class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^7
! !

!NhElvenBroadsword class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^10
! !

!NhElvenBroadsword class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^70
! !


!NhElvenDagger class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhElvenDagger class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhElvenDagger class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^2
! !

!NhElvenDagger class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^5
! !

!NhElvenDagger class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^10
! !


!NhElvenLeatherHelm class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'elven leather helm'

! !

!NhElvenLeatherHelm class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhElvenLeatherHelm class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^0
! !

!NhElvenLeatherHelm class methodsFor: 'type info' stamp: 'cr 5/12/2005 23:00'!
baseArmorClassMod
	^3
! !

!NhElvenLeatherHelm class methodsFor: 'type info' stamp: 'cr 4/24/2005 17:09'!
baseWeight
       ^800

! !


!NhElvenMithrilCoat class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'elven mithril coat'

! !

!NhElvenMithrilCoat class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhElvenMithrilCoat class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^2
! !

!NhElvenMithrilCoat class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^5
! !

!NhElvenMithrilCoat class methodsFor: 'type info' stamp: 'cr 4/24/2005 18:53'!
baseWeight
       ^24000

! !


!NhElvenShortSword class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhElvenShortSword class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhElvenShortSword class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^5
! !

!NhElvenShortSword class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^8
! !

!NhElvenShortSword class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^30
! !


!NhElvenSpear class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhElvenSpear class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhElvenSpear class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^4
! !

!NhElvenSpear class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^7
! !

!NhElvenSpear class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^30
! !


!NhEmerald class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 03:53'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $* color: Color black name: 'emerald'

! !

!NhEmerald class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 03:53'!
isConcrete
	^true
! !

!NhEmerald class methodsFor: 'type info' stamp: 'cr 5/3/2005 23:56'!
baseCost
	^2500


! !


!NhEndgameLevelBuilder methodsFor: 'map layout' stamp: 'cr 5/16/2005 00:20'!
mapLayout
	^{
'/==================\                                               /=====================================\
|                  |                                               |                                     |                /====\
|                  |                                               |    1111111111111111111              |                |    |
|                  |                                               |    1111111111111111111              +################+    |
|                  |                                               |    1111111111111111111              |    #           |    |
|                  |                                      #########+    1111111111111111111              +######          |    |
|   11111111111    +######################                #        |    1111111111111111111              |                |    |
|   11111111111    |                     #                #        |                                     |                |    |
|   11111111111    |                     #                #        \=====================================/                |    |
|   11111111111    |                     #    /===========+=====\                   /================\                    |    |
|   11111111111    |                     #    |                 | /=========\       |                |                    |    |
|   11111111111    |        ##############    |                 | |         |       |                +##########          |    |
|                  |        #                 |                 | |         |       |                |         #          |    |
|                  |        #                 \==+==============/ |         +#######+                |         #          |    |
|                  |        #########            #                |         |       |                |         #          |    |
|   11111111111    |                #            #                |         |       \================/         #          |    |
|   11111111111    |                #            #                |         |   /=======\                      #          |    |
|   11111111111    |                #            #                |         |   |       |                      #          |    |
|   11111111111    |                #            #                |         |   |       |               /======+=====\    |    |
|   11111111111    |         /======+===\        #                |         |   |   0   +####           |            |    |    |
|   11111111111    |         |          |    /===+==============\ \=====+===/   |       |   #           |            |    |    |
|   11111111111    |         |          |    |                  |       #       |       |   #           |            |    |    |
|                  |         |          |    |                  |       #       \=======/   #           |            |    \==+=/
|                  |         |          |    |                  |  /====+=========\     /===+===\       |            |       #
|   11111111111    |         |          |    |                  |  |              |     |       |       |            |       #    ###
|   11111111111    |         |          |    \======+===========/  |              |     |       |       |            |       #    # #
|   11111111111    |         |          |           #              |              +#####+       |       \===+========/       #    # #
|   11111111111    |         |          |           #              |              |     |       |           #                #    # #
|   11111111111    |         |          |           #              |              |     |       |           #                #    # #
|   11111111111    |         |          |           #              \==============/     \=======/           #            #####    # #
|                  |         |          |           #                                                       #            #        # #
|                  |         \==+=======/    /======+=======\                 /==============\          /===+=====\      #        # #
|                  |            #            |              |                 |              |          |         |      ##########
|                  |            #            |              |                 |              +##########+         |               #
|                  |            #            |              |                 |              |          |         |        ########
|                  |            #            |              +#################+              |          |         |        #
|                  |         /==+=====\      |              |                 |              |          |         |        #
|                  |         |        |      \==============/                 |              |          |         |        #
|    1111111       |         |        |     ######### #########               \==============/          \=========/        #
|    1111111       |         |        +#### #       # #    /==+====\                                                       #
|    111<111       |         |        |   # # # ##### # ###|       |      /================================================+===\
|    1111111       |         |        |   # # # #     # # #|       |      |                                                    |
|    1111111       |         |        |   # # # ####### # #|       |      |                                                    |
|                  |         |        |   # # #         # #|       |      |                                                    |
|                  |         |        |   # ############# #|       +###   \====+===============================================/
\==================/         |        |   #               #|       |  #        #
                             |        |   #################|       |  #        #
                             |        |                    \=======/  ##########
                             \========/
'.
	NhTailorOfYendor.
	NhDevilBunny
}.! !


!NhFedora class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'fedora'

! !

!NhFedora class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhFedora class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^0
! !

!NhFedora class methodsFor: 'type info' stamp: 'cr 5/12/2005 23:00'!
baseArmorClassMod
	^1
! !

!NhFedora class methodsFor: 'type info' stamp: 'cr 4/24/2005 17:27'!
baseWeight
       ^100

! !


!NhFluorite class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 03:53'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $* color: Color black name: 'fluorite'

! !

!NhFluorite class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 03:53'!
isConcrete
	^true
! !

!NhFluorite class methodsFor: 'type info' stamp: 'cr 5/3/2005 23:56'!
baseCost
	^400


! !


!NhFlyingThing methodsFor: 'tests-capabilities' stamp: 'cr 3/12/2005 01:43'!
flies
	^true
! !

!NhFlyingThing methodsFor: 'tests-capabilities' stamp: 'cr 3/12/2005 01:43'!
swims
	^false! !

!NhFlyingThing methodsFor: 'tests-capabilities' stamp: 'cr 3/12/2005 01:43'!
walks
	^true! !


!NhBat methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhBat methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^40
! !

!NhBat methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhBat class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $B color: Color black name: 'bat'

! !

!NhBat class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhBat class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^0
! !

!NhBat class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 5.
		GmConstitution	-> 2.
		GmExperience	-> 1.
		GmDexterity		-> 7.
	}.
! !


!NhCrow methodsFor: 'attributes' stamp: 'cr 3/12/2005 02:09'!
damageRating
	^1! !

!NhCrow methodsFor: 'attributes' stamp: 'cr 3/10/2005 00:04'!
experienceValue
	^10
! !

!NhCrow methodsFor: 'attributes' stamp: 'cr 3/12/2005 00:10'!
toHitRating
	^1! !


!NhCrow class methodsFor: 'ascii tiles' stamp: 'cr 3/10/2005 03:35'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $B color: Color black name: 'crow'
! !

!NhCrow class methodsFor: 'object management stats' stamp: 'cr 3/5/2005 20:28'!
isConcrete
	^true
! !

!NhCrow class methodsFor: 'stat defaults' stamp: 'cr 3/11/2005 15:18'!
initialStatValues
	^super initialStatValues, 
	{
		GmStrength 		-> 3.
		GmWisdom		-> 1.
		GmIntelligence	-> 5.
		GmDexterity		-> 6.
		GmConstitution	-> 13.
		GmCharisma		-> 7.
		GmExperience	-> 3.
		GmArmorClass	-> 1.
	}.! !

!NhCrow class methodsFor: 'type info' stamp: 'cr 9/21/2005 12:38'!
bareIntrinsicAttackClasses
	^{GmUnarmedAttack. GmUnarmedAttack}
! !


!NhFogCloud methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhFogCloud methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^160
! !

!NhFogCloud methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhFogCloud class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $v color: Color black name: 'fog cloud'

! !

!NhFogCloud class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhFogCloud class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^3
! !

!NhFogCloud class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 8.
		GmConstitution	-> 5.
		GmExperience	-> 4.
		GmDexterity		-> 10.
	}.
! !


!NhForestCentaur methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhForestCentaur methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^240
! !

!NhForestCentaur methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhForestCentaur class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $C color: Color black name: 'forest centaur'

! !

!NhForestCentaur class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhForestCentaur class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^5
! !

!NhForestCentaur class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 10.
		GmConstitution	-> 7.
		GmExperience	-> 6.
		GmDexterity		-> 12.
	}.
! !


!NhGame methodsFor: 'initialization' stamp: 'cr 4/26/2005 00:10'!
initialize

	debugMode := false.
	turn := 1.

	self initializeStateManagers.
	self initializePlayer.
	self initializeMap.
	self initializeView.
! !

!NhGame methodsFor: 'init-overridable' stamp: 'cr 4/3/2005 18:37'!
initializeMap

	| builder |
	builder := GmDungeonBuilder 
				inGame: self withState: NhDungeonBuilderState new 
					genManagers: {creatureManager. stuffManager}.

	dungeon := 	builder	buildDungeon;
					dungeon.

	dungeon placeCreature: self player.
	
	self player addToStuffHere: GmBattleSpork new.! !

!NhGame methodsFor: 'init-overridable' stamp: 'cr 4/26/2005 00:05'!
initializePlayer
	| brain turnStat |
	player := creatureManager createPlayer.
	brain := GmPlayerBrain for: player.
	player brain: brain.
	brain game: self.

	turnStat := GmTurn on: player value: 0.
	turnStat game: self.
	player addStatObject: turnStat.
! !

!NhGame methodsFor: 'init-overridable' stamp: 'cr 4/3/2005 21:09'!
initializeStateManagers
	creatureManager := NhBestiary on: self.
	stuffManager := NhStuffManager on: self.
! !

!NhGame methodsFor: 'init-overridable' stamp: 'cr 1/21/2005 19:42'!
initializeView
	view := SimpleGUI on: self.
! !

!NhGame methodsFor: 'starting' stamp: 'cr 4/3/2005 18:48'!
go
	view openInWorld.
	view manager owner 
		extent: World extent // 2;
		position: World extent // 3.
	self displayWelcomeMessage.
	self showPlayerSquareContents.! !

!NhGame methodsFor: 'starting' stamp: 'cr 5/14/2005 15:20'!
goDebug
	self go.
	debugMode := true.
! !

!NhGame methodsFor: 'starting' stamp: 'cr 4/3/2005 18:48'!
showPlayerSquareContents
	
	"This only ever needs to be called when the game starts up.  Usually, the
	 GmYouSee gets returned as part of a move."

	self player inform: (GmYouSee recipient: self player).! !

!NhGame methodsFor: 'starting' stamp: 'cr 4/3/2005 18:48'!
startFullScreen
	view openInWholeWorld.
	World color: view manager color.
	self displayWelcomeMessage.
	self showPlayerSquareContents.
	view updateView.
! !

!NhGame methodsFor: 'accessing' stamp: 'cr 3/11/2005 13:57'!
debugMode
	^debugMode
! !

!NhGame methodsFor: 'accessing' stamp: 'cr 3/11/2005 13:57'!
debugMode: aBoolean
	debugMode := aBoolean.
! !

!NhGame methodsFor: 'accessing' stamp: 'cr 3/20/2005 18:45'!
dungeon
	^dungeon! !

!NhGame methodsFor: 'accessing' stamp: 'cr 3/20/2005 18:45'!
map
	^player map
! !

!NhGame methodsFor: 'accessing' stamp: 'cr 1/9/2004 19:27'!
player
	^player
! !

!NhGame methodsFor: 'accessing' stamp: 'cr 4/3/2005 21:34'!
stuffManager
	^stuffManager! !

!NhGame methodsFor: 'accessing' stamp: 'cr 4/6/2005 00:15'!
turn
	^turn! !

!NhGame methodsFor: 'accessing' stamp: 'cr 1/8/2004 22:46'!
view
	^view
! !

!NhGame methodsFor: 'player action' stamp: 'cr 3/11/2005 14:59'!
creaturesMove
	mapThisTurn shuffledNonPlayerCreatures
		do: [ :creature | creature isDead ifFalse: [creature brain makeMove]]
! !

!NhGame methodsFor: 'player action' stamp: 'cr 4/3/2005 18:46'!
displayWelcomeMessage

	| msg |
	msg :=	'Welcome to Quest For Pants, version ', self versionString, '\',
			'Copyright (C) 1996-2005 Chris Reuter and others.\',
			'(See the file Copyright.txt for details).\',
			'This program is distributed in the hope that it will be useful,\',
			'but WITHOUT ANY WARRANTY; without even the implied warranty\',
			'of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.'.

	view message: msg withCRs.

! !

!NhGame methodsFor: 'player action' stamp: 'cr 4/6/2005 00:10'!
incrementTurn
	turn := turn + 1.! !

!NhGame methodsFor: 'player action' stamp: 'cr 3/3/2005 15:07'!
playerMessage: aNotification
	aNotification hasUserMessage
		ifTrue: [view message: aNotification humanDesc].
! !

!NhGame methodsFor: 'player action' stamp: 'cr 4/6/2005 00:43'!
playerMove: eventSymbol
	^(self player perform: eventSymbol)
		ifHasUserMessage: [ :response | 
			view message: response humanDesc.
			response
		].


! !

!NhGame methodsFor: 'player action' stamp: 'cr 3/11/2005 15:00'!
updateCreatures
	mapThisTurn allCreatures do: [ :creature | creature endOfTurnUpdate].
! !

!NhGame methodsFor: 'player action' stamp: 'cr 3/11/2005 15:11'!
updateMapThisTurn
	mapThisTurn := player map.

	"If the player dies as a result of its first move, this will still be nil, so we set it to the top
	 of the dungeon so that the rest of the turn plays out correctly."
	mapThisTurn ifNil: [mapThisTurn := dungeon].! !

!NhGame methodsFor: 'player action' stamp: 'cr 3/11/2005 15:00'!
updateVisuals
	self view updateView.
	mapThisTurn clearChangedPoints.! !

!NhGame methodsFor: 'player action' stamp: 'cr 4/6/2005 00:43'!
userEvent: eventSymbol
	(self playerMove: eventSymbol) ifCancelled: [^self].
	self updateMapThisTurn.
	self creaturesMove.

	player isDead ifTrue: [^self].

	self updateCreatures.
	self updateVisuals.
	self incrementTurn.! !

!NhGame methodsFor: 'player action-waiting' stamp: 'cr 9/25/2005 13:36'!
interactiveWaitUntilHealed
	| response |
	(self isSafeToWait not)
		ifTrue: [^self].

	response := FillInTheBlank request: 'Rest for how long? (0 means until healed.)' 
								initialAnswer: '200'.

	response := response asInteger.
	response isNil ifTrue: [^self].

	^self waitUntilHealedOrDisturbedFor: response.
! !

!NhGame methodsFor: 'player action-waiting' stamp: 'cr 5/12/2005 14:08'!
isSafeToWait
	^self notSafeToWait not! !

!NhGame methodsFor: 'player action-waiting' stamp: 'cr 5/12/2005 14:08'!
notSafeToWait
	^player statHitPoints isAtMaximum or: [player canSeeCreatureNotMe]! !

!NhGame methodsFor: 'player action-waiting' stamp: 'cr 9/25/2005 13:40'!
waitUntilHealedOrDisturbedFor: initialCount
	| updateCount count |

	"Since asInteger seems to have problems with negative numbers, we need to treat zero as
	 meaning forever.  This complicates things a bit."
	count := initialCount.
	count = 0 ifTrue: [count := -1].

	updateCount := 0.
	[count ~= 0 and: [self isSafeToWait]]
		whileTrue: [
			self userEvent: #wait.
			updateCount \\ 20 == 0 ifTrue: [World displayWorld].
			updateCount := updateCount + 1.
			count := count - 1.
		].
! !

!NhGame methodsFor: 'end of game' stamp: 'cr 4/10/2005 13:57'!
deleteImageUnlessDevelopment
	self class isDevelopmentImage
		ifTrue: [
			Transcript nextPutAll: 'Refusing to delete current image.'; cr; endEntry.
			^self.
		].

	FileDirectory deleteFilePath: Smalltalk imageName
! !

!NhGame methodsFor: 'end of game' stamp: 'cr 4/3/2005 23:36'!
gameOverPlayerDied

	self updateVisuals.

	(self finalMessage findTokens: String cr) do: [ :line | view message: line].
	self inform: 'You have ', player totalPointValue printString, ' points.'.

	self quitGame.! !

!NhGame methodsFor: 'end of game' stamp: 'cr 3/24/2005 22:43'!
gameOverPlayerWins
	self
		inform: ('Congratulations.  You left the dungeon with ', player totalPointValue printString, 
				' points.\(That''s enough to fund a pretty impressive pub crawl.)') withCRs.
	self quitGame.
! !

!NhGame methodsFor: 'end of game' stamp: 'cr 4/10/2005 14:10'!
quitGame
	view close.
	self deleteImageUnlessDevelopment.
	self class quitUnlessDevelopment.
! !

!NhGame methodsFor: 'debug utils' stamp: 'cr 3/12/2005 12:16'!
createPants
	player addToStuffHere: (NhPantsOfYendor new).		"Yes, this creates duplicate pants."
! !

!NhGame methodsFor: 'debug utils' stamp: 'cr 4/4/2005 23:04'!
debugIfRequested
	"If the image name has been changed to the sooper sekret magic word, pop open
	 an inspector on the game."

	(Smalltalk imageName endsWith: 'wizardmode.image')
		ifTrue: [self inspect].
! !

!NhGame methodsFor: 'debug utils' stamp: 'cr 5/15/2005 23:38'!
downAndMap
	| stairsCoords |
	stairsCoords := (player map selectPoints: 
				[ :pt | (player map featureAt: pt) isKindOf: GmDownStairway]) first.

	(player map moveCreature: player to: stairsCoords)
		ifFailure: [ :rsp | ^rsp].

	player invokePortal.

"	self magicMap."		"Mapping is a bit broken so it's disabled for now."
	self player markStatsChanged.

	^GmSilentSuccess new.
! !

!NhGame methodsFor: 'debug utils' stamp: 'cr 9/25/2005 18:33'!
goToEndgame
	"Equip the player for the endgame, place him/her at level 19 and clear that level."


	self addStats: {
		GmArmorClass -> 0.
		GmCharisma -> 10.
		GmConfused -> false.
		GmDungeonLevel -> 19.
		GmBurdened -> false.
		NhHungover -> false.
		GmStrength -> 11.
		GmIntelligence -> 8.
		GmDexterity -> 10.
		GmWisdom -> 11.
		GmConstitution -> 10.
		GmExperience -> 141540.
		GmTurn -> 23478.
		GmHitPoints -> 114.
	}.


	{	
		NhRingOfStudliness new.
		NhRingOfStudliness new.
		NhDwarvishIronHelm new.
		GmAluminumBaseballBat new.
		NhLeatherGloves new.
		NhSilverDragonScaleMail new.
	} do: [ :item | player insertAndDeploy: item or: []].

	{	GmSilverBattleSpork new.
		NhRingOfStrength new.
		NhRingOfStrength new.
		GmBattleSpork new.
		NhHighBoots new.
		NhElvenShortSword new.
		NhRingOfConstitution new.
		NhRingOfConstitution new.
	} do: [ :item | player insert: item].

	[player map level >= 19] whileFalse: [self downAndMap].
	self killAllCreaturesOnLevel.

	player markStatsChanged.

! !

!NhGame methodsFor: 'debug utils' stamp: 'cr 9/25/2005 18:33'!
killAllCreaturesOnLevel
	player map allCreatures do: [ :creature | creature atStatHitPoints put: 0].! !

!NhGame methodsFor: 'debug utils' stamp: 'cr 3/3/2005 15:29'!
magicMap
	view updateAllPoints.
! !

!NhGame methodsFor: 'debug utils' stamp: 'cr 9/20/2005 13:03'!
neighbouringCreatures
	^player map allCreatures asArray
		select: [ :creature | creature ~= player 
					and: [(creature coordinates - player coordinates) abs <= (1@1)]]! !

!NhGame methodsFor: 'debug utils' stamp: 'cr 5/15/2005 23:35'!
wizardMode
	"Put the game in debug mode and make the player really buff."

	debugMode := true.
	player statHitPoints increaseMaxBy: 200; add: 200.
	#('Strength' 'Dexterity' 'Constitution') do: [:stat | player atStat: stat put: 18].

	100 timesRepeat: [player statExperience add: 40].
	10000 timesRepeat: [player statExperience add: 800].

	player statExperience add: 100000000.

	{	NhSilverDragonScaleMail new.
		NhDwarvishIronHelm new.
		NhIronShoes new.
		NhLeatherGloves new.
		GmAluminumBaseballBat new.
	} do: [ :item | player insertAndDeploy: item or: []].

	player markStatsChanged.

! !

!NhGame methodsFor: 'constants' stamp: 'cr 3/25/2005 08:58'!
finalMessage
	^
'Death appears.  He says, "AS THOU ART A DEMIGOD, THOU ART IMMORTAL.
BUT I''M GETTING SICK AND TIRED OF THY ALCOHOL-RELATED DEATHS SO THIS
TIME, I''M SENDING YOU OFF FOR REINCARNATION.  HAVE FUN TOILET
TRAINING AGAIN."'.! !

!NhGame methodsFor: 'constants' stamp: 'cr 3/12/2005 12:48'!
saveFileName
	^self class saveFileName.
! !

!NhGame methodsFor: 'constants' stamp: 'cr 4/10/2005 14:40'!
versionString
	^'1.0.2'.! !

!NhGame methodsFor: 'saving' stamp: 'cr 4/4/2005 23:02'!
saveAndQuit
	"To do: code some object-serialization code here."

	(self class isDevelopmentImage)
		ifTrue: [(nil confirm: 'Really save and quit?') or: [^self]].

	Smalltalk snapshot: true andQuit: true.

	self displayWelcomeMessage.
	self debugIfRequested.! !


!NhGame class methodsFor: 'instance creation' stamp: 'cr 3/26/2005 13:38'!
new
	^self basicNew initialize.! !

!NhGame class methodsFor: 'instance creation' stamp: 'cr 3/13/2005 14:11'!
newFromSaveFile
	| stream instance |

	self halt: 'serialization is not yet supported.  Don''t call this method.'.

	[
		stream := FileStream oldFileNamed: self saveFileName
	] on: FileDoesNotExistException do: [
		nil inform: 'No saved file found.  Creating new game'.
		^self new.
	].

	instance := self readSixxFrom: stream.
	stream close.
	^instance.! !

!NhGame class methodsFor: 'utilities' stamp: 'cr 3/11/2005 14:11'!
isDevelopmentImage
	"I use the presence of sources files to test if this is a development image or not.  The handy thing is that
	 I can then continue to hack on a production image just by dropping the source and changes files into
	 the working directory."
	^(SourceFiles first isNil and: [SourceFiles second isNil]) not
	! !

!NhGame class methodsFor: 'utilities' stamp: 'cr 3/11/2005 14:15'!
quitUnlessDevelopment
	self isDevelopmentImage
		ifTrue: [Transcript nextPutAll: 'Refusing to quit.'; cr; endEntry]
		ifFalse: [Smalltalk snapshot: false andQuit: true].! !

!NhGame class methodsFor: 'constants' stamp: 'cr 3/13/2005 21:10'!
backgroundImageName
	^'qfp-background.jpg'! !

!NhGame class methodsFor: 'constants' stamp: 'cr 3/12/2005 12:47'!
saveFileName
	^'qfp-saved-game.gam'! !

!NhGame class methodsFor: 'deliverables' stamp: 'cr 3/13/2005 20:59'!
deleteAllWindows
	World submorphs do: [ :sm | sm delete].
! !

!NhGame class methodsFor: 'deliverables' stamp: 'cr 3/13/2005 21:33'!
getAndHideAllWindows
	| list |
	list := World submorphs copy.
	list do: [ :sm | sm delete].
	^list.
! !

!NhGame class methodsFor: 'deliverables' stamp: 'cr 8/5/2005 21:06'!
makeDeliverable

	"First, save a copy of the image and let the user move it elsewhere.  We use the absence
	 of sources to identify which is which."
	| bg |
	Smalltalk snapshot: true andQuit: false.
	self isDevelopmentImage
		ifTrue: [
			nil inform: 'Copy the image elsewhere and run it with the VM.'.
			^self
		].


	"Now, we do cleanup and let the user resize the main screen, select a background
	 image and do whatever else needs to be done."	

	self rigImageForDeliverable.
	self deleteAllWindows.
	
	bg := Form fromFileNamed: self backgroundImageName.
	(bg magnifyBy: 2) setAsBackground.		"to aid in resizing the outer window."

	nil inform: 'Resize the main window as required',
					'\Click OK to continue saving.' withCRs.

	"And free up the big form."
	World color: Color black.

	"Do a thorough GC and save."
	5 timesRepeat: [Smalltalk garbageCollect].
	Smalltalk snapshot: true andQuit: true.

	"And start the game (unless something either went wrong or I'm trying to hack on
	 a deliverable image)."
	self isDevelopmentImage
		ifFalse: [

			"Keep from getting the same dungeon each time."
			self resetCollectionRandom.
		
			(bg magnifyBy: 2) displayAt: 0@0.
			self new startFullScreen.
		].
! !

!NhGame class methodsFor: 'deliverables' stamp: 'cr 5/11/2005 11:21'!
resetCollectionRandom
	"Set the seed of the randomizer used by Collection, since that ends up making almost
	 all of our decisions.  It has to be based on something that varies widely between
	 instantiations.  The millisecond clock value (which the default initialize uses)
	 isn't adequate for that since it's based on the total run time and that
	 tends toward a constant in this case."
	| seed |

	"Set a reasonable Park-Miller starting seed.  This is ripped from Random>>initialize
	 but uses totalSeconds instead. "
	[seed := (Time totalSeconds bitAnd: 16r3FFFFFFF) bitXor: Sensor mousePoint x * Sensor mousePoint y.
	 seed = 0] whileTrue. "Try again if ever get a seed = 0".

	Collection randomForPicking seed: seed.

! !

!NhGame class methodsFor: 'deliverables' stamp: 'cr 3/27/2005 15:41'!
rigImageForDeliverable

	Preferences
		disable: #cmdDotEnabled;
		disable: #warnIfNoChangesFile;
		disable: #warnIfNoSourcesFile;
		disable: #debugHaloHandle;
		disable: #honorDesktopCmdKeys;
		disable: #preserveTrash;
		
		enable: #allHalosDisabled;		"This is a hackjob, added for this project."

		yourself.

	"to do--disable halos somehow."! !


!NhGarnet class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 03:53'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $* color: Color black name: 'garnet'

! !

!NhGarnet class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 03:53'!
isConcrete
	^true
! !

!NhGarnet class methodsFor: 'type info' stamp: 'cr 5/3/2005 23:56'!
baseCost
	^700


! !


!NhGiantBat methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhGiantBat methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^120
! !

!NhGiantBat methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhGiantBat class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $B color: Color black name: 'giant bat'

! !

!NhGiantBat class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhGiantBat class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^2
! !

!NhGiantBat class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 7.
		GmConstitution	-> 4.
		GmExperience	-> 3.
		GmDexterity		-> 9.
	}.
! !


!NhGnome methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhGnome methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^80
! !

!NhGnome methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhGnome class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $G color: Color black name: 'gnome'

! !

!NhGnome class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhGnome class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^1
! !

!NhGnome class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 6.
		GmConstitution	-> 3.
		GmExperience	-> 2.
		GmDexterity		-> 8.
	}.
! !


!NhGnomeKing methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhGnomeKing methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^240
! !

!NhGnomeKing methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhGnomeKing class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $G color: Color black name: 'gnome king'

! !

!NhGnomeKing class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhGnomeKing class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^5
! !

!NhGnomeKing class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 10.
		GmConstitution	-> 8.
		GmExperience	-> 6.
		GmDexterity		-> 12.
	}.
! !


!NhGnomeLord methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhGnomeLord methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^160
! !

!NhGnomeLord methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^8
! !


!NhGnomeLord class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $G color: Color black name: 'gnome lord'

! !

!NhGnomeLord class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhGnomeLord class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^3
! !

!NhGnomeLord class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 8.
		GmConstitution	-> 5.
		GmExperience	-> 4.
		GmDexterity		-> 10.
	}.
! !


!NhGoblin methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhGoblin methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^40
! !

!NhGoblin methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhGoblin class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $o color: Color black name: 'goblin'

! !

!NhGoblin class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhGoblin class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^0
! !

!NhGoblin class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 5.
		GmConstitution	-> 2.
		GmExperience	-> 1.
		GmDexterity		-> 7.
	}.
! !


!NhGoldenNagaHatchling methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhGoldenNagaHatchling methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^160
! !

!NhGoldenNagaHatchling methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhGoldenNagaHatchling class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $N color: Color black name: 'golden naga hatchling'

! !

!NhGoldenNagaHatchling class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhGoldenNagaHatchling class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^3
! !

!NhGoldenNagaHatchling class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 8.
		GmConstitution	-> 5.
		GmExperience	-> 4.
		GmDexterity		-> 10.
	}.
! !


!NhGlassGolem methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhGlassGolem methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^680
! !

!NhGlassGolem methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^8
! !


!NhGlassGolem class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $' color: Color black name: 'glass golem'

! !

!NhGlassGolem class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhGlassGolem class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^16
! !

!NhGlassGolem class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 18.
		GmConstitution	-> 18.
		GmExperience	-> 17.
		GmDexterity		-> 18.
	}.
! !


!NhGrayDragonScaleMail class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'gray dragon scale mail'

! !

!NhGrayDragonScaleMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhGrayDragonScaleMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^12
! !

!NhGrayDragonScaleMail class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^9
! !


!NhGrayDragonScales class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'gray dragon scales'

! !

!NhGrayDragonScales class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhGrayDragonScales class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^7
! !

!NhGrayDragonScales class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^3
! !


!NhGreenDragonScaleMail class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'green dragon scale mail'

! !

!NhGreenDragonScaleMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhGreenDragonScaleMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^9
! !

!NhGreenDragonScaleMail class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^9
! !


!NhGreenDragonScales class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'green dragon scales'

! !

!NhGreenDragonScales class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhGreenDragonScales class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^5
! !

!NhGreenDragonScales class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^3
! !


!NhGreenElf methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhGreenElf methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^240
! !

!NhGreenElf methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhGreenElf class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $@ color: Color black name: 'Green-elf'

! !

!NhGreenElf class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhGreenElf class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^5
! !

!NhGreenElf class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 10.
		GmConstitution	-> 8.
		GmExperience	-> 6.
		GmDexterity		-> 12.
	}.
! !


!NhGreyElf methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhGreyElf methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^280
! !

!NhGreyElf methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhGreyElf class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $@ color: Color black name: 'Grey-elf'

! !

!NhGreyElf class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhGreyElf class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^6
! !

!NhGreyElf class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 11.
		GmConstitution	-> 9.
		GmExperience	-> 7.
		GmDexterity		-> 13.
	}.
! !


!NhGuardianNagaHatchling methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhGuardianNagaHatchling methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^160
! !

!NhGuardianNagaHatchling methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhGuardianNagaHatchling class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $N color: Color black name: 'guardian naga hatchling'

! !

!NhGuardianNagaHatchling class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhGuardianNagaHatchling class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^3
! !

!NhGuardianNagaHatchling class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 8.
		GmConstitution	-> 5.
		GmExperience	-> 4.
		GmDexterity		-> 10.
	}.
! !


!NhHighBoots class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'high boots'

! !

!NhHighBoots class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhHighBoots class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^0
! !

!NhHighBoots class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^2
! !

!NhHighBoots class methodsFor: 'type info' stamp: 'cr 4/24/2005 19:04'!
baseWeight
	^2000
! !


!NhHillOrc methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhHillOrc methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^120
! !

!NhHillOrc methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhHillOrc class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $o color: Color black name: 'hill orc'

! !

!NhHillOrc class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhHillOrc class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^2
! !

!NhHillOrc class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 7.
		GmConstitution	-> 4.
		GmExperience	-> 3.
		GmDexterity		-> 9.
	}.
! !


!NhHobbit methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhHobbit methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^80
! !

!NhHobbit methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhHobbit class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $h color: Color black name: 'hobbit'

! !

!NhHobbit class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhHobbit class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^1
! !

!NhHobbit class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 6.
		GmConstitution	-> 3.
		GmExperience	-> 2.
		GmDexterity		-> 8.
	}.
! !


!NhHobgoblin methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhHobgoblin methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^80
! !

!NhHobgoblin methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhHobgoblin class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $o color: Color black name: 'hobgoblin'

! !

!NhHobgoblin class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhHobgoblin class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^1
! !

!NhHobgoblin class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 6.
		GmConstitution	-> 3.
		GmExperience	-> 2.
		GmDexterity		-> 8.
	}.
! !


!NhHuman methodsFor: 'attributes' stamp: 'cr 3/10/2005 03:33'!
damageRating
	^5! !

!NhHuman methodsFor: 'attributes' stamp: 'cr 3/10/2005 03:33'!
experienceValue
	^20
! !


!NhHuman class methodsFor: 'ascii tiles' stamp: 'cr 3/3/2005 03:06'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $@ color: Color black name: 'human'
! !

!NhHuman class methodsFor: 'object management stats' stamp: 'cr 3/5/2005 23:34'!
canCreateIn: aMap
	^false.		"Humans aren't randomly generated."
! !

!NhHuman class methodsFor: 'object management stats' stamp: 'cr 3/5/2005 20:32'!
isConcrete
	^true
! !


!NhHungover methodsFor: 'core protocol' stamp: 'cr 3/8/2005 12:04'!
valueName
	^'Hungover'
! !


!NhCaveSpider methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhCaveSpider methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^80
! !

!NhCaveSpider methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^2
! !


!NhCaveSpider class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $s color: Color black name: 'cave spider'

! !

!NhCaveSpider class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhCaveSpider class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^1
! !

!NhCaveSpider class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 6.
		GmConstitution	-> 3.
		GmExperience	-> 2.
		GmDexterity		-> 8.
	}.
! !


!NhGiantAnt methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhGiantAnt methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^120
! !

!NhGiantAnt methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhGiantAnt class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $a color: Color black name: 'giant ant'

! !

!NhGiantAnt class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhGiantAnt class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^2
! !

!NhGiantAnt class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 7.
		GmConstitution	-> 4.
		GmExperience	-> 3.
		GmDexterity		-> 9.
	}.
! !


!NhGiantBeetle methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^3
! !

!NhGiantBeetle methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^240
! !

!NhGiantBeetle methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhGiantBeetle class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $a color: Color black name: 'giant beetle'

! !

!NhGiantBeetle class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhGiantBeetle class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^5
! !

!NhGiantBeetle class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 10.
		GmConstitution	-> 9.
		GmExperience	-> 6.
		GmDexterity		-> 12.
	}.
! !


!NhIronGolem methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^4
! !

!NhIronGolem methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^760
! !

!NhIronGolem methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhIronGolem class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $' color: Color black name: 'iron golem'

! !

!NhIronGolem class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhIronGolem class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^18
! !

!NhIronGolem class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 18.
		GmConstitution	-> 18.
		GmExperience	-> 19.
		GmDexterity		-> 18.
	}.
! !


!NhIronShoes class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'iron shoes'

! !

!NhIronShoes class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhIronShoes class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^0
! !

!NhIronShoes class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^2
! !

!NhIronShoes class methodsFor: 'type info' stamp: 'cr 4/24/2005 19:04'!
baseWeight
       ^5000

! !


!NhJade class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 03:53'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $* color: Color black name: 'jade'

! !

!NhJade class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 03:53'!
isConcrete
	^true
! !

!NhJade class methodsFor: 'type info' stamp: 'cr 5/3/2005 23:56'!
baseCost
	^300


! !


!NhJasper class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 03:53'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $* color: Color black name: 'jasper'

! !

!NhJasper class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 03:53'!
isConcrete
	^true
! !

!NhJasper class methodsFor: 'type info' stamp: 'cr 5/3/2005 23:56'!
baseCost
	^500


! !


!NhJavelin class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhJavelin class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhJavelin class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^3
! !

!NhJavelin class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^6
! !

!NhJavelin class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^20
! !


!NhKatana class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhKatana class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhKatana class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^7
! !

!NhKatana class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^10
! !

!NhKatana class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^40
! !


!NhKobold methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhKobold methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^40
! !

!NhKobold methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhKobold class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $k color: Color black name: 'kobold'

! !

!NhKobold class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhKobold class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^0
! !

!NhKobold class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 5.
		GmConstitution	-> 2.
		GmExperience	-> 1.
		GmDexterity		-> 7.
	}.
! !


!NhKoboldLord methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhKoboldLord methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^120
! !

!NhKoboldLord methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhKoboldLord class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $k color: Color black name: 'kobold lord'

! !

!NhKoboldLord class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhKoboldLord class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^2
! !

!NhKoboldLord class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 7.
		GmConstitution	-> 5.
		GmExperience	-> 3.
		GmDexterity		-> 9.
	}.
! !


!NhLance class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhLance class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhLance class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^3
! !

!NhLance class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^6
! !

!NhLance class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^180
! !


!NhLargeKobold methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhLargeKobold methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^80
! !

!NhLargeKobold methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhLargeKobold class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $k color: Color black name: 'large kobold'

! !

!NhLargeKobold class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhLargeKobold class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^1
! !

!NhLargeKobold class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 6.
		GmConstitution	-> 3.
		GmExperience	-> 2.
		GmDexterity		-> 8.
	}.
! !


!NhLeatherArmor class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'leather armor'

! !

!NhLeatherArmor class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhLeatherArmor class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^0
! !

!NhLeatherArmor class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^2
! !

!NhLeatherArmor class methodsFor: 'type info' stamp: 'cr 4/24/2005 18:53'!
baseWeight
       ^15000

! !


!NhLeatherGloves class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'leather gloves'

! !

!NhLeatherGloves class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhLeatherGloves class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^0
! !

!NhLeatherGloves class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^1
! !

!NhLeatherGloves class methodsFor: 'type info' stamp: 'cr 4/24/2005 19:04'!
baseWeight
       ^1000

! !


!NhLeatherJacket class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'leather jacket'

! !

!NhLeatherJacket class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhLeatherJacket class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^0
! !

!NhLeatherJacket class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^1
! !

!NhLeatherJacket class methodsFor: 'type info' stamp: 'cr 4/24/2005 18:54'!
baseWeight
       ^3000

! !


!NhLemure methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhLemure methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^160
! !

!NhLemure methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^3
! !


!NhLemure class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $i color: Color black name: 'lemure'

! !

!NhLemure class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhLemure class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^3
! !

!NhLemure class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 8.
		GmConstitution	-> 5.
		GmExperience	-> 4.
		GmDexterity		-> 10.
	}.
! !


!NhLowBoots class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'low boots'

! !

!NhLowBoots class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhLowBoots class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^0
! !

!NhLowBoots class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^1
! !

!NhLowBoots class methodsFor: 'type info' stamp: 'cr 4/24/2005 19:04'!
baseWeight
	^1000! !


!NhMace class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhMace class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhMace class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^3
! !

!NhMace class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^6
! !

!NhMace class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^30
! !


!NhManes methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhManes methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^80
! !

!NhManes methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhManes class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $i color: Color black name: 'manes'

! !

!NhManes class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhManes class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^1
! !

!NhManes class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 6.
		GmConstitution	-> 3.
		GmExperience	-> 2.
		GmDexterity		-> 8.
	}.
! !


!NhMauveDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^8
! !

!NhMauveDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^640
! !

!NhMauveDragon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhMauveDragon class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $D color: Color black name: 'mauve dragon'

! !

!NhMauveDragon class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhMauveDragon class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^15
! !

!NhMauveDragon class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 10:39'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 18.
		GmConstitution	-> 18.
		GmExperience	-> 16.
		GmDexterity		-> 18.

		GmArmorClass	-> 9.
	}.
! !


!NhMinotaur methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhMinotaur methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^640
! !

!NhMinotaur methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^8
! !


!NhMinotaur class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $H color: Color black name: 'minotaur'

! !

!NhMinotaur class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhMinotaur class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^15
! !

!NhMinotaur class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 18.
		GmConstitution	-> 18.
		GmExperience	-> 16.
		GmDexterity		-> 18.
	}.
! !


!NhApe methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhApe methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^200
! !

!NhApe methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhApe class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $Y color: Color black name: 'ape'

! !

!NhApe class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhApe class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^4
! !

!NhApe class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 9.
		GmConstitution	-> 6.
		GmExperience	-> 5.
		GmDexterity		-> 11.
	}.
! !


!NhCarnivorousApe methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhCarnivorousApe methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^280
! !

!NhCarnivorousApe methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^8
! !


!NhCarnivorousApe class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $Y color: Color black name: 'carnivorous ape'

! !

!NhCarnivorousApe class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhCarnivorousApe class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^6
! !

!NhCarnivorousApe class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 11.
		GmConstitution	-> 8.
		GmExperience	-> 7.
		GmDexterity		-> 13.
	}.
! !


!NhGargoyle methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhGargoyle methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^280
! !

!NhGargoyle methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhGargoyle class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $g color: Color black name: 'gargoyle'

! !

!NhGargoyle class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhGargoyle class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^6
! !

!NhGargoyle class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 11.
		GmConstitution	-> 9.
		GmExperience	-> 7.
		GmDexterity		-> 13.
	}.
! !


!NhGhost methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhGhost methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^440
! !

!NhGhost methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^1
! !


!NhGhost class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $  color: Color black name: 'ghost'

! !

!NhGhost class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhGhost class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^10
! !

!NhGhost class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 15.
		GmConstitution	-> 12.
		GmExperience	-> 11.
		GmDexterity		-> 17.
	}.
! !

!NhGhost class methodsFor: 'type info' stamp: 'cr 9/22/2005 11:31'!
isUndead
	^true
! !


!NhGlassPiercer methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^4
! !

!NhGlassPiercer methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^320
! !

!NhGlassPiercer methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhGlassPiercer class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $p color: Color black name: 'glass piercer'

! !

!NhGlassPiercer class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhGlassPiercer class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^7
! !

!NhGlassPiercer class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 12.
		GmConstitution	-> 12.
		GmExperience	-> 8.
		GmDexterity		-> 14.
	}.
! !


!NhIronPiercer methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^3
! !

!NhIronPiercer methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^240
! !

!NhIronPiercer methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhIronPiercer class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $p color: Color black name: 'iron piercer'

! !

!NhIronPiercer class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhIronPiercer class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^5
! !

!NhIronPiercer class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 10.
		GmConstitution	-> 9.
		GmExperience	-> 6.
		GmDexterity		-> 12.
	}.
! !


!NhMordorOrc methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhMordorOrc methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^160
! !

!NhMordorOrc methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhMordorOrc class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $o color: Color black name: 'Mordor orc'

! !

!NhMordorOrc class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhMordorOrc class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^3
! !

!NhMordorOrc class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 8.
		GmConstitution	-> 5.
		GmExperience	-> 4.
		GmDexterity		-> 10.
	}.
! !


!NhMorningStar class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhMorningStar class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhMorningStar class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^5
! !

!NhMorningStar class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^8
! !

!NhMorningStar class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^120
! !


!NhMountainCentaur methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhMountainCentaur methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^280
! !

!NhMountainCentaur methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhMountainCentaur class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $C color: Color black name: 'mountain centaur'

! !

!NhMountainCentaur class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhMountainCentaur class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^6
! !

!NhMountainCentaur class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 11.
		GmConstitution	-> 8.
		GmExperience	-> 7.
		GmDexterity		-> 13.
	}.
! !


!NhMummy methodsFor: 'tests--capabilites' stamp: 'cr 4/3/2005 22:53'!
wearsArmor
	^false.! !


!NhDwarfMummy methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhDwarfMummy methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^240
! !

!NhDwarfMummy methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhElfMummy methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhElfMummy methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^280
! !

!NhElfMummy methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhEttinMummy methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhEttinMummy methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^320
! !

!NhEttinMummy methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhGiantMummy methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^3
! !

!NhGiantMummy methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^360
! !

!NhGiantMummy methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhGnomeMummy methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhGnomeMummy methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^200
! !

!NhGnomeMummy methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhHumanMummy methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhHumanMummy methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^280
! !

!NhHumanMummy methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhKoboldMummy methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhKoboldMummy methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^160
! !

!NhKoboldMummy methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhMummy class methodsFor: 'type info' stamp: 'cr 9/22/2005 11:29'!
isUndead
	^true
! !

!NhMummy class methodsFor: 'type info' stamp: 'cr 9/23/2005 12:58'!
usesTools
	^false! !


!NhDwarfMummy class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $M color: Color black name: 'dwarf mummy'

! !

!NhDwarfMummy class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhDwarfMummy class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^5
! !

!NhDwarfMummy class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 10.
		GmConstitution	-> 7.
		GmExperience	-> 6.
		GmDexterity		-> 12.
	}.
! !


!NhElfMummy class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $M color: Color black name: 'elf mummy'

! !

!NhElfMummy class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhElfMummy class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^6
! !

!NhElfMummy class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 11.
		GmConstitution	-> 9.
		GmExperience	-> 7.
		GmDexterity		-> 13.
	}.
! !


!NhEttinMummy class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $M color: Color black name: 'ettin mummy'

! !

!NhEttinMummy class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhEttinMummy class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^7
! !

!NhEttinMummy class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 12.
		GmConstitution	-> 10.
		GmExperience	-> 8.
		GmDexterity		-> 14.
	}.
! !


!NhGiantMummy class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $M color: Color black name: 'giant mummy'

! !

!NhGiantMummy class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhGiantMummy class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^8
! !

!NhGiantMummy class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 13.
		GmConstitution	-> 12.
		GmExperience	-> 9.
		GmDexterity		-> 15.
	}.
! !


!NhGnomeMummy class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $M color: Color black name: 'gnome mummy'

! !

!NhGnomeMummy class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhGnomeMummy class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^4
! !

!NhGnomeMummy class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 9.
		GmConstitution	-> 6.
		GmExperience	-> 5.
		GmDexterity		-> 11.
	}.
! !


!NhHumanMummy class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $M color: Color black name: 'human mummy'

! !

!NhHumanMummy class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhHumanMummy class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^6
! !

!NhHumanMummy class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 11.
		GmConstitution	-> 9.
		GmExperience	-> 7.
		GmDexterity		-> 13.
	}.
! !


!NhKoboldMummy class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $M color: Color black name: 'kobold mummy'

! !

!NhKoboldMummy class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhKoboldMummy class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^3
! !

!NhKoboldMummy class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 8.
		GmConstitution	-> 5.
		GmExperience	-> 4.
		GmDexterity		-> 10.
	}.
! !


!NhOgre methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhOgre methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^240
! !

!NhOgre methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^5
! !


!NhOgre class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $O color: Color black name: 'ogre'

! !

!NhOgre class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhOgre class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^5
! !

!NhOgre class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 10.
		GmConstitution	-> 8.
		GmExperience	-> 6.
		GmDexterity		-> 12.
	}.
! !


!NhOgreKing methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^3
! !

!NhOgreKing methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^400
! !

!NhOgreKing methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^5
! !


!NhOgreKing class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $O color: Color black name: 'ogre king'

! !

!NhOgreKing class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhOgreKing class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^9
! !

!NhOgreKing class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 14.
		GmConstitution	-> 13.
		GmExperience	-> 10.
		GmDexterity		-> 16.
	}.
! !


!NhOgreLord methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhOgreLord methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^320
! !

!NhOgreLord methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhOgreLord class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $O color: Color black name: 'ogre lord'

! !

!NhOgreLord class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhOgreLord class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^7
! !

!NhOgreLord class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 12.
		GmConstitution	-> 10.
		GmExperience	-> 8.
		GmDexterity		-> 14.
	}.
! !


!NhOpal class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 03:53'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $* color: Color black name: 'opal'

! !

!NhOpal class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 03:53'!
isConcrete
	^true
! !

!NhOpal class methodsFor: 'type info' stamp: 'cr 5/3/2005 23:56'!
baseCost
	^800


! !


!NhOrangeDragonScaleMail class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'orange dragon scale mail'

! !

!NhOrangeDragonScaleMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhOrangeDragonScaleMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^9
! !

!NhOrangeDragonScaleMail class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^9
! !


!NhOrangeDragonScales class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'orange dragon scales'

! !

!NhOrangeDragonScales class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhOrangeDragonScales class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^5
! !

!NhOrangeDragonScales class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^3
! !


!NhOrc methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhOrc methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^80
! !

!NhOrc methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^8
! !


!NhOrc class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $o color: Color black name: 'orc'

! !

!NhOrc class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhOrc class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^1
! !

!NhOrc class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 6.
		GmConstitution	-> 3.
		GmExperience	-> 2.
		GmDexterity		-> 8.
	}.
! !


!NhOrcCaptain methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhOrcCaptain methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^240
! !

!NhOrcCaptain methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhOrcCaptain class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $o color: Color black name: 'orc-captain'

! !

!NhOrcCaptain class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhOrcCaptain class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^5
! !

!NhOrcCaptain class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 10.
		GmConstitution	-> 8.
		GmExperience	-> 6.
		GmDexterity		-> 12.
	}.
! !


!NhOrcMummy methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhOrcMummy methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^240
! !

!NhOrcMummy methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhOrcMummy class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $M color: Color black name: 'orc mummy'

! !

!NhOrcMummy class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhOrcMummy class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^5
! !

!NhOrcMummy class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 10.
		GmConstitution	-> 7.
		GmExperience	-> 6.
		GmDexterity		-> 12.
	}.
! !


!NhOrcishChainMail class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'orcish chain mail'

! !

!NhOrcishChainMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhOrcishChainMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^0
! !

!NhOrcishChainMail class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^4
! !

!NhOrcishChainMail class methodsFor: 'type info' stamp: 'cr 4/24/2005 18:54'!
baseWeight
       ^30000

! !


!NhOrcishDagger class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhOrcishDagger class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhOrcishDagger class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^0
! !

!NhOrcishDagger class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^3
! !

!NhOrcishDagger class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^10
! !


!NhOrcishHelm class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'orcish helm'

! !

!NhOrcishHelm class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhOrcishHelm class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^0
! !

!NhOrcishHelm class methodsFor: 'type info' stamp: 'cr 5/12/2005 23:00'!
baseArmorClassMod
	^2
! !

!NhOrcishHelm class methodsFor: 'type info' stamp: 'cr 4/24/2005 17:27'!
baseWeight
       ^1000

! !


!NhOrcishRingMail class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'orcish ring mail'

! !

!NhOrcishRingMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhOrcishRingMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^0
! !

!NhOrcishRingMail class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^2
! !

!NhOrcishRingMail class methodsFor: 'type info' stamp: 'cr 4/24/2005 18:55'!
baseWeight
       ^25000

! !


!NhOrcishShortSword class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhOrcishShortSword class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhOrcishShortSword class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^2
! !

!NhOrcishShortSword class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^5
! !

!NhOrcishShortSword class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^30
! !


!NhOrcishSpear class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhOrcishSpear class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhOrcishSpear class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^2
! !

!NhOrcishSpear class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^5
! !

!NhOrcishSpear class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^30
! !


!NhPantsOfYendor methodsFor: 'type tests' stamp: 'cr 3/12/2005 05:42'!
isPantsOfYendor
	^true

! !

!NhPantsOfYendor methodsFor: 'description' stamp: 'cr 3/12/2005 05:40'!
descriptionString
	^self theDescriptionString.
! !

!NhPantsOfYendor methodsFor: 'description' stamp: 'cr 3/12/2005 05:40'!
theDescriptionString
	^'The Pants of Yendor'
! !


!NhPantsOfYendor class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:39'!
canCreateIn: aMap
	^false.		"This is unique so we don't let it get generated in the usual way."
! !

!NhPantsOfYendor class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 11:43'!
isConcrete
	^true
! !

!NhPantsOfYendor class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:40'!
maxAllowed
	^1
! !

!NhPantsOfYendor class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 11:43'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'the Pants of Yendor'

! !

!NhPantsOfYendor class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^6! !

!NhPantsOfYendor class methodsFor: 'type info' stamp: 'cr 4/24/2005 17:10'!
baseWeight
       ^600

! !


!NhPaperGolem methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhPaperGolem methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^160
! !

!NhPaperGolem methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^3
! !


!NhPaperGolem class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $' color: Color black name: 'paper golem'

! !

!NhPaperGolem class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhPaperGolem class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^3
! !

!NhPaperGolem class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 8.
		GmConstitution	-> 5.
		GmExperience	-> 4.
		GmDexterity		-> 10.
	}.
! !


!NhPlainsCentaur methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhPlainsCentaur methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^200
! !

!NhPlainsCentaur methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhPlainsCentaur class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $C color: Color black name: 'plains centaur'

! !

!NhPlainsCentaur class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhPlainsCentaur class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^4
! !

!NhPlainsCentaur class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 9.
		GmConstitution	-> 6.
		GmExperience	-> 5.
		GmDexterity		-> 11.
	}.
! !


!NhPlateMail class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'plate mail'

! !

!NhPlateMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhPlateMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^6
! !

!NhPlateMail class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^7
! !

!NhPlateMail class methodsFor: 'type info' stamp: 'cr 4/24/2005 18:55'!
baseWeight
       ^45000

! !


!NhCoyote methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhCoyote methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^80
! !

!NhCoyote methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhCoyote class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $d color: Color black name: 'coyote'

! !

!NhCoyote class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhCoyote class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^1
! !

!NhCoyote class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 6.
		GmConstitution	-> 3.
		GmExperience	-> 2.
		GmDexterity		-> 8.
	}.
! !


!NhDingo methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhDingo methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^200
! !

!NhDingo methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhDingo class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $d color: Color black name: 'dingo'

! !

!NhDingo class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhDingo class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^4
! !

!NhDingo class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 9.
		GmConstitution	-> 6.
		GmExperience	-> 5.
		GmDexterity		-> 11.
	}.
! !


!NhDog methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhDog methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^200
! !

!NhDog methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhDog class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $d color: Color black name: 'dog'

! !

!NhDog class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhDog class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^4
! !

!NhDog class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 9.
		GmConstitution	-> 6.
		GmExperience	-> 5.
		GmDexterity		-> 11.
	}.
! !


!NhFox methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhFox methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^40
! !

!NhFox methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^3
! !


!NhFox class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $d color: Color black name: 'fox'

! !

!NhFox class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhFox class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^0
! !

!NhFox class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 5.
		GmConstitution	-> 2.
		GmExperience	-> 1.
		GmDexterity		-> 7.
	}.
! !


!NhHousecat methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhHousecat methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^200
! !

!NhHousecat methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhHousecat class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $f color: Color black name: 'housecat'

! !

!NhHousecat class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhHousecat class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^4
! !

!NhHousecat class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 9.
		GmConstitution	-> 6.
		GmExperience	-> 5.
		GmDexterity		-> 11.
	}.
! !


!NhJackal methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhJackal methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^40
! !

!NhJackal methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^2
! !


!NhJackal class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $d color: Color black name: 'jackal'

! !

!NhJackal class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhJackal class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^0
! !

!NhJackal class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 5.
		GmConstitution	-> 2.
		GmExperience	-> 1.
		GmDexterity		-> 7.
	}.
! !


!NhJaguar methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhJaguar methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^200
! !

!NhJaguar methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^8
! !


!NhJaguar class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $f color: Color black name: 'jaguar'

! !

!NhJaguar class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhJaguar class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^4
! !

!NhJaguar class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 9.
		GmConstitution	-> 6.
		GmExperience	-> 5.
		GmDexterity		-> 11.
	}.
! !


!NhKitten methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhKitten methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^120
! !

!NhKitten methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhKitten class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $f color: Color black name: 'kitten'

! !

!NhKitten class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhKitten class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^2
! !

!NhKitten class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 7.
		GmConstitution	-> 4.
		GmExperience	-> 3.
		GmDexterity		-> 9.
	}.
! !


!NhLargeCat methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhLargeCat methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^280
! !

!NhLargeCat methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhLargeCat class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $f color: Color black name: 'large cat'

! !

!NhLargeCat class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhLargeCat class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^6
! !

!NhLargeCat class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 11.
		GmConstitution	-> 9.
		GmExperience	-> 7.
		GmDexterity		-> 13.
	}.
! !


!NhLargeDog methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhLargeDog methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^280
! !

!NhLargeDog methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhLargeDog class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $d color: Color black name: 'large dog'

! !

!NhLargeDog class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhLargeDog class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^6
! !

!NhLargeDog class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 11.
		GmConstitution	-> 9.
		GmExperience	-> 7.
		GmDexterity		-> 13.
	}.
! !


!NhBaluchitherium methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^5
! !

!NhBaluchitherium methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^600
! !

!NhBaluchitherium methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhBaluchitherium class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $q color: Color black name: 'baluchitherium'

! !

!NhBaluchitherium class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhBaluchitherium class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^14
! !

!NhBaluchitherium class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 18.
		GmConstitution	-> 18.
		GmExperience	-> 15.
		GmDexterity		-> 18.
	}.
! !


!NhHorse methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhHorse methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^240
! !

!NhHorse methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^3
! !


!NhHorse class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $u color: Color black name: 'horse'

! !

!NhHorse class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhHorse class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^5
! !

!NhHorse class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 10.
		GmConstitution	-> 7.
		GmExperience	-> 6.
		GmDexterity		-> 12.
	}.
! !


!NhLeocrotta methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhLeocrotta methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^280
! !

!NhLeocrotta methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhLeocrotta class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $q color: Color black name: 'leocrotta'

! !

!NhLeocrotta class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhLeocrotta class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^6
! !

!NhLeocrotta class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 11.
		GmConstitution	-> 9.
		GmExperience	-> 7.
		GmDexterity		-> 13.
	}.
! !


!NhLittleDog methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhLittleDog methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^120
! !

!NhLittleDog methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhLittleDog class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $d color: Color black name: 'little dog'

! !

!NhLittleDog class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhLittleDog class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^2
! !

!NhLittleDog class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 7.
		GmConstitution	-> 4.
		GmExperience	-> 3.
		GmDexterity		-> 9.
	}.
! !


!NhMastodon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^4
! !

!NhMastodon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^840
! !

!NhMastodon methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^8
! !


!NhMastodon class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $q color: Color black name: 'mastodon'

! !

!NhMastodon class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhMastodon class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^20
! !

!NhMastodon class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 18.
		GmConstitution	-> 18.
		GmExperience	-> 21.
		GmDexterity		-> 18.
	}.
! !


!NhMumak methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhMumak methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^240
! !

!NhMumak methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhMumak class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $q color: Color black name: 'mumak'

! !

!NhMumak class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhMumak class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^5
! !

!NhMumak class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 10.
		GmConstitution	-> 8.
		GmExperience	-> 6.
		GmDexterity		-> 12.
	}.
! !


!NhPony methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhPony methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^160
! !

!NhPony methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^2
! !


!NhPony class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $u color: Color black name: 'pony'

! !

!NhPony class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhPony class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^3
! !

!NhPony class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 8.
		GmConstitution	-> 5.
		GmExperience	-> 4.
		GmDexterity		-> 10.
	}.
! !


!NhQuarterstaff class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhQuarterstaff class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhQuarterstaff class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^3
! !

!NhQuarterstaff class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^6
! !

!NhQuarterstaff class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^40
! !


!NhQueenBee methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhQueenBee methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^400
! !

!NhQueenBee methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^8
! !


!NhQueenBee class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $a color: Color black name: 'queen bee'

! !

!NhQueenBee class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhQueenBee class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^9
! !

!NhQueenBee class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 14.
		GmConstitution	-> 11.
		GmExperience	-> 10.
		GmDexterity		-> 16.
	}.
! !


!NhRaven methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhRaven methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^200
! !

!NhRaven methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhRaven class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $B color: Color black name: 'raven'

! !

!NhRaven class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhRaven class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^4
! !

!NhRaven class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 9.
		GmConstitution	-> 6.
		GmExperience	-> 5.
		GmDexterity		-> 11.
	}.
! !


!NhRedDragonScaleMail class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'red dragon scale mail'

! !

!NhRedDragonScaleMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhRedDragonScaleMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^9
! !

!NhRedDragonScaleMail class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^9
! !


!NhRedDragonScales class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'red dragon scales'

! !

!NhRedDragonScales class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhRedDragonScales class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^5
! !

!NhRedDragonScales class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^3
! !


!NhRedNagaHatchling methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhRedNagaHatchling methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^160
! !

!NhRedNagaHatchling methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhRedNagaHatchling class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $N color: Color black name: 'red naga hatchling'

! !

!NhRedNagaHatchling class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhRedNagaHatchling class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^3
! !

!NhRedNagaHatchling class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 8.
		GmConstitution	-> 5.
		GmExperience	-> 4.
		GmDexterity		-> 10.
	}.
! !


!NhRingMail class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'ring mail'

! !

!NhRingMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhRingMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^1
! !

!NhRingMail class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^3
! !

!NhRingMail class methodsFor: 'type info' stamp: 'cr 4/24/2005 18:55'!
baseWeight
       ^25000

! !


!NhRingOfCharisma methodsFor: 'stat modifications' stamp: 'cr 3/12/2005 04:18'!
charismaMod
	^3
! !


!NhRingOfCharisma class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 04:18'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $= color: Color black name: 'ring of charisma'

! !

!NhRingOfCharisma class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 04:18'!
isConcrete
	^true
! !


!NhRingOfConstitution methodsFor: 'stat modifications' stamp: 'cr 3/12/2005 04:18'!
constitutionMod
	^3
! !


!NhRingOfConstitution class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 04:18'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $= color: Color black name: 'ring of constitution'

! !

!NhRingOfConstitution class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 04:18'!
isConcrete
	^true
! !

!NhRingOfConstitution class methodsFor: 'type info' stamp: 'cr 5/3/2005 23:58'!
baseCost
	^1200! !


!NhRingOfDexterity methodsFor: 'stat modifications' stamp: 'cr 3/12/2005 04:18'!
dexterityMod
	^3
! !


!NhRingOfDexterity class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 04:18'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $= color: Color black name: 'ring of dexterity'

! !

!NhRingOfDexterity class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 04:18'!
isConcrete
	^true
! !

!NhRingOfDexterity class methodsFor: 'type info' stamp: 'cr 5/3/2005 23:59'!
baseCost
	^1200! !


!NhRingOfIntelligence methodsFor: 'stat modifications' stamp: 'cr 3/12/2005 04:18'!
intelligenceMod
	^3
! !


!NhRingOfIntelligence class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 04:18'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $= color: Color black name: 'ring of intelligence'

! !

!NhRingOfIntelligence class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 04:18'!
isConcrete
	^true
! !


!NhRingOfStrength methodsFor: 'stat modifications' stamp: 'cr 3/12/2005 04:18'!
strengthMod
	^3
! !


!NhRingOfStrength class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 04:18'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $= color: Color black name: 'ring of strength'

! !

!NhRingOfStrength class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 04:18'!
isConcrete
	^true
! !

!NhRingOfStrength class methodsFor: 'type info' stamp: 'cr 5/3/2005 23:59'!
baseCost
	^1400
! !


!NhRingOfStudliness methodsFor: 'stat modifications' stamp: 'cr 3/12/2005 04:19'!
armorClassMod
	^4
! !

!NhRingOfStudliness methodsFor: 'stat modifications' stamp: 'cr 3/12/2005 04:19'!
dexterityMod
	^5
! !

!NhRingOfStudliness methodsFor: 'stat modifications' stamp: 'cr 3/12/2005 04:19'!
strengthMod
	^5
! !


!NhRingOfStudliness class methodsFor: 'ascii tiles' stamp: 'cr 4/4/2005 00:16'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $= color: Color black name: 'ring of wisdom'

! !

!NhRingOfStudliness class methodsFor: 'object management stats' stamp: 'cr 4/4/2005 00:17'!
isConcrete
	^true! !

!NhRingOfStudliness class methodsFor: 'object management stats' stamp: 'cr 4/4/2005 03:46'!
minCreationLevel
	^15! !

!NhRingOfStudliness class methodsFor: 'type info' stamp: 'cr 5/3/2005 23:59'!
baseCost
	^3000
! !


!NhRingOfWisdom methodsFor: 'stat modifications' stamp: 'cr 3/12/2005 04:18'!
wisdomMod
	^3
! !


!NhRingOfWisdom class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 04:18'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $= color: Color black name: 'ring of wisdom'

! !

!NhRingOfWisdom class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 04:18'!
isConcrete
	^true
! !


!NhRockPiercer methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhRockPiercer methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^160
! !

!NhRockPiercer methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhRockPiercer class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $p color: Color black name: 'rock piercer'

! !

!NhRockPiercer class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhRockPiercer class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^3
! !

!NhRockPiercer class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 8.
		GmConstitution	-> 6.
		GmExperience	-> 4.
		GmDexterity		-> 10.
	}.
! !


!NhDevilBunny methodsFor: 'attributes' stamp: 'cr 3/12/2005 10:34'!
damageRating
	^20
! !

!NhDevilBunny methodsFor: 'attributes' stamp: 'cr 3/12/2005 10:41'!
experienceValue
	^640
! !

!NhDevilBunny methodsFor: 'attributes' stamp: 'cr 3/12/2005 10:16'!
toHitValue
	^3
! !


!NhDevilBunny class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 10:16'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $r color: Color black name: 'giant rat'

! !

!NhDevilBunny class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 10:16'!
isConcrete
	^true
! !

!NhDevilBunny class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 10:41'!
minCreationLevel
	^20
! !

!NhDevilBunny class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 10:36'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 12.
		GmConstitution	-> 6.
		GmExperience	-> 2.
		GmDexterity		-> 14.
	}.
! !


!NhGiantRat methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhGiantRat methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^80
! !

!NhGiantRat methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^3
! !


!NhGiantRat class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $r color: Color black name: 'giant rat'

! !

!NhGiantRat class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhGiantRat class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^1
! !

!NhGiantRat class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 6.
		GmConstitution	-> 3.
		GmExperience	-> 2.
		GmDexterity		-> 8.
	}.
! !


!NhRockMole methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhRockMole methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^160
! !

!NhRockMole methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhRockMole class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $r color: Color black name: 'rock mole'

! !

!NhRockMole class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhRockMole class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^3
! !

!NhRockMole class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 8.
		GmConstitution	-> 5.
		GmExperience	-> 4.
		GmDexterity		-> 10.
	}.
! !


!NhRopeGolem methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^6
! !

!NhRopeGolem methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^200
! !

!NhRopeGolem methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^1
! !


!NhRopeGolem class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $' color: Color black name: 'rope golem'

! !

!NhRopeGolem class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhRopeGolem class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^4
! !

!NhRopeGolem class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 9.
		GmConstitution	-> 11.
		GmExperience	-> 5.
		GmDexterity		-> 11.
	}.
! !


!NhRothe methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhRothe methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^120
! !

!NhRothe methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^8
! !


!NhRothe class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $q color: Color black name: 'rothe'

! !

!NhRothe class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhRothe class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^2
! !

!NhRothe class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 7.
		GmConstitution	-> 4.
		GmExperience	-> 3.
		GmDexterity		-> 9.
	}.
! !


!NhRuby class methodsFor: 'object management stats' stamp: 'cr 3/5/2005 20:32'!
isConcrete
	^true
! !

!NhRuby class methodsFor: 'ascii tiles' stamp: 'cr 3/5/2005 21:32'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $* color: Color red name: 'ruby'! !

!NhRuby class methodsFor: 'type info' stamp: 'cr 5/3/2005 23:56'!
baseCost
	^5000

! !


!NhRunesword class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhRunesword class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhRunesword class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^5
! !

!NhRunesword class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^8
! !

!NhRunesword class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^40
! !


!NhSaber class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhSaber class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhSaber class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^5
! !

!NhSaber class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^8
! !

!NhSaber class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^30
! !


!NhSapphire class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 03:53'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $* color: Color black name: 'sapphire'

! !

!NhSapphire class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 03:53'!
isConcrete
	^true
! !

!NhSapphire class methodsFor: 'type info' stamp: 'cr 5/3/2005 23:56'!
baseCost
	^3000


! !


!NhSasquatch methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhSasquatch methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^320
! !

!NhSasquatch methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^8
! !


!NhSasquatch class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $Y color: Color black name: 'sasquatch'

! !

!NhSasquatch class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhSasquatch class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^7
! !

!NhSasquatch class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 12.
		GmConstitution	-> 9.
		GmExperience	-> 8.
		GmDexterity		-> 14.
	}.
! !


!NhScaleMail class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'scale mail'

! !

!NhScaleMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhScaleMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^0
! !

!NhScaleMail class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^4
! !

!NhScaleMail class methodsFor: 'type info' stamp: 'cr 4/24/2005 18:56'!
baseWeight
       ^25000
! !


!NhScalpel class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhScalpel class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhScalpel class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^0
! !

!NhScalpel class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^3
! !

!NhScalpel class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^5
! !


!NhScimitar class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhScimitar class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhScimitar class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^5
! !

!NhScimitar class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^8
! !

!NhScimitar class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^30
! !


!NhSewerRat methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhSewerRat methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^40
! !

!NhSewerRat methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^3
! !


!NhSewerRat class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $r color: Color black name: 'sewer rat'

! !

!NhSewerRat class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhSewerRat class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^0
! !

!NhSewerRat class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 5.
		GmConstitution	-> 2.
		GmExperience	-> 1.
		GmDexterity		-> 7.
	}.
! !


!NhShade methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhShade methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^520
! !

!NhShade methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhShade class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $  color: Color black name: 'shade'

! !

!NhShade class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhShade class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^12
! !

!NhShade class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 17.
		GmConstitution	-> 15.
		GmExperience	-> 13.
		GmDexterity		-> 18.
	}.
! !

!NhShade class methodsFor: 'type info' stamp: 'cr 9/22/2005 11:31'!
isUndead
	^true! !


!NhSilverDagger class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhSilverDagger class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhSilverDagger class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^1
! !

!NhSilverDagger class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^4
! !

!NhSilverDagger class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^12
! !

!NhSilverDagger class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:53'!
isSilver
	^true! !


!NhSilverDragonScaleMail class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'silver dragon scale mail'

! !

!NhSilverDragonScaleMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhSilverDragonScaleMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^12
! !

!NhSilverDragonScaleMail class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^9
! !

!NhSilverDragonScaleMail class methodsFor: 'type info' stamp: 'cr 9/18/2005 14:46'!
isSilver
	^true
! !


!NhSilverDragonScales class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'silver dragon scales'

! !

!NhSilverDragonScales class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhSilverDragonScales class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^7
! !

!NhSilverDragonScales class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^3
! !

!NhSilverDragonScales class methodsFor: 'type info' stamp: 'cr 9/18/2005 14:47'!
isSilver
	^true
! !


!NhSilverSpear class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhSilverSpear class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhSilverSpear class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^3
! !

!NhSilverSpear class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^6
! !

!NhSilverSpear class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^36
! !

!NhSilverSpear class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:53'!
isSilver
	^true
! !


!NhSoldierAnt methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^3
! !

!NhSoldierAnt methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^160
! !

!NhSoldierAnt methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhSoldierAnt class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $a color: Color black name: 'soldier ant'

! !

!NhSoldierAnt class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhSoldierAnt class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^3
! !

!NhSoldierAnt class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 8.
		GmConstitution	-> 7.
		GmExperience	-> 4.
		GmDexterity		-> 10.
	}.
! !


!NhSpear class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhSpear class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhSpear class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^3
! !

!NhSpear class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^6
! !

!NhSpear class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^30
! !


!NhSplintMail class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'splint mail'

! !

!NhSplintMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhSplintMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^0
! !

!NhSplintMail class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^6
! !

!NhSplintMail class methodsFor: 'type info' stamp: 'cr 4/24/2005 18:56'!
baseWeight
       ^40000
! !


!NhStiletto class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhStiletto class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhStiletto class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^0
! !

!NhStiletto class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^3
! !

!NhStiletto class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^5
! !


!NhStoneGolem methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^3
! !

!NhStoneGolem methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^600
! !

!NhStoneGolem methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^8
! !


!NhStoneGolem class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $' color: Color black name: 'stone golem'

! !

!NhStoneGolem class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhStoneGolem class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^14
! !

!NhStoneGolem class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 18.
		GmConstitution	-> 18.
		GmExperience	-> 15.
		GmDexterity		-> 18.
	}.
! !


!NhStrawGolem methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhStrawGolem methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^160
! !

!NhStrawGolem methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^2
! !


!NhStrawGolem class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $' color: Color black name: 'straw golem'

! !

!NhStrawGolem class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhStrawGolem class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^3
! !

!NhStrawGolem class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 8.
		GmConstitution	-> 5.
		GmExperience	-> 4.
		GmDexterity		-> 10.
	}.
! !


!NhStuddedLeatherArmor class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'studded leather armor'

! !

!NhStuddedLeatherArmor class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhStuddedLeatherArmor class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^0
! !

!NhStuddedLeatherArmor class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^3
! !

!NhStuddedLeatherArmor class methodsFor: 'type info' stamp: 'cr 4/24/2005 18:56'!
baseWeight
       ^20000

! !


!NhStuffManager methodsFor: 'calculations' stamp: 'cr 3/5/2005 21:54'!
numForUpdateIn: map
	^0		"objects don't spontaneously reappear."

! !

!NhStuffManager methodsFor: 'calculations' stamp: 'cr 9/20/2005 13:47'!
numRequiredIn: map
	| sides |
	sides := GmThing subclasses size.		"So that there's one of each."
	^(map creationState level max: 5) d: sides! !

!NhStuffManager methodsFor: 'map population' stamp: 'cr 9/20/2005 15:59'!
setupMap: aMap

"
	aMap creationState isBottom
		ifTrue: [self addItem: NhPantsOfYendor to: aMap
					ifUnable: [self error: 'unable to place the Pants of Yendor.']].
"   "Should probably remove this method."
	^super setupMap: aMap! !

!NhStuffManager methodsFor: 'overrides' stamp: 'cr 9/24/2005 21:32'!
depthFudgeFactor
	^4! !

!NhStuffManager methodsFor: 'overrides' stamp: 'cr 5/11/2005 11:41'!
lastDitchArmor
	^self slotForClass: GmAssHat! !

!NhStuffManager methodsFor: 'overrides' stamp: 'cr 5/11/2005 11:42'!
lastDitchWeapon
	^self slotForClass: GmRubberBaseballBat
! !

!NhStuffManager methodsFor: 'overrides' stamp: 'cr 9/24/2005 20:23'!
maxDepth
	^20		"This should probably get the depth from the Game object."! !

!NhStuffManager methodsFor: 'overrides' stamp: 'cr 9/19/2005 23:33'!
numPartitions
	"Number of classes of difficulty.  We use one per 4 levels."
	^5
! !


!NhTailorOfYendor methodsFor: 'initialization' stamp: 'cr 5/15/2005 22:50'!
createInitialInventory

	"Create the Tailor's inventory.  Note that this bypasses the usual stuff management
	 system."

	"To do: make his inventory more interesting.  Right now, it's pretty boring since I don't
	 have enough nifty items."

	{	NhPantsOfYendor new.
		NhElvenMithrilCoat new.
		NhHighBoots new.
		NhCommonHelmet new.
		NhLeatherGloves new.
		GmLongSword new.
	} do: [ :item | self insertAndDeploy: item or: [self error: 'createInitialInventory failed.']].! !

!NhTailorOfYendor methodsFor: 'initialization' stamp: 'cr 5/15/2005 22:37'!
initialize
	super initialize.	
	self createInitialInventory.! !

!NhTailorOfYendor methodsFor: 'attributes' stamp: 'cr 5/15/2005 22:29'!
damageRating
	^5! !

!NhTailorOfYendor methodsFor: 'attributes' stamp: 'cr 5/15/2005 22:29'!
experienceValue
	^2000
! !


!NhTailorOfYendor class methodsFor: 'ascii tiles' stamp: 'cr 5/15/2005 22:29'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $@ color: Color black name: 'human'
! !

!NhTailorOfYendor class methodsFor: 'object management stats' stamp: 'cr 5/15/2005 22:30'!
canCreateIn: aMap
	^false.		"This gets created as part of a custom level."! !

!NhTailorOfYendor class methodsFor: 'object management stats' stamp: 'cr 5/15/2005 22:29'!
isConcrete
	^true
! !

!NhTailorOfYendor class methodsFor: 'object management stats' stamp: 'cr 5/15/2005 22:30'!
maxAllowed
	^1.
! !

!NhTailorOfYendor class methodsFor: 'stat defaults' stamp: 'cr 9/25/2005 19:09'!
initialStatValues
	"The Tailor of Yendor is one bad-ass monster, let me tell you!!"
	^{
		GmStrength		-> 18.
		GmWisdom		-> 12.		"He can't be that bright, if he's working for Rodney."
		GmIntelligence	-> 16.
		GmDexterity		-> 18.
		GmConstitution	-> 18.
		GmCharisma		-> 18.
		GmExperience	-> 20000000.	"So he can't easily level up."
		GmArmorClass	-> 0.

		GmHitPoints		-> (100 + 30 atRandom).
		NhHungover	-> false.
		GmConfused		-> false.
		GmBurdened		-> false.
	}.! !


!NhTengu methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhTengu methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^280
! !

!NhTengu methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^7
! !


!NhTengu class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $i color: Color black name: 'tengu'

! !

!NhTengu class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhTengu class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^6
! !

!NhTengu class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 11.
		GmConstitution	-> 8.
		GmExperience	-> 7.
		GmDexterity		-> 13.
	}.
! !


!NhTiger methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1.1
! !

!NhTiger methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^280
! !

!NhTiger methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^1.1
! !


!NhTiger class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $f color: Color black name: 'tiger'

! !

!NhTiger class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhTiger class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^6
! !

!NhTiger class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 11.
		GmConstitution	-> 8.1.
		GmExperience	-> 7.
		GmDexterity		-> 13.
	}.
! !


!NhTitanothere methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhTitanothere methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^520
! !

!NhTitanothere methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^8
! !


!NhTitanothere class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $q color: Color black name: 'titanothere'

! !

!NhTitanothere class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhTitanothere class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^12
! !

!NhTitanothere class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 17.
		GmConstitution	-> 15.
		GmExperience	-> 13.
		GmDexterity		-> 18.
	}.
! !


!NhTopaz class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 03:53'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $* color: Color black name: 'topaz'

! !

!NhTopaz class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 03:53'!
isConcrete
	^true
! !

!NhTopaz class methodsFor: 'type info' stamp: 'cr 5/3/2005 23:56'!
baseCost
	^900


! !


!NhTrident class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhTrident class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhTrident class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^3
! !

!NhTrident class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^6
! !

!NhTrident class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^25
! !


!NhOlogHai methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhOlogHai methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^560
! !

!NhOlogHai methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhOlogHai class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $T color: Color black name: 'Olog-hai'

! !

!NhOlogHai class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhOlogHai class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^13
! !

!NhOlogHai class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 18.
		GmConstitution	-> 16.
		GmExperience	-> 14.
		GmDexterity		-> 18.
	}.
! !


!NhTroll methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhTroll methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^320
! !

!NhTroll methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhTroll class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $T color: Color black name: 'troll'

! !

!NhTroll class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhTroll class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^7
! !

!NhTroll class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 12.
		GmConstitution	-> 10.
		GmExperience	-> 8.
		GmDexterity		-> 14.
	}.
! !


!NhTurquoise class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 03:53'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $* color: Color black name: 'turquoise'

! !

!NhTurquoise class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 03:53'!
isConcrete
	^true
! !

!NhTurquoise class methodsFor: 'type info' stamp: 'cr 5/3/2005 23:56'!
baseCost
	^2000


! !


!NhUrukHai methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhUrukHai methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^160
! !

!NhUrukHai methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^8
! !


!NhUrukHai class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $o color: Color black name: 'Uruk-hai'

! !

!NhUrukHai class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhUrukHai class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^3
! !

!NhUrukHai class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 8.
		GmConstitution	-> 5.
		GmExperience	-> 4.
		GmDexterity		-> 10.
	}.
! !


!NhWarHammer class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhWarHammer class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhWarHammer class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^1
! !

!NhWarHammer class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^4
! !

!NhWarHammer class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^50
! !


!NhWarg methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhWarg methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^320
! !

!NhWarg methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhWarg class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $d color: Color black name: 'warg'

! !

!NhWarg class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhWarg class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^7
! !

!NhWarg class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 12.
		GmConstitution	-> 10.
		GmExperience	-> 8.
		GmDexterity		-> 14.
	}.
! !


!NhWarhorse methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhWarhorse methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^320
! !

!NhWarhorse methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhWarhorse class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $u color: Color black name: 'warhorse'

! !

!NhWarhorse class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhWarhorse class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^7
! !

!NhWarhorse class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 12.
		GmConstitution	-> 9.
		GmExperience	-> 8.
		GmDexterity		-> 14.
	}.
! !


!NhWhiteDragonScaleMail class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'white dragon scale mail'

! !

!NhWhiteDragonScaleMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhWhiteDragonScaleMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^9
! !

!NhWhiteDragonScaleMail class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^9
! !


!NhWhiteDragonScales class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'white dragon scales'

! !

!NhWhiteDragonScales class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhWhiteDragonScales class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^5
! !

!NhWhiteDragonScales class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^3
! !


!NhWingedGargoyle methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^3
! !

!NhWingedGargoyle methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^400
! !

!NhWingedGargoyle methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhWingedGargoyle class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $g color: Color black name: 'winged gargoyle'

! !

!NhWingedGargoyle class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhWingedGargoyle class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^9
! !

!NhWingedGargoyle class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 14.
		GmConstitution	-> 13.
		GmExperience	-> 10.
		GmDexterity		-> 16.
	}.
! !


!NhWolf methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhWolf methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^240
! !

!NhWolf methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhWolf class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $d color: Color black name: 'wolf'

! !

!NhWolf class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhWolf class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^5
! !

!NhWolf class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 10.
		GmConstitution	-> 8.
		GmExperience	-> 6.
		GmDexterity		-> 12.
	}.
! !


!NhWoodchuck methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhWoodchuck methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^160
! !

!NhWoodchuck methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhWoodchuck class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $r color: Color black name: 'woodchuck'

! !

!NhWoodchuck class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhWoodchuck class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^3
! !

!NhWoodchuck class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 8.
		GmConstitution	-> 5.
		GmExperience	-> 4.
		GmDexterity		-> 10.
	}.
! !


!NhWoodlandElf methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhWoodlandElf methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^200
! !

!NhWoodlandElf methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhWoodlandElf class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $@ color: Color black name: 'Woodland-elf'

! !

!NhWoodlandElf class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhWoodlandElf class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^4
! !

!NhWoodlandElf class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 9.
		GmConstitution	-> 7.
		GmExperience	-> 5.
		GmDexterity		-> 11.
	}.
! !


!NhWormTooth class methodsFor: 'ascii tiles' stamp: 'cr 9/18/2005 19:52'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $) color: Color black name: 'weapon'.

! !

!NhWormTooth class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
isConcrete
	^true
! !

!NhWormTooth class methodsFor: 'object management stats' stamp: 'cr 9/18/2005 19:52'!
minCreationLevel
	^-1
! !

!NhWormTooth class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseDamageRating
	^2
! !

!NhWormTooth class methodsFor: 'type info' stamp: 'cr 9/18/2005 19:52'!
baseWeight
	^20
! !


!NhWumpus methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^3
! !

!NhWumpus methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^360
! !

!NhWumpus methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhWumpus class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $q color: Color black name: 'wumpus'

! !

!NhWumpus class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhWumpus class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^8
! !

!NhWumpus class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 13.
		GmConstitution	-> 12.
		GmExperience	-> 9.
		GmDexterity		-> 15.
	}.
! !


!NhXorn methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^4
! !

!NhXorn methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^360
! !

!NhXorn methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhXorn class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $X color: Color black name: 'xorn'

! !

!NhXorn class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhXorn class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^8
! !

!NhXorn class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 13.
		GmConstitution	-> 13.
		GmExperience	-> 9.
		GmDexterity		-> 15.
	}.
! !


!NhYellowDragonScaleMail class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'yellow dragon scale mail'

! !

!NhYellowDragonScaleMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhYellowDragonScaleMail class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^9
! !

!NhYellowDragonScaleMail class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^9
! !


!NhYellowDragonScales class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:23'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $[ color: Color black name: 'yellow dragon scales'

! !

!NhYellowDragonScales class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
isConcrete
	^true
! !

!NhYellowDragonScales class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:23'!
minCreationLevel
	^5
! !

!NhYellowDragonScales class methodsFor: 'type info' stamp: 'cr 4/26/2005 23:35'!
baseArmorClassMod
	^3
! !


!NhYeti methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhYeti methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^240
! !

!NhYeti methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhYeti class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $Y color: Color black name: 'yeti'

! !

!NhYeti class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhYeti class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^5
! !

!NhYeti class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 10.
		GmConstitution	-> 7.
		GmExperience	-> 6.
		GmDexterity		-> 12.
	}.
! !


!NhZombie methodsFor: 'tests--capabilites' stamp: 'cr 4/3/2005 22:51'!
wearsArmor
	^false! !


!NhDwarfZombie methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhDwarfZombie methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^120
! !

!NhDwarfZombie methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhElfZombie methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhElfZombie methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^160
! !

!NhElfZombie methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^7
! !


!NhEttinZombie methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhEttinZombie methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^280
! !

!NhEttinZombie methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^10
! !


!NhGhoul methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhGhoul methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^160
! !

!NhGhoul methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^2
! !


!NhGiantZombie methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^2
! !

!NhGiantZombie methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^360
! !

!NhGiantZombie methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^8
! !


!NhGnomeZombie methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhGnomeZombie methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^80
! !

!NhGnomeZombie methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^5
! !


!NhHumanZombie methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhHumanZombie methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^200
! !

!NhHumanZombie methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^8
! !


!NhKoboldZombie methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhKoboldZombie methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^40
! !

!NhKoboldZombie methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^4
! !


!NhOrcZombie methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhOrcZombie methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^120
! !

!NhOrcZombie methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhSkeleton methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^1
! !

!NhSkeleton methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^520
! !

!NhSkeleton methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhZombie class methodsFor: 'type info' stamp: 'cr 9/22/2005 11:30'!
isUndead
	^true
! !

!NhZombie class methodsFor: 'type info' stamp: 'cr 9/23/2005 12:59'!
usesTools
	^false.		"Zombies are too dumb to use tools."
! !


!NhDwarfZombie class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $Z color: Color black name: 'dwarf zombie'

! !

!NhDwarfZombie class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhDwarfZombie class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^2
! !

!NhDwarfZombie class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 7.
		GmConstitution	-> 4.
		GmExperience	-> 3.
		GmDexterity		-> 9.
	}.
! !


!NhElfZombie class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $Z color: Color black name: 'elf zombie'

! !

!NhElfZombie class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhElfZombie class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^3
! !

!NhElfZombie class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 8.
		GmConstitution	-> 5.
		GmExperience	-> 4.
		GmDexterity		-> 10.
	}.
! !


!NhEttinZombie class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $Z color: Color black name: 'ettin zombie'

! !

!NhEttinZombie class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhEttinZombie class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^6
! !

!NhEttinZombie class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 11.
		GmConstitution	-> 8.
		GmExperience	-> 7.
		GmDexterity		-> 13.
	}.
! !


!NhGhoul class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $Z color: Color black name: 'ghoul'

! !

!NhGhoul class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhGhoul class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^3
! !

!NhGhoul class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 8.
		GmConstitution	-> 5.
		GmExperience	-> 4.
		GmDexterity		-> 10.
	}.
! !


!NhGiantZombie class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $Z color: Color black name: 'giant zombie'

! !

!NhGiantZombie class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhGiantZombie class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^8
! !

!NhGiantZombie class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 13.
		GmConstitution	-> 11.
		GmExperience	-> 9.
		GmDexterity		-> 15.
	}.
! !


!NhGnomeZombie class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $Z color: Color black name: 'gnome zombie'

! !

!NhGnomeZombie class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhGnomeZombie class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^1
! !

!NhGnomeZombie class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 6.
		GmConstitution	-> 3.
		GmExperience	-> 2.
		GmDexterity		-> 8.
	}.
! !


!NhHumanZombie class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $Z color: Color black name: 'human zombie'

! !

!NhHumanZombie class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhHumanZombie class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^4
! !

!NhHumanZombie class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 9.
		GmConstitution	-> 6.
		GmExperience	-> 5.
		GmDexterity		-> 11.
	}.
! !


!NhKoboldZombie class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $Z color: Color black name: 'kobold zombie'

! !

!NhKoboldZombie class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhKoboldZombie class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^0
! !

!NhKoboldZombie class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 5.
		GmConstitution	-> 2.
		GmExperience	-> 1.
		GmDexterity		-> 7.
	}.
! !


!NhOrcZombie class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $Z color: Color black name: 'orc zombie'

! !

!NhOrcZombie class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhOrcZombie class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^2
! !

!NhOrcZombie class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 7.
		GmConstitution	-> 4.
		GmExperience	-> 3.
		GmDexterity		-> 9.
	}.
! !


!NhSkeleton class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $Z color: Color black name: 'skeleton'

! !

!NhSkeleton class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhSkeleton class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^12
! !

!NhSkeleton class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 17.
		GmConstitution	-> 14.
		GmExperience	-> 13.
		GmDexterity		-> 18.
	}.
! !


!NhZruty methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
damageRating
	^3
! !

!NhZruty methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
experienceValue
	^400
! !

!NhZruty methodsFor: 'attributes' stamp: 'cr 3/12/2005 05:55'!
toHitValue
	^6
! !


!NhZruty class methodsFor: 'ascii tiles' stamp: 'cr 3/12/2005 05:55'!
asciiObjectDescription
	^GmAsciiObjectDescription letter: $z color: Color black name: 'zruty'

! !

!NhZruty class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
isConcrete
	^true
! !

!NhZruty class methodsFor: 'object management stats' stamp: 'cr 3/12/2005 05:55'!
minCreationLevel
	^9
! !

!NhZruty class methodsFor: 'stat defaults' stamp: 'cr 3/12/2005 05:55'!
initialStatValues
	^super initialStatValues,
	{
		GmStrength		-> 14.
		GmConstitution	-> 13.
		GmExperience	-> 10.
		GmDexterity		-> 16.
	}.
! !


!Point methodsFor: 'ObjEng-arithmetic' stamp: 'cr 1/3/2004 19:05'!
displacementRectArea
	"Return the area of the rectangle formed by this point and the origin."
	^(self x * self y) abs.
! !

!Point methodsFor: 'ObjEng-rounding' stamp: 'cr 10/2/2004 20:14'!
roundUpTo: grid
	| gridPoint |

	gridPoint := grid asPoint.
	^(x roundUpTo: gridPoint x) @ (y roundUpTo: gridPoint y).
! !


!PrefabLabel methodsFor: '*ObjEng-marking changed' stamp: 'cr 5/14/2005 17:59'!
changeText: newText
	self text: newText.
	self indicateChanged.
! !

!PrefabLabel methodsFor: '*ObjEng-marking changed' stamp: 'cr 5/14/2005 17:59'!
indicateChanged
	self borderColor: Color red.
! !

!PrefabLabel methodsFor: '*ObjEng-marking changed' stamp: 'cr 5/14/2005 18:00'!
indicateUnchanged
	self borderColor: self color.! !


!Rectangle methodsFor: 'accessing'!
corners
	"Return an array of corner points in the order of a quadrilateral spec for WarpBlt."

	^ Array
		with: self topLeft
		with: self bottomLeft
		with: self bottomRight
		with: self topRight
! !

!Rectangle methodsFor: 'ObjHack-random' stamp: 'cr 3/2/2005 14:10'!
randomInternalPoint
	^(self origin x to: self corner x - 1) atRandom @
		(self origin y to: self corner y - 1) atRandom.! !

!Rectangle methodsFor: 'ObjHack-enumerating' stamp: 'cr 10/2/2004 20:45'!
allBorderPointsDo: block
	(self topInside to: self bottomInside) do: [ :y | 
		block value: self leftInside @ y.
		block value: self rightInside @ y.
	].

	(self leftInside to: self rightInside) do: [ :x |
		block value: x@self topInside.
		block value: x@self bottomInside.
	].
! !

!Rectangle methodsFor: 'ObjHack-enumerating' stamp: 'cr 10/2/2004 20:45'!
allInteriorPointsDo: aBlock
	(self origin x to: self corner x - 1) do: [ :x |
		(self origin y to: self corner y - 1) do: [ :y |
			aBlock value: x@y.
		].
	].
! !

!Rectangle methodsFor: 'ObjHack-enumerating' stamp: 'cr 10/2/2004 20:46'!
bottomInsideDo: aBlock
	(self leftInside to: self rightInside) do: [ :x | aBlock value: x @ self bottom].
! !

!Rectangle methodsFor: 'ObjHack-enumerating' stamp: 'cr 10/2/2004 20:46'!
leftInsideDo: aBlock
	(self topInside to: self bottomInside) do: [ :y | aBlock value: self left @ y].
! !

!Rectangle methodsFor: 'ObjHack-enumerating' stamp: 'cr 10/2/2004 20:46'!
rightInsideDo: aBlock
	(self topInside to: self bottomInside) do: [ :y | aBlock value: self right @ y].
! !

!Rectangle methodsFor: 'ObjHack-enumerating' stamp: 'cr 10/2/2004 20:47'!
topInsideDo: aBlock
	(self leftInside to: self rightInside) do: [ :x | aBlock value: x @ self top].
! !

!Rectangle methodsFor: 'ObjHack-walls' stamp: 'cr 1/27/2004 23:40'!
expanded
	^self expandBy: 1! !

!Rectangle methodsFor: 'ObjHack-walls' stamp: 'cr 2/24/2005 03:20'!
insideRect
	"Assuming that self describes a room, return a rectangle that contains the entire space within
	 the walls of that room."
	^self origin + 1 corner: self corner - 1.! !

!Rectangle methodsFor: 'ObjHack-walls' stamp: 'cr 5/14/2005 14:26'!
minusWalls
	"The inverse of #plusWalls.  x plusWalls minusWalls = x."
	^self origin extent: self extent - 1.
! !

!Rectangle methodsFor: 'ObjHack-walls' stamp: 'cr 2/24/2005 03:07'!
plusWalls
	"Self such that #containsPoint will be true for the walls as well."
	^self origin extent: self extent + 1.
! !

!Rectangle methodsFor: 'ObjHack-walls' stamp: 'cr 2/28/2005 13:57'!
wallsComment

	"Because of the geometric requirements of rectangles, the outer borders are not considered
	 to be inside the rectangle.  That is, the area of a rectangle is the points between the origin
	 and the corner - 1@1 inclusively. 

	 This isn't too great for us.  We want the rectangle to contain the all of the points occupied
	 by the room INCLUDING the ones occupied by the walls.

	 In general, we try not to make waves.  Thus, a Rectangle representing a room has the
 	 top and right walls inside its bounds and the bottom and right walls outside.  That is, the
	 origin contains the coordinates for the top-left corner wall part and the corner the 
	 coordinates of the bottom-right corner wall part.

	 In addition, the method #plusWalls returns a rectangle where all of the wall points are
	 considered within the bounds of the rectangle by the normal rectangle functions.  In addition,
	 the *Inside methods return wall coordinates for type 1) rectangles.

	"! !

!Rectangle methodsFor: 'ObjHack-walls' stamp: 'cr 3/2/2005 14:25'!
withInsideRectPoints
	"Assuming that self describes a room, return a rectangle that contains the entire space within
	 the walls of that room such that #containsPoint: et. al. will ONLY be true for ALL points that
	 make up the inside of a room."
	^self origin + 1 corner: self corner.! !

!Rectangle methodsFor: 'ObjHack-tests' stamp: 'cr 5/14/2005 15:45'!
containsPointInAllRects: point
	^self insideRect containsPoint: point

	"This is for protocol compatibility with GmViewablePointSet."! !

!Rectangle methodsFor: 'ObjHack-tests' stamp: 'cr 5/13/2005 17:58'!
isRectangle
	^true! !

!Rectangle methodsFor: 'ObjHack-tests' stamp: 'cr 3/2/2005 15:11'!
within: distance of: otherRect
	"Determine whether self is within the the given distance from otherRect."

	"Note: this doesn't seem to work.  Must fix."
	^((self pointNearestTo: otherRect center) - (otherRect pointNearestTo: self center)) abs r <= distance
	! !

!Rectangle methodsFor: 'ObjHack-borders' stamp: 'cr 10/2/2004 20:44'!
bottomInside
	"Return the bottommost value that is still INSIDE the rectangle.  (The right and botton borders are not
	 considered part of the rectangle."
	^self bottom - 1.! !

!Rectangle methodsFor: 'ObjHack-borders' stamp: 'cr 10/3/2004 17:34'!
bottomLeftInside
	^self leftInside @ self bottomInside! !

!Rectangle methodsFor: 'ObjHack-borders' stamp: 'cr 10/3/2004 17:34'!
bottomRightInside
	^self rightInside @ self bottomInside
! !

!Rectangle methodsFor: 'ObjHack-borders' stamp: 'cr 2/23/2005 17:25'!
cornersInside
	"Return the coordinates of the corner pieces."
	^{	self topLeftInside. 
		self topRightInside.
		self bottomRightInside.
		self bottomLeftInside.
	}.
! !

!Rectangle methodsFor: 'ObjHack-borders' stamp: 'cr 10/2/2004 20:43'!
leftInside
	^self left
! !

!Rectangle methodsFor: 'ObjHack-borders' stamp: 'cr 10/2/2004 20:43'!
rightInside
	"Return the rightmost value that is still INSIDE the rectangle.  (The right and botton borders are not
	 considered part of the rectangle."
	^self right - 1.! !

!Rectangle methodsFor: 'ObjHack-borders' stamp: 'cr 10/2/2004 20:44'!
topInside
	^self top! !

!Rectangle methodsFor: 'ObjHack-borders' stamp: 'cr 10/3/2004 17:33'!
topLeftInside
	^self topLeft
! !

!Rectangle methodsFor: 'ObjHack-borders' stamp: 'cr 10/3/2004 17:33'!
topRightInside
	^self rightInside @ self topInside! !

!Rectangle methodsFor: 'ObjHack-GUI' stamp: 'cr 10/2/2004 20:17'!
griddedTo: grid
	"Answer a rectangle that conforms to 'grid' but can contain the receiver."

	^Rectangle origin: (origin truncateTo: grid)
				corner: (corner roundUpTo: grid)! !

!Rectangle methodsFor: 'ObjHack-GUI' stamp: 'cr 10/2/2004 14:45'!
limitedBy: aPoint
	"Return a copy that has been squashed to fit into 1@1 extent: aPoint."
	^(self origin max: 1@1) corner: (self corner min: aPoint).! !

!Rectangle methodsFor: 'ObjHack-GUI' stamp: 'cr 2/28/2005 13:11'!
shrunkByFraction: fraction
	| offset |

	[0.0 <= fraction and: [fraction <= 1.0]] assert.

	offset := (self extent * fraction * 0.5) rounded.
	^self origin + offset corner: self corner - offset.! !


!RoguelikeMapDisplay methodsFor: 'initialization' stamp: 'cr 9/29/2004 23:59'!
initialize
	super initialize.

	self color: Color white.
	self borderWidth: 0.

	self setSize: 2@2 font: (StrikeFont familyName: 'DefaultTextStyle' size: 10).
! !

!RoguelikeMapDisplay methodsFor: 'accessing' stamp: 'cr 10/2/2004 14:51'!
at: point

	"This is here because this method gets called from #drawOn: and errors during window updates
	 can wedge the entire system (sometimes).  So we're a bit more tolerant."
	((1@1 extent: characters extent) containsPoint: point) 
		ifFalse: [
			"Transcript nextPutAll: point printString; cr; endEntry."
			^Character space.
		].

	^characters at: point x at: point y.
! !

!RoguelikeMapDisplay methodsFor: 'accessing' stamp: 'cr 9/29/2004 23:33'!
at: point put: char
	characters at: point x at: point y put: char.
	self damageAt: point.

! !

!RoguelikeMapDisplay methodsFor: 'accessing' stamp: 'cr 9/29/2004 23:20'!
clear
	characters atAllPut: Character space.
! !

!RoguelikeMapDisplay methodsFor: 'accessing' stamp: 'cr 3/3/2005 14:22'!
contentsCopy
	^characters copy
! !

!RoguelikeMapDisplay methodsFor: 'accessing' stamp: 'cr 3/2/2005 23:04'!
highlightPoint: aPoint
	highlightPoint := aPoint.
	self damageAt: aPoint.
! !

!RoguelikeMapDisplay methodsFor: 'accessing' stamp: 'cr 3/3/2005 17:37'!
setContents: a2dArray

	[a2dArray extent = characters extent] assert.
	
	characters := a2dArray copy.

! !

!RoguelikeMapDisplay methodsFor: 'accessing' stamp: 'cr 9/29/2004 23:21'!
setSize: extent font: dispFont
	characters := Array2D extent: extent.
	self clear.

	font := dispFont.
	self sizeToFit.
! !

!RoguelikeMapDisplay methodsFor: 'accessing' stamp: 'cr 5/19/2005 21:10'!
view: attachedSimpleGUI
	view := attachedSimpleGUI! !

!RoguelikeMapDisplay methodsFor: 'geometry' stamp: 'cr 9/29/2004 23:11'!
extent: aPoint
	"do nothing--changing size is Not Allowed."
! !

!RoguelikeMapDisplay methodsFor: 'geometry' stamp: 'cr 10/2/2004 14:44'!
indexRectFor: screenRect
	"Given a rectangle within my bounds, return a rectangle encompasing the indexes of those tiles
	 with some part within that rectangle."
	| resultOrigin resultExtent adjustedRect |

	adjustedRect := (screenRect translateBy: self innerBounds origin negated) griddedTo: self tileSize.

	resultOrigin := (adjustedRect origin // self tileSize).
	resultExtent := (adjustedRect extent // self tileSize).

	^(resultOrigin extent: resultExtent) limitedBy: characters extent.
! !

!RoguelikeMapDisplay methodsFor: 'geometry' stamp: 'cr 9/29/2004 23:35'!
rectForTileAt: point
	^self innerBounds origin + 
		((point - 1) * self tileSize) extent: self tileSize.

	
	! !

!RoguelikeMapDisplay methodsFor: 'geometry' stamp: 'cr 9/29/2004 23:19'!
sizeToFit
	super extent: characters extent * self tileSize.! !

!RoguelikeMapDisplay methodsFor: 'geometry' stamp: 'cr 5/19/2005 21:17'!
tileCoordForPoint: pt
	^(self indexRectFor: (pt extent: self tileSize * 2)) origin + 1! !

!RoguelikeMapDisplay methodsFor: 'geometry' stamp: 'cr 9/29/2004 23:19'!
tileSize
	^font maxWidth @ font height! !

!RoguelikeMapDisplay methodsFor: 'drawing' stamp: 'cr 10/3/2004 22:14'!
damageAt: aPoint
	self invalidRect: (self rectForTileAt: aPoint).
	

! !

!RoguelikeMapDisplay methodsFor: 'drawing' stamp: 'cr 3/2/2005 23:12'!
drawCharAt: point on: canvas

	"canvas fillRectangle: (self rectForTileAt: point) color: Color random."

	| letterColor |
	letterColor := Color black.
	point = highlightPoint
		ifTrue: [
			canvas fillRectangle: (self rectForTileAt: point) color: Color red.
			letterColor := Color white.
		].

	canvas 
		drawString: (self at: point) asString
		at: (self rectForTileAt: point) origin
		font: font
		color: letterColor.

! !

!RoguelikeMapDisplay methodsFor: 'drawing' stamp: 'cr 10/3/2004 22:20'!
drawOn: aCanvas
	super drawOn: aCanvas.

	"aCanvas fillRectangle: (aCanvas clipRect intersect: self innerBounds) color: Color random."

	((self indexRectFor: (aCanvas clipRect intersect: self innerBounds)) expandBy: 1)
		allInteriorPointsDo: [ :pt | self drawCharAt: pt on: aCanvas]    "^^^^^^^^^^^^ Kludge!!"

	"There's some bug somewhere that's causing tiles to get clipped during small updates.  After spending
	 far too much time trying to track it down, I gave up and just update the tiles around them too."

! !

!RoguelikeMapDisplay methodsFor: 'drawing' stamp: 'cr 10/2/2004 15:55'!
xxxdrawCharAt: point on: canvas
	"canvas fillRectangle: (self rectForTileAt: point) color: Color random."
	"canvas frameRectangle: (self rectForTileAt: point) color: Color random."

"
	canvas fillRectangle: canvas clipRect color: Color lightRed.
	canvas fillRectangle: (self rectForTileAt: point) color: Color lightGreen.
"
"
	((self rectForTileAt: point) containsRect: canvas clipRect)
		ifFalse: [canvas fillRectangle: canvas clipRect color: Color lightRed].
"

	((self indexRectFor: (self rectForTileAt: point)) containsPoint: point - 1)
		ifFalse: [canvas fillRectangle: canvas clipRect color: Color lightRed].


	canvas 
		drawString: (self at: point) asString
		at: (self rectForTileAt: point) origin
		font: font
		color: Color black.
! !

!RoguelikeMapDisplay methodsFor: 'events' stamp: 'cr 5/19/2005 20:59'!
handlesMouseDown: evt
	^evt redButtonChanged! !

!RoguelikeMapDisplay methodsFor: 'events' stamp: 'cr 5/24/2005 19:28'!
mouseUp: evt
	view showMapDetailAt: (self tileCoordForPoint: evt position)! !


!SequenceableCollection methodsFor: '*ObjEng-testing' stamp: 'cr 3/6/2005 00:08'!
includesIndex: index
	^index > 0 and: [index <= self size]
! !

!SequenceableCollection methodsFor: '*ObjEng-copying' stamp: 'cr 3/8/2005 15:22'!
withUniqueKeys
	"Where self is an array of associations, return a copy such that only the last entry for
	 a particular key is in the result."
	| dict |
	dict := Dictionary new.
	self do: [ :assoc | dict add: assoc].
	^(dict keys collect: [ :key | dict associationAt: key]) asOrderedCollection.! !


!Array2D methodsFor: 'copying' stamp: 'cr 3/3/2005 14:37'!
copy
	^ super clone setContents: contents copy! !

!Array2D methodsFor: '*ObjEng-enumeration' stamp: 'cr 5/15/2005 17:56'!
horizFirstWithCoordsDo: aBlock
	1 to: self height do: [ :y |
		1 to: self width do: [ :x |
			aBlock value: x@y value: (self at: x at: y).
		].
	].

		! !


!SimpleGUI methodsFor: 'initialization' stamp: 'cr 4/25/2005 00:37'!
initializeControlPanel
	controlPanel := PrefabManager new.
	statDict := IdentityDictionary new.

	self statsToShow withIndexDo: [ :stat :index | self addStatItem: stat at: index].
 	self updateControlPanel.
! !

!SimpleGUI methodsFor: 'initialization' stamp: 'cr 10/4/2004 00:43'!
initializeKeyHandling
	self initializeKeyTransTbl.
	self takeAllKeystrokes.! !

!SimpleGUI methodsFor: 'initialization' stamp: 'cr 10/4/2004 00:42'!
initializeKeyTransTbl
	keyTranslationTable := IdentityDictionary new.
	self class defaultKeyTable pairsDo: [ :key :message | keyTranslationTable at: key put: message].! !

!SimpleGUI methodsFor: 'initialization' stamp: 'cr 3/13/2005 19:45'!
initializeManagers
	self buildMainWindow.
	self fixLayoutDistances.! !

!SimpleGUI methodsFor: 'initialization' stamp: 'cr 3/20/2005 19:10'!
initializeMapCache
	self testAndClearMapReplacement.
! !

!SimpleGUI methodsFor: 'initialization' stamp: 'cr 10/3/2004 22:22'!
initializeMessagePanel
	messagePanel := PrefabEditScrollableWrapper new.
	messagePanel payload
		isReadOnly: true.

! !

!SimpleGUI methodsFor: 'initialization' stamp: 'cr 1/10/2004 00:45'!
initializeMovementButtons
	(controlPanel clients collect: [ :x | x tag ] thenSelect: [ :tag | tag beginsWith: 'go'])
		do: [ :tag | 
				(controlPanel clientWithTag: tag) 
					action: #keystrokeEvent:;
					target: self;
					args: {tag}.
		].
! !

!SimpleGUI methodsFor: 'initialization' stamp: 'cr 3/20/2005 19:13'!
initializePanel
	self initializeMapCache.
	self createPanel.
	self updateEntireMap.

! !

!SimpleGUI methodsFor: 'initialization' stamp: 'cr 5/14/2005 19:05'!
on: aGame
	game := aGame.
	seenLevels := IdentityDictionary new.
	monsterPoints := Set new.

	self initializePanel.
	self initializeControlPanel.
	self initializeMessagePanel.

	self initializeManagers.
	
	self initializeKeyHandling.

! !

!SimpleGUI methodsFor: 'initialization' stamp: 'cr 3/20/2005 19:11'!
takeAllKeystrokes

	"Set all submorphs to forward their keystrokes to, this object.  I'm doing this because
	 Prefab's keyboard support is currently non-existant.  This is a quick-n-dirty fix."
	
	| top |
	top := manager owner ifNil: [manager].
	top allMorphsDo: [ :m | m on: #keyStroke send: #keyPressed: to: self].

! !

!SimpleGUI methodsFor: 'construction' stamp: 'cr 4/25/2005 00:41'!
addStatItem: stat at: index
	| morph panelCoord |
	morph := PrefabLabel new
				extent: self panelColumnWidth @ self panelRowHeight;
				color: controlPanel color muchLighter;
				text: '';
				yourself.

	panelCoord := ((index - 1) // self panelRows) @ ((index - 1) \\ self panelRows).
	controlPanel addClient: morph atRelPosition: panelCoord
											* (self panelColumnWidth @ self panelRowHeight).
	stat ifNil: [^self].

	morph text: stat descString.
	statDict at: stat put: morph.

	! !

!SimpleGUI methodsFor: 'construction' stamp: 'cr 2/23/2005 02:20'!
buildMainWindow
	| panelManager controlPanelPos |

	controlPanelPos := 0 @ (self messagePanelHeight + self mapPaneHeight).

	self createAndSizeMainManager.

	panelManager := self createAndSizePanelManager.
	controlPanel extent: (self windowWidth @ self controlPaneHeight) * self pixelMult.
	messagePanel extent: (self windowWidth @ self messagePanelHeight) * self pixelMult.

	manager
		addClient: messagePanel atRelPosition: 0@0;
		addClient: panelManager atRelPosition: (0 @ self messagePanelHeight) * self pixelMult;
		addClient: controlPanel atRelPosition: controlPanelPos * self pixelMult.


! !

!SimpleGUI methodsFor: 'construction' stamp: 'cr 5/11/2005 12:33'!
createAndSizeMainManager
	| windowDim |
	windowDim := self windowWidth @ 
					(self messagePanelHeight + self mapPaneHeight + self controlPaneHeight).
	
	manager := GmPrefabFullScreenManager new.
	manager
		minSize: 350@350;
		resizer: FixedDistanceResizer new;
		extent: windowDim * self pixelMult;
		resizeAction: #centerPlayer;
		resizeTarget: self.

! !

!SimpleGUI methodsFor: 'construction' stamp: 'cr 2/23/2005 02:16'!
createAndSizePanelManager
	^ PrefabScrollingManager new
		color: panel color;
		addClient: panel atRelPosition: 0@0;
		extent: (self windowWidth @ self mapPaneHeight) * self pixelMult;
		yourself.
! !

!SimpleGUI methodsFor: 'construction' stamp: 'cr 5/19/2005 21:10'!
createPanel
	panel := RoguelikeMapDisplay new.
	panel	setSize: self map extent font: (Prefab fontNamed: self preferredFont);
			view: self.
! !

!SimpleGUI methodsFor: 'construction' stamp: 'cr 2/23/2005 02:27'!
fixLayoutDistances
	manager resizer
		fixRightOf: messagePanel;
		fixRightAndBottomOf: panel owner owner;  "<--ick!! depends on layout order."
		fixAllButLeftOf: controlPanel.
! !

!SimpleGUI methodsFor: 'construction' stamp: 'cr 4/25/2005 00:39'!
statsToShow
	^self shownStatNames collect: [ :nm | nm isEmpty ifTrue: [nil] ifFalse: [game player statNamed: nm]]! !

!SimpleGUI methodsFor: 'tests' stamp: 'cr 3/3/2005 15:42'!
levelChanged
	^(map = game player map) not
! !

!SimpleGUI methodsFor: 'map panel management' stamp: 'cr 4/3/2005 19:40'!
checkForCreatureAt: point
	(self map hasCreatureAt: point)
		ifTrue: [monsterPoints add: point]
		ifFalse: [monsterPoints remove: point ifAbsent: []].
! !

!SimpleGUI methodsFor: 'map panel management' stamp: 'cr 3/4/2005 01:02'!
resetPlayerViewRegion
	game player viewRegion clearCache.
! !

!SimpleGUI methodsFor: 'map panel management' stamp: 'cr 3/20/2005 19:07'!
testAndClearMapReplacement
	map = game player map
		ifFalse: [
			map := game player map.
			^true.
		].

	^false.
! !

!SimpleGUI methodsFor: 'map panel management' stamp: 'cr 3/4/2005 00:59'!
updateMapReference
	map := game player map.
! !

!SimpleGUI methodsFor: 'display' stamp: 'cr 2/28/2005 13:37'!
centerPlayer
	| centerCoords |
	centerCoords := (panel rectForTileAt: game player coordinates) center.
	panel manager scrollToShow: centerCoords withThreshold: 0.2.! !

!SimpleGUI methodsFor: 'display' stamp: 'cr 4/3/2005 19:59'!
clearUnseenMonsters
	| viewable newMonsterPoints |

	viewable := game player viewRegion.
	newMonsterPoints := Set new.

	monsterPoints do: [ :pt |
		(viewable canSeePoint: pt)
			ifTrue: [newMonsterPoints add: pt]
			ifFalse: [self redrawWithoutMonsterAt: pt].
	].

	monsterPoints := newMonsterPoints.
! !

!SimpleGUI methodsFor: 'display' stamp: 'cr 3/2/2005 23:09'!
highlightPlayer
	panel highlightPoint: game player coordinates.
! !

!SimpleGUI methodsFor: 'display' stamp: 'cr 3/27/2005 16:10'!
openInWholeWorld
	manager openInWorld; startStepping.
	manager on: #mouseDown send: #yourself to: self.  "Prevent grabs."
	self updateView.
! !

!SimpleGUI methodsFor: 'display' stamp: 'cr 3/13/2005 19:58'!
openInWorld
	manager openInSystemWindowNamed: 'Nethack II: Quest For Pants'.
	manager stopStepping.
	self updateView.
! !

!SimpleGUI methodsFor: 'display' stamp: 'cr 4/3/2005 19:42'!
redrawAt: aPoint
	| asciiDescr |
	asciiDescr := game player map asciiTileAt: aPoint.
	panel at: aPoint put: asciiDescr letter asString.
! !

!SimpleGUI methodsFor: 'display' stamp: 'cr 4/3/2005 19:56'!
redrawWithoutMonsterAt: aPoint
	| asciiDescr |
	asciiDescr := game player map nonCreatureAsciiTileAt: aPoint.
	panel at: aPoint put: asciiDescr letter asString.
! !

!SimpleGUI methodsFor: 'display' stamp: 'cr 3/5/2005 19:53'!
switchPanelToCurrentMap
	seenLevels at: map put: panel contentsCopy.

	(seenLevels includesKey: game player map)
		ifTrue: [panel setContents: (seenLevels at: game player map)]
		ifFalse: [panel clear].

	panel changed.

	self updateVisiblePoints.
! !

!SimpleGUI methodsFor: 'display' stamp: 'cr 3/3/2005 15:30'!
updateAllPoints
	map bounds allInteriorPointsDo: [ :pt | self updateAt: pt].! !

!SimpleGUI methodsFor: 'display' stamp: 'cr 4/3/2005 19:42'!
updateAt: aPoint
	self redrawAt: aPoint.
	self checkForCreatureAt: aPoint.
! !

!SimpleGUI methodsFor: 'display' stamp: 'cr 5/14/2005 18:02'!
updateControlPanel
	statDict keysAndValuesDo: [ :stat :morph | 
		stat testAndClearChanged
			ifTrue: [morph changeText: stat descString]
			ifFalse: [morph indicateUnchanged].
	].
! !

!SimpleGUI methodsFor: 'display' stamp: 'cr 3/4/2005 01:01'!
updateEntireMap
	self resetPlayerViewRegion.
	self switchPanelToCurrentMap.
	self updateMapReference.
! !

!SimpleGUI methodsFor: 'display' stamp: 'cr 4/3/2005 19:26'!
updateFromMap
	self levelChanged
		ifTrue: [self updateEntireMap]
		ifFalse: [
			self updateVisiblePoints.
			self clearUnseenMonsters.
		].
	
	self highlightPlayer.
	self centerPlayer.! !

!SimpleGUI methodsFor: 'display' stamp: 'cr 3/20/2005 19:18'!
updateView
	self updateFromMap.
	self updateControlPanel.
! !

!SimpleGUI methodsFor: 'display' stamp: 'cr 5/14/2005 15:01'!
updateVisiblePoints
	| viewRegion |

	viewRegion := game player viewRegion.
	viewRegion update.
	viewRegion fastVisiblePointsDo: [ :pt | self updateAt: pt].! !

!SimpleGUI methodsFor: 'accessing' stamp: 'cr 3/11/2005 14:36'!
close
	manager owner
		ifNotNil: [manager owner delete]
		ifNil: [manager delete].

! !

!SimpleGUI methodsFor: 'accessing' stamp: 'cr 1/8/2004 22:48'!
game
	^game! !

!SimpleGUI methodsFor: 'accessing' stamp: 'cr 1/9/2004 21:37'!
manager
	^manager
! !

!SimpleGUI methodsFor: 'accessing' stamp: 'cr 3/20/2005 20:09'!
map
	^map
! !

!SimpleGUI methodsFor: 'keystrokes' stamp: 'cr 9/25/2005 15:43'!
keyPressed: evt
	| messageName |

	messageName := keyTranslationTable at: evt keyCharacter ifAbsent: [^self].

	"To do: come up with a cleaner way to handle the special cases."

	"Special case: auto-wait."
	messageName = #restUntilHealed
		ifTrue: [^self game interactiveWaitUntilHealed].

	"Special case 2: help"
	messageName = #showHelp
		ifTrue: [^self showUserHelp].

	self game userEvent: messageName.! !

!SimpleGUI methodsFor: 'keystrokes' stamp: 'cr 9/28/2004 22:15'!
keystrokeEvent: messageName
	self game userEvent: messageName.! !

!SimpleGUI methodsFor: 'user information' stamp: 'cr 9/25/2005 15:57'!
commandList
	| commands tabs |

	commands := OrderedCollection new.
	tabs := String tab, String tab, String tab.

	self class defaultKeyTable pairsDo: [ :key :msg |
		(msg beginsWith: 'interactive')
			ifTrue: [msg := msg allButFirst: 11].

		commands add: tabs, key asString, tabs, msg asString studlyCapsToWords
	].

	^commands! !

!SimpleGUI methodsFor: 'user information' stamp: 'cr 5/24/2005 19:33'!
describeVisibleAt: point	
	| topObj |
	topObj := map topmostAt: point.
	self message: topObj longDescriptionString, ' (', topObj class asciiObjectDescription longDescription, ')'! !

!SimpleGUI methodsFor: 'user information' stamp: 'cr 5/24/2005 19:24'!
mapDetailMsg: msg
	^self message: msg! !

!SimpleGUI methodsFor: 'user information' stamp: 'cr 5/24/2005 19:24'!
showMapDetailAt: point
	(game player viewRegion canSeePoint: point)
		ifFalse: [^self mapDetailMsg: 'You can''t see that point right now.'].
	
	self describeVisibleAt: point.
! !

!SimpleGUI methodsFor: 'user information' stamp: 'cr 9/25/2005 15:52'!
showUserHelp
	(PopUpMenu labelArray: self commandList lines: #()) startUpWithCaption: 'Keyboard Commands:'.
! !

!SimpleGUI methodsFor: 'text messages' stamp: 'cr 5/14/2005 19:03'!
message: msgText
	| text |
	text := messagePanel payload text, msgText guaranteeTrailingCR.
	text := text shortenedToLineBy: self messageTextChopSize 
				ifLongerThan: self maxMessageTextSize.
	messagePanel	payload text: text;
					fractionalPosition: 1.0.
! !

!SimpleGUI methodsFor: 'geometry' stamp: 'cr 2/23/2005 02:15'!
pixelMult

	"The number by which to multiply all coordinates to better match the existing resolution. "

	"This is a bit of a hack in that it depends on the panel existing when really we should be getting
	 this number from somewhere else, the display for example."

	^panel tileSize.
! !

!SimpleGUI methodsFor: 'constants' stamp: 'cr 2/23/2005 02:03'!
controlPaneHeight
	^10
! !

!SimpleGUI methodsFor: 'constants' stamp: 'cr 2/23/2005 01:56'!
mapPaneHeight
	^70
! !

!SimpleGUI methodsFor: 'constants' stamp: 'cr 5/14/2005 19:04'!
maxMessageTextSize
	^2000! !

!SimpleGUI methodsFor: 'constants' stamp: 'cr 2/23/2005 01:56'!
messagePanelHeight
	^10
! !

!SimpleGUI methodsFor: 'constants' stamp: 'cr 5/14/2005 19:05'!
messageTextChopSize
	^300! !

!SimpleGUI methodsFor: 'constants' stamp: 'cr 5/11/2005 11:12'!
panelColumnWidth
	^((Prefab fontNamed: self preferredFont) widthOf: $X) * 25.! !

!SimpleGUI methodsFor: 'constants' stamp: 'cr 2/13/2005 23:30'!
panelColumns
	^4! !

!SimpleGUI methodsFor: 'constants' stamp: 'cr 2/13/2005 23:31'!
panelRowHeight
	^((Prefab fontNamed: self preferredFont) height * 1.5) rounded.! !

!SimpleGUI methodsFor: 'constants' stamp: 'cr 3/13/2005 20:00'!
panelRows
	^6! !

!SimpleGUI methodsFor: 'constants' stamp: 'cr 9/28/2004 22:48'!
preferredFont
	^'Atlanta-12'.! !

!SimpleGUI methodsFor: 'constants' stamp: 'cr 4/25/2005 00:43'!
shownStatNames
	^#(	'DungeonLevel' 'HitPoints' 'ArmorClass' 'Strength' 'Dexterity' 'Constitution'
		'Turn' 'Experience' 'Intelligence' 'Wisdom' 'Charisma' ''
		'Burdened' 'Confused' 'Hungover' '' '' '')! !

!SimpleGUI methodsFor: 'constants' stamp: 'cr 2/23/2005 01:55'!
windowWidth
	^160
! !


!SimpleGUI class methodsFor: 'instance creation' stamp: 'cr 1/3/2004 19:42'!
on: aMap
	^self basicNew on: aMap; yourself.! !

!SimpleGUI class methodsFor: 'constants' stamp: 'cr 9/25/2005 15:43'!
defaultKeyTable

	^#(
		$h	goWest
		$j	goSouth
		$k	goNorth
		$l	goEast
		$y	goNorthWest
		$u	goNorthEast
		$b	goSouthWest
		$n	goSouthEast
		$.	wait
		$>	invokePortal
		$<	invokePortal		"for the benefit of nethack finger macros."

		$d	interactiveDrop
		$,	interactiveTake
		$i	interactiveInventory
		$w	interactiveWield
		$W	interactiveWear
		$T	interactiveUnWear
		$P	interactivePutOn
		$R	interactiveTakeOff

		$r	restUntilHealed

		$S	interactiveSaveAndQuit

		$?	showHelp
	).! !


!SortedCollection methodsFor: '*ObjEng-random' stamp: 'cr 5/10/2005 23:17'!
atRandomPartitionedBy: numPartitions numDice: numDice 
	^self atRandomPartitionedBy: numPartitions numDice: numDice
		ifEmpty: [self error: 'attempt to pick a random item from empty collection.'].
! !

!SortedCollection methodsFor: '*ObjEng-random' stamp: 'cr 9/19/2005 23:35'!
atRandomPartitionedBy: numPartitions numDice: numDice ifEmpty: errorBlock
	| numSides index |
	self isEmpty ifTrue: [^errorBlock value].

	numSides := self size // numPartitions max: 1.
	index := (numDice d: numSides) - numDice + 1.
	index := index min: self size max: 1.
	^self at: index.

! !

!SortedCollection methodsFor: '*ObjEng-random' stamp: 'cr 9/24/2005 20:47'!
atRandomUpToFraction: fraction
	| rangeEnd |
	rangeEnd := (self size * fraction) min: self size max: 1.
	^self at: (1 to: rangeEnd rounded) atRandom
! !

!SortedCollection methodsFor: '*ObjEng-searching' stamp: 'cr 8/5/2005 20:03'!
firstIndexRejecting: aBlock
	self withIndexDo: [ :item :index | (aBlock value: item) ifFalse: [^index]].
	^self size + 1.
! !


!String methodsFor: '*obj-eng' stamp: 'cr 5/14/2005 18:52'!
allLinesAfterIndex: cutoffIndex
	| index |
	index := self indexOf: Character cr startingAt: cutoffIndex ifAbsent: [cutoffIndex].
	^self copyFrom: index to: self size.
! !

!String methodsFor: '*obj-eng' stamp: 'cr 2/13/2005 19:47'!
asStatName

	| result |

	result := self.
	(self beginsWith: 'stat')
		ifTrue: [result := self allButFirst: 4].

	(self beginsWith: 'atStat')
		ifTrue: [result := self allButFirst: 6].

	^self last = $:
		ifTrue: [result allButLast]
		ifFalse: [result].

				! !

!String methodsFor: '*obj-eng' stamp: 'cr 5/14/2005 18:34'!
guaranteeTrailingCR
	self last = Character cr ifTrue: [^self].
	^self, String cr.! !

!String methodsFor: '*obj-eng' stamp: 'cr 5/14/2005 18:46'!
shortenedToLineBy: numChars ifLongerThan: maxLen
	self size <= maxLen ifTrue: [^self].
	^self allLinesAfterIndex: numChars
! !

!String methodsFor: '*obj-eng' stamp: 'cr 3/4/2005 18:03'!
studlyCapsToWords

	"Example: converts 'SmallTalk' to 'small talk'."

	^(self inject: '' into: [ :str :char | char isUppercase 
									ifTrue: [str, ' ', char asLowercase asString]
									ifFalse: [str, char asString]])
		withBlanksTrimmed.! !

!String methodsFor: '*obj-eng' stamp: 'cr 3/9/2005 23:08'!
unCapitalized
	(self isEmpty or: [self first isUppercase not]) ifTrue: [^self].
	^self first asLowercase asString, self allButFirst.! !

!String methodsFor: '*obj-eng' stamp: 'cr 4/3/2005 19:03'!
withDefiniteArticle
	^'the ', self
! !

!String methodsFor: '*obj-eng' stamp: 'cr 3/4/2005 17:59'!
withIndefiniteArticle
	self first isLetter ifFalse: [^self].

	^self first isVowel
		ifTrue: ['an ', self]
		ifFalse: ['a ', self]! !

!String methodsFor: '*obj-eng' stamp: 'cr 3/11/2005 21:08'!
wordsToStudlyCaps
	| result capitalizeNext |

	capitalizeNext := true.
	result := WriteStream on: (String new: self size).
	self do: [ :c | 
		c isSeparator 
			ifTrue: [capitalizeNext := true]
			ifFalse: [
				capitalizeNext ifTrue: [c := c asUppercase].
				result nextPut: c.
				capitalizeNext := false
			]
	].

	^result contents.

				! !

String removeSelector: #shortenToLineBy:ifLongerThan:!
SortedCollection removeSelector: #entryNearest:using:!

!SimpleGUI class reorganize!
('instance creation' on:)
('constants' defaultKeyTable)
!

SimpleGUI removeSelector: #describeMonsterAt:!
SimpleGUI removeSelector: #showMessageLine:!
SimpleGUI removeSelector: #showTopItemAt:!
SimpleGUI removeSelector: #userHelpText!
SimpleGUI removeSelector: #youSee:!

!SimpleGUI reorganize!
('initialization' initializeControlPanel initializeKeyHandling initializeKeyTransTbl initializeManagers initializeMapCache initializeMessagePanel initializeMovementButtons initializePanel on: takeAllKeystrokes)
('construction' addStatItem:at: buildMainWindow createAndSizeMainManager createAndSizePanelManager createPanel fixLayoutDistances statsToShow)
('tests' levelChanged)
('map panel management' checkForCreatureAt: resetPlayerViewRegion testAndClearMapReplacement updateMapReference)
('display' centerPlayer clearUnseenMonsters highlightPlayer openInWholeWorld openInWorld redrawAt: redrawWithoutMonsterAt: switchPanelToCurrentMap updateAllPoints updateAt: updateControlPanel updateEntireMap updateFromMap updateView updateVisiblePoints)
('accessing' close game manager map)
('keystrokes' keyPressed: keystrokeEvent:)
('user information' commandList describeVisibleAt: mapDetailMsg: showMapDetailAt: showUserHelp)
('text messages' message:)
('geometry' pixelMult)
('constants' controlPaneHeight mapPaneHeight maxMessageTextSize messagePanelHeight messageTextChopSize panelColumnWidth panelColumns panelRowHeight panelRows preferredFont shownStatNames windowWidth)
('private')
!


!RoguelikeMapDisplay reorganize!
('initialization' initialize)
('accessing' at: at:put: clear contentsCopy highlightPoint: setContents: setSize:font: view:)
('geometry' extent: indexRectFor: rectForTileAt: sizeToFit tileCoordForPoint: tileSize)
('drawing' damageAt: drawCharAt:on: drawOn: xxxdrawCharAt:on:)
('events' handlesMouseDown: mouseUp:)
!


!Rectangle reorganize!
('accessing' aboveCenter area bottom bottom: bottomCenter bottomLeft bottomRight boundingBox center corner corners extent height innerCorners left left: leftCenter origin right right: rightCenter top top: topCenter topLeft topRight width)
('comparing' = hash hashMappedBy:)
('rectangle functions' adjustTo:along: allAreasOutsideList:do: allAreasOutsideList:startingAt:do: amountToTranslateWithin: areasOutside: bordersOn:along: encompass: expandBy: extendBy: forPoint:closestSideDistLen: insetBy: insetOriginBy:cornerBy: intersect: merge: outsetBy: pointNearestTo: quickMerge: rectanglesAt:height: sideNearestTo: translatedToBeWithin: withBottom: withHeight: withLeft: withRight: withSide:setTo: withSideOrCorner:setToPoint: withSideOrCorner:setToPoint:minExtent: withSideOrCorner:setToPoint:minExtent:limit: withTop: withWidth:)
('testing' containsPoint: containsRect: hasPositiveExtent intersects: isTall isWide isZero)
('truncation and round off' rounded truncateTo: truncated)
('transforming' align:with: centeredBeneath: flipBy:centerAt: newRectButtonPressedDo: newRectFrom: rotateBy:centerAt: scaleBy: scaleFrom:to: squishedWithin: translateBy:)
('printing' encodeForRemoteCanvas encodeForRemoteCanvasB encodePostscriptOn: printOn: propertyListOn: storeOn:)
('private' setOrigin:corner:)
('FMP' deltaToEnsureInOrCentered:extra:)
('Prefab-rectangle functions' bestFitIn: heightKeepingShape: tallness widthKeepingShape:)
('ObjHack-random' randomInternalPoint)
('ObjHack-enumerating' allBorderPointsDo: allInteriorPointsDo: bottomInsideDo: leftInsideDo: rightInsideDo: topInsideDo:)
('ObjHack-walls' expanded insideRect minusWalls plusWalls wallsComment withInsideRectPoints)
('ObjHack-tests' containsPointInAllRects: isRectangle within:of:)
('ObjHack-borders' bottomInside bottomLeftInside bottomRightInside cornersInside leftInside rightInside topInside topLeftInside topRightInside)
('ObjHack-GUI' griddedTo: limitedBy: shrunkByFraction:)
!

PrefabLabel removeSelector: #markChanged!
PrefabLabel removeSelector: #markUnchanged!

!NhZombie class reorganize!
('type info' isUndead usesTools)
!

NhZombie removeSelector: #usesTools!

!NhZombie reorganize!
('tests--capabilites' wearsArmor)
!

NhYellowDragonScales class removeSelector: #armorClassMod!
NhYellowDragonScales removeSelector: #armorClassMod!
NhYellowDragonScaleMail class removeSelector: #armorClassMod!
NhYellowDragonScaleMail removeSelector: #armorClassMod!
NhWhiteDragonScales class removeSelector: #armorClassMod!
NhWhiteDragonScales removeSelector: #armorClassMod!
NhWhiteDragonScaleMail class removeSelector: #armorClassMod!
NhWhiteDragonScaleMail removeSelector: #armorClassMod!
NhTurquoise removeSelector: #pointValue!
NhTopaz removeSelector: #pointValue!
NhTailorOfYendor removeSelector: #bareIntrinsicAttackClasses!
NhStuffManager removeSelector: #maxLevels!
NhStuffManager removeSelector: #numLevels!
NhStuffManager removeSelector: #weaponsForMap:!
NhStuddedLeatherArmor class removeSelector: #armorClassMod!
NhStuddedLeatherArmor removeSelector: #armorClassMod!
NhSplintMail class removeSelector: #armorClassMod!
NhSplintMail removeSelector: #armorClassMod!
NhSilverDragonScales class removeSelector: #armorClassMod!
NhSilverDragonScales removeSelector: #armorClassMod!
NhSilverDragonScaleMail class removeSelector: #armorClassMod!
NhSilverDragonScaleMail removeSelector: #armorClassMod!
NhScaleMail class removeSelector: #armorClassMod!
NhScaleMail removeSelector: #armorClassMod!
NhSapphire removeSelector: #pointValue!
NhRuby removeSelector: #pointValue!
NhRingMail class removeSelector: #armorClassMod!
NhRingMail removeSelector: #armorClassMod!
NhRedDragonScales class removeSelector: #armorClassMod!
NhRedDragonScales removeSelector: #armorClassMod!
NhRedDragonScaleMail class removeSelector: #armorClassMod!
NhRedDragonScaleMail removeSelector: #armorClassMod!
NhPlateMail class removeSelector: #armorClassMod!
NhPlateMail removeSelector: #armorClassMod!
NhPantsOfYendor class removeSelector: #armorClassMod!
NhPantsOfYendor removeSelector: #armorClassMod!
NhOrcishRingMail class removeSelector: #armorClassMod!
NhOrcishRingMail removeSelector: #armorClassMod!
NhOrcishHelm class removeSelector: #armorClassMod!
NhOrcishHelm removeSelector: #armorClassMod!
NhOrcishChainMail class removeSelector: #armorClassMod!
NhOrcishChainMail removeSelector: #armorClassMod!
NhOrangeDragonScales class removeSelector: #armorClassMod!
NhOrangeDragonScales removeSelector: #armorClassMod!
NhOrangeDragonScaleMail class removeSelector: #armorClassMod!
NhOrangeDragonScaleMail removeSelector: #armorClassMod!
NhOpal removeSelector: #pointValue!

!NhMummy class reorganize!
('type info' isUndead usesTools)
!

NhMummy removeSelector: #usesTools!

!NhGhost class reorganize!
('ascii tiles' asciiObjectDescription)
('object management stats' isConcrete minCreationLevel)
('stat defaults' initialStatValues)
('type info' isUndead)
!

NhLowBoots class removeSelector: #armorClassMod!
NhLowBoots removeSelector: #armorClassMod!
NhLeatherJacket class removeSelector: #armorClassMod!
NhLeatherJacket removeSelector: #armorClassMod!
NhLeatherGloves class removeSelector: #armorClassMod!
NhLeatherGloves removeSelector: #armorClassMod!
NhLeatherArmor class removeSelector: #armorClassMod!
NhLeatherArmor removeSelector: #armorClassMod!
NhJasper removeSelector: #pointValue!
NhJade removeSelector: #pointValue!
NhIronShoes class removeSelector: #armorClassMod!
NhIronShoes removeSelector: #armorClassMod!
NhHuman removeSelector: #bareIntrinsicAttackClasses!
NhHighBoots class removeSelector: #armorClassMod!
NhHighBoots removeSelector: #armorClassMod!
NhGreenDragonScales class removeSelector: #armorClassMod!
NhGreenDragonScales removeSelector: #armorClassMod!
NhGreenDragonScaleMail class removeSelector: #armorClassMod!
NhGreenDragonScaleMail removeSelector: #armorClassMod!
NhGrayDragonScales class removeSelector: #armorClassMod!
NhGrayDragonScales removeSelector: #armorClassMod!
NhGrayDragonScaleMail class removeSelector: #armorClassMod!
NhGrayDragonScaleMail removeSelector: #armorClassMod!
NhGarnet removeSelector: #pointValue!
NhGame removeSelector: #waitUntilHealedOrDisturbed!
NhGame removeSelector: #waitUntilHealedOrDisturbedFor50!

!NhGame reorganize!
('initialization' initialize)
('init-overridable' initializeMap initializePlayer initializeStateManagers initializeView)
('starting' go goDebug showPlayerSquareContents startFullScreen)
('accessing' debugMode debugMode: dungeon map player stuffManager turn view)
('player action' creaturesMove displayWelcomeMessage incrementTurn playerMessage: playerMove: updateCreatures updateMapThisTurn updateVisuals userEvent:)
('player action-waiting' interactiveWaitUntilHealed isSafeToWait notSafeToWait waitUntilHealedOrDisturbedFor:)
('end of game' deleteImageUnlessDevelopment gameOverPlayerDied gameOverPlayerWins quitGame)
('debug utils' createPants debugIfRequested downAndMap goToEndgame killAllCreaturesOnLevel magicMap neighbouringCreatures wizardMode)
('constants' finalMessage saveFileName versionString)
('saving' saveAndQuit)
!

NhCrow removeSelector: #bareIntrinsicAttackClasses!
NhFluorite removeSelector: #pointValue!
NhFedora class removeSelector: #armorClassMod!
NhFedora removeSelector: #armorClassMod!
NhEmerald removeSelector: #pointValue!
NhElvenMithrilCoat class removeSelector: #armorClassMod!
NhElvenMithrilCoat removeSelector: #armorClassMod!
NhElvenLeatherHelm class removeSelector: #armorClassMod!
NhElvenLeatherHelm removeSelector: #armorClassMod!
NhDwarvishMithrilCoat class removeSelector: #armorClassMod!
NhDwarvishMithrilCoat removeSelector: #armorClassMod!
NhDwarvishIronHelm class removeSelector: #armorClassMod!
NhDwarvishIronHelm removeSelector: #armorClassMod!
NhDunceCap class removeSelector: #armorClassMod!
NhDunceCap removeSelector: #armorClassMod!
NhDilithiumCrystal removeSelector: #pointValue!
NhDiamond removeSelector: #pointValue!
NhDentedPot class removeSelector: #armorClassMod!
NhDentedPot removeSelector: #armorClassMod!
NhCrystalPlateMail class removeSelector: #armorClassMod!
NhCrystalPlateMail removeSelector: #armorClassMod!
NhCornuthaum class removeSelector: #armorClassMod!
NhCornuthaum removeSelector: #armorClassMod!
NhCommonHelmet class removeSelector: #armorClassMod!
NhCommonHelmet removeSelector: #armorClassMod!
NhChainMail class removeSelector: #armorClassMod!
NhChainMail removeSelector: #armorClassMod!
NhBronzePlateMail class removeSelector: #armorClassMod!
NhBronzePlateMail removeSelector: #armorClassMod!
NhBlueDragonScales class removeSelector: #armorClassMod!
NhBlueDragonScales removeSelector: #armorClassMod!
NhBlueDragonScaleMail class removeSelector: #armorClassMod!
NhBlueDragonScaleMail removeSelector: #armorClassMod!
NhBlackDragonScales class removeSelector: #armorClassMod!
NhBlackDragonScales removeSelector: #armorClassMod!
NhBlackDragonScaleMail class removeSelector: #armorClassMod!
NhBlackDragonScaleMail removeSelector: #armorClassMod!
NhBestiary removeSelector: #armorTries!
NhBandedMail class removeSelector: #armorClassMod!
NhBandedMail removeSelector: #armorClassMod!
NhAquamarine removeSelector: #pointValue!
NhAmethyst removeSelector: #pointValue!
NhAmber removeSelector: #pointValue!
GmSilverKilledUndeadTarget class removeSelector: #target:!
GmYouDoUndeadAttack class removeSelector: #target:!
GmUndeadBonusAttack removeSelector: #doDamage!
GmUndeadBonusAttack removeSelector: #doerHitNotification!
GmUndeadBonusAttack removeSelector: #doerHitTargetNotification!
GmUndeadBonusAttack removeSelector: #rcptHitNotification!
GmWeaponAttack removeSelector: #doerDamageRating!
GmWeaponAttack removeSelector: #rcptHitNotification!
GmWeaponAttack removeSelector: #recipientNotification!
GmRubberBaseballBat class removeSelector: #minCreationLevel!
GmAluminumBaseballBat class removeSelector: #baseAttackList!
GmBluntWeapon class removeSelector: #baseAttackList!

!GmBluntWeapon class reorganize!
('type info')
!

GmWeapon class removeSelector: #baseAttackList!
GmShortSword removeSelector: #damageRating!

!GmShortSword reorganize!
('attributes')
!

GmLongSword removeSelector: #damageRating!
GmCrudeDagger removeSelector: #damageRating!
GmBattleSpork removeSelector: #damageRating!

!GmBattleSpork reorganize!
('attacks' attacksFrom:)
!

GmAluminumBaseballBat removeSelector: #damageRating!
GmWeapon removeSelector: #isWeapon!

!GmWeapon reorganize!
('type tests' isSword)
('slot info' slotType)
('attacks' attacksFrom:)
('attributes' damageRating)
!


!GmWall reorganize!
('tests' allowsFlyers allowsSwimmers allowsWalkers)
('type tests' isRoomPart)
('wall tests' isCornerWall isDiggable isWall)
('construction tests')
('construction' constrDigYields)
!

GmViewablePointSet class removeSelector: #calculateRoomPointsIn:around:!
GmViewablePointSet class removeSelector: #calculateRoomRectIn:around:!
GmViewRegion removeSelector: #analyzePosition!
GmViewRegion removeSelector: #updateViewableRegion!

!GmViewRegion reorganize!
('initialization' initialize:)
('updating' clearCache update)
('visibility' changedVisiblePointsDo: containsPoint: fastVisiblePointsDo: ifIncludes:do: visiblePointsDo:)
('whole-room updates' clearEnteredFlag setEnteredFlag)
('tests' canOptimize canSeeCreatureNot: canSeePoint: enteredRoom lightRadiusSmall stillInSameRoom)
('printing' printOn:)
('junk' calculateRoomRectangle createDarkRoomViewable createDoorwayViewable createLitRoomViewable darkRoomLightRadius findEdge: oldCalculateRoomRectangle)
('constants')
('private-calculation')
!


!GmUnusedSpace reorganize!
('tests' allowsFlyers allowsSwimmers allowsWalkers)
('construction tests' isDiggable)
('type tests' isUnusedSpace)
!

GmUnarmedAttack removeSelector: #doerDamageRating!
GmUnarmedAttack removeSelector: #recipientNotification!
GmTurn removeSelector: #descString!
GmToolUser removeSelector: #usesTools!
GmAssHat class removeSelector: #armorClassMod!
GmPants removeSelector: #theDescriptionString!
GmAssHat removeSelector: #armorClassMod!
GmGloves removeSelector: #descriptionString!
GmGloves removeSelector: #theDescriptionString!
GmBoots removeSelector: #descriptionString!
GmBoots removeSelector: #theDescriptionString!
GmClothing removeSelector: #isClothing!

!GmThing reorganize!
('type tests' isClothing isGem isJewelry isPantsOfYendor isSilver isThing isWeapon)
('type info' cost pointValue rootTypeName weight)
('slot tests' fitsInSlot: isPutOnAble isWearable isWieldable)
('slot info' slotType)
('stat modifications' armorClassMod charismaMod constitutionMod dexterityMod intelligenceMod strengthMod wisdomMod)
!


!GmSilentSuccess class reorganize!
('instance creation' new)
!


!GmSilentSuccess reorganize!
('testing' hasUserMessage)
('message ops' talkingSpecies)
!


!GmSuccess reorganize!
('control flow' ifFailure: ifSuccess: ifSuccess:ifFailure:)
('testing' isStatusResponse)
!

GmStuffManager removeSelector: #armorForMap:!
GmStuffManager removeSelector: #calcCostBoundaries!
GmStuffManager removeSelector: #maxLevels!
GmStuffManager removeSelector: #weaponForMap:!
GmStuffManager removeSelector: #weaponsForMap:!

!GmSortedBucketCollection reorganize!
('initialize' initialize)
('contents' add: itemsValuedAround:)
('private-buckets' bucketFor: newBucketFor:)
!

GmRoguelikeMapBuilder removeSelector: #addRoomWithBounds:!
GmRoguelikeMapBuilder removeSelector: #buildMap!
GmRoguelikeMapBuilder removeSelector: #initializeToExtent:!
GmRoguelikeMapBuilder removeSelector: #litRegionList!

!GmRoguelikeMapBuilder reorganize!
('initialization')
('map building' buildMapFeatures)
('creature placement' randomCandidatePoint)
('construction' addRoomsAndTunnels randomDirection)
('construction-rooms' addRandomRoom addRoomAround:)
('construction-corridors' newCorridorFrom: tunnelFrom:)
('tests' canContainRect:)
('randomness constraints' maxRoomAttempts)
('room rectangles' adjacentPathOn:inRect: canMakeRoomShapedBy: hasRoomIntersecting: needWackyDoorsFor: roomRectAround: transFactorFor:toBeAround: validRoomBoundsAround:)
('constants' maxAdjacentDoors maxRoomExtent maxSingleRoomAttempts minRoomDistance minRoomExtent)
('junk' isTooCloseToOtherRoom: nilOrValidRoomBoundsAround: randomDirectionNot: randomRoomCornerPointFor: randomRoomOriginPoint randomRoomRect rectIsSuitable:)
!


!GmResponse class reorganize!
('as yet unclassified')
!


!GmFailure reorganize!
('flow control' ifFailure: ifSuccess: ifSuccess:ifFailure:)
('testing' isStatusResponse)
!


!GmResponse reorganize!
('flow control' ifCancelled: ifFailure: ifKilledTarget: ifSpaceOccupied: ifSuccess: ifSuccess:ifFailure:)
('testing' isResponse)
!


!GmPortal reorganize!
('accessing' coordinates endPoint endPoint: endPointMap map map:)
('maps' destinationMap)
('invoking' displaceOccupant)
('type tests' isPortal)
('construction' endpointClass)
('construction tests' canBeEndpointFor: canReplaceWithPortal)
!


!GmPanelEntry reorganize!
('accessing' message message: messageArgs messageArgs: morph morph: object object:)
('updating' update)
!


!GmAsciiObjectDescription class reorganize!
('instance creation' letter:color:name:)
!


!GmObjectDescription class reorganize!
('instance creation' for: new)
!


!GmAsciiObjectDescription reorganize!
('initialization' letter:color:name:)
('accessing' color letter name)
('description' longDescription)
('junk' flort)
!

GmObject class removeSelector: #isWeapon!

!GmObject class reorganize!
('instance creation' new)
('object management stats' canCreateIn: isConcrete maxAllowed)
!


!GmFloor reorganize!
('construction tests' canReplaceWithPortal isDug)
('tests' allowsFlyers allowsSwimmers allowsWalkers)
('type tests' isFloor isLit isRoomPart)
!

GmDoor removeSelector: #isLit!

!GmDoor reorganize!
('initialization' initialize)
('accessing' isOpen)
('access tests' allowsFlyers allowsSwimmers allowsWalkers)
('construction tests' isDug)
('type tests' isDoor isRoomPart)
!


!GmFeature reorganize!
('access tests--overrides' allowsFlyers allowsSwimmers allowsWalkers)
('access tests--convenience' allowsAllAccess allowsSomeAccess)
('access tests--creatures' allowsAccessBy:)
('type tests' isDiggable isDoor isDownStairway isDug isDungeonExit isFloor isLit isPortal isRoomPart isTunnelFloor isUnusedSpace isUpStairway isWall)
('type info' rootTypeName)
('construction tests' canReplaceWithDoor canReplaceWithPortal)
('construction' constrDigYields)
('creature management' displaceOccupantOf:in: ifRoomDisplaceOccupantOf:in:by:)
('private' displaceCreature:to:in:by:)
!

GmCreature removeSelector: #bareIntrinsicAttackClasses!
GmCreature removeSelector: #insertAndDeploy:!
GmCreature removeSelector: #inventory!
GmCreature removeSelector: #removeAndDrop:!

!GmCreature reorganize!
('initialization' addDefaultStats addSlots addStat:initializedTo: addStats: initialize)
('accessing' brain brain: slots)
('type tests' isCreature isHumanoid isUndead)
('type info' rootTypeName)
('stats' addStatObject: atStat: atStat:put: markStatsChanged sortedStatList statNamed:)
('stats-dnu' commentReadMe doesNotUnderstand: statAccessMsg: statObjAccessMsg:)
('tests--capabilites' flies swims usesTools walks wearsArmor)
('tests--circumstances' standingOnPortal)
('tests--stats' isAlive isDead)
('tests' canSeeCreatureNotMe isPlayer isWearingPants)
('attributes' computedExperienceValue computedHitBonus damageRating experienceValue inventoryWeight toHitRating)
('creature capabilities' goEast goNorth goNorthEast goNorthWest goSouth goSouthEast goSouthWest goWest invokePortal wait)
('creature capabilities -- player' interactiveDrop interactiveInventory interactivePutOn interactiveSaveAndQuit interactiveTake interactiveTakeOff interactiveUnWear interactiveWear interactiveWield)
('creature capabilities -- non-interactive' attackInDirection: deploy: drop: goInDirection: take: undeploy: wield:)
('creature communication' inform:)
('creature perception')
('creature actions' attacks intrinsicAttacks)
('creature status changes' die heal healFully updateForGainedLevel)
('current square accessing' addToStuffHere: featureHere stuffHere)
('game cycle' endOfTurnUpdate)
('position' coordinates map pointToThe: yourFloor)
('position cache' setMap:andCoords:)
('vision' viewRegion)
('inventory' applyToDeployedAndSum: dropAllItems insert:or: insertAndDeploy:or: isDeploying: removeAndDrop:or: totalPointValue)
('printing' printOn:)
('class attributes' brainClass)
('private-movement' moveToEndpoint: tryToLeaveDungeon)
!


!GmObject reorganize!
('initialization' initialize)
('type tests' isCreature isFeature isThing)
('description' descriptionString longDescriptionString theDescriptionString)
('user interface')
('type properties' isUnique)
('map reference' map:)
!


!GmObjStat class reorganize!
('instance creation' new on:value:)
!

GmHitPoints removeSelector: #flort!
GmHitPoints removeSelector: #testAndClearChanged!

!GmHitPoints reorganize!
('initialization' initialize)
('maximum  value' clipValue increaseMaxBy: maxHitpoints)
('core protocol' descString name setValue: value)
('tests' isAtMaximum)
('healing' delayHealing heal healToMax)
('debugging')
!


!GmExperience reorganize!
('core protocol' descString setValue:)
('level values' levelValue setLevelValue:)
('private- exp to level calculation' expForLevel: levelForExperience:)
!


!GmDungeonLevel reorganize!
('core protocol' descString setValue: value)
('tests' testAndClearChanged)
!

GmDexterity removeSelector: #isChanged!
GmDexterity removeSelector: #testAndClearChanged!

!GmNumStat reorganize!
('initialization' initialize)
('arithmetic' add: asNumber occupiesWhichRangeIn:startingIndex: subtract:)
('tests' isSet)
('core protocol' name)
!

GmBoolStat removeSelector: #name!

!GmBestiary reorganize!
('initialization' initialize)
('monster generation' createPlayer)
('calculations' numForUpdateIn: numRequiredIn:)
!

GmObjGenManager removeSelector: #itemInfoListClass!
GmObjGenManager removeSelector: #itemsAvailableOnLevel:!

!GmObjGenManager reorganize!
('initialization' addToItemInfo: fillItemInfoFrom: initialize initializeItemInfo on:)
('map population' setupMap: updateMap:)
('item generation' addItem:to:ifUnable: addRandomItemTo:ifUnable: generateItemsIn:count: itemsAvailableOnMap: itemsAvailableOnMap:and: pickItemForMap:or: prepareObject:forMap:)
('accessing' itemInfo slotForClass:)
('calculations' numForUpdateIn: numRequiredIn:)
!

GmAttackedUnsuccessfully class removeSelector: #desc:byCreature:!
GmAttackedUnsuccessfully class removeSelector: #theCreature:does:!
GmAttacked class removeSelector: #desc:byCreature:!
GmAttacked class removeSelector: #theCreature:does:!
GmNotification class removeSelector: #desc:byCreature:!
GmAttackedUnsuccessfully removeSelector: #hostilityLevel!
GmAttacked removeSelector: #hostilityLevel!

!GmMapEntry class reorganize!
('instance creation' new)
('display class' descriptionClass)
!

GmMapEntry removeSelector: #nonCreatureTile!

!GmMapEntry reorganize!
('initialization' initialize)
('accessing' addThing: creature creature: feature feature: pileOfStuff)
('contents' firstThing nonCreatureTopmostObject removeCreature topmostObject)
('tests' contains: hasCreature hasStuff terrainAllows:)
('map visibility')
('display' asciiTile nonCreatureAsciiTile)
!


!GmMapBuilder class reorganize!
('instance creation' mapExtent: new)
('debug' makeAndShow makeAndShow:)
!

GmCustomRoomBuilder removeSelector: #litRegionList!
GmCustomRoomBuilder removeSelector: #processTemplates!
GmBigRoomBuilder removeSelector: #buildMap!
GmBigRoomBuilder removeSelector: #litRegionList!
GmBigRoomBuilder removeSelector: #litRoomList!

!GmBigRoomBuilder reorganize!
('map building' buildMapFeatures)
!

GmMapBuilder removeSelector: #litRoomList!

!GmMapBuilder reorganize!
('initialization' initializeToExtent:)
('build parameters' initialExtent:)
('map building' addDoorAt: addLitRegionList at:putDoorOr: at:putFeature: buildMap buildMapFeatures initializeMap litRegionList)
('utilities' fillRegion:with: randomInsidePoint randomPointBetween:and:)
('accessing' map mapBounds mapExtent rooms)
('construction-walls' addCornersFor: addEWWallFrom:to: addNSWallFrom:to: addWallsFor:)
('construction-rooms' addRoomWithBounds:)
('debug' displaySoFar)
!


!GmMap class reorganize!
('instance creation' new withExtent:)
('instance creation-sixx' createInstanceOf:withSixxElement:)
!

GmMap removeSelector: #LitAreaWithPoint:or:!
GmMap removeSelector: #findOrAddEndpointFor:!
GmMap removeSelector: #hasMonsterAt:!

!GmMap reorganize!
('initialization' game: initializeToExtent: itemsWithExtent:)
('accessing' adjacentMaps allCreatures at:addThing: at:putCreature: at:putFeature: at:putObject: bounds coordinatesOf: creationState creationState: creatureAt: entryAt: extent featureAt: game litRegions litRegions: lowerLevels portals shuffledNonPlayerCreatures thingsAt: topmostAt: upperLevels)
('removing' removeCreature: removeCreatureAt:)
('random placement' placeCreature: placeThing:or:)
('portals' addEndpointFor: addPortal: connectSomePortalTo:)
('display' asciiTileAt: nonCreatureAsciiTileAt:)
('geometry' center directionFrom:to:)
('enumeration' doAndSetFeatures: entriesDo: entriesSelect: entriesWithPointsDo: selectFeatures: selectPoints:)
('queries' allPortals canPutCreature:at: containsPlayer containsPoint: descriptionString difficultyLevel hasCreatureAt: litAreaWithPoint:or: player playerCoordsOr: positionOf: positionOf:ifAbsent: quickRandomCoordMatching:onFailure: randomCoordMatching:onFailure: randomSpotFor:or: sectorsWithCreatures terrainAt:fitFor:)
('changes' changedPoints clearChangedPoints getAndClearChangedPoints)
('creature movement' moveCreature:to: moveEast: moveNorth: moveNorthEast: moveNorthWest: moveSouth: moveSouthEast: moveSouthWest: moveWest:)
('constants' randomPlacementAttempts)
('constants-directions' directionNames east north northEast northWest south southEast southWest west)
('private' at:putThing: changedAt: purgeMissingCreatures)
('debug' displaySoFar)
('serialization-not used' itemsAsPointAndValuePairs sixxFix)
!


!GmManagedObjectInfo reorganize!
('initialization' initializeOn:)
('accessing' itemClass maxAllowed numCreated)
('testing' canCreateIn: countExhausted)
('item creation' create uncreate)
('printing' printOn:)
!


!GmGenericBrain reorganize!
('stimulus' notify:)
('attacking' canAttackPlayer)
('response' getsDistracted goInRandomDirection makeMove tryToAttackPlayer tryToMoveTowardPlayer walkableDirections)
('player direction' directionOfPlayer possibleDirections)
!


!GmDungeonBuilderState reorganize!
('initialization' initialize)
('copying' nextLevelOnBranch:)
('level information' mapGenerator outPortalsHere totalMapsToBeGenerated)
('level customization' finalChangesTo:)
('map information' descriptionString)
('advancing')
('testing' isBottom isTop)
('accessing' level level:)
('constants' defaultMapExtent maxLevelsPerBranch)
!


!GmDungeonBuilder reorganize!
('initialization' game:initialState:genManagers: initialize)
('accessing' dungeon)
('dungeon creation' attachMap:to: buildDungeon buildDungeonUpdating: generateLevel:fromPortal: generateNextLevelFrom:accordingTo:)
('progress' updateProgressBar)
('constants')
!


!GmDeployments class reorganize!
('instance creation' new newForHumanoid)
('constants' knownSlotTypeNames putOnSlotTypeNames wearSlotTypeNames wieldSlotTypeNames)
('private instance creation' fromDescrArray:)
!


!GmDeployments reorganize!
('initialization' initialize)
('deployment' deploy:or: undeploy:or:)
('queries' allInSlots allInSlots: allPutOn allWielded allWorn isDeploying: sumOf:)
('slots' addSlot: emptySlotFor:or: slotHolding:or:)
!

GmAttack removeSelector: #defenseRoll!
GmAttack removeSelector: #sendDebugMessageIfDesired!
GmAttack removeSelector: #withWeaponString!

!GmAttack reorganize!
('notifications' doerHitTargetResponse doerKilledTargetResponse rcptHitHarmlesslyNotification rcptHitNotification rcptMissedNotification recipientNotification setRcptNotificationForDamage:)
('accessing' damageRoll: toHitRoll:)
('utility' attacksMessage weapon)
('rolls' canHitTarget damageAmount doDamage doerToHitValue)
('core protocol' doAction)
('debug' averageDamage canHitFraction xxxxxDEBUGcanHitTarget)
!

GmAction removeSelector: #argument!
GmAction removeSelector: #argument:!

!GmAbstractCreatureBrain reorganize!
('initialization' for:)
('stimulus' notify:)
('response' makeMove)
('constants' directions)
('tests' isPlayerBrain)
!


!Collection reorganize!
('accessing' anyOne atRandom capacity size)
('adapting' adaptToCollection:andSend: adaptToNumber:andSend: adaptToPoint:andSend: adaptToString:andSend:)
('adding' add: add:withOccurrences: addAll: addIfNotPresent:)
('arithmetic' * + - / // \\)
('comparing' hash)
('converting' asArray asBag asByteArray asCharacterSet asIdentitySet asIdentitySkipList asOrderedCollection asSet asSkipList asSkipList: asSortedArray asSortedCollection asSortedCollection: topologicallySortedUsing:)
('copying' copyWith: copyWithDependent: copyWithout: copyWithoutAll:)
('enumerating' allSatisfy: anySatisfy: associationsDo: collect: collect:thenSelect: count: detect: detect:ifNone: detectMax: detectMin: detectSum: difference: do: do:separatedBy: do:without: groupBy:having: inject:into: intersection: noneSatisfy: reject: select: select:thenCollect: union:)
('filter streaming' contents flattenOnStream: write:)
('math functions' abs average ceiling floor log max median min negated range reciprocal rounded sqrt squared sum truncated)
('printing' printElementsOn: printNameOn: printOn: storeOn:)
('private' emptyCheck errorEmptyCollection errorNoMatch errorNotFound: errorNotKeyed toBraceStack:)
('removing' remove: remove:ifAbsent: removeAll: removeAllFoundIn: removeAllSuchThat:)
('testing' identityIncludes: includes: includesAllOf: includesAnyOf: includesSubstringAnywhere: isCollection isEmpty isEmptyOrNil isSequenceable notEmpty occurrencesOf:)
('*ObjHack-GUI' ifChoicePickOneOr:withCaption: pickOneOr: pickOneOr:withCaption: pickOneOr:withCaption:ifMatches:addLabel: pickOneWithCaption: pickOneWithFirst:appending:withCaption:or: pickWeaponWhileHolding:withCaption:or:)
('*ObjHack-printing' contentsString objDescriptionListString)
('*ObjHack-util' flatten ifEmpty:)
('*ObjHack-debugging' showHistogram)
('*ObjHack-Math' zeroPlusSum)
!

